import 'dart:ui';
import 'package:flutter/material.dart';
import 'package:countries_world_map/canvas/touchable_canvas.dart';
import 'package:countries_world_map/countries/north-america/usa/src/usa_colors.dart';

class USAPainter extends CustomPainter {
  final Color defaultColor;
  final USAColors usaColors;
  final BuildContext context;
  final Function(String, TapUpDetails) callback;

  const USAPainter({
    required this.defaultColor,
    required this.usaColors,
    required this.context,
    required this.callback,
  });

  @override
  void paint(Canvas canvas, Size size) {
    var usaCanvas = TouchyCanvas(context, canvas);
    Path alabamaPath = Path();
    alabamaPath.moveTo(size.width * 0.6704901, size.height * 0.7881956);
    alabamaPath.lineTo(size.width * 0.6709072, size.height * 0.7758853);
    alabamaPath.lineTo(size.width * 0.6699687, size.height * 0.7738617);
    alabamaPath.lineTo(size.width * 0.6681960, size.height * 0.7726813);
    alabamaPath.lineTo(size.width * 0.6655892, size.height * 0.7679595);
    alabamaPath.lineTo(size.width * 0.6661105, size.height * 0.7630691);
    alabamaPath.lineTo(size.width * 0.7169969, size.height * 0.7544688);
    alabamaPath.lineTo(size.width * 0.7162669, size.height * 0.7507589);
    alabamaPath.lineTo(size.width * 0.7147028, size.height * 0.7482293);
    alabamaPath.lineTo(size.width * 0.7141814, size.height * 0.7458685);
    alabamaPath.lineTo(size.width * 0.7148071, size.height * 0.7352445);
    alabamaPath.lineTo(size.width * 0.7123045, size.height * 0.7256324);
    alabamaPath.lineTo(size.width * 0.7128259, size.height * 0.7212479);
    alabamaPath.lineTo(size.width * 0.7131387, size.height * 0.7150084);
    alabamaPath.lineTo(size.width * 0.7154327, size.height * 0.7086003);
    alabamaPath.lineTo(size.width * 0.7152242, size.height * 0.7067454);
    alabamaPath.lineTo(size.width * 0.7134515, size.height * 0.7050590);
    alabamaPath.lineTo(size.width * 0.7134515, size.height * 0.6996627);
    alabamaPath.lineTo(size.width * 0.7115746, size.height * 0.6964587);
    alabamaPath.lineTo(size.width * 0.7085506, size.height * 0.6861720);
    alabamaPath.lineTo(size.width * 0.6950991, size.height * 0.6089376);
    alabamaPath.lineTo(size.width * 0.6474453, size.height * 0.6156830);
    alabamaPath.lineTo(size.width * 0.6488008, size.height * 0.6190556);
    alabamaPath.lineTo(size.width * 0.6474453, size.height * 0.7320405);
    alabamaPath.lineTo(size.width * 0.6520334, size.height * 0.7880270);
    alabamaPath.lineTo(size.width * 0.6529718, size.height * 0.7871838);
    alabamaPath.lineTo(size.width * 0.6543274, size.height * 0.7873524);
    alabamaPath.lineTo(size.width * 0.6549531, size.height * 0.7880270);
    alabamaPath.lineTo(size.width * 0.6557873, size.height * 0.7878583);
    alabamaPath.lineTo(size.width * 0.6578728, size.height * 0.7814503);
    alabamaPath.lineTo(size.width * 0.6578728, size.height * 0.7775717);
    alabamaPath.lineTo(size.width * 0.6590198, size.height * 0.7757167);
    alabamaPath.lineTo(size.width * 0.6604797, size.height * 0.7765599);
    alabamaPath.lineTo(size.width * 0.6640250, size.height * 0.7873524);
    alabamaPath.lineTo(size.width * 0.6640250, size.height * 0.7888702);
    alabamaPath.lineTo(size.width * 0.6605839, size.height * 0.7925801);
    alabamaPath.lineTo(size.width * 0.6642336, size.height * 0.7919056);
    alabamaPath.lineTo(size.width * 0.6693431, size.height * 0.7892074);
    alabamaPath.close();

    Paint alabamaPaint = Paint()..style = PaintingStyle.fill;
    alabamaPaint.color = usaColors.alabama ?? defaultColor;
    usaCanvas.drawPath(alabamaPath, alabamaPaint, onTapUp: (tabdetail) {
      callback('alabama', tabdetail);
    });

    Path alaskaPath = Path();
    alaskaPath.moveTo(size.width * 0.01647550, size.height * 0.9645868);
    alaskaPath.lineTo(size.width * 0.01897810, size.height * 0.9645868);
    alaskaPath.lineTo(size.width * 0.01970803, size.height * 0.9657673);
    alaskaPath.lineTo(size.width * 0.01866528, size.height * 0.9677909);
    alaskaPath.lineTo(size.width * 0.01668405, size.height * 0.9681282);
    alaskaPath.lineTo(size.width * 0.01407716, size.height * 0.9703204);
    alaskaPath.lineTo(size.width * 0.01021898, size.height * 0.9701518);
    alaskaPath.lineTo(size.width * 0.01251303, size.height * 0.9686341);
    alaskaPath.lineTo(size.width * 0.01282586, size.height * 0.9667791);
    alaskaPath.lineTo(size.width * 0.01543274, size.height * 0.9662732);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.02513034, size.height * 0.9617201);
    alaskaPath.lineTo(size.width * 0.02648592, size.height * 0.9625632);
    alaskaPath.lineTo(size.width * 0.02742440, size.height * 0.9625632);
    alaskaPath.lineTo(size.width * 0.02794578, size.height * 0.9645868);
    alaskaPath.lineTo(size.width * 0.02825860, size.height * 0.9635750);
    alaskaPath.lineTo(size.width * 0.02919708, size.height * 0.9639123);
    alaskaPath.lineTo(size.width * 0.03034411, size.height * 0.9664418);
    alaskaPath.lineTo(size.width * 0.03034411, size.height * 0.9672850);
    alaskaPath.lineTo(size.width * 0.02596455, size.height * 0.9704890);
    alaskaPath.lineTo(size.width * 0.02346194, size.height * 0.9703204);
    alaskaPath.lineTo(size.width * 0.02241919, size.height * 0.9694772);
    alaskaPath.lineTo(size.width * 0.02127216, size.height * 0.9706577);
    alaskaPath.lineTo(size.width * 0.01918665, size.height * 0.9706577);
    alaskaPath.lineTo(size.width * 0.01803962, size.height * 0.9682968);
    alaskaPath.lineTo(size.width * 0.02294056, size.height * 0.9674536);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.03076121, size.height * 0.9615514);
    alaskaPath.lineTo(size.width * 0.03180396, size.height * 0.9617201);
    alaskaPath.lineTo(size.width * 0.03253389, size.height * 0.9629005);
    alaskaPath.lineTo(size.width * 0.03253389, size.height * 0.9645868);
    alaskaPath.lineTo(size.width * 0.03117831, size.height * 0.9647555);
    alaskaPath.lineTo(size.width * 0.03023983, size.height * 0.9629005);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.03336809, size.height * 0.9620573);
    alaskaPath.lineTo(size.width * 0.03472367, size.height * 0.9618887);
    alaskaPath.lineTo(size.width * 0.03461940, size.height * 0.9635750);
    alaskaPath.lineTo(size.width * 0.03347237, size.height * 0.9645868);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.03368092, size.height * 0.9657673);
    alaskaPath.lineTo(size.width * 0.03722628, size.height * 0.9655987);
    alaskaPath.lineTo(size.width * 0.03743483, size.height * 0.9674536);
    alaskaPath.lineTo(size.width * 0.03607925, size.height * 0.9676223);
    alaskaPath.lineTo(size.width * 0.03576642, size.height * 0.9667791);
    alaskaPath.lineTo(size.width * 0.03493222, size.height * 0.9677909);
    alaskaPath.lineTo(size.width * 0.03451512, size.height * 0.9667791);
    alaskaPath.lineTo(size.width * 0.03357664, size.height * 0.9664418);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.2070907, size.height * 0.9785835);
    alaskaPath.lineTo(size.width * 0.2092805, size.height * 0.9787521);
    alaskaPath.lineTo(size.width * 0.2082377, size.height * 0.9819562);
    alaskaPath.lineTo(size.width * 0.2070907, size.height * 0.9817875);
    alaskaPath.lineTo(size.width * 0.2066736, size.height * 0.9804384);
    alaskaPath.lineTo(size.width * 0.2071950, size.height * 0.9782462);
    alaskaPath.moveTo(size.width * 0.2060480, size.height * 0.9733558);
    alaskaPath.lineTo(size.width * 0.2066736, size.height * 0.9711636);
    alaskaPath.lineTo(size.width * 0.2064651, size.height * 0.9672850);
    alaskaPath.lineTo(size.width * 0.2089677, size.height * 0.9664418);
    alaskaPath.lineTo(size.width * 0.2136601, size.height * 0.9738617);
    alaskaPath.lineTo(size.width * 0.2150156, size.height * 0.9795953);
    alaskaPath.lineTo(size.width * 0.2169969, size.height * 0.9822934);
    alaskaPath.lineTo(size.width * 0.2173097, size.height * 0.9908938);
    alaskaPath.lineTo(size.width * 0.2158498, size.height * 0.9908938);
    alaskaPath.lineTo(size.width * 0.2144943, size.height * 0.9870152);
    alaskaPath.lineTo(size.width * 0.2112617, size.height * 0.9829680);
    alaskaPath.lineTo(size.width * 0.2106361, size.height * 0.9829680);
    alaskaPath.lineTo(size.width * 0.2117831, size.height * 0.9876897);
    alaskaPath.lineTo(size.width * 0.2135558, size.height * 0.9880270);
    alaskaPath.lineTo(size.width * 0.2137643, size.height * 0.9915683);
    alaskaPath.lineTo(size.width * 0.2128259, size.height * 0.9917369);
    alaskaPath.lineTo(size.width * 0.2085506, size.height * 0.9843170);
    alaskaPath.lineTo(size.width * 0.2084463, size.height * 0.9827993);
    alaskaPath.lineTo(size.width * 0.2104275, size.height * 0.9811130);
    alaskaPath.lineTo(size.width * 0.2104275, size.height * 0.9794266);
    alaskaPath.lineTo(size.width * 0.2099062, size.height * 0.9780776);
    alaskaPath.lineTo(size.width * 0.2082377, size.height * 0.9770658);
    alaskaPath.lineTo(size.width * 0.2064651, size.height * 0.9748735);
    alaskaPath.lineTo(size.width * 0.2079249, size.height * 0.9750422);
    alaskaPath.lineTo(size.width * 0.2084463, size.height * 0.9743676);
    alaskaPath.lineTo(size.width * 0.2078206, size.height * 0.9728499);
    alaskaPath.lineTo(size.width * 0.2071950, size.height * 0.9736931);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.2022941, size.height * 0.9580101);
    alaskaPath.lineTo(size.width * 0.2036496, size.height * 0.9581788);
    alaskaPath.lineTo(size.width * 0.2061522, size.height * 0.9623946);
    alaskaPath.lineTo(size.width * 0.2059437, size.height * 0.9637437);
    alaskaPath.lineTo(size.width * 0.2051095, size.height * 0.9635750);
    alaskaPath.lineTo(size.width * 0.2050052, size.height * 0.9666105);
    alaskaPath.lineTo(size.width * 0.2055266, size.height * 0.9674536);
    alaskaPath.lineTo(size.width * 0.2055266, size.height * 0.9699831);
    alaskaPath.lineTo(size.width * 0.2046924, size.height * 0.9704890);
    alaskaPath.lineTo(size.width * 0.2042753, size.height * 0.9725126);
    alaskaPath.lineTo(size.width * 0.2034411, size.height * 0.9718381);
    alaskaPath.lineTo(size.width * 0.2030240, size.height * 0.9681282);
    alaskaPath.lineTo(size.width * 0.2041710, size.height * 0.9657673);
    alaskaPath.lineTo(size.width * 0.2019812, size.height * 0.9620573);
    alaskaPath.lineTo(size.width * 0.2020855, size.height * 0.9600337);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.2038582, size.height * 0.9554806);
    alaskaPath.lineTo(size.width * 0.2058394, size.height * 0.9558179);
    alaskaPath.lineTo(size.width * 0.2084463, size.height * 0.9559865);
    alaskaPath.lineTo(size.width * 0.2119917, size.height * 0.9613828);
    alaskaPath.lineTo(size.width * 0.2117831, size.height * 0.9622260);
    alaskaPath.lineTo(size.width * 0.2106361, size.height * 0.9632378);
    alaskaPath.lineTo(size.width * 0.2094891, size.height * 0.9629005);
    alaskaPath.lineTo(size.width * 0.2093848, size.height * 0.9617201);
    alaskaPath.lineTo(size.width * 0.2081335, size.height * 0.9590219);
    alaskaPath.lineTo(size.width * 0.2078206, size.height * 0.9602024);
    alaskaPath.lineTo(size.width * 0.2088634, size.height * 0.9623946);
    alaskaPath.lineTo(size.width * 0.2086548, size.height * 0.9644182);
    alaskaPath.lineTo(size.width * 0.2078206, size.height * 0.9642496);
    alaskaPath.lineTo(size.width * 0.2064651, size.height * 0.9645868);
    alaskaPath.lineTo(size.width * 0.2063608, size.height * 0.9617201);
    alaskaPath.lineTo(size.width * 0.2036496, size.height * 0.9569983);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.1906152, size.height * 0.9404722);
    alaskaPath.lineTo(size.width * 0.1915537, size.height * 0.9397976);
    alaskaPath.lineTo(size.width * 0.1932221, size.height * 0.9397976);
    alaskaPath.lineTo(size.width * 0.1939520, size.height * 0.9389545);
    alaskaPath.lineTo(size.width * 0.1982273, size.height * 0.9426644);
    alaskaPath.lineTo(size.width * 0.1983316, size.height * 0.9451939);
    alaskaPath.lineTo(size.width * 0.1978102, size.height * 0.9460371);
    alaskaPath.lineTo(size.width * 0.1969760, size.height * 0.9460371);
    alaskaPath.lineTo(size.width * 0.1955162, size.height * 0.9448567);
    alaskaPath.lineTo(size.width * 0.1966632, size.height * 0.9470489);
    alaskaPath.lineTo(size.width * 0.1985401, size.height * 0.9470489);
    alaskaPath.lineTo(size.width * 0.1990615, size.height * 0.9504216);
    alaskaPath.lineTo(size.width * 0.1981230, size.height * 0.9504216);
    alaskaPath.lineTo(size.width * 0.1958290, size.height * 0.9478921);
    alaskaPath.lineTo(size.width * 0.1946820, size.height * 0.9475548);
    alaskaPath.lineTo(size.width * 0.1953076, size.height * 0.9497470);
    alaskaPath.lineTo(size.width * 0.1954119, size.height * 0.9512648);
    alaskaPath.lineTo(size.width * 0.1962461, size.height * 0.9502530);
    alaskaPath.lineTo(size.width * 0.1980188, size.height * 0.9522766);
    alaskaPath.lineTo(size.width * 0.1993743, size.height * 0.9521079);
    alaskaPath.lineTo(size.width * 0.1991658, size.height * 0.9534570);
    alaskaPath.lineTo(size.width * 0.2011470, size.height * 0.9607083);
    alaskaPath.lineTo(size.width * 0.2011470, size.height * 0.9664418);
    alaskaPath.lineTo(size.width * 0.2015641, size.height * 0.9699831);
    alaskaPath.lineTo(size.width * 0.2007299, size.height * 0.9704890);
    alaskaPath.lineTo(size.width * 0.1994786, size.height * 0.9671164);
    alaskaPath.lineTo(size.width * 0.1989572, size.height * 0.9645868);
    alaskaPath.lineTo(size.width * 0.1972888, size.height * 0.9618887);
    alaskaPath.lineTo(size.width * 0.1970803, size.height * 0.9573356);
    alaskaPath.lineTo(size.width * 0.1964546, size.height * 0.9544688);
    alaskaPath.lineTo(size.width * 0.1957247, size.height * 0.9544688);
    alaskaPath.lineTo(size.width * 0.1960375, size.height * 0.9563238);
    alaskaPath.lineTo(size.width * 0.1960375, size.height * 0.9571669);
    alaskaPath.lineTo(size.width * 0.1945777, size.height * 0.9588533);
    alaskaPath.lineTo(size.width * 0.1946820, size.height * 0.9532884);
    alaskaPath.lineTo(size.width * 0.1930136, size.height * 0.9505902);
    alaskaPath.lineTo(size.width * 0.1916580, size.height * 0.9467116);
    alaskaPath.lineTo(size.width * 0.1904067, size.height * 0.9446880);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.1981230, size.height * 0.9365936);
    alaskaPath.lineTo(size.width * 0.1992701, size.height * 0.9396290);
    alaskaPath.lineTo(size.width * 0.2017727, size.height * 0.9394604);
    alaskaPath.lineTo(size.width * 0.2028154, size.height * 0.9430017);
    alaskaPath.lineTo(size.width * 0.2021898, size.height * 0.9440135);
    alaskaPath.lineTo(size.width * 0.2042753, size.height * 0.9494098);
    alaskaPath.lineTo(size.width * 0.2042753, size.height * 0.9516020);
    alaskaPath.lineTo(size.width * 0.2030240, size.height * 0.9529511);
    alaskaPath.lineTo(size.width * 0.2030240, size.height * 0.9541315);
    alaskaPath.lineTo(size.width * 0.2009385, size.height * 0.9573356);
    alaskaPath.lineTo(size.width * 0.2004171, size.height * 0.9549747);
    alaskaPath.lineTo(size.width * 0.2003128, size.height * 0.9527825);
    alaskaPath.lineTo(size.width * 0.2009385, size.height * 0.9516020);
    alaskaPath.lineTo(size.width * 0.2009385, size.height * 0.9497470);
    alaskaPath.lineTo(size.width * 0.1993743, size.height * 0.9465430);
    alaskaPath.lineTo(size.width * 0.1988530, size.height * 0.9403035);
    alaskaPath.lineTo(size.width * 0.1979145, size.height * 0.9377740);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.1389990, size.height * 0.9057336);
    alaskaPath.lineTo(size.width * 0.1348279, size.height * 0.9126476);
    alaskaPath.lineTo(size.width * 0.1348279, size.height * 0.9153457);
    alaskaPath.lineTo(size.width * 0.1370177, size.height * 0.9139966);
    alaskaPath.lineTo(size.width * 0.1378519, size.height * 0.9107926);
    alaskaPath.lineTo(size.width * 0.1401460, size.height * 0.9067454);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.1060480, size.height * 0.9337268);
    alaskaPath.lineTo(size.width * 0.1060480, size.height * 0.9347386);
    alaskaPath.lineTo(size.width * 0.1079249, size.height * 0.9367622);
    alaskaPath.lineTo(size.width * 0.1081335, size.height * 0.9344013);
    alaskaPath.lineTo(size.width * 0.1087591, size.height * 0.9359191);
    alaskaPath.lineTo(size.width * 0.1124088, size.height * 0.9360877);
    alaskaPath.lineTo(size.width * 0.1131387, size.height * 0.9350759);
    alaskaPath.lineTo(size.width * 0.1133472, size.height * 0.9320405);
    alaskaPath.lineTo(size.width * 0.1128259, size.height * 0.9308600);
    alaskaPath.lineTo(size.width * 0.1113660, size.height * 0.9308600);
    alaskaPath.lineTo(size.width * 0.1113660, size.height * 0.9295110);
    alaskaPath.lineTo(size.width * 0.1117831, size.height * 0.9284992);
    alaskaPath.lineTo(size.width * 0.1117831, size.height * 0.9278246);
    alaskaPath.lineTo(size.width * 0.1102190, size.height * 0.9273187);
    alaskaPath.lineTo(size.width * 0.1067779, size.height * 0.9333895);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.09760167, size.height * 0.9441821);
    alaskaPath.lineTo(size.width * 0.09916580, size.height * 0.9539629);
    alaskaPath.lineTo(size.width * 0.1013556, size.height * 0.9539629);
    alaskaPath.lineTo(size.width * 0.1038582, size.height * 0.9497470);
    alaskaPath.lineTo(size.width * 0.1041710, size.height * 0.9517707);
    alaskaPath.lineTo(size.width * 0.1107404, size.height * 0.9450253);
    alaskaPath.lineTo(size.width * 0.1114703, size.height * 0.9433390);
    alaskaPath.lineTo(size.width * 0.1104275, size.height * 0.9414840);
    alaskaPath.lineTo(size.width * 0.1104275, size.height * 0.9403035);
    alaskaPath.lineTo(size.width * 0.1109489, size.height * 0.9381113);
    alaskaPath.lineTo(size.width * 0.1100104, size.height * 0.9379427);
    alaskaPath.lineTo(size.width * 0.1079249, size.height * 0.9396290);
    alaskaPath.lineTo(size.width * 0.1079249, size.height * 0.9376054);
    alaskaPath.lineTo(size.width * 0.1051095, size.height * 0.9365936);
    alaskaPath.lineTo(size.width * 0.1026069, size.height * 0.9370995);
    alaskaPath.lineTo(size.width * 0.1023983, size.height * 0.9428331);
    alaskaPath.lineTo(size.width * 0.1015641, size.height * 0.9394604);
    alaskaPath.lineTo(size.width * 0.1000000, size.height * 0.9392917);
    alaskaPath.lineTo(size.width * 0.09895725, size.height * 0.9403035);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.09530761, size.height * 0.9580101);
    alaskaPath.lineTo(size.width * 0.09541189, size.height * 0.9568297);
    alaskaPath.lineTo(size.width * 0.09760167, size.height * 0.9546374);
    alaskaPath.lineTo(size.width * 0.09822732, size.height * 0.9551433);
    alaskaPath.lineTo(size.width * 0.09958290, size.height * 0.9554806);
    alaskaPath.lineTo(size.width * 0.1009385, size.height * 0.9575042);
    alaskaPath.lineTo(size.width * 0.09864442, size.height * 0.9571669);
    alaskaPath.lineTo(size.width * 0.09822732, size.height * 0.9561551);
    alaskaPath.lineTo(size.width * 0.09718457, size.height * 0.9571669);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.08988530, size.height * 0.9635750);
    alaskaPath.lineTo(size.width * 0.08873827, size.height * 0.9649241);
    alaskaPath.lineTo(size.width * 0.09030240, size.height * 0.9672850);
    alaskaPath.lineTo(size.width * 0.09113660, size.height * 0.9661046);
    alaskaPath.lineTo(size.width * 0.09103233, size.height * 0.9639123);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.08331595, size.height * 0.9502530);
    alaskaPath.lineTo(size.width * 0.08477581, size.height * 0.9504216);
    alaskaPath.lineTo(size.width * 0.08519291, size.height * 0.9514334);
    alaskaPath.lineTo(size.width * 0.08331595, size.height * 0.9516020);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.06882169, size.height * 0.9703204);
    alaskaPath.lineTo(size.width * 0.06882169, size.height * 0.9711636);
    alaskaPath.lineTo(size.width * 0.06955162, size.height * 0.9713322);
    alaskaPath.lineTo(size.width * 0.06944734, size.height * 0.9703204);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.06840459, size.height * 0.9649241);
    alaskaPath.lineTo(size.width * 0.06736184, size.height * 0.9666105);
    alaskaPath.lineTo(size.width * 0.06736184, size.height * 0.9674536);
    alaskaPath.lineTo(size.width * 0.06809176, size.height * 0.9693086);
    alaskaPath.lineTo(size.width * 0.06913452, size.height * 0.9676223);
    alaskaPath.lineTo(size.width * 0.06840459, size.height * 0.9674536);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.06631908, size.height * 0.9635750);
    alaskaPath.lineTo(size.width * 0.06600626, size.height * 0.9652614);
    alaskaPath.lineTo(size.width * 0.06465068, size.height * 0.9654300);
    alaskaPath.lineTo(size.width * 0.06423358, size.height * 0.9657673);
    alaskaPath.lineTo(size.width * 0.06423358, size.height * 0.9679595);
    alaskaPath.lineTo(size.width * 0.06371220, size.height * 0.9694772);
    alaskaPath.lineTo(size.width * 0.06433785, size.height * 0.9694772);
    alaskaPath.lineTo(size.width * 0.06506778, size.height * 0.9679595);
    alaskaPath.lineTo(size.width * 0.06590198, size.height * 0.9677909);
    alaskaPath.lineTo(size.width * 0.06684046, size.height * 0.9661046);
    alaskaPath.lineTo(size.width * 0.06704901, size.height * 0.9639123);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.06173097, size.height * 0.9602024);
    alaskaPath.lineTo(size.width * 0.06152242, size.height * 0.9632378);
    alaskaPath.lineTo(size.width * 0.06298227, size.height * 0.9645868);
    alaskaPath.lineTo(size.width * 0.06423358, size.height * 0.9635750);
    alaskaPath.lineTo(size.width * 0.06423358, size.height * 0.9618887);
    alaskaPath.lineTo(size.width * 0.06600626, size.height * 0.9613828);
    alaskaPath.lineTo(size.width * 0.06590198, size.height * 0.9603710);
    alaskaPath.lineTo(size.width * 0.06496350, size.height * 0.9600337);
    alaskaPath.lineTo(size.width * 0.06423358, size.height * 0.9610455);
    alaskaPath.lineTo(size.width * 0.06329510, size.height * 0.9602024);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.05662148, size.height * 0.9600337);
    alaskaPath.lineTo(size.width * 0.05766423, size.height * 0.9612142);
    alaskaPath.lineTo(size.width * 0.05735141, size.height * 0.9632378);
    alaskaPath.lineTo(size.width * 0.05589155, size.height * 0.9613828);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.05224192, size.height * 0.9622260);
    alaskaPath.lineTo(size.width * 0.05370177, size.height * 0.9623946);
    alaskaPath.lineTo(size.width * 0.05297185, size.height * 0.9637437);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.04859228, size.height * 0.9672850);
    alaskaPath.lineTo(size.width * 0.05046924, size.height * 0.9691400);
    alaskaPath.lineTo(size.width * 0.04869656, size.height * 0.9693086);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.02210636, size.height * 0.9146712);
    alaskaPath.lineTo(size.width * 0.02335766, size.height * 0.9156830);
    alaskaPath.lineTo(size.width * 0.02252346, size.height * 0.9166948);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.02137643, size.height * 0.9040472);
    alaskaPath.lineTo(size.width * 0.02179353, size.height * 0.9060708);
    alaskaPath.lineTo(size.width * 0.02262774, size.height * 0.9040472);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.04671533, size.height * 0.8715008);
    alaskaPath.lineTo(size.width * 0.04827946, size.height * 0.8713322);
    alaskaPath.lineTo(size.width * 0.04921794, size.height * 0.8720067);
    alaskaPath.lineTo(size.width * 0.05036496, size.height * 0.8711636);
    alaskaPath.lineTo(size.width * 0.05172054, size.height * 0.8709949);
    alaskaPath.lineTo(size.width * 0.05338895, size.height * 0.8723440);
    alaskaPath.lineTo(size.width * 0.05422315, size.height * 0.8755481);
    alaskaPath.lineTo(size.width * 0.05411887, size.height * 0.8770658);
    alaskaPath.lineTo(size.width * 0.05286757, size.height * 0.8804384);
    alaskaPath.lineTo(size.width * 0.05036496, size.height * 0.8801012);
    alaskaPath.lineTo(size.width * 0.04817518, size.height * 0.8770658);
    alaskaPath.lineTo(size.width * 0.04713243, size.height * 0.8763912);
    alaskaPath.lineTo(size.width * 0.04598540, size.height * 0.8730185);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.02471324, size.height * 0.8472175);
    alaskaPath.lineTo(size.width * 0.02481752, size.height * 0.8504216);
    alaskaPath.lineTo(size.width * 0.02690302, size.height * 0.8537943);
    alaskaPath.lineTo(size.width * 0.02690302, size.height * 0.8546374);
    alaskaPath.lineTo(size.width * 0.02606882, size.height * 0.8543002);
    alaskaPath.lineTo(size.width * 0.02429614, size.height * 0.8529511);
    alaskaPath.lineTo(size.width * 0.02398332, size.height * 0.8510961);
    alaskaPath.lineTo(size.width * 0.02367049, size.height * 0.8483980);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.04379562, size.height * 0.8079258);
    alaskaPath.lineTo(size.width * 0.04379562, size.height * 0.8099494);
    alaskaPath.lineTo(size.width * 0.04577685, size.height * 0.8129848);
    alaskaPath.lineTo(size.width * 0.04817518, size.height * 0.8129848);
    alaskaPath.lineTo(size.width * 0.04880083, size.height * 0.8148398);
    alaskaPath.lineTo(size.width * 0.04880083, size.height * 0.8175379);
    alaskaPath.lineTo(size.width * 0.05099062, size.height * 0.8207420);
    alaskaPath.lineTo(size.width * 0.05286757, size.height * 0.8227656);
    alaskaPath.lineTo(size.width * 0.05276330, size.height * 0.8239460);
    alaskaPath.lineTo(size.width * 0.05203337, size.height * 0.8258010);
    alaskaPath.lineTo(size.width * 0.05057351, size.height * 0.8237774);
    alaskaPath.lineTo(size.width * 0.04838373, size.height * 0.8239460);
    alaskaPath.lineTo(size.width * 0.04754953, size.height * 0.8225970);
    alaskaPath.lineTo(size.width * 0.04661105, size.height * 0.8190556);
    alaskaPath.lineTo(size.width * 0.04504692, size.height * 0.8153457);
    alaskaPath.lineTo(size.width * 0.04233577, size.height * 0.8151771);
    alaskaPath.lineTo(size.width * 0.04129301, size.height * 0.8139966);
    alaskaPath.lineTo(size.width * 0.04233577, size.height * 0.8104553);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.06131387, size.height * 0.8003373);
    alaskaPath.lineTo(size.width * 0.06235662, size.height * 0.8003373);
    alaskaPath.lineTo(size.width * 0.06246090, size.height * 0.8021922);
    alaskaPath.lineTo(size.width * 0.06141814, size.height * 0.8021922);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.07820647, size.height * 0.8335582);
    alaskaPath.lineTo(size.width * 0.07914494, size.height * 0.8337268);
    alaskaPath.lineTo(size.width * 0.07914494, size.height * 0.8357504);
    alaskaPath.lineTo(size.width * 0.07737226, size.height * 0.8349073);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.2114703, size.height * 0.9645868);
    alaskaPath.lineTo(size.width * 0.2102190, size.height * 0.9652614);
    alaskaPath.lineTo(size.width * 0.2101147, size.height * 0.9671164);
    alaskaPath.lineTo(size.width * 0.2113660, size.height * 0.9671164);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.04713243, size.height * 0.9569983);
    alaskaPath.lineTo(size.width * 0.04577685, size.height * 0.9563238);
    alaskaPath.lineTo(size.width * 0.04150156, size.height * 0.9573356);
    alaskaPath.lineTo(size.width * 0.03858186, size.height * 0.9596965);
    alaskaPath.lineTo(size.width * 0.03847758, size.height * 0.9629005);
    alaskaPath.lineTo(size.width * 0.04045881, size.height * 0.9640809);
    alaskaPath.lineTo(size.width * 0.04202294, size.height * 0.9625632);
    alaskaPath.lineTo(size.width * 0.04379562, size.height * 0.9623946);
    alaskaPath.lineTo(size.width * 0.04869656, size.height * 0.9647555);
    alaskaPath.lineTo(size.width * 0.04880083, size.height * 0.9625632);
    alaskaPath.lineTo(size.width * 0.04713243, size.height * 0.9607083);
    alaskaPath.close();
    alaskaPath.moveTo(size.width * 0.04932221, size.height * 0.9608769);
    alaskaPath.lineTo(size.width * 0.04890511, size.height * 0.9585160);
    alaskaPath.lineTo(size.width * 0.05015641, size.height * 0.9588533);
    alaskaPath.lineTo(size.width * 0.05026069, size.height * 0.9612142);
    alaskaPath.lineTo(size.width * 0.05213764, size.height * 0.9612142);
    alaskaPath.lineTo(size.width * 0.05255474, size.height * 0.9569983);
    alaskaPath.lineTo(size.width * 0.05286757, size.height * 0.9610455);
    alaskaPath.lineTo(size.width * 0.05547445, size.height * 0.9608769);
    alaskaPath.lineTo(size.width * 0.05881126, size.height * 0.9553120);
    alaskaPath.lineTo(size.width * 0.05964546, size.height * 0.9554806);
    alaskaPath.lineTo(size.width * 0.05891554, size.height * 0.9576728);
    alaskaPath.lineTo(size.width * 0.06037539, size.height * 0.9591906);
    alaskaPath.lineTo(size.width * 0.06475495, size.height * 0.9588533);
    alaskaPath.lineTo(size.width * 0.06746611, size.height * 0.9568297);
    alaskaPath.lineTo(size.width * 0.06892596, size.height * 0.9566610);
    alaskaPath.lineTo(size.width * 0.06923879, size.height * 0.9591906);
    alaskaPath.lineTo(size.width * 0.06986444, size.height * 0.9583474);
    alaskaPath.lineTo(size.width * 0.07028154, size.height * 0.9559865);
    alaskaPath.lineTo(size.width * 0.07643379, size.height * 0.9563238);
    alaskaPath.lineTo(size.width * 0.07841502, size.height * 0.9536256);
    alaskaPath.lineTo(size.width * 0.07705944, size.height * 0.9517707);
    alaskaPath.lineTo(size.width * 0.07768509, size.height * 0.9497470);
    alaskaPath.lineTo(size.width * 0.08039625, size.height * 0.9500843);
    alaskaPath.lineTo(size.width * 0.08018770, size.height * 0.9480607);
    alaskaPath.lineTo(size.width * 0.08279458, size.height * 0.9483980);
    alaskaPath.lineTo(size.width * 0.08352450, size.height * 0.9465430);
    alaskaPath.lineTo(size.width * 0.08467153, size.height * 0.9468803);
    alaskaPath.lineTo(size.width * 0.08946820, size.height * 0.9436762);
    alaskaPath.lineTo(size.width * 0.08967675, size.height * 0.9408094);
    alaskaPath.lineTo(size.width * 0.09551616, size.height * 0.9367622);
    alaskaPath.lineTo(size.width * 0.09760167, size.height * 0.9335582);
    alaskaPath.lineTo(size.width * 0.09885297, size.height * 0.9325464);
    alaskaPath.lineTo(size.width * 0.1002086, size.height * 0.9338954);
    alaskaPath.lineTo(size.width * 0.1026069, size.height * 0.9323777);
    alaskaPath.lineTo(size.width * 0.1037539, size.height * 0.9291737);
    alaskaPath.lineTo(size.width * 0.1042753, size.height * 0.9269815);
    alaskaPath.lineTo(size.width * 0.1060480, size.height * 0.9254637);
    alaskaPath.lineTo(size.width * 0.1076121, size.height * 0.9242833);
    alaskaPath.lineTo(size.width * 0.1080292, size.height * 0.9219224);
    alaskaPath.lineTo(size.width * 0.1068822, size.height * 0.9190556);
    alaskaPath.lineTo(size.width * 0.1045881, size.height * 0.9187184);
    alaskaPath.lineTo(size.width * 0.1043796, size.height * 0.9165261);
    alaskaPath.lineTo(size.width * 0.1052138, size.height * 0.9138280);
    alaskaPath.lineTo(size.width * 0.1066736, size.height * 0.9134907);
    alaskaPath.lineTo(size.width * 0.1080292, size.height * 0.9109612);
    alaskaPath.lineTo(size.width * 0.1100104, size.height * 0.9107926);
    alaskaPath.lineTo(size.width * 0.1135558, size.height * 0.9053963);
    alaskaPath.lineTo(size.width * 0.1139729, size.height * 0.9030354);
    alaskaPath.lineTo(size.width * 0.1155370, size.height * 0.8991568);
    alaskaPath.lineTo(size.width * 0.1194995, size.height * 0.8922428);
    alaskaPath.lineTo(size.width * 0.1221064, size.height * 0.8907251);
    alaskaPath.lineTo(size.width * 0.1240876, size.height * 0.8892074);
    alaskaPath.lineTo(size.width * 0.1262774, size.height * 0.8905565);
    alaskaPath.lineTo(size.width * 0.1277372, size.height * 0.8949410);
    alaskaPath.lineTo(size.width * 0.1261731, size.height * 0.8949410);
    alaskaPath.lineTo(size.width * 0.1247132, size.height * 0.8924115);
    alaskaPath.lineTo(size.width * 0.1215850, size.height * 0.8957841);
    alaskaPath.lineTo(size.width * 0.1198123, size.height * 0.8959528);
    alaskaPath.lineTo(size.width * 0.1196038, size.height * 0.9011804);
    alaskaPath.lineTo(size.width * 0.1163712, size.height * 0.9094435);
    alaskaPath.lineTo(size.width * 0.1169969, size.height * 0.9128162);
    alaskaPath.lineTo(size.width * 0.1193952, size.height * 0.9128162);
    alaskaPath.lineTo(size.width * 0.1187696, size.height * 0.9145025);
    alaskaPath.lineTo(size.width * 0.1173097, size.height * 0.9146712);
    alaskaPath.lineTo(size.width * 0.1148071, size.height * 0.9177066);
    alaskaPath.lineTo(size.width * 0.1148071, size.height * 0.9192243);
    alaskaPath.lineTo(size.width * 0.1167883, size.height * 0.9209106);
    alaskaPath.lineTo(size.width * 0.1203337, size.height * 0.9198988);
    alaskaPath.lineTo(size.width * 0.1217935, size.height * 0.9170320);
    alaskaPath.lineTo(size.width * 0.1232534, size.height * 0.9172007);
    alaskaPath.lineTo(size.width * 0.1263816, size.height * 0.9143339);
    alaskaPath.lineTo(size.width * 0.1269030, size.height * 0.9104553);
    alaskaPath.lineTo(size.width * 0.1285714, size.height * 0.9102867);
    alaskaPath.lineTo(size.width * 0.1351408, size.height * 0.9116358);
    alaskaPath.lineTo(size.width * 0.1361835, size.height * 0.9097808);
    alaskaPath.lineTo(size.width * 0.1372263, size.height * 0.9021922);
    alaskaPath.lineTo(size.width * 0.1355579, size.height * 0.9040472);
    alaskaPath.lineTo(size.width * 0.1361835, size.height * 0.9003373);
    alaskaPath.lineTo(size.width * 0.1345151, size.height * 0.8979764);
    alaskaPath.lineTo(size.width * 0.1353493, size.height * 0.8954469);
    alaskaPath.lineTo(size.width * 0.1354536, size.height * 0.8979764);
    alaskaPath.lineTo(size.width * 0.1389990, size.height * 0.8979764);
    alaskaPath.lineTo(size.width * 0.1397289, size.height * 0.8962901);
    alaskaPath.lineTo(size.width * 0.1413973, size.height * 0.8961214);
    alaskaPath.lineTo(size.width * 0.1410845, size.height * 0.8989882);
    alaskaPath.lineTo(size.width * 0.1430657, size.height * 0.8991568);
    alaskaPath.lineTo(size.width * 0.1410845, size.height * 0.9013491);
    alaskaPath.lineTo(size.width * 0.1453597, size.height * 0.9032040);
    alaskaPath.lineTo(size.width * 0.1417101, size.height * 0.9038786);
    alaskaPath.lineTo(size.width * 0.1403545, size.height * 0.9059022);
    alaskaPath.lineTo(size.width * 0.1412930, size.height * 0.9082631);
    alaskaPath.lineTo(size.width * 0.1460897, size.height * 0.9053963);
    alaskaPath.lineTo(size.width * 0.1484880, size.height * 0.9082631);
    alaskaPath.lineTo(size.width * 0.1492179, size.height * 0.9067454);
    alaskaPath.lineTo(size.width * 0.1498436, size.height * 0.9091062);
    alaskaPath.lineTo(size.width * 0.1540146, size.height * 0.9129848);
    alaskaPath.lineTo(size.width * 0.1570386, size.height * 0.9129848);
    alaskaPath.lineTo(size.width * 0.1611053, size.height * 0.9121417);
    alaskaPath.lineTo(size.width * 0.1655892, size.height * 0.9139966);
    alaskaPath.lineTo(size.width * 0.1676747, size.height * 0.9172007);
    alaskaPath.lineTo(size.width * 0.1723670, size.height * 0.9178752);
    alaskaPath.lineTo(size.width * 0.1742440, size.height * 0.9153457);
    alaskaPath.lineTo(size.width * 0.1750782, size.height * 0.9193929);
    alaskaPath.lineTo(size.width * 0.1732013, size.height * 0.9205734);
    alaskaPath.lineTo(size.width * 0.1744526, size.height * 0.9225970);
    alaskaPath.lineTo(size.width * 0.1821689, size.height * 0.9290051);
    alaskaPath.lineTo(size.width * 0.1836288, size.height * 0.9332209);
    alaskaPath.lineTo(size.width * 0.1892596, size.height * 0.9401349);
    alaskaPath.lineTo(size.width * 0.1927007, size.height * 0.9367622);
    alaskaPath.lineTo(size.width * 0.1920751, size.height * 0.9330523);
    alaskaPath.lineTo(size.width * 0.1884254, size.height * 0.9296796);
    alaskaPath.lineTo(size.width * 0.1916580, size.height * 0.9317032);
    alaskaPath.lineTo(size.width * 0.1921794, size.height * 0.9305228);
    alaskaPath.lineTo(size.width * 0.1931178, size.height * 0.9327150);
    alaskaPath.lineTo(size.width * 0.1931178, size.height * 0.9372681);
    alaskaPath.lineTo(size.width * 0.1953076, size.height * 0.9362563);
    alaskaPath.lineTo(size.width * 0.1974974, size.height * 0.9392917);
    alaskaPath.lineTo(size.width * 0.1948905, size.height * 0.9227656);
    alaskaPath.lineTo(size.width * 0.1961418, size.height * 0.9249578);
    alaskaPath.lineTo(size.width * 0.1976017, size.height * 0.9350759);
    alaskaPath.lineTo(size.width * 0.1998957, size.height * 0.9392917);
    alaskaPath.lineTo(size.width * 0.2023983, size.height * 0.9386172);
    alaskaPath.lineTo(size.width * 0.2042753, size.height * 0.9445194);
    alaskaPath.lineTo(size.width * 0.2052138, size.height * 0.9445194);
    alaskaPath.lineTo(size.width * 0.2058394, size.height * 0.9539629);
    alaskaPath.lineTo(size.width * 0.2093848, size.height * 0.9548061);
    alaskaPath.lineTo(size.width * 0.2110532, size.height * 0.9585160);
    alaskaPath.lineTo(size.width * 0.2129301, size.height * 0.9603710);
    alaskaPath.lineTo(size.width * 0.2133472, size.height * 0.9650927);
    alaskaPath.lineTo(size.width * 0.2114703, size.height * 0.9694772);
    alaskaPath.lineTo(size.width * 0.2144943, size.height * 0.9721754);
    alaskaPath.lineTo(size.width * 0.2157456, size.height * 0.9681282);
    alaskaPath.lineTo(size.width * 0.2155370, size.height * 0.9733558);
    alaskaPath.lineTo(size.width * 0.2147028, size.height * 0.9748735);
    alaskaPath.lineTo(size.width * 0.2161627, size.height * 0.9777403);
    alaskaPath.lineTo(size.width * 0.2168926, size.height * 0.9736931);
    alaskaPath.lineTo(size.width * 0.2166840, size.height * 0.9716695);
    alaskaPath.lineTo(size.width * 0.2175182, size.height * 0.9720067);
    alaskaPath.lineTo(size.width * 0.2181439, size.height * 0.9758853);
    alaskaPath.lineTo(size.width * 0.2171011, size.height * 0.9782462);
    alaskaPath.lineTo(size.width * 0.2177268, size.height * 0.9826307);
    alaskaPath.lineTo(size.width * 0.2182482, size.height * 0.9833052);
    alaskaPath.lineTo(size.width * 0.2185610, size.height * 0.9806071);
    alaskaPath.lineTo(size.width * 0.2192909, size.height * 0.9816189);
    alaskaPath.lineTo(size.width * 0.2189781, size.height * 0.9849916);
    alaskaPath.lineTo(size.width * 0.2202294, size.height * 0.9853288);
    alaskaPath.lineTo(size.width * 0.2198123, size.height * 0.9868465);
    alaskaPath.lineTo(size.width * 0.2215850, size.height * 0.9866779);
    alaskaPath.lineTo(size.width * 0.2215850, size.height * 0.9849916);
    alaskaPath.lineTo(size.width * 0.2205422, size.height * 0.9849916);
    alaskaPath.lineTo(size.width * 0.2206465, size.height * 0.9821248);
    alaskaPath.lineTo(size.width * 0.2198123, size.height * 0.9811130);
    alaskaPath.lineTo(size.width * 0.2215850, size.height * 0.9806071);
    alaskaPath.lineTo(size.width * 0.2221064, size.height * 0.9792580);
    alaskaPath.lineTo(size.width * 0.2221064, size.height * 0.9765599);
    alaskaPath.lineTo(size.width * 0.2226277, size.height * 0.9787521);
    alaskaPath.lineTo(size.width * 0.2220021, size.height * 0.9817875);
    alaskaPath.lineTo(size.width * 0.2232534, size.height * 0.9883642);
    alaskaPath.lineTo(size.width * 0.2251303, size.height * 0.9885329);
    alaskaPath.lineTo(size.width * 0.2274244, size.height * 0.9814503);
    alaskaPath.lineTo(size.width * 0.2275287, size.height * 0.9782462);
    alaskaPath.lineTo(size.width * 0.2261731, size.height * 0.9715008);
    alaskaPath.lineTo(size.width * 0.2260688, size.height * 0.9694772);
    alaskaPath.lineTo(size.width * 0.2265902, size.height * 0.9674536);
    alaskaPath.lineTo(size.width * 0.2258603, size.height * 0.9662732);
    alaskaPath.lineTo(size.width * 0.2240876, size.height * 0.9664418);
    alaskaPath.lineTo(size.width * 0.2214807, size.height * 0.9630691);
    alaskaPath.lineTo(size.width * 0.2197080, size.height * 0.9630691);
    alaskaPath.lineTo(size.width * 0.2176225, size.height * 0.9607083);
    alaskaPath.lineTo(size.width * 0.2160584, size.height * 0.9607083);
    alaskaPath.lineTo(size.width * 0.2155370, size.height * 0.9580101);
    alaskaPath.lineTo(size.width * 0.2140772, size.height * 0.9575042);
    alaskaPath.lineTo(size.width * 0.2138686, size.height * 0.9549747);
    alaskaPath.lineTo(size.width * 0.2128259, size.height * 0.9541315);
    alaskaPath.lineTo(size.width * 0.2129301, size.height * 0.9512648);
    alaskaPath.lineTo(size.width * 0.2076121, size.height * 0.9387858);
    alaskaPath.lineTo(size.width * 0.2057351, size.height * 0.9362563);
    alaskaPath.lineTo(size.width * 0.2057351, size.height * 0.9342327);
    alaskaPath.lineTo(size.width * 0.2012513, size.height * 0.9283305);
    alaskaPath.lineTo(size.width * 0.2005214, size.height * 0.9264755);
    alaskaPath.lineTo(size.width * 0.1988530, size.height * 0.9231029);
    alaskaPath.lineTo(size.width * 0.1968717, size.height * 0.9220911);
    alaskaPath.lineTo(size.width * 0.1968717, size.height * 0.9183811);
    alaskaPath.lineTo(size.width * 0.1956204, size.height * 0.9161889);
    alaskaPath.lineTo(size.width * 0.1938478, size.height * 0.9150084);
    alaskaPath.lineTo(size.width * 0.1916580, size.height * 0.9172007);
    alaskaPath.lineTo(size.width * 0.1899896, size.height * 0.9207420);
    alaskaPath.lineTo(size.width * 0.1895725, size.height * 0.9247892);
    alaskaPath.lineTo(size.width * 0.1880083, size.height * 0.9249578);
    alaskaPath.lineTo(size.width * 0.1854015, size.height * 0.9295110);
    alaskaPath.lineTo(size.width * 0.1845673, size.height * 0.9290051);
    alaskaPath.lineTo(size.width * 0.1845673, size.height * 0.9247892);
    alaskaPath.lineTo(size.width * 0.1820647, size.height * 0.9210793);
    alaskaPath.lineTo(size.width * 0.1796663, size.height * 0.9177066);
    alaskaPath.lineTo(size.width * 0.1791449, size.height * 0.9143339);
    alaskaPath.lineTo(size.width * 0.1765381, size.height * 0.9121417);
    alaskaPath.lineTo(size.width * 0.1767466, size.height * 0.9084317);
    alaskaPath.lineTo(size.width * 0.1738269, size.height * 0.9082631);
    alaskaPath.lineTo(size.width * 0.1730970, size.height * 0.9101180);
    alaskaPath.lineTo(size.width * 0.1718457, size.height * 0.9101180);
    alaskaPath.lineTo(size.width * 0.1711157, size.height * 0.9089376);
    alaskaPath.lineTo(size.width * 0.1698644, size.height * 0.9102867);
    alaskaPath.lineTo(size.width * 0.1679875, size.height * 0.9082631);
    alaskaPath.lineTo(size.width * 0.1679875, size.height * 0.7635750);
    alaskaPath.lineTo(size.width * 0.1607925, size.height * 0.7566610);
    alaskaPath.lineTo(size.width * 0.1589155, size.height * 0.7558179);
    alaskaPath.lineTo(size.width * 0.1566215, size.height * 0.7576728);
    alaskaPath.lineTo(size.width * 0.1543274, size.height * 0.7578415);
    alaskaPath.lineTo(size.width * 0.1519291, size.height * 0.7551433);
    alaskaPath.lineTo(size.width * 0.1474453, size.height * 0.7541315);
    alaskaPath.lineTo(size.width * 0.1413973, size.height * 0.7480607);
    alaskaPath.lineTo(size.width * 0.1354536, size.height * 0.7473862);
    alaskaPath.lineTo(size.width * 0.1333681, size.height * 0.7482293);
    alaskaPath.lineTo(size.width * 0.1331595, size.height * 0.7451939);
    alaskaPath.lineTo(size.width * 0.1312826, size.height * 0.7440135);
    alaskaPath.lineTo(size.width * 0.1324296, size.height * 0.7423272);
    alaskaPath.lineTo(size.width * 0.1322211, size.height * 0.7408094);
    alaskaPath.lineTo(size.width * 0.1288843, size.height * 0.7389545);
    alaskaPath.lineTo(size.width * 0.1263816, size.height * 0.7389545);
    alaskaPath.lineTo(size.width * 0.1259645, size.height * 0.7396290);
    alaskaPath.lineTo(size.width * 0.1250261, size.height * 0.7386172);
    alaskaPath.lineTo(size.width * 0.1251303, size.height * 0.7342327);
    alaskaPath.lineTo(size.width * 0.1242961, size.height * 0.7327150);
    alaskaPath.lineTo(size.width * 0.1216893, size.height * 0.7376054);
    alaskaPath.lineTo(size.width * 0.1208551, size.height * 0.7374368);
    alaskaPath.lineTo(size.width * 0.1208551, size.height * 0.7360877);
    alaskaPath.lineTo(size.width * 0.1226277, size.height * 0.7347386);
    alaskaPath.lineTo(size.width * 0.1226277, size.height * 0.7333895);
    alaskaPath.lineTo(size.width * 0.1206465, size.height * 0.7293423);
    alaskaPath.lineTo(size.width * 0.1194995, size.height * 0.7291737);
    alaskaPath.lineTo(size.width * 0.1148071, size.height * 0.7344013);
    alaskaPath.lineTo(size.width * 0.1107404, size.height * 0.7344013);
    alaskaPath.lineTo(size.width * 0.1111575, size.height * 0.7328836);
    alaskaPath.lineTo(size.width * 0.1092805, size.height * 0.7327150);
    alaskaPath.lineTo(size.width * 0.1038582, size.height * 0.7384486);
    alaskaPath.lineTo(size.width * 0.1019812, size.height * 0.7384486);
    alaskaPath.lineTo(size.width * 0.1013556, size.height * 0.7370995);
    alaskaPath.lineTo(size.width * 0.09854015, size.height * 0.7396290);
    alaskaPath.lineTo(size.width * 0.09478624, size.height * 0.7458685);
    alaskaPath.lineTo(size.width * 0.09186653, size.height * 0.7504216);
    alaskaPath.lineTo(size.width * 0.09030240, size.height * 0.7524452);
    alaskaPath.lineTo(size.width * 0.08759124, size.height * 0.7526138);
    alaskaPath.lineTo(size.width * 0.08529718, size.height * 0.7519393);
    alaskaPath.lineTo(size.width * 0.08289885, size.height * 0.7497470);
    alaskaPath.lineTo(size.width * 0.08289885, size.height * 0.7497470);
    alaskaPath.lineTo(size.width * 0.07997914, size.height * 0.7563238);
    alaskaPath.lineTo(size.width * 0.07987487, size.height * 0.7603710);
    alaskaPath.lineTo(size.width * 0.08258603, size.height * 0.7644182);
    alaskaPath.lineTo(size.width * 0.08477581, size.height * 0.7720067);
    alaskaPath.lineTo(size.width * 0.08498436, size.height * 0.7809444);
    alaskaPath.lineTo(size.width * 0.08800834, size.height * 0.7843170);
    alaskaPath.lineTo(size.width * 0.09155370, size.height * 0.7849916);
    alaskaPath.lineTo(size.width * 0.09228363, size.height * 0.7863406);
    alaskaPath.lineTo(size.width * 0.09071950, size.height * 0.7902192);
    alaskaPath.lineTo(size.width * 0.09144943, size.height * 0.7947723);
    alaskaPath.lineTo(size.width * 0.08967675, size.height * 0.7903879);
    alaskaPath.lineTo(size.width * 0.08967675, size.height * 0.7863406);
    alaskaPath.lineTo(size.width * 0.08811262, size.height * 0.7858347);
    alaskaPath.lineTo(size.width * 0.08821689, size.height * 0.7878583);
    alaskaPath.lineTo(size.width * 0.08894682, size.height * 0.7913997);
    alaskaPath.lineTo(size.width * 0.09197080, size.height * 0.7976391);
    alaskaPath.lineTo(size.width * 0.09051095, size.height * 0.7976391);
    alaskaPath.lineTo(size.width * 0.08821689, size.height * 0.7994941);
    alaskaPath.lineTo(size.width * 0.08175182, size.height * 0.7952782);
    alaskaPath.lineTo(size.width * 0.08164755, size.height * 0.7919056);
    alaskaPath.lineTo(size.width * 0.08310740, size.height * 0.7897133);
    alaskaPath.lineTo(size.width * 0.08310740, size.height * 0.7873524);
    alaskaPath.lineTo(size.width * 0.08091762, size.height * 0.7865093);
    alaskaPath.lineTo(size.width * 0.07851929, size.height * 0.7868465);
    alaskaPath.lineTo(size.width * 0.07351408, size.height * 0.7871838);
    alaskaPath.lineTo(size.width * 0.07507821, size.height * 0.7910624);
    alaskaPath.lineTo(size.width * 0.07309698, size.height * 0.7880270);
    alaskaPath.lineTo(size.width * 0.06433785, size.height * 0.7900506);
    alaskaPath.lineTo(size.width * 0.06350365, size.height * 0.7925801);
    alaskaPath.lineTo(size.width * 0.06861314, size.height * 0.8005059);
    alaskaPath.lineTo(size.width * 0.06777894, size.height * 0.8028668);
    alaskaPath.lineTo(size.width * 0.06746611, size.height * 0.8062395);
    alaskaPath.lineTo(size.width * 0.06673618, size.height * 0.8075885);
    alaskaPath.lineTo(size.width * 0.06663191, size.height * 0.8107926);
    alaskaPath.lineTo(size.width * 0.07122002, size.height * 0.8168634);
    alaskaPath.lineTo(size.width * 0.07549531, size.height * 0.8172007);
    alaskaPath.lineTo(size.width * 0.08029197, size.height * 0.8204047);
    alaskaPath.lineTo(size.width * 0.08237748, size.height * 0.8204047);
    alaskaPath.lineTo(size.width * 0.08321168, size.height * 0.8193929);
    alaskaPath.lineTo(size.width * 0.08717414, size.height * 0.8195616);
    alaskaPath.lineTo(size.width * 0.08727842, size.height * 0.8182125);
    alaskaPath.lineTo(size.width * 0.08852972, size.height * 0.8200675);
    alaskaPath.lineTo(size.width * 0.08863399, size.height * 0.8234401);
    alaskaPath.lineTo(size.width * 0.08602711, size.height * 0.8232715);
    alaskaPath.lineTo(size.width * 0.08613139, size.height * 0.8288364);
    alaskaPath.lineTo(size.width * 0.08665276, size.height * 0.8342327);
    alaskaPath.lineTo(size.width * 0.08362878, size.height * 0.8387858);
    alaskaPath.lineTo(size.width * 0.08164755, size.height * 0.8386172);
    alaskaPath.lineTo(size.width * 0.07956204, size.height * 0.8372681);
    alaskaPath.lineTo(size.width * 0.07851929, size.height * 0.8374368);
    alaskaPath.lineTo(size.width * 0.07528676, size.height * 0.8409781);
    alaskaPath.lineTo(size.width * 0.07351408, size.height * 0.8413153);
    alaskaPath.lineTo(size.width * 0.07205422, size.height * 0.8365936);
    alaskaPath.lineTo(size.width * 0.06882169, size.height * 0.8365936);
    alaskaPath.lineTo(size.width * 0.06652763, size.height * 0.8399663);
    alaskaPath.lineTo(size.width * 0.06600626, size.height * 0.8430017);
    alaskaPath.lineTo(size.width * 0.06256517, size.height * 0.8460371);
    alaskaPath.lineTo(size.width * 0.05703858, size.height * 0.8532884);
    alaskaPath.lineTo(size.width * 0.05672576, size.height * 0.8585160);
    alaskaPath.lineTo(size.width * 0.05745568, size.height * 0.8622260);
    alaskaPath.lineTo(size.width * 0.05849844, size.height * 0.8642496);
    alaskaPath.lineTo(size.width * 0.05954119, size.height * 0.8635750);
    alaskaPath.lineTo(size.width * 0.06047967, size.height * 0.8652614);
    alaskaPath.lineTo(size.width * 0.05964546, size.height * 0.8662732);
    alaskaPath.lineTo(size.width * 0.05808133, size.height * 0.8677909);
    alaskaPath.lineTo(size.width * 0.05922836, size.height * 0.8703204);
    alaskaPath.lineTo(size.width * 0.05651721, size.height * 0.8721754);
    alaskaPath.lineTo(size.width * 0.05735141, size.height * 0.8758853);
    alaskaPath.lineTo(size.width * 0.05912409, size.height * 0.8797639);
    alaskaPath.lineTo(size.width * 0.05995829, size.height * 0.8866779);
    alaskaPath.lineTo(size.width * 0.06412930, size.height * 0.8892074);
    alaskaPath.lineTo(size.width * 0.06684046, size.height * 0.8878583);
    alaskaPath.lineTo(size.width * 0.06861314, size.height * 0.8860034);
    alaskaPath.lineTo(size.width * 0.06913452, size.height * 0.8895447);
    alaskaPath.lineTo(size.width * 0.06944734, size.height * 0.8969646);
    alaskaPath.lineTo(size.width * 0.06746611, size.height * 0.8993255);
    alaskaPath.lineTo(size.width * 0.06746611, size.height * 0.9067454);
    alaskaPath.lineTo(size.width * 0.06684046, size.height * 0.9082631);
    alaskaPath.lineTo(size.width * 0.06506778, size.height * 0.9082631);
    alaskaPath.lineTo(size.width * 0.06684046, size.height * 0.9102867);
    alaskaPath.lineTo(size.width * 0.06903024, size.height * 0.9101180);
    alaskaPath.lineTo(size.width * 0.06944734, size.height * 0.9084317);
    alaskaPath.lineTo(size.width * 0.07424400, size.height * 0.9074199);
    alaskaPath.lineTo(size.width * 0.07632951, size.height * 0.9118044);
    alaskaPath.lineTo(size.width * 0.07768509, size.height * 0.9106239);
    alaskaPath.lineTo(size.width * 0.07904067, size.height * 0.9192243);
    alaskaPath.lineTo(size.width * 0.08008342, size.height * 0.9200675);
    alaskaPath.lineTo(size.width * 0.08112617, size.height * 0.9188870);
    alaskaPath.lineTo(size.width * 0.08123045, size.height * 0.9148398);
    alaskaPath.lineTo(size.width * 0.08216893, size.height * 0.9131535);
    alaskaPath.lineTo(size.width * 0.08289885, size.height * 0.9150084);
    alaskaPath.lineTo(size.width * 0.08310740, size.height * 0.9177066);
    alaskaPath.lineTo(size.width * 0.08477581, size.height * 0.9183811);
    alaskaPath.lineTo(size.width * 0.08967675, size.height * 0.9163575);
    alaskaPath.lineTo(size.width * 0.08988530, size.height * 0.9183811);
    alaskaPath.lineTo(size.width * 0.08779979, size.height * 0.9202361);
    alaskaPath.lineTo(size.width * 0.08613139, size.height * 0.9231029);
    alaskaPath.lineTo(size.width * 0.08321168, size.height * 0.9349073);
    alaskaPath.lineTo(size.width * 0.07872784, size.height * 0.9382799);
    alaskaPath.lineTo(size.width * 0.07726799, size.height * 0.9408094);
    alaskaPath.lineTo(size.width * 0.07695516, size.height * 0.9431703);
    alaskaPath.lineTo(size.width * 0.07591241, size.height * 0.9421585);
    alaskaPath.lineTo(size.width * 0.06621481, size.height * 0.9477234);
    alaskaPath.lineTo(size.width * 0.06433785, size.height * 0.9546374);
    alaskaPath.lineTo(size.width * 0.06298227, size.height * 0.9539629);
    alaskaPath.lineTo(size.width * 0.06350365, size.height * 0.9521079);
    alaskaPath.lineTo(size.width * 0.06193952, size.height * 0.9497470);
    alaskaPath.lineTo(size.width * 0.05828989, size.height * 0.9494098);
    alaskaPath.lineTo(size.width * 0.05276330, size.height * 0.9548061);
    alaskaPath.lineTo(size.width * 0.05046924, size.height * 0.9569983);
    alaskaPath.lineTo(size.width * 0.04807091, size.height * 0.9569983);
    alaskaPath.lineTo(size.width * 0.04754953, size.height * 0.9610455);
    alaskaPath.close();

    Paint alaskaPaint = Paint()..style = PaintingStyle.fill;
    alaskaPaint.color = usaColors.alaska ?? defaultColor;
    usaCanvas.drawPath(alaskaPath, alaskaPaint, onTapUp: (tabdetail) {
      callback('alaska', tabdetail);
    });

    Path arizonaPath = Path();
    arizonaPath.moveTo(size.width * 0.1455683, size.height * 0.6536256);
    arizonaPath.lineTo(size.width * 0.1486966, size.height * 0.6499157);
    arizonaPath.lineTo(size.width * 0.1495308, size.height * 0.6458685);
    arizonaPath.lineTo(size.width * 0.1484880, size.height * 0.6431703);
    arizonaPath.lineTo(size.width * 0.1466111, size.height * 0.6428331);
    arizonaPath.lineTo(size.width * 0.1454640, size.height * 0.6401349);
    arizonaPath.lineTo(size.width * 0.1466111, size.height * 0.6284992);
    arizonaPath.lineTo(size.width * 0.1482795, size.height * 0.6279933);
    arizonaPath.lineTo(size.width * 0.1507821, size.height * 0.6225970);
    arizonaPath.lineTo(size.width * 0.1524505, size.height * 0.6107926);
    arizonaPath.lineTo(size.width * 0.1549531, size.height * 0.6047218);
    arizonaPath.lineTo(size.width * 0.1599583, size.height * 0.6018550);
    arizonaPath.lineTo(size.width * 0.1613139, size.height * 0.5996627);
    arizonaPath.lineTo(size.width * 0.1608968, size.height * 0.5964587);
    arizonaPath.lineTo(size.width * 0.1584984, size.height * 0.5922428);
    arizonaPath.lineTo(size.width * 0.1572471, size.height * 0.5824621);
    arizonaPath.lineTo(size.width * 0.1557873, size.height * 0.5794266);
    arizonaPath.lineTo(size.width * 0.1544317, size.height * 0.5736931);
    arizonaPath.lineTo(size.width * 0.1553702, size.height * 0.5701518);
    arizonaPath.lineTo(size.width * 0.1568300, size.height * 0.5650927);
    arizonaPath.lineTo(size.width * 0.1573514, size.height * 0.5602024);
    arizonaPath.lineTo(size.width * 0.1568300, size.height * 0.5519393);
    arizonaPath.lineTo(size.width * 0.1578728, size.height * 0.5290051);
    arizonaPath.lineTo(size.width * 0.1615224, size.height * 0.5279933);
    arizonaPath.lineTo(size.width * 0.1653806, size.height * 0.5303541);
    arizonaPath.lineTo(size.width * 0.1666319, size.height * 0.5349073);
    arizonaPath.lineTo(size.width * 0.1687174, size.height * 0.5349073);
    arizonaPath.lineTo(size.width * 0.1712200, size.height * 0.5300169);
    arizonaPath.lineTo(size.width * 0.1747654, size.height * 0.5005059);
    arizonaPath.lineTo(size.width * 0.2229406, size.height * 0.5143339);
    arizonaPath.lineTo(size.width * 0.2646507, size.height * 0.5244519);
    arizonaPath.lineTo(size.width * 0.2465068, size.height * 0.7337268);
    arizonaPath.lineTo(size.width * 0.2076121, size.height * 0.7246206);
    arizonaPath.lineTo(size.width * 0.1406674, size.height * 0.6613828);
    arizonaPath.lineTo(size.width * 0.1411887, size.height * 0.6564924);
    arizonaPath.lineTo(size.width * 0.1432742, size.height * 0.6534570);
    arizonaPath.close();

    Paint arizonaPaint = Paint()..style = PaintingStyle.fill;
    arizonaPaint.color = usaColors.arizona ?? defaultColor;
    usaCanvas.drawPath(arizonaPath, arizonaPaint, onTapUp: (tabdetail) {
      callback('arizona', tabdetail);
    });

    Path arkansasPath = Path();
    arkansasPath.moveTo(size.width * 0.6091762, size.height * 0.6188870);
    arkansasPath.lineTo(size.width * 0.6101147, size.height * 0.6151771);
    arkansasPath.lineTo(size.width * 0.6113660, size.height * 0.6160202);
    arkansasPath.lineTo(size.width * 0.6120959, size.height * 0.6143339);
    arkansasPath.lineTo(size.width * 0.6112617, size.height * 0.6131535);
    arkansasPath.lineTo(size.width * 0.6115746, size.height * 0.6106239);
    arkansasPath.lineTo(size.width * 0.6104275, size.height * 0.6091062);
    arkansasPath.lineTo(size.width * 0.6110532, size.height * 0.6074199);
    arkansasPath.lineTo(size.width * 0.6109489, size.height * 0.6048904);
    arkansasPath.lineTo(size.width * 0.6098019, size.height * 0.6047218);
    arkansasPath.lineTo(size.width * 0.6106361, size.height * 0.6033727);
    arkansasPath.lineTo(size.width * 0.6119917, size.height * 0.6047218);
    arkansasPath.lineTo(size.width * 0.6123045, size.height * 0.6023609);
    arkansasPath.lineTo(size.width * 0.6118874, size.height * 0.6005059);
    arkansasPath.lineTo(size.width * 0.6119917, size.height * 0.5993255);
    arkansasPath.lineTo(size.width * 0.6140772, size.height * 0.6003373);
    arkansasPath.lineTo(size.width * 0.6136601, size.height * 0.5978078);
    arkansasPath.lineTo(size.width * 0.6153285, size.height * 0.5956155);
    arkansasPath.lineTo(size.width * 0.6148071, size.height * 0.5940978);
    arkansasPath.lineTo(size.width * 0.6136601, size.height * 0.5942664);
    arkansasPath.lineTo(size.width * 0.6130344, size.height * 0.5927487);
    arkansasPath.lineTo(size.width * 0.6139729, size.height * 0.5912310);
    arkansasPath.lineTo(size.width * 0.6156413, size.height * 0.5908938);
    arkansasPath.lineTo(size.width * 0.6161627, size.height * 0.5895447);
    arkansasPath.lineTo(size.width * 0.6176225, size.height * 0.5892074);
    arkansasPath.lineTo(size.width * 0.6175182, size.height * 0.5878583);
    arkansasPath.lineTo(size.width * 0.6165798, size.height * 0.5863406);
    arkansasPath.lineTo(size.width * 0.6165798, size.height * 0.5854975);
    arkansasPath.lineTo(size.width * 0.6181439, size.height * 0.5854975);
    arkansasPath.lineTo(size.width * 0.6185610, size.height * 0.5843170);
    arkansasPath.lineTo(size.width * 0.6171011, size.height * 0.5826307);
    arkansasPath.lineTo(size.width * 0.6169969, size.height * 0.5816189);
    arkansasPath.lineTo(size.width * 0.6053180, size.height * 0.5829680);
    arkansasPath.lineTo(size.width * 0.6082377, size.height * 0.5743676);
    arkansasPath.lineTo(size.width * 0.6100104, size.height * 0.5718381);
    arkansasPath.lineTo(size.width * 0.6100104, size.height * 0.5681282);
    arkansasPath.lineTo(size.width * 0.6083420, size.height * 0.5639123);
    arkansasPath.lineTo(size.width * 0.5668405, size.height * 0.5672850);
    arkansasPath.lineTo(size.width * 0.5260688, size.height * 0.5684654);
    arkansasPath.lineTo(size.width * 0.5303441, size.height * 0.6096121);
    arkansasPath.lineTo(size.width * 0.5296142, size.height * 0.6753794);
    arkansasPath.lineTo(size.width * 0.5323253, size.height * 0.6792580);
    arkansasPath.lineTo(size.width * 0.5352450, size.height * 0.6770658);
    arkansasPath.lineTo(size.width * 0.5385819, size.height * 0.6784148);
    arkansasPath.lineTo(size.width * 0.5387904, size.height * 0.6984823);
    arkansasPath.lineTo(size.width * 0.5933264, size.height * 0.6962901);
    arkansasPath.lineTo(size.width * 0.5945777, size.height * 0.6937605);
    arkansasPath.lineTo(size.width * 0.5950991, size.height * 0.6887015);
    arkansasPath.lineTo(size.width * 0.5935349, size.height * 0.6848229);
    arkansasPath.lineTo(size.width * 0.5930136, size.height * 0.6811130);
    arkansasPath.lineTo(size.width * 0.5939520, size.height * 0.6799325);
    arkansasPath.lineTo(size.width * 0.5939520, size.height * 0.6785835);
    arkansasPath.lineTo(size.width * 0.5921794, size.height * 0.6767285);
    arkansasPath.lineTo(size.width * 0.5920751, size.height * 0.6755481);
    arkansasPath.lineTo(size.width * 0.5937435, size.height * 0.6740304);
    arkansasPath.lineTo(size.width * 0.5924922, size.height * 0.6721754);
    arkansasPath.lineTo(size.width * 0.5942649, size.height * 0.6602024);
    arkansasPath.lineTo(size.width * 0.5978102, size.height * 0.6575042);
    arkansasPath.lineTo(size.width * 0.5978102, size.height * 0.6561551);
    arkansasPath.lineTo(size.width * 0.5966632, size.height * 0.6537943);
    arkansasPath.lineTo(size.width * 0.5996872, size.height * 0.6446880);
    arkansasPath.lineTo(size.width * 0.6016684, size.height * 0.6446880);
    arkansasPath.lineTo(size.width * 0.6032325, size.height * 0.6426644);
    arkansasPath.lineTo(size.width * 0.6029197, size.height * 0.6338954);
    arkansasPath.lineTo(size.width * 0.6061522, size.height * 0.6263069);
    arkansasPath.lineTo(size.width * 0.6080292, size.height * 0.6252951);
    arkansasPath.lineTo(size.width * 0.6075078, size.height * 0.6200675);
    arkansasPath.close();

    Paint arkansasPaint = Paint()..style = PaintingStyle.fill;
    arkansasPaint.color = usaColors.arkansas ?? defaultColor;
    usaCanvas.drawPath(arkansasPath, arkansasPaint, onTapUp: (tabdetail) {
      callback('arkansas', tabdetail);
    });

    Path californiaPath = Path();
    californiaPath.moveTo(size.width * 0.07236705, size.height * 0.6165261);
    californiaPath.lineTo(size.width * 0.07591241, size.height * 0.6252951);
    californiaPath.lineTo(size.width * 0.07445255, size.height * 0.6254637);
    californiaPath.lineTo(size.width * 0.07257560, size.height * 0.6222597);
    californiaPath.close();
    californiaPath.moveTo(size.width * 0.07434828, size.height * 0.6000000);
    californiaPath.lineTo(size.width * 0.07622523, size.height * 0.6069140);
    californiaPath.lineTo(size.width * 0.07893639, size.height * 0.6086003);
    californiaPath.lineTo(size.width * 0.07966632, size.height * 0.6075885);
    californiaPath.lineTo(size.width * 0.07831074, size.height * 0.6033727);
    californiaPath.lineTo(size.width * 0.07559958, size.height * 0.5993255);
    californiaPath.close();
    californiaPath.moveTo(size.width * 0.05359750, size.height * 0.5679595);
    californiaPath.lineTo(size.width * 0.05359750, size.height * 0.5720067);
    californiaPath.lineTo(size.width * 0.05568300, size.height * 0.5740304);
    californiaPath.lineTo(size.width * 0.06027112, size.height * 0.5736931);
    californiaPath.lineTo(size.width * 0.06131387, size.height * 0.5720067);
    californiaPath.lineTo(size.width * 0.05808133, size.height * 0.5716695);
    californiaPath.close();
    californiaPath.moveTo(size.width * 0.04744526, size.height * 0.5681282);
    californiaPath.lineTo(size.width * 0.05088634, size.height * 0.5689713);
    californiaPath.lineTo(size.width * 0.05234619, size.height * 0.5726813);
    californiaPath.lineTo(size.width * 0.04838373, size.height * 0.5726813);
    californiaPath.close();
    californiaPath.moveTo(size.width * 0.09739312, size.height * 0.6448567);
    californiaPath.lineTo(size.width * 0.09635036, size.height * 0.6397976);
    californiaPath.lineTo(size.width * 0.09655892, size.height * 0.6347386);
    californiaPath.lineTo(size.width * 0.09614181, size.height * 0.6214165);
    californiaPath.lineTo(size.width * 0.09426486, size.height * 0.6133221);
    californiaPath.lineTo(size.width * 0.09301356, size.height * 0.6109612);
    californiaPath.lineTo(size.width * 0.09238790, size.height * 0.6084317);
    californiaPath.lineTo(size.width * 0.08508863, size.height * 0.5939292);
    californiaPath.lineTo(size.width * 0.08133472, size.height * 0.5940978);
    californiaPath.lineTo(size.width * 0.07924922, size.height * 0.5908938);
    californiaPath.lineTo(size.width * 0.08039625, size.height * 0.5878583);
    californiaPath.lineTo(size.width * 0.07966632, size.height * 0.5816189);
    californiaPath.lineTo(size.width * 0.07737226, size.height * 0.5795953);
    californiaPath.lineTo(size.width * 0.07330553, size.height * 0.5785835);
    californiaPath.lineTo(size.width * 0.07038582, size.height * 0.5763912);
    californiaPath.lineTo(size.width * 0.06882169, size.height * 0.5731872);
    californiaPath.lineTo(size.width * 0.06412930, size.height * 0.5620573);
    californiaPath.lineTo(size.width * 0.06131387, size.height * 0.5583474);
    californiaPath.lineTo(size.width * 0.05745568, size.height * 0.5575042);
    californiaPath.lineTo(size.width * 0.05422315, size.height * 0.5536256);
    californiaPath.lineTo(size.width * 0.04932221, size.height * 0.5510961);
    californiaPath.lineTo(size.width * 0.04640250, size.height * 0.5505902);
    californiaPath.lineTo(size.width * 0.04379562, size.height * 0.5463744);
    californiaPath.lineTo(size.width * 0.04400417, size.height * 0.5416526);
    californiaPath.lineTo(size.width * 0.04483837, size.height * 0.5335582);
    californiaPath.lineTo(size.width * 0.04671533, size.height * 0.5249578);
    californiaPath.lineTo(size.width * 0.04525547, size.height * 0.5222597);
    californiaPath.lineTo(size.width * 0.04108446, size.height * 0.5064081);
    californiaPath.lineTo(size.width * 0.03826903, size.height * 0.5001686);
    californiaPath.lineTo(size.width * 0.03785193, size.height * 0.4951096);
    californiaPath.lineTo(size.width * 0.03618352, size.height * 0.4912310);
    californiaPath.lineTo(size.width * 0.03639208, size.height * 0.4870152);
    californiaPath.lineTo(size.width * 0.03430657, size.height * 0.4785835);
    californiaPath.lineTo(size.width * 0.03128259, size.height * 0.4740304);
    californiaPath.lineTo(size.width * 0.03190824, size.height * 0.4620573);
    californiaPath.lineTo(size.width * 0.03441084, size.height * 0.4607083);
    californiaPath.lineTo(size.width * 0.03628780, size.height * 0.4554806);
    californiaPath.lineTo(size.width * 0.03587070, size.height * 0.4500843);
    californiaPath.lineTo(size.width * 0.03482795, size.height * 0.4485666);
    californiaPath.lineTo(size.width * 0.03222106, size.height * 0.4485666);
    californiaPath.lineTo(size.width * 0.02961418, size.height * 0.4430017);
    californiaPath.lineTo(size.width * 0.02805005, size.height * 0.4370995);
    californiaPath.lineTo(size.width * 0.02805005, size.height * 0.4244519);
    californiaPath.lineTo(size.width * 0.02930136, size.height * 0.4173693);
    californiaPath.lineTo(size.width * 0.02950991, size.height * 0.4138280);
    californiaPath.lineTo(size.width * 0.03211679, size.height * 0.4141653);
    californiaPath.lineTo(size.width * 0.03201251, size.height * 0.4168634);
    californiaPath.lineTo(size.width * 0.03117831, size.height * 0.4180438);
    californiaPath.lineTo(size.width * 0.03117831, size.height * 0.4222597);
    californiaPath.lineTo(size.width * 0.03503650, size.height * 0.4276560);
    californiaPath.lineTo(size.width * 0.03503650, size.height * 0.4197302);
    californiaPath.lineTo(size.width * 0.03357664, size.height * 0.4139966);
    californiaPath.lineTo(size.width * 0.03409802, size.height * 0.4121417);
    californiaPath.lineTo(size.width * 0.03305527, size.height * 0.4092749);
    californiaPath.lineTo(size.width * 0.03597497, size.height * 0.4067454);
    californiaPath.lineTo(size.width * 0.03399374, size.height * 0.4016863);
    californiaPath.lineTo(size.width * 0.03253389, size.height * 0.4025295);
    californiaPath.lineTo(size.width * 0.03096976, size.height * 0.4089376);
    californiaPath.lineTo(size.width * 0.03149114, size.height * 0.4111298);
    californiaPath.lineTo(size.width * 0.03065693, size.height * 0.4128162);
    californiaPath.lineTo(size.width * 0.02971846, size.height * 0.4126476);
    californiaPath.lineTo(size.width * 0.02408759, size.height * 0.4023609);
    californiaPath.lineTo(size.width * 0.02481752, size.height * 0.3929174);
    californiaPath.lineTo(size.width * 0.02367049, size.height * 0.3863406);
    californiaPath.lineTo(size.width * 0.01689260, size.height * 0.3647555);
    californiaPath.lineTo(size.width * 0.01772680, size.height * 0.3467116);
    californiaPath.lineTo(size.width * 0.02012513, size.height * 0.3406408);
    californiaPath.lineTo(size.width * 0.02033368, size.height * 0.3298482);
    californiaPath.lineTo(size.width * 0.01459854, size.height * 0.3111298);
    californiaPath.lineTo(size.width * 0.01491137, size.height * 0.3023609);
    californiaPath.lineTo(size.width * 0.02210636, size.height * 0.2897133);
    californiaPath.lineTo(size.width * 0.02387904, size.height * 0.2856661);
    californiaPath.lineTo(size.width * 0.02377477, size.height * 0.2833052);
    californiaPath.lineTo(size.width * 0.02794578, size.height * 0.2677909);
    californiaPath.lineTo(size.width * 0.02805005, size.height * 0.2536256);
    californiaPath.lineTo(size.width * 0.02898853, size.height * 0.2494098);
    californiaPath.lineTo(size.width * 0.09791449, size.height * 0.2807757);
    californiaPath.lineTo(size.width * 0.08081335, size.height * 0.3871838);
    californiaPath.lineTo(size.width * 0.08196038, size.height * 0.3930860);
    californiaPath.lineTo(size.width * 0.1553702, size.height * 0.5701518);
    californiaPath.lineTo(size.width * 0.1544317, size.height * 0.5736931);
    californiaPath.lineTo(size.width * 0.1557873, size.height * 0.5794266);
    californiaPath.lineTo(size.width * 0.1572471, size.height * 0.5824621);
    californiaPath.lineTo(size.width * 0.1584984, size.height * 0.5922428);
    californiaPath.lineTo(size.width * 0.1608968, size.height * 0.5964587);
    californiaPath.lineTo(size.width * 0.1613139, size.height * 0.5996627);
    californiaPath.lineTo(size.width * 0.1599583, size.height * 0.6018550);
    californiaPath.lineTo(size.width * 0.1549531, size.height * 0.6047218);
    californiaPath.lineTo(size.width * 0.1524505, size.height * 0.6107926);
    californiaPath.lineTo(size.width * 0.1507821, size.height * 0.6225970);
    californiaPath.lineTo(size.width * 0.1482795, size.height * 0.6279933);
    californiaPath.lineTo(size.width * 0.1466111, size.height * 0.6284992);
    californiaPath.lineTo(size.width * 0.1454640, size.height * 0.6401349);
    californiaPath.lineTo(size.width * 0.1466111, size.height * 0.6428331);
    californiaPath.lineTo(size.width * 0.1484880, size.height * 0.6431703);
    californiaPath.lineTo(size.width * 0.1495308, size.height * 0.6458685);
    californiaPath.lineTo(size.width * 0.1486966, size.height * 0.6499157);
    californiaPath.lineTo(size.width * 0.1455683, size.height * 0.6536256);
    californiaPath.lineTo(size.width * 0.1432742, size.height * 0.6534570);
    californiaPath.close();

    Paint californiaPaint = Paint()..style = PaintingStyle.fill;
    californiaPaint.color = usaColors.california ?? defaultColor;
    usaCanvas.drawPath(californiaPath, californiaPaint, onTapUp: (tabdetail) {
      callback('california', tabdetail);
    });

    Path coloradoPath = Path();
    coloradoPath.moveTo(size.width * 0.3906152, size.height * 0.5451939);
    coloradoPath.lineTo(size.width * 0.3734098, size.height * 0.5435076);
    coloradoPath.lineTo(size.width * 0.3194995, size.height * 0.5354132);
    coloradoPath.lineTo(size.width * 0.2646507, size.height * 0.5244519);
    coloradoPath.lineTo(size.width * 0.2766423, size.height * 0.3755481);
    coloradoPath.lineTo(size.width * 0.3234619, size.height * 0.3851602);
    coloradoPath.lineTo(size.width * 0.3625652, size.height * 0.3908938);
    coloradoPath.lineTo(size.width * 0.3970803, size.height * 0.3949410);
    coloradoPath.lineTo(size.width * 0.3956204, size.height * 0.4322091);
    coloradoPath.close();

    Paint coloradoPaint = Paint()..style = PaintingStyle.fill;
    coloradoPaint.color = usaColors.colorado ?? defaultColor;
    usaCanvas.drawPath(coloradoPath, coloradoPaint, onTapUp: (tabdetail) {
      callback('colorado', tabdetail);
    });

    Path connecticutPath = Path();
    connecticutPath.moveTo(size.width * 0.9108446, size.height * 0.3016863);
    connecticutPath.lineTo(size.width * 0.9112617, size.height * 0.2998314);
    connecticutPath.lineTo(size.width * 0.9079249, size.height * 0.2790894);
    connecticutPath.lineTo(size.width * 0.9078206, size.height * 0.2785835);
    connecticutPath.lineTo(size.width * 0.8922836, size.height * 0.2843170);
    connecticutPath.lineTo(size.width * 0.8922836, size.height * 0.2854975);
    connecticutPath.lineTo(size.width * 0.8913452, size.height * 0.2860034);
    connecticutPath.lineTo(size.width * 0.8908238, size.height * 0.2848229);
    connecticutPath.lineTo(size.width * 0.8798749, size.height * 0.2888702);
    connecticutPath.lineTo(size.width * 0.8827946, size.height * 0.3163575);
    connecticutPath.lineTo(size.width * 0.8846715, size.height * 0.3188870);
    connecticutPath.lineTo(size.width * 0.8810219, size.height * 0.3246206);
    connecticutPath.lineTo(size.width * 0.8827946, size.height * 0.3283305);
    connecticutPath.lineTo(size.width * 0.8884254, size.height * 0.3207420);
    connecticutPath.lineTo(size.width * 0.8901981, size.height * 0.3185497);
    connecticutPath.lineTo(size.width * 0.8910323, size.height * 0.3185497);
    connecticutPath.lineTo(size.width * 0.8935349, size.height * 0.3133221);
    connecticutPath.lineTo(size.width * 0.8949948, size.height * 0.3134907);
    connecticutPath.lineTo(size.width * 0.8980188, size.height * 0.3116358);
    connecticutPath.lineTo(size.width * 0.9002086, size.height * 0.3116358);
    connecticutPath.lineTo(size.width * 0.9057351, size.height * 0.3070826);
    connecticutPath.lineTo(size.width * 0.9086548, size.height * 0.3055649);
    connecticutPath.lineTo(size.width * 0.9096976, size.height * 0.3038786);
    connecticutPath.lineTo(size.width * 0.9112617, size.height * 0.3047218);
    connecticutPath.close();

    Paint connecticutPaint = Paint()..style = PaintingStyle.fill;
    connecticutPaint.color = usaColors.connecticut ?? defaultColor;
    usaCanvas.drawPath(connecticutPath, connecticutPaint, onTapUp: (tabdetail) {
      callback('connecticut', tabdetail);
    });

    Path delawarePath = Path();
    delawarePath.moveTo(size.width * 0.8573514, size.height * 0.3821248);
    delawarePath.lineTo(size.width * 0.8556830, size.height * 0.3826307);
    delawarePath.lineTo(size.width * 0.8541189, size.height * 0.3844857);
    delawarePath.lineTo(size.width * 0.8528676, size.height * 0.3880270);
    delawarePath.lineTo(size.width * 0.8607925, size.height * 0.4337268);
    delawarePath.lineTo(size.width * 0.8721585, size.height * 0.4298482);
    delawarePath.lineTo(size.width * 0.8698644, size.height * 0.4170320);
    delawarePath.lineTo(size.width * 0.8687174, size.height * 0.4178752);
    delawarePath.lineTo(size.width * 0.8652763, size.height * 0.4134907);
    delawarePath.lineTo(size.width * 0.8647550, size.height * 0.4106239);
    delawarePath.lineTo(size.width * 0.8628780, size.height * 0.4089376);
    delawarePath.lineTo(size.width * 0.8626694, size.height * 0.4026981);
    delawarePath.lineTo(size.width * 0.8604797, size.height * 0.3989882);
    delawarePath.lineTo(size.width * 0.8593326, size.height * 0.3976391);
    delawarePath.lineTo(size.width * 0.8580813, size.height * 0.3957841);
    delawarePath.lineTo(size.width * 0.8576642, size.height * 0.3903879);
    delawarePath.lineTo(size.width * 0.8579771, size.height * 0.3868465);
    delawarePath.lineTo(size.width * 0.8590198, size.height * 0.3831366);
    delawarePath.close();

    Paint delawarePaint = Paint()..style = PaintingStyle.fill;
    delawarePaint.color = usaColors.delaware ?? defaultColor;
    usaCanvas.drawPath(delawarePath, delawarePaint, onTapUp: (tabdetail) {
      callback('delaware', tabdetail);
    });

    Path floridaPath = Path();
    floridaPath.moveTo(size.width * 0.7838373, size.height * 0.7505902);
    floridaPath.lineTo(size.width * 0.7796663, size.height * 0.7494098);
    floridaPath.lineTo(size.width * 0.7778936, size.height * 0.7478921);
    floridaPath.lineTo(size.width * 0.7755996, size.height * 0.7502530);
    floridaPath.lineTo(size.width * 0.7755996, size.height * 0.7544688);
    floridaPath.lineTo(size.width * 0.7770594, size.height * 0.7580101);
    floridaPath.lineTo(size.width * 0.7765381, size.height * 0.7652614);
    floridaPath.lineTo(size.width * 0.7743483, size.height * 0.7662732);
    floridaPath.lineTo(size.width * 0.7733055, size.height * 0.7644182);
    floridaPath.lineTo(size.width * 0.7726799, size.height * 0.7590219);
    floridaPath.lineTo(size.width * 0.7204380, size.height * 0.7645868);
    floridaPath.lineTo(size.width * 0.7169969, size.height * 0.7544688);
    floridaPath.lineTo(size.width * 0.6661105, size.height * 0.7630691);
    floridaPath.lineTo(size.width * 0.6655892, size.height * 0.7679595);
    floridaPath.lineTo(size.width * 0.6681960, size.height * 0.7726813);
    floridaPath.lineTo(size.width * 0.6699687, size.height * 0.7738617);
    floridaPath.lineTo(size.width * 0.6709072, size.height * 0.7758853);
    floridaPath.lineTo(size.width * 0.6704901, size.height * 0.7881956);
    floridaPath.lineTo(size.width * 0.6693431, size.height * 0.7892074);
    floridaPath.lineTo(size.width * 0.6698644, size.height * 0.7898820);
    floridaPath.lineTo(size.width * 0.6709072, size.height * 0.7893761);
    floridaPath.lineTo(size.width * 0.6716371, size.height * 0.7880270);
    floridaPath.lineTo(size.width * 0.6825860, size.height * 0.7834739);
    floridaPath.lineTo(size.width * 0.6921794, size.height * 0.7826307);
    floridaPath.lineTo(size.width * 0.7006257, size.height * 0.7858347);
    floridaPath.lineTo(size.width * 0.7094891, size.height * 0.7942664);
    floridaPath.lineTo(size.width * 0.7119917, size.height * 0.7956155);
    floridaPath.lineTo(size.width * 0.7142857, size.height * 0.7989882);
    floridaPath.lineTo(size.width * 0.7141814, size.height * 0.8035413);
    floridaPath.lineTo(size.width * 0.7166840, size.height * 0.8035413);
    floridaPath.lineTo(size.width * 0.7186653, size.height * 0.8018550);
    floridaPath.lineTo(size.width * 0.7212722, size.height * 0.8020236);
    floridaPath.lineTo(size.width * 0.7233577, size.height * 0.8006745);
    floridaPath.lineTo(size.width * 0.7263816, size.height * 0.7973019);
    floridaPath.lineTo(size.width * 0.7296142, size.height * 0.7924115);
    floridaPath.lineTo(size.width * 0.7307612, size.height * 0.7917369);
    floridaPath.lineTo(size.width * 0.7313869, size.height * 0.7925801);
    floridaPath.lineTo(size.width * 0.7328467, size.height * 0.7925801);
    floridaPath.lineTo(size.width * 0.7333681, size.height * 0.7912310);
    floridaPath.lineTo(size.width * 0.7328467, size.height * 0.7892074);
    floridaPath.lineTo(size.width * 0.7322211, size.height * 0.7881956);
    floridaPath.lineTo(size.width * 0.7324296, size.height * 0.7868465);
    floridaPath.lineTo(size.width * 0.7345151, size.height * 0.7849916);
    floridaPath.lineTo(size.width * 0.7397289, size.height * 0.7843170);
    floridaPath.lineTo(size.width * 0.7405631, size.height * 0.7860034);
    floridaPath.lineTo(size.width * 0.7416058, size.height * 0.7861720);
    floridaPath.lineTo(size.width * 0.7440042, size.height * 0.7878583);
    floridaPath.lineTo(size.width * 0.7471324, size.height * 0.7908938);
    floridaPath.lineTo(size.width * 0.7483837, size.height * 0.7937605);
    floridaPath.lineTo(size.width * 0.7495308, size.height * 0.7957841);
    floridaPath.lineTo(size.width * 0.7524505, size.height * 0.7981450);
    floridaPath.lineTo(size.width * 0.7524505, size.height * 0.8021922);
    floridaPath.lineTo(size.width * 0.7553702, size.height * 0.8053963);
    floridaPath.lineTo(size.width * 0.7564129, size.height * 0.8055649);
    floridaPath.lineTo(size.width * 0.7580813, size.height * 0.8079258);
    floridaPath.lineTo(size.width * 0.7588113, size.height * 0.8106239);
    floridaPath.lineTo(size.width * 0.7598540, size.height * 0.8109612);
    floridaPath.lineTo(size.width * 0.7606882, size.height * 0.8145025);
    floridaPath.lineTo(size.width * 0.7614181, size.height * 0.8155143);
    floridaPath.lineTo(size.width * 0.7624609, size.height * 0.8136594);
    floridaPath.lineTo(size.width * 0.7654849, size.height * 0.8138280);
    floridaPath.lineTo(size.width * 0.7660063, size.height * 0.8161889);
    floridaPath.lineTo(size.width * 0.7671533, size.height * 0.8177066);
    floridaPath.lineTo(size.width * 0.7671533, size.height * 0.8198988);
    floridaPath.lineTo(size.width * 0.7701773, size.height * 0.8236088);
    floridaPath.lineTo(size.width * 0.7703858, size.height * 0.8397976);
    floridaPath.lineTo(size.width * 0.7685089, size.height * 0.8495784);
    floridaPath.lineTo(size.width * 0.7695516, size.height * 0.8516020);
    floridaPath.lineTo(size.width * 0.7693431, size.height * 0.8573356);
    floridaPath.lineTo(size.width * 0.7685089, size.height * 0.8596965);
    floridaPath.lineTo(size.width * 0.7692388, size.height * 0.8617201);
    floridaPath.lineTo(size.width * 0.7716371, size.height * 0.8655987);
    floridaPath.lineTo(size.width * 0.7719499, size.height * 0.8681282);
    floridaPath.lineTo(size.width * 0.7727842, size.height * 0.8698145);
    floridaPath.lineTo(size.width * 0.7723670, size.height * 0.8666105);
    floridaPath.lineTo(size.width * 0.7737226, size.height * 0.8655987);
    floridaPath.lineTo(size.width * 0.7745568, size.height * 0.8595278);
    floridaPath.lineTo(size.width * 0.7714286, size.height * 0.8575042);
    floridaPath.lineTo(size.width * 0.7715328, size.height * 0.8564924);
    floridaPath.lineTo(size.width * 0.7742440, size.height * 0.8558179);
    floridaPath.lineTo(size.width * 0.7751825, size.height * 0.8602024);
    floridaPath.lineTo(size.width * 0.7763295, size.height * 0.8612142);
    floridaPath.lineTo(size.width * 0.7764338, size.height * 0.8578415);
    floridaPath.lineTo(size.width * 0.7775808, size.height * 0.8583474);
    floridaPath.lineTo(size.width * 0.7782065, size.height * 0.8596965);
    floridaPath.lineTo(size.width * 0.7781022, size.height * 0.8608769);
    floridaPath.lineTo(size.width * 0.7750782, size.height * 0.8679595);
    floridaPath.lineTo(size.width * 0.7748697, size.height * 0.8698145);
    floridaPath.lineTo(size.width * 0.7730970, size.height * 0.8730185);
    floridaPath.lineTo(size.width * 0.7730970, size.height * 0.8748735);
    floridaPath.lineTo(size.width * 0.7769552, size.height * 0.8812816);
    floridaPath.lineTo(size.width * 0.7824818, size.height * 0.8946037);
    floridaPath.lineTo(size.width * 0.7843587, size.height * 0.8981450);
    floridaPath.lineTo(size.width * 0.7843587, size.height * 0.9011804);
    floridaPath.lineTo(size.width * 0.7872784, size.height * 0.9089376);
    floridaPath.lineTo(size.width * 0.7896767, size.height * 0.9099494);
    floridaPath.lineTo(size.width * 0.7904067, size.height * 0.9079258);
    floridaPath.lineTo(size.width * 0.7882169, size.height * 0.9084317);
    floridaPath.lineTo(size.width * 0.7850886, size.height * 0.9008432);
    floridaPath.lineTo(size.width * 0.7852972, size.height * 0.8984823);
    floridaPath.lineTo(size.width * 0.7868613, size.height * 0.8971332);
    floridaPath.lineTo(size.width * 0.7868613, size.height * 0.8946037);
    floridaPath.lineTo(size.width * 0.7862357, size.height * 0.8924115);
    floridaPath.lineTo(size.width * 0.7871741, size.height * 0.8908938);
    floridaPath.lineTo(size.width * 0.7875912, size.height * 0.8924115);
    floridaPath.lineTo(size.width * 0.7883212, size.height * 0.8932546);
    floridaPath.lineTo(size.width * 0.7883212, size.height * 0.9000000);
    floridaPath.lineTo(size.width * 0.7870699, size.height * 0.8989882);
    floridaPath.lineTo(size.width * 0.7862357, size.height * 0.9005059);
    floridaPath.lineTo(size.width * 0.7876955, size.height * 0.9032040);
    floridaPath.lineTo(size.width * 0.7887383, size.height * 0.9075885);
    floridaPath.lineTo(size.width * 0.7899896, size.height * 0.9065767);
    floridaPath.lineTo(size.width * 0.7923879, size.height * 0.9086003);
    floridaPath.lineTo(size.width * 0.7945777, size.height * 0.9123103);
    floridaPath.lineTo(size.width * 0.7962461, size.height * 0.9209106);
    floridaPath.lineTo(size.width * 0.7994786, size.height * 0.9290051);
    floridaPath.lineTo(size.width * 0.8003128, size.height * 0.9268128);
    floridaPath.lineTo(size.width * 0.8032325, size.height * 0.9259696);
    floridaPath.lineTo(size.width * 0.8065693, size.height * 0.9281619);
    floridaPath.lineTo(size.width * 0.8068822, size.height * 0.9310287);
    floridaPath.lineTo(size.width * 0.8103233, size.height * 0.9374368);
    floridaPath.lineTo(size.width * 0.8104275, size.height * 0.9392917);
    floridaPath.lineTo(size.width * 0.8127216, size.height * 0.9438449);
    floridaPath.lineTo(size.width * 0.8119917, size.height * 0.9446880);
    floridaPath.lineTo(size.width * 0.8119917, size.height * 0.9492411);
    floridaPath.lineTo(size.width * 0.8148071, size.height * 0.9516020);
    floridaPath.lineTo(size.width * 0.8163712, size.height * 0.9516020);
    floridaPath.lineTo(size.width * 0.8191867, size.height * 0.9485666);
    floridaPath.lineTo(size.width * 0.8207508, size.height * 0.9490725);
    floridaPath.lineTo(size.width * 0.8218978, size.height * 0.9497470);
    floridaPath.lineTo(size.width * 0.8242961, size.height * 0.9468803);
    floridaPath.lineTo(size.width * 0.8245047, size.height * 0.9456998);
    floridaPath.lineTo(size.width * 0.8257560, size.height * 0.9462057);
    floridaPath.lineTo(size.width * 0.8282586, size.height * 0.9433390);
    floridaPath.lineTo(size.width * 0.8296142, size.height * 0.9394604);
    floridaPath.lineTo(size.width * 0.8288843, size.height * 0.9340641);
    floridaPath.lineTo(size.width * 0.8286757, size.height * 0.9318718);
    floridaPath.lineTo(size.width * 0.8298227, size.height * 0.9251265);
    floridaPath.lineTo(size.width * 0.8304484, size.height * 0.9247892);
    floridaPath.lineTo(size.width * 0.8310740, size.height * 0.9274874);
    floridaPath.lineTo(size.width * 0.8319082, size.height * 0.9244519);
    floridaPath.lineTo(size.width * 0.8310740, size.height * 0.9123103);
    floridaPath.lineTo(size.width * 0.8306569, size.height * 0.8946037);
    floridaPath.lineTo(size.width * 0.8296142, size.height * 0.8831366);
    floridaPath.lineTo(size.width * 0.8288843, size.height * 0.8802698);
    floridaPath.lineTo(size.width * 0.8220021, size.height * 0.8615514);
    floridaPath.lineTo(size.width * 0.8165798, size.height * 0.8462057);
    floridaPath.lineTo(size.width * 0.8142857, size.height * 0.8406408);
    floridaPath.lineTo(size.width * 0.8129301, size.height * 0.8345700);
    floridaPath.lineTo(size.width * 0.8127216, size.height * 0.8288364);
    floridaPath.lineTo(size.width * 0.8136601, size.height * 0.8283305);
    floridaPath.lineTo(size.width * 0.8136601, size.height * 0.8268128);
    floridaPath.lineTo(size.width * 0.8125130, size.height * 0.8231029);
    floridaPath.lineTo(size.width * 0.8083420, size.height * 0.8163575);
    floridaPath.lineTo(size.width * 0.8004171, size.height * 0.8000000);
    floridaPath.lineTo(size.width * 0.7944734, size.height * 0.7824621);
    floridaPath.lineTo(size.width * 0.7899896, size.height * 0.7644182);
    floridaPath.lineTo(size.width * 0.7893639, size.height * 0.7581788);
    floridaPath.lineTo(size.width * 0.7881126, size.height * 0.7564924);
    floridaPath.lineTo(size.width * 0.7875912, size.height * 0.7500843);
    floridaPath.close();
    floridaPath.moveTo(size.width * 0.7934307, size.height * 0.9774030);
    floridaPath.lineTo(size.width * 0.7952033, size.height * 0.9772344);
    floridaPath.lineTo(size.width * 0.7944734, size.height * 0.9755481);
    floridaPath.close();
    floridaPath.moveTo(size.width * 0.8010428, size.height * 0.9755481);
    floridaPath.lineTo(size.width * 0.8010428, size.height * 0.9743676);
    floridaPath.lineTo(size.width * 0.8027112, size.height * 0.9740304);
    floridaPath.lineTo(size.width * 0.8065693, size.height * 0.9684654);
    floridaPath.lineTo(size.width * 0.8081335, size.height * 0.9674536);
    floridaPath.lineTo(size.width * 0.8106361, size.height * 0.9659359);
    floridaPath.lineTo(size.width * 0.8109489, size.height * 0.9681282);
    floridaPath.lineTo(size.width * 0.8127216, size.height * 0.9694772);
    floridaPath.lineTo(size.width * 0.8100104, size.height * 0.9715008);
    floridaPath.lineTo(size.width * 0.8075078, size.height * 0.9715008);
    floridaPath.lineTo(size.width * 0.8034411, size.height * 0.9757167);
    floridaPath.close();
    floridaPath.moveTo(size.width * 0.8189781, size.height * 0.9627319);
    floridaPath.lineTo(size.width * 0.8158498, size.height * 0.9650927);
    floridaPath.lineTo(size.width * 0.8148071, size.height * 0.9672850);
    floridaPath.lineTo(size.width * 0.8159541, size.height * 0.9674536);
    floridaPath.close();
    floridaPath.moveTo(size.width * 0.8229406, size.height * 0.9578415);
    floridaPath.lineTo(size.width * 0.8217935, size.height * 0.9583474);
    floridaPath.lineTo(size.width * 0.8203337, size.height * 0.9617201);
    floridaPath.lineTo(size.width * 0.8214807, size.height * 0.9613828);
    floridaPath.lineTo(size.width * 0.8230448, size.height * 0.9586847);
    floridaPath.close();
    floridaPath.moveTo(size.width * 0.8315954, size.height * 0.9313659);
    floridaPath.lineTo(size.width * 0.8298227, size.height * 0.9408094);
    floridaPath.lineTo(size.width * 0.8289885, size.height * 0.9424958);
    floridaPath.lineTo(size.width * 0.8279458, size.height * 0.9468803);
    floridaPath.lineTo(size.width * 0.8266945, size.height * 0.9495784);
    floridaPath.lineTo(size.width * 0.8259645, size.height * 0.9524452);
    floridaPath.lineTo(size.width * 0.8239833, size.height * 0.9561551);
    floridaPath.lineTo(size.width * 0.8239833, size.height * 0.9576728);
    floridaPath.lineTo(size.width * 0.8267987, size.height * 0.9529511);
    floridaPath.lineTo(size.width * 0.8293014, size.height * 0.9470489);
    floridaPath.lineTo(size.width * 0.8299270, size.height * 0.9436762);
    floridaPath.lineTo(size.width * 0.8321168, size.height * 0.9354132);
    floridaPath.close();

    Paint floridaPaint = Paint()..style = PaintingStyle.fill;
    floridaPaint.color = usaColors.florida ?? defaultColor;
    usaCanvas.drawPath(floridaPath, floridaPaint, onTapUp: (tabdetail) {
      callback('florida', tabdetail);
    });

    Path georgiaPath = Path();
    georgiaPath.moveTo(size.width * 0.7943691, size.height * 0.6983137);
    georgiaPath.lineTo(size.width * 0.7943691, size.height * 0.7006745);
    georgiaPath.lineTo(size.width * 0.7899896, size.height * 0.7111298);
    georgiaPath.lineTo(size.width * 0.7887383, size.height * 0.7114671);
    georgiaPath.lineTo(size.width * 0.7903024, size.height * 0.7123103);
    georgiaPath.lineTo(size.width * 0.7903024, size.height * 0.7156830);
    georgiaPath.lineTo(size.width * 0.7893639, size.height * 0.7175379);
    georgiaPath.lineTo(size.width * 0.7887383, size.height * 0.7276560);
    georgiaPath.lineTo(size.width * 0.7863399, size.height * 0.7381113);
    georgiaPath.lineTo(size.width * 0.7868613, size.height * 0.7414840);
    georgiaPath.lineTo(size.width * 0.7875912, size.height * 0.7500843);
    georgiaPath.lineTo(size.width * 0.7838373, size.height * 0.7505902);
    georgiaPath.lineTo(size.width * 0.7796663, size.height * 0.7494098);
    georgiaPath.lineTo(size.width * 0.7778936, size.height * 0.7478921);
    georgiaPath.lineTo(size.width * 0.7755996, size.height * 0.7502530);
    georgiaPath.lineTo(size.width * 0.7755996, size.height * 0.7544688);
    georgiaPath.lineTo(size.width * 0.7770594, size.height * 0.7580101);
    georgiaPath.lineTo(size.width * 0.7765381, size.height * 0.7652614);
    georgiaPath.lineTo(size.width * 0.7743483, size.height * 0.7662732);
    georgiaPath.lineTo(size.width * 0.7733055, size.height * 0.7644182);
    georgiaPath.lineTo(size.width * 0.7726799, size.height * 0.7590219);
    georgiaPath.lineTo(size.width * 0.7204380, size.height * 0.7645868);
    georgiaPath.lineTo(size.width * 0.7169969, size.height * 0.7544688);
    georgiaPath.lineTo(size.width * 0.7162669, size.height * 0.7507589);
    georgiaPath.lineTo(size.width * 0.7147028, size.height * 0.7482293);
    georgiaPath.lineTo(size.width * 0.7141814, size.height * 0.7458685);
    georgiaPath.lineTo(size.width * 0.7148071, size.height * 0.7352445);
    georgiaPath.lineTo(size.width * 0.7123045, size.height * 0.7256324);
    georgiaPath.lineTo(size.width * 0.7128259, size.height * 0.7212479);
    georgiaPath.lineTo(size.width * 0.7131387, size.height * 0.7150084);
    georgiaPath.lineTo(size.width * 0.7154327, size.height * 0.7086003);
    georgiaPath.lineTo(size.width * 0.7152242, size.height * 0.7067454);
    georgiaPath.lineTo(size.width * 0.7134515, size.height * 0.7050590);
    georgiaPath.lineTo(size.width * 0.7134515, size.height * 0.6996627);
    georgiaPath.lineTo(size.width * 0.7115746, size.height * 0.6964587);
    georgiaPath.lineTo(size.width * 0.7085506, size.height * 0.6861720);
    georgiaPath.lineTo(size.width * 0.6950991, size.height * 0.6089376);
    georgiaPath.lineTo(size.width * 0.7189781, size.height * 0.6040472);
    georgiaPath.lineTo(size.width * 0.7412930, size.height * 0.5989882);
    georgiaPath.lineTo(size.width * 0.7411887, size.height * 0.6021922);
    georgiaPath.lineTo(size.width * 0.7392075, size.height * 0.6038786);
    georgiaPath.lineTo(size.width * 0.7377477, size.height * 0.6092749);
    georgiaPath.lineTo(size.width * 0.7379562, size.height * 0.6114671);
    georgiaPath.lineTo(size.width * 0.7443170, size.height * 0.6178752);
    georgiaPath.lineTo(size.width * 0.7470282, size.height * 0.6173693);
    georgiaPath.lineTo(size.width * 0.7502607, size.height * 0.6241147);
    georgiaPath.lineTo(size.width * 0.7506778, size.height * 0.6269815);
    georgiaPath.lineTo(size.width * 0.7550574, size.height * 0.6355818);
    georgiaPath.lineTo(size.width * 0.7577685, size.height * 0.6384486);
    georgiaPath.lineTo(size.width * 0.7592284, size.height * 0.6387858);
    georgiaPath.lineTo(size.width * 0.7615224, size.height * 0.6414840);
    georgiaPath.lineTo(size.width * 0.7626694, size.height * 0.6451939);
    georgiaPath.lineTo(size.width * 0.7647550, size.height * 0.6478921);
    georgiaPath.lineTo(size.width * 0.7666319, size.height * 0.6487352);
    georgiaPath.lineTo(size.width * 0.7694473, size.height * 0.6532884);
    georgiaPath.lineTo(size.width * 0.7695516, size.height * 0.6556492);
    georgiaPath.lineTo(size.width * 0.7722628, size.height * 0.6603710);
    georgiaPath.lineTo(size.width * 0.7774765, size.height * 0.6642496);
    georgiaPath.lineTo(size.width * 0.7812304, size.height * 0.6755481);
    georgiaPath.lineTo(size.width * 0.7815433, size.height * 0.6801012);
    georgiaPath.lineTo(size.width * 0.7856100, size.height * 0.6836425);
    georgiaPath.lineTo(size.width * 0.7882169, size.height * 0.6917369);
    georgiaPath.lineTo(size.width * 0.7890511, size.height * 0.6969646);
    georgiaPath.lineTo(size.width * 0.7934307, size.height * 0.6976391);
    georgiaPath.close();

    Paint georgiaPaint = Paint()..style = PaintingStyle.fill;
    georgiaPaint.color = usaColors.georgia ?? defaultColor;
    usaCanvas.drawPath(georgiaPath, georgiaPaint, onTapUp: (tabdetail) {
      callback('georgia', tabdetail);
    });

    Path hawaiiPath = Path();
    hawaiiPath.moveTo(size.width * 0.3305527, size.height * 0.9337268);
    hawaiiPath.lineTo(size.width * 0.3303441, size.height * 0.9391231);
    hawaiiPath.lineTo(size.width * 0.3321168, size.height * 0.9423272);
    hawaiiPath.lineTo(size.width * 0.3322211, size.height * 0.9443508);
    hawaiiPath.lineTo(size.width * 0.3272158, size.height * 0.9519393);
    hawaiiPath.lineTo(size.width * 0.3271116, size.height * 0.9539629);
    hawaiiPath.lineTo(size.width * 0.3290928, size.height * 0.9593592);
    hawaiiPath.lineTo(size.width * 0.3308655, size.height * 0.9664418);
    hawaiiPath.lineTo(size.width * 0.3308655, size.height * 0.9708263);
    hawaiiPath.lineTo(size.width * 0.3303441, size.height * 0.9728499);
    hawaiiPath.lineTo(size.width * 0.3304484, size.height * 0.9785835);
    hawaiiPath.lineTo(size.width * 0.3347237, size.height * 0.9821248);
    hawaiiPath.lineTo(size.width * 0.3358707, size.height * 0.9839798);
    hawaiiPath.lineTo(size.width * 0.3371220, size.height * 0.9821248);
    hawaiiPath.lineTo(size.width * 0.3393118, size.height * 0.9760540);
    hawaiiPath.lineTo(size.width * 0.3440042, size.height * 0.9711636);
    hawaiiPath.lineTo(size.width * 0.3474453, size.height * 0.9703204);
    hawaiiPath.lineTo(size.width * 0.3500521, size.height * 0.9686341);
    hawaiiPath.lineTo(size.width * 0.3518248, size.height * 0.9666105);
    hawaiiPath.lineTo(size.width * 0.3551616, size.height * 0.9607083);
    hawaiiPath.lineTo(size.width * 0.3522419, size.height * 0.9588533);
    hawaiiPath.lineTo(size.width * 0.3507821, size.height * 0.9564924);
    hawaiiPath.lineTo(size.width * 0.3508863, size.height * 0.9536256);
    hawaiiPath.lineTo(size.width * 0.3503650, size.height * 0.9526138);
    hawaiiPath.lineTo(size.width * 0.3482795, size.height * 0.9526138);
    hawaiiPath.lineTo(size.width * 0.3484880, size.height * 0.9483980);
    hawaiiPath.lineTo(size.width * 0.3477581, size.height * 0.9463744);
    hawaiiPath.lineTo(size.width * 0.3450469, size.height * 0.9424958);
    hawaiiPath.lineTo(size.width * 0.3403545, size.height * 0.9392917);
    hawaiiPath.lineTo(size.width * 0.3374348, size.height * 0.9389545);
    hawaiiPath.lineTo(size.width * 0.3339937, size.height * 0.9344013);
    hawaiiPath.lineTo(size.width * 0.3327424, size.height * 0.9333895);
    hawaiiPath.close();
    hawaiiPath.moveTo(size.width * 0.3145985, size.height * 0.9050590);
    hawaiiPath.lineTo(size.width * 0.3134515, size.height * 0.9075885);
    hawaiiPath.lineTo(size.width * 0.3133472, size.height * 0.9104553);
    hawaiiPath.lineTo(size.width * 0.3161627, size.height * 0.9145025);
    hawaiiPath.lineTo(size.width * 0.3181439, size.height * 0.9153457);
    hawaiiPath.lineTo(size.width * 0.3187696, size.height * 0.9170320);
    hawaiiPath.lineTo(size.width * 0.3191867, size.height * 0.9220911);
    hawaiiPath.lineTo(size.width * 0.3229406, size.height * 0.9224283);
    hawaiiPath.lineTo(size.width * 0.3284672, size.height * 0.9180438);
    hawaiiPath.lineTo(size.width * 0.3283629, size.height * 0.9138280);
    hawaiiPath.lineTo(size.width * 0.3269030, size.height * 0.9129848);
    hawaiiPath.lineTo(size.width * 0.3232534, size.height * 0.9086003);
    hawaiiPath.lineTo(size.width * 0.3213764, size.height * 0.9080944);
    hawaiiPath.lineTo(size.width * 0.3183525, size.height * 0.9102867);
    hawaiiPath.lineTo(size.width * 0.3167883, size.height * 0.9057336);
    hawaiiPath.close();
    hawaiiPath.moveTo(size.width * 0.3130344, size.height * 0.9244519);
    hawaiiPath.lineTo(size.width * 0.3139729, size.height * 0.9220911);
    hawaiiPath.lineTo(size.width * 0.3165798, size.height * 0.9215852);
    hawaiiPath.lineTo(size.width * 0.3172054, size.height * 0.9246206);
    hawaiiPath.close();
    hawaiiPath.moveTo(size.width * 0.3057351, size.height * 0.9097808);
    hawaiiPath.lineTo(size.width * 0.3075078, size.height * 0.9165261);
    hawaiiPath.lineTo(size.width * 0.3107404, size.height * 0.9155143);
    hawaiiPath.lineTo(size.width * 0.3110532, size.height * 0.9121417);
    hawaiiPath.lineTo(size.width * 0.3095933, size.height * 0.9096121);
    hawaiiPath.close();
    hawaiiPath.moveTo(size.width * 0.3014599, size.height * 0.8984823);
    hawaiiPath.lineTo(size.width * 0.3003128, size.height * 0.9025295);
    hawaiiPath.lineTo(size.width * 0.3055266, size.height * 0.9025295);
    hawaiiPath.lineTo(size.width * 0.3105318, size.height * 0.9052277);
    hawaiiPath.lineTo(size.width * 0.3131387, size.height * 0.9025295);
    hawaiiPath.lineTo(size.width * 0.3133472, size.height * 0.9000000);
    hawaiiPath.lineTo(size.width * 0.3083420, size.height * 0.9003373);
    hawaiiPath.close();
    hawaiiPath.moveTo(size.width * 0.2847758, size.height * 0.8806071);
    hawaiiPath.lineTo(size.width * 0.2827946, size.height * 0.8841484);
    hawaiiPath.lineTo(size.width * 0.2797706, size.height * 0.8851602);
    hawaiiPath.lineTo(size.width * 0.2806048, size.height * 0.8888702);
    hawaiiPath.lineTo(size.width * 0.2828989, size.height * 0.8935919);
    hawaiiPath.lineTo(size.width * 0.2830031, size.height * 0.8952782);
    hawaiiPath.lineTo(size.width * 0.2851929, size.height * 0.8947723);
    hawaiiPath.lineTo(size.width * 0.2875912, size.height * 0.8949410);
    hawaiiPath.lineTo(size.width * 0.2893639, size.height * 0.8969646);
    hawaiiPath.lineTo(size.width * 0.2930136, size.height * 0.8956155);
    hawaiiPath.lineTo(size.width * 0.2930136, size.height * 0.8944351);
    hawaiiPath.lineTo(size.width * 0.2919708, size.height * 0.8930860);
    hawaiiPath.lineTo(size.width * 0.2914494, size.height * 0.8895447);
    hawaiiPath.lineTo(size.width * 0.2906152, size.height * 0.8890388);
    hawaiiPath.lineTo(size.width * 0.2900938, size.height * 0.8907251);
    hawaiiPath.lineTo(size.width * 0.2888425, size.height * 0.8885329);
    hawaiiPath.lineTo(size.width * 0.2890511, size.height * 0.8861720);
    hawaiiPath.lineTo(size.width * 0.2871741, size.height * 0.8806071);
    hawaiiPath.lineTo(size.width * 0.2860271, size.height * 0.8794266);
    hawaiiPath.close();
    hawaiiPath.moveTo(size.width * 0.2516163, size.height * 0.8596965);
    hawaiiPath.lineTo(size.width * 0.2472367, size.height * 0.8645868);
    hawaiiPath.lineTo(size.width * 0.2474453, size.height * 0.8684654);
    hawaiiPath.lineTo(size.width * 0.2499479, size.height * 0.8704890);
    hawaiiPath.lineTo(size.width * 0.2519291, size.height * 0.8726813);
    hawaiiPath.lineTo(size.width * 0.2547445, size.height * 0.8733558);
    hawaiiPath.lineTo(size.width * 0.2574557, size.height * 0.8696459);
    hawaiiPath.lineTo(size.width * 0.2572471, size.height * 0.8664418);
    hawaiiPath.lineTo(size.width * 0.2580813, size.height * 0.8635750);
    hawaiiPath.lineTo(size.width * 0.2580813, size.height * 0.8612142);
    hawaiiPath.lineTo(size.width * 0.2570386, size.height * 0.8596965);
    hawaiiPath.close();
    hawaiiPath.moveTo(size.width * 0.2403545, size.height * 0.8677909);
    hawaiiPath.lineTo(size.width * 0.2400417, size.height * 0.8698145);
    hawaiiPath.lineTo(size.width * 0.2380605, size.height * 0.8713322);
    hawaiiPath.lineTo(size.width * 0.2374348, size.height * 0.8743676);
    hawaiiPath.lineTo(size.width * 0.2384776, size.height * 0.8757167);
    hawaiiPath.lineTo(size.width * 0.2396246, size.height * 0.8731872);
    hawaiiPath.lineTo(size.width * 0.2416058, size.height * 0.8721754);
    hawaiiPath.lineTo(size.width * 0.2420229, size.height * 0.8677909);
    hawaiiPath.close();

    Paint hawaiiPaint = Paint()..style = PaintingStyle.fill;
    hawaiiPaint.color = usaColors.hawaii ?? defaultColor;
    usaCanvas.drawPath(hawaiiPath, hawaiiPaint, onTapUp: (tabdetail) {
      callback('hawaii', tabdetail);
    });

    Path idahoPath = Path();
    idahoPath.moveTo(size.width * 0.1723670, size.height * 0.3087690);
    idahoPath.lineTo(size.width * 0.1469239, size.height * 0.2996627);
    idahoPath.lineTo(size.width * 0.1557873, size.height * 0.2367622);
    idahoPath.lineTo(size.width * 0.1588113, size.height * 0.2269815);
    idahoPath.lineTo(size.width * 0.1592284, size.height * 0.2234401);
    idahoPath.lineTo(size.width * 0.1600626, size.height * 0.2219224);
    idahoPath.lineTo(size.width * 0.1591241, size.height * 0.2185497);
    idahoPath.lineTo(size.width * 0.1561001, size.height * 0.2165261);
    idahoPath.lineTo(size.width * 0.1563087, size.height * 0.2094435);
    idahoPath.lineTo(size.width * 0.1604797, size.height * 0.1996627);
    idahoPath.lineTo(size.width * 0.1630865, size.height * 0.1983137);
    idahoPath.lineTo(size.width * 0.1647550, size.height * 0.1944351);
    idahoPath.lineTo(size.width * 0.1646507, size.height * 0.1917369);
    idahoPath.lineTo(size.width * 0.1665276, size.height * 0.1890388);
    idahoPath.lineTo(size.width * 0.1698644, size.height * 0.1797639);
    idahoPath.lineTo(size.width * 0.1742440, size.height * 0.1716695);
    idahoPath.lineTo(size.width * 0.1737226, size.height * 0.1662732);
    idahoPath.lineTo(size.width * 0.1700730, size.height * 0.1610455);
    idahoPath.lineTo(size.width * 0.1684046, size.height * 0.1549747);
    idahoPath.lineTo(size.width * 0.1695516, size.height * 0.1477234);
    idahoPath.lineTo(size.width * 0.1688217, size.height * 0.1409781);
    idahoPath.lineTo(size.width * 0.1820647, size.height * 0.04637437);
    idahoPath.lineTo(size.width * 0.1968717, size.height * 0.05143339);
    idahoPath.lineTo(size.width * 0.1918665, size.height * 0.08853288);
    idahoPath.lineTo(size.width * 0.1957247, size.height * 0.1010118);
    idahoPath.lineTo(size.width * 0.1940563, size.height * 0.1091062);
    idahoPath.lineTo(size.width * 0.1978102, size.height * 0.1172007);
    idahoPath.lineTo(size.width * 0.1997914, size.height * 0.1183811);
    idahoPath.lineTo(size.width * 0.2038582, size.height * 0.1323777);
    idahoPath.lineTo(size.width * 0.2038582, size.height * 0.1359191);
    idahoPath.lineTo(size.width * 0.2062565, size.height * 0.1409781);
    idahoPath.lineTo(size.width * 0.2071950, size.height * 0.1409781);
    idahoPath.lineTo(size.width * 0.2086548, size.height * 0.1445194);
    idahoPath.lineTo(size.width * 0.2119917, size.height * 0.1445194);
    idahoPath.lineTo(size.width * 0.2119917, size.height * 0.1472175);
    idahoPath.lineTo(size.width * 0.2045881, size.height * 0.1758853);
    idahoPath.lineTo(size.width * 0.2040667, size.height * 0.1827993);
    idahoPath.lineTo(size.width * 0.2055266, size.height * 0.1836425);
    idahoPath.lineTo(size.width * 0.2071950, size.height * 0.1880270);
    idahoPath.lineTo(size.width * 0.2101147, size.height * 0.1856661);
    idahoPath.lineTo(size.width * 0.2138686, size.height * 0.1816189);
    idahoPath.lineTo(size.width * 0.2158498, size.height * 0.1848229);
    idahoPath.lineTo(size.width * 0.2163712, size.height * 0.1890388);
    idahoPath.lineTo(size.width * 0.2158498, size.height * 0.1944351);
    idahoPath.lineTo(size.width * 0.2184567, size.height * 0.2107926);
    idahoPath.lineTo(size.width * 0.2211679, size.height * 0.2166948);
    idahoPath.lineTo(size.width * 0.2235662, size.height * 0.2190556);
    idahoPath.lineTo(size.width * 0.2239833, size.height * 0.2241147);
    idahoPath.lineTo(size.width * 0.2239833, size.height * 0.2310287);
    idahoPath.lineTo(size.width * 0.2263816, size.height * 0.2349073);
    idahoPath.lineTo(size.width * 0.2280501, size.height * 0.2310287);
    idahoPath.lineTo(size.width * 0.2352450, size.height * 0.2337268);
    idahoPath.lineTo(size.width * 0.2374348, size.height * 0.2317032);
    idahoPath.lineTo(size.width * 0.2468196, size.height * 0.2345700);
    idahoPath.lineTo(size.width * 0.2497393, size.height * 0.2290051);
    idahoPath.lineTo(size.width * 0.2516163, size.height * 0.2279933);
    idahoPath.lineTo(size.width * 0.2528676, size.height * 0.2310287);
    idahoPath.lineTo(size.width * 0.2545360, size.height * 0.2379427);
    idahoPath.lineTo(size.width * 0.2554745, size.height * 0.2381113);
    idahoPath.lineTo(size.width * 0.2466111, size.height * 0.3305228);
    idahoPath.lineTo(size.width * 0.1966632, size.height * 0.3166948);
    idahoPath.close();

    Paint idahoPaint = Paint()..style = PaintingStyle.fill;
    idahoPaint.color = usaColors.idaho ?? defaultColor;
    usaCanvas.drawPath(idahoPath, idahoPaint, onTapUp: (tabdetail) {
      callback('idaho', tabdetail);
    });

    Path illinoisPath = Path();
    illinoisPath.moveTo(size.width * 0.6501564, size.height * 0.4483980);
    illinoisPath.lineTo(size.width * 0.6491137, size.height * 0.4571669);
    illinoisPath.lineTo(size.width * 0.6491137, size.height * 0.4605396);
    illinoisPath.lineTo(size.width * 0.6516163, size.height * 0.4664418);
    illinoisPath.lineTo(size.width * 0.6516163, size.height * 0.4676223);
    illinoisPath.lineTo(size.width * 0.6513034, size.height * 0.4691400);
    illinoisPath.lineTo(size.width * 0.6522419, size.height * 0.4723440);
    illinoisPath.lineTo(size.width * 0.6519291, size.height * 0.4763912);
    illinoisPath.lineTo(size.width * 0.6502607, size.height * 0.4794266);
    illinoisPath.lineTo(size.width * 0.6489051, size.height * 0.4865093);
    illinoisPath.lineTo(size.width * 0.6449426, size.height * 0.4954469);
    illinoisPath.lineTo(size.width * 0.6448384, size.height * 0.5072513);
    illinoisPath.lineTo(size.width * 0.6437956, size.height * 0.5072513);
    illinoisPath.lineTo(size.width * 0.6447341, size.height * 0.5104553);
    illinoisPath.lineTo(size.width * 0.6447341, size.height * 0.5119730);
    illinoisPath.lineTo(size.width * 0.6424400, size.height * 0.5165261);
    illinoisPath.lineTo(size.width * 0.6425443, size.height * 0.5183811);
    illinoisPath.lineTo(size.width * 0.6441084, size.height * 0.5220911);
    illinoisPath.lineTo(size.width * 0.6440042, size.height * 0.5236088);
    illinoisPath.lineTo(size.width * 0.6401460, size.height * 0.5246206);
    illinoisPath.lineTo(size.width * 0.6395203, size.height * 0.5266442);
    illinoisPath.lineTo(size.width * 0.6382690, size.height * 0.5256324);
    illinoisPath.lineTo(size.width * 0.6372263, size.height * 0.5264755);
    illinoisPath.lineTo(size.width * 0.6368092, size.height * 0.5320405);
    illinoisPath.lineTo(size.width * 0.6385819, size.height * 0.5350759);
    illinoisPath.lineTo(size.width * 0.6381648, size.height * 0.5391231);
    illinoisPath.lineTo(size.width * 0.6366006, size.height * 0.5396290);
    illinoisPath.lineTo(size.width * 0.6294056, size.height * 0.5345700);
    illinoisPath.lineTo(size.width * 0.6252346, size.height * 0.5408094);
    illinoisPath.lineTo(size.width * 0.6255474, size.height * 0.5438449);
    illinoisPath.lineTo(size.width * 0.6226277, size.height * 0.5438449);
    illinoisPath.lineTo(size.width * 0.6211679, size.height * 0.5413153);
    illinoisPath.lineTo(size.width * 0.6192909, size.height * 0.5349073);
    illinoisPath.lineTo(size.width * 0.6192909, size.height * 0.5317032);
    illinoisPath.lineTo(size.width * 0.6201251, size.height * 0.5306914);
    illinoisPath.lineTo(size.width * 0.6202294, size.height * 0.5284992);
    illinoisPath.lineTo(size.width * 0.6184567, size.height * 0.5252951);
    illinoisPath.lineTo(size.width * 0.6175182, size.height * 0.5210793);
    illinoisPath.lineTo(size.width * 0.6147028, size.height * 0.5141653);
    illinoisPath.lineTo(size.width * 0.6096976, size.height * 0.5119730);
    illinoisPath.lineTo(size.width * 0.6019812, size.height * 0.5000000);
    illinoisPath.lineTo(size.width * 0.6015641, size.height * 0.4959528);
    illinoisPath.lineTo(size.width * 0.6044838, size.height * 0.4831366);
    illinoisPath.lineTo(size.width * 0.6040667, size.height * 0.4799325);
    illinoisPath.lineTo(size.width * 0.6053180, size.height * 0.4780776);
    illinoisPath.lineTo(size.width * 0.6053180, size.height * 0.4758853);
    illinoisPath.lineTo(size.width * 0.6023983, size.height * 0.4733558);
    illinoisPath.lineTo(size.width * 0.5992701, size.height * 0.4721754);
    illinoisPath.lineTo(size.width * 0.5957247, size.height * 0.4741990);
    illinoisPath.lineTo(size.width * 0.5943691, size.height * 0.4703204);
    illinoisPath.lineTo(size.width * 0.5949948, size.height * 0.4671164);
    illinoisPath.lineTo(size.width * 0.5942649, size.height * 0.4630691);
    illinoisPath.lineTo(size.width * 0.5852972, size.height * 0.4489039);
    illinoisPath.lineTo(size.width * 0.5830031, size.height * 0.4463744);
    illinoisPath.lineTo(size.width * 0.5803962, size.height * 0.4364250);
    illinoisPath.lineTo(size.width * 0.5791449, size.height * 0.4273187);
    illinoisPath.lineTo(size.width * 0.5806048, size.height * 0.4210793);
    illinoisPath.lineTo(size.width * 0.5813347, size.height * 0.4198988);
    illinoisPath.lineTo(size.width * 0.5814390, size.height * 0.4160202);
    illinoisPath.lineTo(size.width * 0.5807091, size.height * 0.4145025);
    illinoisPath.lineTo(size.width * 0.5817518, size.height * 0.4119730);
    illinoisPath.lineTo(size.width * 0.5836288, size.height * 0.4109612);
    illinoisPath.lineTo(size.width * 0.5845673, size.height * 0.4104553);
    illinoisPath.lineTo(size.width * 0.5856100, size.height * 0.4084317);
    illinoisPath.lineTo(size.width * 0.5856100, size.height * 0.4043845);
    illinoisPath.lineTo(size.width * 0.5873827, size.height * 0.4003373);
    illinoisPath.lineTo(size.width * 0.5879041, size.height * 0.3994941);
    illinoisPath.lineTo(size.width * 0.5880083, size.height * 0.3935919);
    illinoisPath.lineTo(size.width * 0.5870699, size.height * 0.3912310);
    illinoisPath.lineTo(size.width * 0.5860271, size.height * 0.3907251);
    illinoisPath.lineTo(size.width * 0.5848801, size.height * 0.3880270);
    illinoisPath.lineTo(size.width * 0.5859228, size.height * 0.3812816);
    illinoisPath.lineTo(size.width * 0.5890511, size.height * 0.3799325);
    illinoisPath.lineTo(size.width * 0.5915537, size.height * 0.3799325);
    illinoisPath.lineTo(size.width * 0.5959333, size.height * 0.3768971);
    illinoisPath.lineTo(size.width * 0.5977059, size.height * 0.3731872);
    illinoisPath.lineTo(size.width * 0.5978102, size.height * 0.3691400);
    illinoisPath.lineTo(size.width * 0.5989572, size.height * 0.3669477);
    illinoisPath.lineTo(size.width * 0.6003128, size.height * 0.3615514);
    illinoisPath.lineTo(size.width * 0.6002086, size.height * 0.3571669);
    illinoisPath.lineTo(size.width * 0.5972888, size.height * 0.3512648);
    illinoisPath.lineTo(size.width * 0.5960375, size.height * 0.3512648);
    illinoisPath.lineTo(size.width * 0.5950991, size.height * 0.3494098);
    illinoisPath.lineTo(size.width * 0.5953076, size.height * 0.3467116);
    illinoisPath.lineTo(size.width * 0.5935349, size.height * 0.3438449);
    illinoisPath.lineTo(size.width * 0.5909281, size.height * 0.3416526);
    illinoisPath.lineTo(size.width * 0.5914494, size.height * 0.3406408);
    illinoisPath.lineTo(size.width * 0.6393118, size.height * 0.3359191);
    illinoisPath.lineTo(size.width * 0.6394161, size.height * 0.3436762);
    illinoisPath.lineTo(size.width * 0.6429614, size.height * 0.3514334);
    illinoisPath.lineTo(size.width * 0.6442127, size.height * 0.3583474);
    illinoisPath.lineTo(size.width * 0.6458811, size.height * 0.3637437);
    illinoisPath.close();

    Paint illinoisPaint = Paint()..style = PaintingStyle.fill;
    illinoisPaint.color = usaColors.illinois ?? defaultColor;
    usaCanvas.drawPath(illinoisPath, illinoisPaint, onTapUp: (tabdetail) {
      callback('illinois', tabdetail);
    });

    Path indianaPath = Path();
    indianaPath.moveTo(size.width * 0.6561001, size.height * 0.3622260);
    indianaPath.lineTo(size.width * 0.6507821, size.height * 0.3661046);
    indianaPath.lineTo(size.width * 0.6458811, size.height * 0.3637437);
    indianaPath.lineTo(size.width * 0.6501564, size.height * 0.4483980);
    indianaPath.lineTo(size.width * 0.6491137, size.height * 0.4571669);
    indianaPath.lineTo(size.width * 0.6491137, size.height * 0.4605396);
    indianaPath.lineTo(size.width * 0.6516163, size.height * 0.4664418);
    indianaPath.lineTo(size.width * 0.6516163, size.height * 0.4676223);
    indianaPath.lineTo(size.width * 0.6513034, size.height * 0.4691400);
    indianaPath.lineTo(size.width * 0.6522419, size.height * 0.4723440);
    indianaPath.lineTo(size.width * 0.6519291, size.height * 0.4763912);
    indianaPath.lineTo(size.width * 0.6502607, size.height * 0.4794266);
    indianaPath.lineTo(size.width * 0.6489051, size.height * 0.4865093);
    indianaPath.lineTo(size.width * 0.6449426, size.height * 0.4954469);
    indianaPath.lineTo(size.width * 0.6448384, size.height * 0.5072513);
    indianaPath.lineTo(size.width * 0.6437956, size.height * 0.5072513);
    indianaPath.lineTo(size.width * 0.6447341, size.height * 0.5104553);
    indianaPath.lineTo(size.width * 0.6458811, size.height * 0.5118044);
    indianaPath.lineTo(size.width * 0.6465068, size.height * 0.5101180);
    indianaPath.lineTo(size.width * 0.6457769, size.height * 0.5072513);
    indianaPath.lineTo(size.width * 0.6505735, size.height * 0.5064081);
    indianaPath.lineTo(size.width * 0.6507821, size.height * 0.5084317);
    indianaPath.lineTo(size.width * 0.6519291, size.height * 0.5087690);
    indianaPath.lineTo(size.width * 0.6523462, size.height * 0.5072513);
    indianaPath.lineTo(size.width * 0.6517205, size.height * 0.5050590);
    indianaPath.lineTo(size.width * 0.6520334, size.height * 0.5037099);
    indianaPath.lineTo(size.width * 0.6533889, size.height * 0.5050590);
    indianaPath.lineTo(size.width * 0.6551616, size.height * 0.5043845);
    indianaPath.lineTo(size.width * 0.6569343, size.height * 0.5053963);
    indianaPath.lineTo(size.width * 0.6604797, size.height * 0.5089376);
    indianaPath.lineTo(size.width * 0.6623566, size.height * 0.5042159);
    indianaPath.lineTo(size.width * 0.6660063, size.height * 0.5005059);
    indianaPath.lineTo(size.width * 0.6691345, size.height * 0.5060708);
    indianaPath.lineTo(size.width * 0.6708029, size.height * 0.5025295);
    indianaPath.lineTo(size.width * 0.6711157, size.height * 0.4979764);
    indianaPath.lineTo(size.width * 0.6750782, size.height * 0.4940978);
    indianaPath.lineTo(size.width * 0.6752868, size.height * 0.4962901);
    indianaPath.lineTo(size.width * 0.6772680, size.height * 0.4983137);
    indianaPath.lineTo(size.width * 0.6803962, size.height * 0.4979764);
    indianaPath.lineTo(size.width * 0.6816475, size.height * 0.4967960);
    indianaPath.lineTo(size.width * 0.6817518, size.height * 0.4910624);
    indianaPath.lineTo(size.width * 0.6843587, size.height * 0.4848229);
    indianaPath.lineTo(size.width * 0.6891554, size.height * 0.4774030);
    indianaPath.lineTo(size.width * 0.6890511, size.height * 0.4745363);
    indianaPath.lineTo(size.width * 0.6903024, size.height * 0.4681282);
    indianaPath.lineTo(size.width * 0.6925965, size.height * 0.4698145);
    indianaPath.lineTo(size.width * 0.6995829, size.height * 0.4622260);
    indianaPath.lineTo(size.width * 0.6991658, size.height * 0.4593592);
    indianaPath.lineTo(size.width * 0.6976017, size.height * 0.4558179);
    indianaPath.lineTo(size.width * 0.6986444, size.height * 0.4526138);
    indianaPath.lineTo(size.width * 0.6917623, size.height * 0.3561551);
    indianaPath.lineTo(size.width * 0.6916580, size.height * 0.3537943);
    indianaPath.lineTo(size.width * 0.6578728, size.height * 0.3595278);
    indianaPath.close();

    Paint indianaPaint = Paint()..style = PaintingStyle.fill;
    indianaPaint.color = usaColors.indiana ?? defaultColor;
    usaCanvas.drawPath(indianaPath, indianaPaint, onTapUp: (tabdetail) {
      callback('indiana', tabdetail);
    });

    Path iowaPath = Path();
    iowaPath.moveTo(size.width * 0.5807091, size.height * 0.3086003);
    iowaPath.lineTo(size.width * 0.5828989, size.height * 0.3112985);
    iowaPath.lineTo(size.width * 0.5835245, size.height * 0.3131535);
    iowaPath.lineTo(size.width * 0.5818561, size.height * 0.3187184);
    iowaPath.lineTo(size.width * 0.5817518, size.height * 0.3229342);
    iowaPath.lineTo(size.width * 0.5838373, size.height * 0.3322091);
    iowaPath.lineTo(size.width * 0.5866528, size.height * 0.3347386);
    iowaPath.lineTo(size.width * 0.5900938, size.height * 0.3359191);
    iowaPath.lineTo(size.width * 0.5914494, size.height * 0.3406408);
    iowaPath.lineTo(size.width * 0.5909281, size.height * 0.3416526);
    iowaPath.lineTo(size.width * 0.5935349, size.height * 0.3438449);
    iowaPath.lineTo(size.width * 0.5953076, size.height * 0.3467116);
    iowaPath.lineTo(size.width * 0.5950991, size.height * 0.3494098);
    iowaPath.lineTo(size.width * 0.5960375, size.height * 0.3512648);
    iowaPath.lineTo(size.width * 0.5972888, size.height * 0.3512648);
    iowaPath.lineTo(size.width * 0.6002086, size.height * 0.3571669);
    iowaPath.lineTo(size.width * 0.6003128, size.height * 0.3615514);
    iowaPath.lineTo(size.width * 0.5989572, size.height * 0.3669477);
    iowaPath.lineTo(size.width * 0.5978102, size.height * 0.3691400);
    iowaPath.lineTo(size.width * 0.5977059, size.height * 0.3731872);
    iowaPath.lineTo(size.width * 0.5959333, size.height * 0.3768971);
    iowaPath.lineTo(size.width * 0.5915537, size.height * 0.3799325);
    iowaPath.lineTo(size.width * 0.5890511, size.height * 0.3799325);
    iowaPath.lineTo(size.width * 0.5859228, size.height * 0.3812816);
    iowaPath.lineTo(size.width * 0.5848801, size.height * 0.3880270);
    iowaPath.lineTo(size.width * 0.5860271, size.height * 0.3907251);
    iowaPath.lineTo(size.width * 0.5870699, size.height * 0.3912310);
    iowaPath.lineTo(size.width * 0.5880083, size.height * 0.3935919);
    iowaPath.lineTo(size.width * 0.5879041, size.height * 0.3994941);
    iowaPath.lineTo(size.width * 0.5873827, size.height * 0.4003373);
    iowaPath.lineTo(size.width * 0.5856100, size.height * 0.4043845);
    iowaPath.lineTo(size.width * 0.5856100, size.height * 0.4084317);
    iowaPath.lineTo(size.width * 0.5845673, size.height * 0.4104553);
    iowaPath.lineTo(size.width * 0.5836288, size.height * 0.4109612);
    iowaPath.lineTo(size.width * 0.5817518, size.height * 0.4119730);
    iowaPath.lineTo(size.width * 0.5807091, size.height * 0.4145025);
    iowaPath.lineTo(size.width * 0.5814390, size.height * 0.4160202);
    iowaPath.lineTo(size.width * 0.5813347, size.height * 0.4198988);
    iowaPath.lineTo(size.width * 0.5806048, size.height * 0.4210793);
    iowaPath.lineTo(size.width * 0.5790407, size.height * 0.4197302);
    iowaPath.lineTo(size.width * 0.5778936, size.height * 0.4178752);
    iowaPath.lineTo(size.width * 0.5772680, size.height * 0.4151771);
    iowaPath.lineTo(size.width * 0.5754953, size.height * 0.4129848);
    iowaPath.lineTo(size.width * 0.5605839, size.height * 0.4143339);
    iowaPath.lineTo(size.width * 0.5322211, size.height * 0.4163575);
    iowaPath.lineTo(size.width * 0.5052138, size.height * 0.4161889);
    iowaPath.lineTo(size.width * 0.5033368, size.height * 0.4087690);
    iowaPath.lineTo(size.width * 0.5040667, size.height * 0.4050590);
    iowaPath.lineTo(size.width * 0.5032325, size.height * 0.3994941);
    iowaPath.lineTo(size.width * 0.5034411, size.height * 0.3946037);
    iowaPath.lineTo(size.width * 0.5020855, size.height * 0.3934233);
    iowaPath.lineTo(size.width * 0.5016684, size.height * 0.3831366);
    iowaPath.lineTo(size.width * 0.4987487, size.height * 0.3747049);
    iowaPath.lineTo(size.width * 0.4985401, size.height * 0.3684654);
    iowaPath.lineTo(size.width * 0.4962461, size.height * 0.3612142);
    iowaPath.lineTo(size.width * 0.4948905, size.height * 0.3549747);
    iowaPath.lineTo(size.width * 0.4948905, size.height * 0.3526138);
    iowaPath.lineTo(size.width * 0.4942649, size.height * 0.3497470);
    iowaPath.lineTo(size.width * 0.4942649, size.height * 0.3458685);
    iowaPath.lineTo(size.width * 0.4937435, size.height * 0.3443508);
    iowaPath.lineTo(size.width * 0.4930136, size.height * 0.3414840);
    iowaPath.lineTo(size.width * 0.4927007, size.height * 0.3392917);
    iowaPath.lineTo(size.width * 0.4913452, size.height * 0.3372681);
    iowaPath.lineTo(size.width * 0.4923879, size.height * 0.3300169);
    iowaPath.lineTo(size.width * 0.4941606, size.height * 0.3214165);
    iowaPath.lineTo(size.width * 0.4934307, size.height * 0.3180438);
    iowaPath.lineTo(size.width * 0.4920751, size.height * 0.3173693);
    iowaPath.lineTo(size.width * 0.4916580, size.height * 0.3146712);
    iowaPath.lineTo(size.width * 0.4927007, size.height * 0.3138280);
    iowaPath.lineTo(size.width * 0.4928050, size.height * 0.3119730);
    iowaPath.lineTo(size.width * 0.4914494, size.height * 0.3094435);
    iowaPath.lineTo(size.width * 0.4915537, size.height * 0.3067454);
    iowaPath.lineTo(size.width * 0.4938478, size.height * 0.3069140);
    iowaPath.lineTo(size.width * 0.5232534, size.height * 0.3069140);
    iowaPath.lineTo(size.width * 0.5611053, size.height * 0.3053963);
    iowaPath.lineTo(size.width * 0.5805005, size.height * 0.3042159);
    iowaPath.close();

    Paint iowaPaint = Paint()..style = PaintingStyle.fill;
    iowaPaint.color = usaColors.iowa ?? defaultColor;
    usaCanvas.drawPath(iowaPath, iowaPaint, onTapUp: (tabdetail) {
      callback('iowa', tabdetail);
    });

    Path kansasPath = Path();
    kansasPath.moveTo(size.width * 0.4787278, size.height * 0.4376054);
    kansasPath.lineTo(size.width * 0.4331595, size.height * 0.4355818);
    kansasPath.lineTo(size.width * 0.3956204, size.height * 0.4322091);
    kansasPath.lineTo(size.width * 0.3906152, size.height * 0.5451939);
    kansasPath.lineTo(size.width * 0.4612096, size.height * 0.5500843);
    kansasPath.lineTo(size.width * 0.5258603, size.height * 0.5502530);
    kansasPath.lineTo(size.width * 0.5253389, size.height * 0.4691400);
    kansasPath.lineTo(size.width * 0.5220021, size.height * 0.4679595);
    kansasPath.lineTo(size.width * 0.5192909, size.height * 0.4600337);
    kansasPath.lineTo(size.width * 0.5166840, size.height * 0.4558179);
    kansasPath.lineTo(size.width * 0.5172054, size.height * 0.4519393);
    kansasPath.lineTo(size.width * 0.5200209, size.height * 0.4475548);
    kansasPath.lineTo(size.width * 0.5201251, size.height * 0.4455312);
    kansasPath.lineTo(size.width * 0.5185610, size.height * 0.4419899);
    kansasPath.lineTo(size.width * 0.5176225, size.height * 0.4436762);
    kansasPath.lineTo(size.width * 0.5155370, size.height * 0.4426644);
    kansasPath.lineTo(size.width * 0.5125130, size.height * 0.4376054);
    kansasPath.close();

    Paint kansasPaint = Paint()..style = PaintingStyle.fill;
    kansasPaint.color = usaColors.kansas ?? defaultColor;
    usaCanvas.drawPath(kansasPath, kansasPaint, onTapUp: (tabdetail) {
      callback('kansas', tabdetail);
    });

    Path kentuckyPath = Path();
    kentuckyPath.moveTo(size.width * 0.7216893, size.height * 0.5438449);
    kentuckyPath.lineTo(size.width * 0.7003128, size.height * 0.5462057);
    kentuckyPath.lineTo(size.width * 0.6948905, size.height * 0.5475548);
    kentuckyPath.lineTo(size.width * 0.6767466, size.height * 0.5492411);
    kentuckyPath.lineTo(size.width * 0.6740355, size.height * 0.5505902);
    kentuckyPath.lineTo(size.width * 0.6504692, size.height * 0.5539629);
    kentuckyPath.lineTo(size.width * 0.6497393, size.height * 0.5529511);
    kentuckyPath.lineTo(size.width * 0.6458811, size.height * 0.5529511);
    kentuckyPath.lineTo(size.width * 0.6471324, size.height * 0.5583474);
    kentuckyPath.lineTo(size.width * 0.6465068, size.height * 0.5598651);
    kentuckyPath.lineTo(size.width * 0.6222106, size.height * 0.5623946);
    kentuckyPath.lineTo(size.width * 0.6232534, size.height * 0.5578415);
    kentuckyPath.lineTo(size.width * 0.6247132, size.height * 0.5593592);
    kentuckyPath.lineTo(size.width * 0.6254432, size.height * 0.5586847);
    kentuckyPath.lineTo(size.width * 0.6266945, size.height * 0.5517707);
    kentuckyPath.lineTo(size.width * 0.6256517, size.height * 0.5500843);
    kentuckyPath.lineTo(size.width * 0.6266945, size.height * 0.5467116);
    kentuckyPath.lineTo(size.width * 0.6269030, size.height * 0.5451939);
    kentuckyPath.lineTo(size.width * 0.6255474, size.height * 0.5438449);
    kentuckyPath.lineTo(size.width * 0.6252346, size.height * 0.5408094);
    kentuckyPath.lineTo(size.width * 0.6294056, size.height * 0.5345700);
    kentuckyPath.lineTo(size.width * 0.6366006, size.height * 0.5396290);
    kentuckyPath.lineTo(size.width * 0.6381648, size.height * 0.5391231);
    kentuckyPath.lineTo(size.width * 0.6385819, size.height * 0.5350759);
    kentuckyPath.lineTo(size.width * 0.6368092, size.height * 0.5320405);
    kentuckyPath.lineTo(size.width * 0.6372263, size.height * 0.5264755);
    kentuckyPath.lineTo(size.width * 0.6382690, size.height * 0.5256324);
    kentuckyPath.lineTo(size.width * 0.6395203, size.height * 0.5266442);
    kentuckyPath.lineTo(size.width * 0.6401460, size.height * 0.5246206);
    kentuckyPath.lineTo(size.width * 0.6440042, size.height * 0.5236088);
    kentuckyPath.lineTo(size.width * 0.6441084, size.height * 0.5220911);
    kentuckyPath.lineTo(size.width * 0.6425443, size.height * 0.5183811);
    kentuckyPath.lineTo(size.width * 0.6424400, size.height * 0.5165261);
    kentuckyPath.lineTo(size.width * 0.6447341, size.height * 0.5119730);
    kentuckyPath.lineTo(size.width * 0.6447341, size.height * 0.5104553);
    kentuckyPath.lineTo(size.width * 0.6458811, size.height * 0.5118044);
    kentuckyPath.lineTo(size.width * 0.6465068, size.height * 0.5101180);
    kentuckyPath.lineTo(size.width * 0.6457769, size.height * 0.5072513);
    kentuckyPath.lineTo(size.width * 0.6505735, size.height * 0.5064081);
    kentuckyPath.lineTo(size.width * 0.6507821, size.height * 0.5084317);
    kentuckyPath.lineTo(size.width * 0.6519291, size.height * 0.5087690);
    kentuckyPath.lineTo(size.width * 0.6523462, size.height * 0.5072513);
    kentuckyPath.lineTo(size.width * 0.6517205, size.height * 0.5050590);
    kentuckyPath.lineTo(size.width * 0.6520334, size.height * 0.5037099);
    kentuckyPath.lineTo(size.width * 0.6533889, size.height * 0.5050590);
    kentuckyPath.lineTo(size.width * 0.6551616, size.height * 0.5043845);
    kentuckyPath.lineTo(size.width * 0.6569343, size.height * 0.5053963);
    kentuckyPath.lineTo(size.width * 0.6604797, size.height * 0.5089376);
    kentuckyPath.lineTo(size.width * 0.6623566, size.height * 0.5042159);
    kentuckyPath.lineTo(size.width * 0.6660063, size.height * 0.5005059);
    kentuckyPath.lineTo(size.width * 0.6691345, size.height * 0.5060708);
    kentuckyPath.lineTo(size.width * 0.6708029, size.height * 0.5025295);
    kentuckyPath.lineTo(size.width * 0.6711157, size.height * 0.4979764);
    kentuckyPath.lineTo(size.width * 0.6750782, size.height * 0.4940978);
    kentuckyPath.lineTo(size.width * 0.6752868, size.height * 0.4962901);
    kentuckyPath.lineTo(size.width * 0.6772680, size.height * 0.4983137);
    kentuckyPath.lineTo(size.width * 0.6803962, size.height * 0.4979764);
    kentuckyPath.lineTo(size.width * 0.6816475, size.height * 0.4967960);
    kentuckyPath.lineTo(size.width * 0.6817518, size.height * 0.4910624);
    kentuckyPath.lineTo(size.width * 0.6843587, size.height * 0.4848229);
    kentuckyPath.lineTo(size.width * 0.6891554, size.height * 0.4774030);
    kentuckyPath.lineTo(size.width * 0.6890511, size.height * 0.4745363);
    kentuckyPath.lineTo(size.width * 0.6903024, size.height * 0.4681282);
    kentuckyPath.lineTo(size.width * 0.6925965, size.height * 0.4698145);
    kentuckyPath.lineTo(size.width * 0.6995829, size.height * 0.4622260);
    kentuckyPath.lineTo(size.width * 0.6991658, size.height * 0.4593592);
    kentuckyPath.lineTo(size.width * 0.6976017, size.height * 0.4558179);
    kentuckyPath.lineTo(size.width * 0.6986444, size.height * 0.4526138);
    kentuckyPath.lineTo(size.width * 0.7000000, size.height * 0.4534570);
    kentuckyPath.lineTo(size.width * 0.7022941, size.height * 0.4536256);
    kentuckyPath.lineTo(size.width * 0.7042753, size.height * 0.4522766);
    kentuckyPath.lineTo(size.width * 0.7072993, size.height * 0.4543002);
    kentuckyPath.lineTo(size.width * 0.7095933, size.height * 0.4600337);
    kentuckyPath.lineTo(size.width * 0.7095933, size.height * 0.4617201);
    kentuckyPath.lineTo(size.width * 0.7138686, size.height * 0.4629005);
    kentuckyPath.lineTo(size.width * 0.7162669, size.height * 0.4625632);
    kentuckyPath.lineTo(size.width * 0.7182482, size.height * 0.4661046);
    kentuckyPath.lineTo(size.width * 0.7205422, size.height * 0.4664418);
    kentuckyPath.lineTo(size.width * 0.7205422, size.height * 0.4647555);
    kentuckyPath.lineTo(size.width * 0.7225235, size.height * 0.4634064);
    kentuckyPath.lineTo(size.width * 0.7256517, size.height * 0.4647555);
    kentuckyPath.lineTo(size.width * 0.7269030, size.height * 0.4661046);
    kentuckyPath.lineTo(size.width * 0.7282586, size.height * 0.4649241);
    kentuckyPath.lineTo(size.width * 0.7291971, size.height * 0.4649241);
    kentuckyPath.lineTo(size.width * 0.7298227, size.height * 0.4620573);
    kentuckyPath.lineTo(size.width * 0.7333681, size.height * 0.4590219);
    kentuckyPath.lineTo(size.width * 0.7338895, size.height * 0.4603710);
    kentuckyPath.lineTo(size.width * 0.7347237, size.height * 0.4652614);
    kentuckyPath.lineTo(size.width * 0.7383733, size.height * 0.4676223);
    kentuckyPath.lineTo(size.width * 0.7396246, size.height * 0.4711636);
    kentuckyPath.lineTo(size.width * 0.7395203, size.height * 0.4730185);
    kentuckyPath.lineTo(size.width * 0.7401460, size.height * 0.4747049);
    kentuckyPath.lineTo(size.width * 0.7395203, size.height * 0.4807757);
    kentuckyPath.lineTo(size.width * 0.7415016, size.height * 0.4834739);
    kentuckyPath.lineTo(size.width * 0.7423358, size.height * 0.4853288);
    kentuckyPath.lineTo(size.width * 0.7433785, size.height * 0.4863406);
    kentuckyPath.lineTo(size.width * 0.7432742, size.height * 0.4878583);
    kentuckyPath.lineTo(size.width * 0.7478624, size.height * 0.4973019);
    kentuckyPath.lineTo(size.width * 0.7493222, size.height * 0.4973019);
    kentuckyPath.lineTo(size.width * 0.7508863, size.height * 0.5003373);
    kentuckyPath.lineTo(size.width * 0.7521376, size.height * 0.5008432);
    kentuckyPath.lineTo(size.width * 0.7535975, size.height * 0.5006745);
    kentuckyPath.lineTo(size.width * 0.7484880, size.height * 0.5118044);
    kentuckyPath.lineTo(size.width * 0.7454640, size.height * 0.5134907);
    kentuckyPath.lineTo(size.width * 0.7423358, size.height * 0.5185497);
    kentuckyPath.lineTo(size.width * 0.7419187, size.height * 0.5222597);
    kentuckyPath.lineTo(size.width * 0.7397289, size.height * 0.5244519);
    kentuckyPath.lineTo(size.width * 0.7396246, size.height * 0.5273187);
    kentuckyPath.lineTo(size.width * 0.7381648, size.height * 0.5296796);
    kentuckyPath.lineTo(size.width * 0.7362878, size.height * 0.5305228);
    kentuckyPath.lineTo(size.width * 0.7357664, size.height * 0.5337268);
    kentuckyPath.lineTo(size.width * 0.7347237, size.height * 0.5344013);
    kentuckyPath.lineTo(size.width * 0.7275287, size.height * 0.5414840);
    kentuckyPath.close();
    kentuckyPath.moveTo(size.width * 0.6194995, size.height * 0.5629005);
    kentuckyPath.lineTo(size.width * 0.6187696, size.height * 0.5617201);
    kentuckyPath.lineTo(size.width * 0.6189781, size.height * 0.5600337);
    kentuckyPath.lineTo(size.width * 0.6201251, size.height * 0.5600337);
    kentuckyPath.lineTo(size.width * 0.6208551, size.height * 0.5612142);
    kentuckyPath.lineTo(size.width * 0.6205422, size.height * 0.5629005);
    kentuckyPath.close();

    Paint kentuckyPaint = Paint()..style = PaintingStyle.fill;
    kentuckyPaint.color = usaColors.kentucky ?? defaultColor;
    usaCanvas.drawPath(kentuckyPath, kentuckyPaint, onTapUp: (tabdetail) {
      callback('kentucky', tabdetail);
    });

    Path louisianaPath = Path();
    louisianaPath.moveTo(size.width * 0.6282586, size.height * 0.7973019);
    louisianaPath.lineTo(size.width * 0.6270073, size.height * 0.7942664);
    louisianaPath.lineTo(size.width * 0.6273201, size.height * 0.7920742);
    louisianaPath.lineTo(size.width * 0.6223149, size.height * 0.7806071);
    louisianaPath.lineTo(size.width * 0.6232534, size.height * 0.7728499);
    louisianaPath.lineTo(size.width * 0.6242961, size.height * 0.7704890);
    louisianaPath.lineTo(size.width * 0.6244004, size.height * 0.7681282);
    louisianaPath.lineTo(size.width * 0.5868613, size.height * 0.7715008);
    louisianaPath.lineTo(size.width * 0.5886340, size.height * 0.7514334);
    louisianaPath.lineTo(size.width * 0.5911366, size.height * 0.7433390);
    louisianaPath.lineTo(size.width * 0.5973931, size.height * 0.7291737);
    louisianaPath.lineTo(size.width * 0.5955162, size.height * 0.7249578);
    louisianaPath.lineTo(size.width * 0.5976017, size.height * 0.7249578);
    louisianaPath.lineTo(size.width * 0.5976017, size.height * 0.7193929);
    louisianaPath.lineTo(size.width * 0.5950991, size.height * 0.7151771);
    louisianaPath.lineTo(size.width * 0.5956204, size.height * 0.7123103);
    louisianaPath.lineTo(size.width * 0.5943691, size.height * 0.7106239);
    louisianaPath.lineTo(size.width * 0.5927007, size.height * 0.6986509);
    louisianaPath.lineTo(size.width * 0.5933264, size.height * 0.6962901);
    louisianaPath.lineTo(size.width * 0.5387904, size.height * 0.6984823);
    louisianaPath.lineTo(size.width * 0.5393118, size.height * 0.7320405);
    louisianaPath.lineTo(size.width * 0.5400417, size.height * 0.7377740);
    louisianaPath.lineTo(size.width * 0.5427529, size.height * 0.7424958);
    louisianaPath.lineTo(size.width * 0.5434828, size.height * 0.7516020);
    louisianaPath.lineTo(size.width * 0.5474453, size.height * 0.7593592);
    louisianaPath.lineTo(size.width * 0.5482795, size.height * 0.7666105);
    louisianaPath.lineTo(size.width * 0.5493222, size.height * 0.7666105);
    louisianaPath.lineTo(size.width * 0.5492179, size.height * 0.7789207);
    louisianaPath.lineTo(size.width * 0.5457769, size.height * 0.7897133);
    louisianaPath.lineTo(size.width * 0.5471324, size.height * 0.7935919);
    louisianaPath.lineTo(size.width * 0.5457769, size.height * 0.7961214);
    louisianaPath.lineTo(size.width * 0.5465068, size.height * 0.8011804);
    louisianaPath.lineTo(size.width * 0.5464025, size.height * 0.8084317);
    louisianaPath.lineTo(size.width * 0.5441084, size.height * 0.8143339);
    louisianaPath.lineTo(size.width * 0.5440042, size.height * 0.8156830);
    louisianaPath.lineTo(size.width * 0.5422315, size.height * 0.8177066);
    louisianaPath.lineTo(size.width * 0.5432742, size.height * 0.8207420);
    louisianaPath.lineTo(size.width * 0.5445255, size.height * 0.8225970);
    louisianaPath.lineTo(size.width * 0.5461940, size.height * 0.8204047);
    louisianaPath.lineTo(size.width * 0.5517205, size.height * 0.8188870);
    louisianaPath.lineTo(size.width * 0.5580813, size.height * 0.8187184);
    louisianaPath.lineTo(size.width * 0.5680918, size.height * 0.8251265);
    louisianaPath.lineTo(size.width * 0.5764338, size.height * 0.8268128);
    louisianaPath.lineTo(size.width * 0.5779979, size.height * 0.8244519);
    louisianaPath.lineTo(size.width * 0.5798749, size.height * 0.8241147);
    louisianaPath.lineTo(size.width * 0.5848801, size.height * 0.8278246);
    louisianaPath.lineTo(size.width * 0.5865485, size.height * 0.8271501);
    louisianaPath.lineTo(size.width * 0.5876955, size.height * 0.8246206);
    louisianaPath.lineTo(size.width * 0.5833160, size.height * 0.8215852);
    louisianaPath.lineTo(size.width * 0.5810219, size.height * 0.8232715);
    louisianaPath.lineTo(size.width * 0.5798749, size.height * 0.8229342);
    louisianaPath.lineTo(size.width * 0.5784150, size.height * 0.8195616);
    louisianaPath.lineTo(size.width * 0.5818561, size.height * 0.8158516);
    louisianaPath.lineTo(size.width * 0.5835245, size.height * 0.8156830);
    louisianaPath.lineTo(size.width * 0.5835245, size.height * 0.8185497);
    louisianaPath.lineTo(size.width * 0.5850886, size.height * 0.8183811);
    louisianaPath.lineTo(size.width * 0.5886340, size.height * 0.8178752);
    louisianaPath.lineTo(size.width * 0.5890511, size.height * 0.8217538);
    louisianaPath.lineTo(size.width * 0.5901981, size.height * 0.8224283);
    louisianaPath.lineTo(size.width * 0.5908238, size.height * 0.8256324);
    louisianaPath.lineTo(size.width * 0.5958290, size.height * 0.8273187);
    louisianaPath.lineTo(size.width * 0.5976017, size.height * 0.8300169);
    louisianaPath.lineTo(size.width * 0.5976017, size.height * 0.8311973);
    louisianaPath.lineTo(size.width * 0.5963504, size.height * 0.8311973);
    louisianaPath.lineTo(size.width * 0.5947862, size.height * 0.8340641);
    louisianaPath.lineTo(size.width * 0.5965589, size.height * 0.8360877);
    louisianaPath.lineTo(size.width * 0.6021898, size.height * 0.8377740);
    louisianaPath.lineTo(size.width * 0.6050052, size.height * 0.8424958);
    louisianaPath.lineTo(size.width * 0.6095933, size.height * 0.8408094);
    louisianaPath.lineTo(size.width * 0.6057351, size.height * 0.8411467);
    louisianaPath.lineTo(size.width * 0.6056309, size.height * 0.8401349);
    louisianaPath.lineTo(size.width * 0.6085506, size.height * 0.8389545);
    louisianaPath.lineTo(size.width * 0.6087591, size.height * 0.8359191);
    louisianaPath.lineTo(size.width * 0.6100104, size.height * 0.8354132);
    louisianaPath.lineTo(size.width * 0.6100104, size.height * 0.8330523);
    louisianaPath.lineTo(size.width * 0.6111575, size.height * 0.8332209);
    louisianaPath.lineTo(size.width * 0.6111575, size.height * 0.8359191);
    louisianaPath.lineTo(size.width * 0.6137643, size.height * 0.8360877);
    louisianaPath.lineTo(size.width * 0.6145985, size.height * 0.8328836);
    louisianaPath.lineTo(size.width * 0.6155370, size.height * 0.8333895);
    louisianaPath.lineTo(size.width * 0.6157456, size.height * 0.8376054);
    louisianaPath.lineTo(size.width * 0.6169969, size.height * 0.8379427);
    louisianaPath.lineTo(size.width * 0.6151199, size.height * 0.8413153);
    louisianaPath.lineTo(size.width * 0.6178311, size.height * 0.8397976);
    louisianaPath.lineTo(size.width * 0.6199166, size.height * 0.8379427);
    louisianaPath.lineTo(size.width * 0.6229406, size.height * 0.8323777);
    louisianaPath.lineTo(size.width * 0.6222106, size.height * 0.8323777);
    louisianaPath.lineTo(size.width * 0.6208551, size.height * 0.8344013);
    louisianaPath.lineTo(size.width * 0.6204380, size.height * 0.8342327);
    louisianaPath.lineTo(size.width * 0.6199166, size.height * 0.8328836);
    louisianaPath.lineTo(size.width * 0.6208551, size.height * 0.8308600);
    louisianaPath.lineTo(size.width * 0.6208551, size.height * 0.8269815);
    louisianaPath.lineTo(size.width * 0.6220021, size.height * 0.8256324);
    louisianaPath.lineTo(size.width * 0.6227320, size.height * 0.8268128);
    louisianaPath.lineTo(size.width * 0.6237748, size.height * 0.8254637);
    louisianaPath.lineTo(size.width * 0.6248175, size.height * 0.8252951);
    louisianaPath.lineTo(size.width * 0.6254432, size.height * 0.8274874);
    louisianaPath.lineTo(size.width * 0.6248175, size.height * 0.8306914);
    louisianaPath.lineTo(size.width * 0.6273201, size.height * 0.8306914);
    louisianaPath.lineTo(size.width * 0.6326382, size.height * 0.8335582);
    louisianaPath.lineTo(size.width * 0.6331595, size.height * 0.8357504);
    louisianaPath.lineTo(size.width * 0.6348279, size.height * 0.8381113);
    louisianaPath.lineTo(size.width * 0.6377477, size.height * 0.8382799);
    louisianaPath.lineTo(size.width * 0.6391032, size.height * 0.8394604);
    louisianaPath.lineTo(size.width * 0.6409802, size.height * 0.8377740);
    louisianaPath.lineTo(size.width * 0.6419187, size.height * 0.8349073);
    louisianaPath.lineTo(size.width * 0.6419187, size.height * 0.8320405);
    louisianaPath.lineTo(size.width * 0.6404588, size.height * 0.8320405);
    louisianaPath.lineTo(size.width * 0.6392075, size.height * 0.8296796);
    louisianaPath.lineTo(size.width * 0.6380605, size.height * 0.8278246);
    louisianaPath.lineTo(size.width * 0.6347237, size.height * 0.8263069);
    louisianaPath.lineTo(size.width * 0.6320125, size.height * 0.8266442);
    louisianaPath.lineTo(size.width * 0.6276330, size.height * 0.8225970);
    louisianaPath.lineTo(size.width * 0.6276330, size.height * 0.8187184);
    louisianaPath.lineTo(size.width * 0.6289885, size.height * 0.8170320);
    louisianaPath.lineTo(size.width * 0.6314911, size.height * 0.8180438);
    louisianaPath.lineTo(size.width * 0.6282586, size.height * 0.8153457);
    louisianaPath.lineTo(size.width * 0.6284672, size.height * 0.8139966);
    louisianaPath.lineTo(size.width * 0.6322211, size.height * 0.8139966);
    louisianaPath.lineTo(size.width * 0.6349322, size.height * 0.8080944);
    louisianaPath.lineTo(size.width * 0.6322211, size.height * 0.8050590);
    louisianaPath.lineTo(size.width * 0.6330553, size.height * 0.8025295);
    louisianaPath.lineTo(size.width * 0.6318040, size.height * 0.8011804);
    louisianaPath.lineTo(size.width * 0.6309698, size.height * 0.8011804);
    louisianaPath.lineTo(size.width * 0.6288843, size.height * 0.8047218);
    louisianaPath.lineTo(size.width * 0.6288843, size.height * 0.8082631);
    louisianaPath.lineTo(size.width * 0.6282586, size.height * 0.8094435);
    louisianaPath.lineTo(size.width * 0.6271116, size.height * 0.8092749);
    louisianaPath.lineTo(size.width * 0.6254432, size.height * 0.8069140);
    louisianaPath.lineTo(size.width * 0.6240876, size.height * 0.8069140);
    louisianaPath.lineTo(size.width * 0.6240876, size.height * 0.8043845);
    louisianaPath.lineTo(size.width * 0.6247132, size.height * 0.8032040);
    louisianaPath.lineTo(size.width * 0.6255474, size.height * 0.8043845);
    louisianaPath.lineTo(size.width * 0.6273201, size.height * 0.8016863);
    louisianaPath.lineTo(size.width * 0.6280501, size.height * 0.7989882);
    louisianaPath.lineTo(size.width * 0.6288843, size.height * 0.7984823);
    louisianaPath.close();
    louisianaPath.moveTo(size.width * 0.6175182, size.height * 0.7927487);
    louisianaPath.lineTo(size.width * 0.6194995, size.height * 0.7944351);
    louisianaPath.lineTo(size.width * 0.6203337, size.height * 0.7962901);
    louisianaPath.lineTo(size.width * 0.6229406, size.height * 0.7964587);
    louisianaPath.lineTo(size.width * 0.6245047, size.height * 0.7978078);
    louisianaPath.lineTo(size.width * 0.6247132, size.height * 0.8001686);
    louisianaPath.lineTo(size.width * 0.6242961, size.height * 0.8011804);
    louisianaPath.lineTo(size.width * 0.6233577, size.height * 0.7986509);
    louisianaPath.lineTo(size.width * 0.6218978, size.height * 0.8006745);
    louisianaPath.lineTo(size.width * 0.6209593, size.height * 0.8030354);
    louisianaPath.lineTo(size.width * 0.6180396, size.height * 0.8043845);
    louisianaPath.lineTo(size.width * 0.6163712, size.height * 0.8045531);
    louisianaPath.lineTo(size.width * 0.6125130, size.height * 0.8028668);
    louisianaPath.lineTo(size.width * 0.6126173, size.height * 0.8000000);
    louisianaPath.lineTo(size.width * 0.6147028, size.height * 0.7966273);
    louisianaPath.lineTo(size.width * 0.6158498, size.height * 0.7925801);
    louisianaPath.close();
    louisianaPath.moveTo(size.width * 0.6126173, size.height * 0.7947723);
    louisianaPath.lineTo(size.width * 0.6126173, size.height * 0.7966273);
    louisianaPath.lineTo(size.width * 0.6107404, size.height * 0.8000000);
    louisianaPath.lineTo(size.width * 0.6094891, size.height * 0.8000000);
    louisianaPath.lineTo(size.width * 0.6094891, size.height * 0.7962901);
    louisianaPath.lineTo(size.width * 0.6111575, size.height * 0.7937605);
    louisianaPath.close();

    Paint louisianaPaint = Paint()..style = PaintingStyle.fill;
    louisianaPaint.color = usaColors.louisiana ?? defaultColor;
    usaCanvas.drawPath(louisianaPath, louisianaPaint, onTapUp: (tabdetail) {
      callback('louisiana', tabdetail);
    });

    Path mainePath = Path();
    mainePath.moveTo(size.width * 0.9124088, size.height * 0.2170320);
    mainePath.lineTo(size.width * 0.9130344, size.height * 0.2237774);
    mainePath.lineTo(size.width * 0.9163712, size.height * 0.2271501);
    mainePath.lineTo(size.width * 0.9172054, size.height * 0.2308600);
    mainePath.lineTo(size.width * 0.9196038, size.height * 0.2332209);
    mainePath.lineTo(size.width * 0.9210636, size.height * 0.2327150);
    mainePath.lineTo(size.width * 0.9221064, size.height * 0.2276560);
    mainePath.lineTo(size.width * 0.9212722, size.height * 0.2227656);
    mainePath.lineTo(size.width * 0.9229406, size.height * 0.2212479);
    mainePath.lineTo(size.width * 0.9234619, size.height * 0.2165261);
    mainePath.lineTo(size.width * 0.9228363, size.height * 0.2143339);
    mainePath.lineTo(size.width * 0.9262774, size.height * 0.2111298);
    mainePath.lineTo(size.width * 0.9239833, size.height * 0.2072513);
    mainePath.lineTo(size.width * 0.9249218, size.height * 0.2032040);
    mainePath.lineTo(size.width * 0.9263816, size.height * 0.1994941);
    mainePath.lineTo(size.width * 0.9269030, size.height * 0.2048904);
    mainePath.lineTo(size.width * 0.9285714, size.height * 0.2015177);
    mainePath.lineTo(size.width * 0.9299270, size.height * 0.2030354);
    mainePath.lineTo(size.width * 0.9311783, size.height * 0.2016863);
    mainePath.lineTo(size.width * 0.9311783, size.height * 0.1988196);
    mainePath.lineTo(size.width * 0.9345151, size.height * 0.1966273);
    mainePath.lineTo(size.width * 0.9348279, size.height * 0.1917369);
    mainePath.lineTo(size.width * 0.9374348, size.height * 0.1913997);
    mainePath.lineTo(size.width * 0.9402503, size.height * 0.1851602);
    mainePath.lineTo(size.width * 0.9402503, size.height * 0.1839798);
    mainePath.lineTo(size.width * 0.9393118, size.height * 0.1831366);
    mainePath.lineTo(size.width * 0.9392075, size.height * 0.1775717);
    mainePath.lineTo(size.width * 0.9398332, size.height * 0.1757167);
    mainePath.lineTo(size.width * 0.9400417, size.height * 0.1784148);
    mainePath.lineTo(size.width * 0.9410845, size.height * 0.1775717);
    mainePath.lineTo(size.width * 0.9408759, size.height * 0.1721754);
    mainePath.lineTo(size.width * 0.9399374, size.height * 0.1726813);
    mainePath.lineTo(size.width * 0.9398332, size.height * 0.1747049);
    mainePath.lineTo(size.width * 0.9385819, size.height * 0.1723440);
    mainePath.lineTo(size.width * 0.9395203, size.height * 0.1699831);
    mainePath.lineTo(size.width * 0.9401460, size.height * 0.1701518);
    mainePath.lineTo(size.width * 0.9412930, size.height * 0.1694772);
    mainePath.lineTo(size.width * 0.9418144, size.height * 0.1741990);
    mainePath.lineTo(size.width * 0.9438999, size.height * 0.1736931);
    mainePath.lineTo(size.width * 0.9469239, size.height * 0.1748735);
    mainePath.lineTo(size.width * 0.9469239, size.height * 0.1731872);
    mainePath.lineTo(size.width * 0.9457769, size.height * 0.1711636);
    mainePath.lineTo(size.width * 0.9471324, size.height * 0.1713322);
    mainePath.lineTo(size.width * 0.9472367, size.height * 0.1674536);
    mainePath.lineTo(size.width * 0.9478624, size.height * 0.1688027);
    mainePath.lineTo(size.width * 0.9481752, size.height * 0.1720067);
    mainePath.lineTo(size.width * 0.9503650, size.height * 0.1745363);
    mainePath.lineTo(size.width * 0.9505735, size.height * 0.1728499);
    mainePath.lineTo(size.width * 0.9515120, size.height * 0.1725126);
    mainePath.lineTo(size.width * 0.9511992, size.height * 0.1711636);
    mainePath.lineTo(size.width * 0.9520334, size.height * 0.1701518);
    mainePath.lineTo(size.width * 0.9519291, size.height * 0.1674536);
    mainePath.lineTo(size.width * 0.9502607, size.height * 0.1671164);
    mainePath.lineTo(size.width * 0.9481752, size.height * 0.1682968);
    mainePath.lineTo(size.width * 0.9496350, size.height * 0.1655987);
    mainePath.lineTo(size.width * 0.9503650, size.height * 0.1642496);
    mainePath.lineTo(size.width * 0.9517205, size.height * 0.1639123);
    mainePath.lineTo(size.width * 0.9521376, size.height * 0.1661046);
    mainePath.lineTo(size.width * 0.9539103, size.height * 0.1688027);
    mainePath.lineTo(size.width * 0.9543274, size.height * 0.1652614);
    mainePath.lineTo(size.width * 0.9567258, size.height * 0.1632378);
    mainePath.lineTo(size.width * 0.9557873, size.height * 0.1610455);
    mainePath.lineTo(size.width * 0.9558916, size.height * 0.1581788);
    mainePath.lineTo(size.width * 0.9570386, size.height * 0.1590219);
    mainePath.lineTo(size.width * 0.9577685, size.height * 0.1590219);
    mainePath.lineTo(size.width * 0.9595412, size.height * 0.1566610);
    mainePath.lineTo(size.width * 0.9599583, size.height * 0.1527825);
    mainePath.lineTo(size.width * 0.9622523, size.height * 0.1532884);
    mainePath.lineTo(size.width * 0.9623566, size.height * 0.1521079);
    mainePath.lineTo(size.width * 0.9625652, size.height * 0.1494098);
    mainePath.lineTo(size.width * 0.9630865, size.height * 0.1517707);
    mainePath.lineTo(size.width * 0.9646507, size.height * 0.1500843);
    mainePath.lineTo(size.width * 0.9670490, size.height * 0.1431703);
    mainePath.lineTo(size.width * 0.9669447, size.height * 0.1394604);
    mainePath.lineTo(size.width * 0.9654849, size.height * 0.1360877);
    mainePath.lineTo(size.width * 0.9623566, size.height * 0.1306914);
    mainePath.lineTo(size.width * 0.9603754, size.height * 0.1306914);
    mainePath.lineTo(size.width * 0.9595412, size.height * 0.1344013);
    mainePath.lineTo(size.width * 0.9565172, size.height * 0.1293423);
    mainePath.lineTo(size.width * 0.9568300, size.height * 0.1279933);
    mainePath.lineTo(size.width * 0.9568300, size.height * 0.1254637);
    mainePath.lineTo(size.width * 0.9551616, size.height * 0.1178752);
    mainePath.lineTo(size.width * 0.9543274, size.height * 0.1175379);
    mainePath.lineTo(size.width * 0.9535975, size.height * 0.1182125);
    mainePath.lineTo(size.width * 0.9485923, size.height * 0.1182125);
    mainePath.lineTo(size.width * 0.9482795, size.height * 0.1121417);
    mainePath.lineTo(size.width * 0.9398332, size.height * 0.06829680);
    mainePath.lineTo(size.width * 0.9322211, size.height * 0.06205734);
    mainePath.lineTo(size.width * 0.9291971, size.height * 0.06188870);
    mainePath.lineTo(size.width * 0.9222106, size.height * 0.07301855);
    mainePath.lineTo(size.width * 0.9193952, size.height * 0.07133221);
    mainePath.lineTo(size.width * 0.9183525, size.height * 0.06475548);
    mainePath.lineTo(size.width * 0.9155370, size.height * 0.06475548);
    mainePath.lineTo(size.width * 0.9083420, size.height * 0.09763912);
    mainePath.lineTo(size.width * 0.9090719, size.height * 0.1080944);
    mainePath.lineTo(size.width * 0.9072993, size.height * 0.1121417);
    mainePath.lineTo(size.width * 0.9068822, size.height * 0.1198988);
    mainePath.lineTo(size.width * 0.9082377, size.height * 0.1261383);
    mainePath.lineTo(size.width * 0.9090719, size.height * 0.1264755);
    mainePath.lineTo(size.width * 0.9090719, size.height * 0.1291737);
    mainePath.lineTo(size.width * 0.9074035, size.height * 0.1367622);
    mainePath.lineTo(size.width * 0.9058394, size.height * 0.1391231);
    mainePath.lineTo(size.width * 0.9044838, size.height * 0.1428331);
    mainePath.lineTo(size.width * 0.9040667, size.height * 0.1559865);
    mainePath.lineTo(size.width * 0.9015641, size.height * 0.1543002);
    mainePath.lineTo(size.width * 0.9000000, size.height * 0.1549747);
    mainePath.close();
    mainePath.moveTo(size.width * 0.9484880, size.height * 0.1753794);
    mainePath.lineTo(size.width * 0.9474453, size.height * 0.1767285);
    mainePath.lineTo(size.width * 0.9474453, size.height * 0.1789207);
    mainePath.lineTo(size.width * 0.9481752, size.height * 0.1775717);
    mainePath.lineTo(size.width * 0.9491137, size.height * 0.1789207);
    mainePath.lineTo(size.width * 0.9495308, size.height * 0.1780776);
    mainePath.lineTo(size.width * 0.9506778, size.height * 0.1784148);
    mainePath.lineTo(size.width * 0.9496350, size.height * 0.1770658);
    mainePath.lineTo(size.width * 0.9500521, size.height * 0.1757167);
    mainePath.close();
    mainePath.moveTo(size.width * 0.9467153, size.height * 0.1797639);
    mainePath.lineTo(size.width * 0.9456726, size.height * 0.1816189);
    mainePath.lineTo(size.width * 0.9461940, size.height * 0.1822934);
    mainePath.lineTo(size.width * 0.9460897, size.height * 0.1839798);
    mainePath.lineTo(size.width * 0.9472367, size.height * 0.1839798);
    mainePath.lineTo(size.width * 0.9472367, size.height * 0.1809444);
    mainePath.close();
    mainePath.moveTo(size.width * 0.9435871, size.height * 0.1770658);
    mainePath.lineTo(size.width * 0.9445255, size.height * 0.1792580);
    mainePath.lineTo(size.width * 0.9455683, size.height * 0.1801012);
    mainePath.lineTo(size.width * 0.9458811, size.height * 0.1784148);
    mainePath.lineTo(size.width * 0.9458811, size.height * 0.1753794);
    mainePath.lineTo(size.width * 0.9445255, size.height * 0.1741990);
    mainePath.lineTo(size.width * 0.9441084, size.height * 0.1762226);
    mainePath.close();
    mainePath.moveTo(size.width * 0.9425443, size.height * 0.1854975);
    mainePath.lineTo(size.width * 0.9407716, size.height * 0.1826307);
    mainePath.lineTo(size.width * 0.9424400, size.height * 0.1785835);
    mainePath.lineTo(size.width * 0.9432742, size.height * 0.1790894);
    mainePath.lineTo(size.width * 0.9434828, size.height * 0.1809444);
    mainePath.lineTo(size.width * 0.9445255, size.height * 0.1822934);
    mainePath.lineTo(size.width * 0.9445255, size.height * 0.1841484);
    mainePath.lineTo(size.width * 0.9434828, size.height * 0.1858347);
    mainePath.close();

    Paint mainePaint = Paint()..style = PaintingStyle.fill;
    mainePaint.color = usaColors.maine ?? defaultColor;
    usaCanvas.drawPath(mainePath, mainePaint, onTapUp: (tabdetail) {
      callback('maine', tabdetail);
    });

    Path marylandPath = Path();
    marylandPath.moveTo(size.width * 0.8580813, size.height * 0.4541315);
    marylandPath.lineTo(size.width * 0.8580813, size.height * 0.4512648);
    marylandPath.lineTo(size.width * 0.8572471, size.height * 0.4512648);
    marylandPath.lineTo(size.width * 0.8572471, size.height * 0.4543002);
    marylandPath.close();
    marylandPath.moveTo(size.width * 0.8703858, size.height * 0.4475548);
    marylandPath.lineTo(size.width * 0.8716371, size.height * 0.4438449);
    marylandPath.lineTo(size.width * 0.8717414, size.height * 0.4396290);
    marylandPath.lineTo(size.width * 0.8711157, size.height * 0.4386172);
    marylandPath.lineTo(size.width * 0.8703858, size.height * 0.4401349);
    marylandPath.lineTo(size.width * 0.8701773, size.height * 0.4436762);
    marylandPath.lineTo(size.width * 0.8693431, size.height * 0.4460371);
    marylandPath.lineTo(size.width * 0.8690302, size.height * 0.4478921);
    marylandPath.lineTo(size.width * 0.8642336, size.height * 0.4505902);
    marylandPath.lineTo(size.width * 0.8635036, size.height * 0.4519393);
    marylandPath.lineTo(size.width * 0.8621481, size.height * 0.4522766);
    marylandPath.lineTo(size.width * 0.8617310, size.height * 0.4537943);
    marylandPath.lineTo(size.width * 0.8603754, size.height * 0.4548061);
    marylandPath.lineTo(size.width * 0.8600626, size.height * 0.4505902);
    marylandPath.lineTo(size.width * 0.8604797, size.height * 0.4494098);
    marylandPath.lineTo(size.width * 0.8596455, size.height * 0.4485666);
    marylandPath.lineTo(size.width * 0.8598540, size.height * 0.4460371);
    marylandPath.lineTo(size.width * 0.8581856, size.height * 0.4477234);
    marylandPath.lineTo(size.width * 0.8581856, size.height * 0.4443508);
    marylandPath.lineTo(size.width * 0.8594369, size.height * 0.4438449);
    marylandPath.lineTo(size.width * 0.8574557, size.height * 0.4431703);
    marylandPath.lineTo(size.width * 0.8567258, size.height * 0.4418212);
    marylandPath.lineTo(size.width * 0.8571429, size.height * 0.4396290);
    marylandPath.lineTo(size.width * 0.8563087, size.height * 0.4386172);
    marylandPath.lineTo(size.width * 0.8555787, size.height * 0.4413153);
    marylandPath.lineTo(size.width * 0.8561001, size.height * 0.4426644);
    marylandPath.lineTo(size.width * 0.8553702, size.height * 0.4436762);
    marylandPath.lineTo(size.width * 0.8542231, size.height * 0.4445194);
    marylandPath.lineTo(size.width * 0.8521376, size.height * 0.4428331);
    marylandPath.lineTo(size.width * 0.8519291, size.height * 0.4408094);
    marylandPath.lineTo(size.width * 0.8508863, size.height * 0.4389545);
    marylandPath.lineTo(size.width * 0.8494265, size.height * 0.4360877);
    marylandPath.lineTo(size.width * 0.8509906, size.height * 0.4347386);
    marylandPath.lineTo(size.width * 0.8499479, size.height * 0.4337268);
    marylandPath.lineTo(size.width * 0.8499479, size.height * 0.4322091);
    marylandPath.lineTo(size.width * 0.8505735, size.height * 0.4305228);
    marylandPath.lineTo(size.width * 0.8523462, size.height * 0.4300169);
    marylandPath.lineTo(size.width * 0.8508863, size.height * 0.4290051);
    marylandPath.lineTo(size.width * 0.8507821, size.height * 0.4278246);
    marylandPath.lineTo(size.width * 0.8494265, size.height * 0.4276560);
    marylandPath.lineTo(size.width * 0.8490094, size.height * 0.4295110);
    marylandPath.lineTo(size.width * 0.8483837, size.height * 0.4300169);
    marylandPath.lineTo(size.width * 0.8484880, size.height * 0.4242833);
    marylandPath.lineTo(size.width * 0.8495308, size.height * 0.4225970);
    marylandPath.lineTo(size.width * 0.8503650, size.height * 0.4237774);
    marylandPath.lineTo(size.width * 0.8504692, size.height * 0.4210793);
    marylandPath.lineTo(size.width * 0.8494265, size.height * 0.4195616);
    marylandPath.lineTo(size.width * 0.8484880, size.height * 0.4214165);
    marylandPath.lineTo(size.width * 0.8474453, size.height * 0.4237774);
    marylandPath.lineTo(size.width * 0.8468196, size.height * 0.4220911);
    marylandPath.lineTo(size.width * 0.8470282, size.height * 0.4180438);
    marylandPath.lineTo(size.width * 0.8479666, size.height * 0.4163575);
    marylandPath.lineTo(size.width * 0.8489051, size.height * 0.4178752);
    marylandPath.lineTo(size.width * 0.8501564, size.height * 0.4166948);
    marylandPath.lineTo(size.width * 0.8497393, size.height * 0.4138280);
    marylandPath.lineTo(size.width * 0.8486966, size.height * 0.4155143);
    marylandPath.lineTo(size.width * 0.8477581, size.height * 0.4119730);
    marylandPath.lineTo(size.width * 0.8475495, size.height * 0.4091062);
    marylandPath.lineTo(size.width * 0.8486966, size.height * 0.4050590);
    marylandPath.lineTo(size.width * 0.8498436, size.height * 0.4026981);
    marylandPath.lineTo(size.width * 0.8513034, size.height * 0.4023609);
    marylandPath.lineTo(size.width * 0.8507821, size.height * 0.4010118);
    marylandPath.lineTo(size.width * 0.8513034, size.height * 0.4000000);
    marylandPath.lineTo(size.width * 0.8509906, size.height * 0.3988196);
    marylandPath.lineTo(size.width * 0.8511992, size.height * 0.3952782);
    marylandPath.lineTo(size.width * 0.8496350, size.height * 0.3959528);
    marylandPath.lineTo(size.width * 0.8488008, size.height * 0.3978078);
    marylandPath.lineTo(size.width * 0.8498436, size.height * 0.4000000);
    marylandPath.lineTo(size.width * 0.8471324, size.height * 0.4060708);
    marylandPath.lineTo(size.width * 0.8461940, size.height * 0.4053963);
    marylandPath.lineTo(size.width * 0.8454640, size.height * 0.4069140);
    marylandPath.lineTo(size.width * 0.8448384, size.height * 0.4106239);
    marylandPath.lineTo(size.width * 0.8429614, size.height * 0.4114671);
    marylandPath.lineTo(size.width * 0.8443170, size.height * 0.4124789);
    marylandPath.lineTo(size.width * 0.8456726, size.height * 0.4146712);
    marylandPath.lineTo(size.width * 0.8454640, size.height * 0.4158516);
    marylandPath.lineTo(size.width * 0.8464025, size.height * 0.4178752);
    marylandPath.lineTo(size.width * 0.8452555, size.height * 0.4195616);
    marylandPath.lineTo(size.width * 0.8457769, size.height * 0.4200675);
    marylandPath.lineTo(size.width * 0.8452555, size.height * 0.4222597);
    marylandPath.lineTo(size.width * 0.8452555, size.height * 0.4258010);
    marylandPath.lineTo(size.width * 0.8447341, size.height * 0.4279933);
    marylandPath.lineTo(size.width * 0.8456726, size.height * 0.4298482);
    marylandPath.lineTo(size.width * 0.8464025, size.height * 0.4355818);
    marylandPath.lineTo(size.width * 0.8477581, size.height * 0.4379427);
    marylandPath.lineTo(size.width * 0.8494265, size.height * 0.4403035);
    marylandPath.lineTo(size.width * 0.8498436, size.height * 0.4450253);
    marylandPath.lineTo(size.width * 0.8515120, size.height * 0.4483980);
    marylandPath.lineTo(size.width * 0.8519291, size.height * 0.4507589);
    marylandPath.lineTo(size.width * 0.8519291, size.height * 0.4524452);
    marylandPath.lineTo(size.width * 0.8511992, size.height * 0.4524452);
    marylandPath.lineTo(size.width * 0.8496350, size.height * 0.4504216);
    marylandPath.lineTo(size.width * 0.8492179, size.height * 0.4507589);
    marylandPath.lineTo(size.width * 0.8479666, size.height * 0.4504216);
    marylandPath.lineTo(size.width * 0.8461940, size.height * 0.4480607);
    marylandPath.lineTo(size.width * 0.8447341, size.height * 0.4475548);
    marylandPath.lineTo(size.width * 0.8436913, size.height * 0.4483980);
    marylandPath.lineTo(size.width * 0.8424400, size.height * 0.4478921);
    marylandPath.lineTo(size.width * 0.8420229, size.height * 0.4482293);
    marylandPath.lineTo(size.width * 0.8402503, size.height * 0.4468803);
    marylandPath.lineTo(size.width * 0.8392075, size.height * 0.4451939);
    marylandPath.lineTo(size.width * 0.8381648, size.height * 0.4430017);
    marylandPath.lineTo(size.width * 0.8375391, size.height * 0.4426644);
    marylandPath.lineTo(size.width * 0.8367049, size.height * 0.4438449);
    marylandPath.lineTo(size.width * 0.8350365, size.height * 0.4460371);
    marylandPath.lineTo(size.width * 0.8338895, size.height * 0.4446880);
    marylandPath.lineTo(size.width * 0.8334724, size.height * 0.4408094);
    marylandPath.lineTo(size.width * 0.8343066, size.height * 0.4372681);
    marylandPath.lineTo(size.width * 0.8339937, size.height * 0.4364250);
    marylandPath.lineTo(size.width * 0.8343066, size.height * 0.4357504);
    marylandPath.lineTo(size.width * 0.8335766, size.height * 0.4340641);
    marylandPath.lineTo(size.width * 0.8346194, size.height * 0.4338954);
    marylandPath.lineTo(size.width * 0.8356621, size.height * 0.4323777);
    marylandPath.lineTo(size.width * 0.8360792, size.height * 0.4293423);
    marylandPath.lineTo(size.width * 0.8378519, size.height * 0.4249578);
    marylandPath.lineTo(size.width * 0.8351408, size.height * 0.4219224);
    marylandPath.lineTo(size.width * 0.8340980, size.height * 0.4247892);
    marylandPath.lineTo(size.width * 0.8334724, size.height * 0.4237774);
    marylandPath.lineTo(size.width * 0.8324296, size.height * 0.4237774);
    marylandPath.lineTo(size.width * 0.8318040, size.height * 0.4236088);
    marylandPath.lineTo(size.width * 0.8313869, size.height * 0.4229342);
    marylandPath.lineTo(size.width * 0.8314911, size.height * 0.4220911);
    marylandPath.lineTo(size.width * 0.8297185, size.height * 0.4210793);
    marylandPath.lineTo(size.width * 0.8288843, size.height * 0.4215852);
    marylandPath.lineTo(size.width * 0.8276330, size.height * 0.4214165);
    marylandPath.lineTo(size.width * 0.8269030, size.height * 0.4202361);
    marylandPath.lineTo(size.width * 0.8263816, size.height * 0.4198988);
    marylandPath.lineTo(size.width * 0.8261731, size.height * 0.4187184);
    marylandPath.lineTo(size.width * 0.8267987, size.height * 0.4173693);
    marylandPath.lineTo(size.width * 0.8267987, size.height * 0.4158516);
    marylandPath.lineTo(size.width * 0.8255474, size.height * 0.4155143);
    marylandPath.lineTo(size.width * 0.8245047, size.height * 0.4139966);
    marylandPath.lineTo(size.width * 0.8235662, size.height * 0.4141653);
    marylandPath.lineTo(size.width * 0.8218978, size.height * 0.4136594);
    marylandPath.lineTo(size.width * 0.8209593, size.height * 0.4129848);
    marylandPath.lineTo(size.width * 0.8211679, size.height * 0.4102867);
    marylandPath.lineTo(size.width * 0.8201251, size.height * 0.4094435);
    marylandPath.lineTo(size.width * 0.8199166, size.height * 0.4082631);
    marylandPath.lineTo(size.width * 0.8191867, size.height * 0.4082631);
    marylandPath.lineTo(size.width * 0.8183525, size.height * 0.4062395);
    marylandPath.lineTo(size.width * 0.8185610, size.height * 0.4045531);
    marylandPath.lineTo(size.width * 0.8158498, size.height * 0.4052277);
    marylandPath.lineTo(size.width * 0.8135558, size.height * 0.4025295);
    marylandPath.lineTo(size.width * 0.8120959, size.height * 0.4030354);
    marylandPath.lineTo(size.width * 0.8111575, size.height * 0.4053963);
    marylandPath.lineTo(size.width * 0.8098019, size.height * 0.4053963);
    marylandPath.lineTo(size.width * 0.8080292, size.height * 0.4102867);
    marylandPath.lineTo(size.width * 0.8045881, size.height * 0.4109612);
    marylandPath.lineTo(size.width * 0.8026069, size.height * 0.4092749);
    marylandPath.lineTo(size.width * 0.7998957, size.height * 0.4156830);
    marylandPath.lineTo(size.width * 0.7976017, size.height * 0.4151771);
    marylandPath.lineTo(size.width * 0.7943691, size.height * 0.4217538);
    marylandPath.lineTo(size.width * 0.7934307, size.height * 0.4244519);
    marylandPath.lineTo(size.width * 0.7915537, size.height * 0.4271501);
    marylandPath.lineTo(size.width * 0.7897810, size.height * 0.4079258);
    marylandPath.lineTo(size.width * 0.8528676, size.height * 0.3880270);
    marylandPath.lineTo(size.width * 0.8607925, size.height * 0.4337268);
    marylandPath.lineTo(size.width * 0.8721585, size.height * 0.4298482);
    marylandPath.lineTo(size.width * 0.8721585, size.height * 0.4387858);
    marylandPath.lineTo(size.width * 0.8720542, size.height * 0.4440135);
    marylandPath.lineTo(size.width * 0.8710115, size.height * 0.4470489);
    marylandPath.close();
    marylandPath.moveTo(size.width * 0.8564129, size.height * 0.4445194);
    marylandPath.lineTo(size.width * 0.8550574, size.height * 0.4460371);
    marylandPath.lineTo(size.width * 0.8558916, size.height * 0.4490725);
    marylandPath.lineTo(size.width * 0.8576642, size.height * 0.4504216);
    marylandPath.lineTo(size.width * 0.8572471, size.height * 0.4477234);
    marylandPath.close();

    Paint marylandPaint = Paint()..style = PaintingStyle.fill;
    marylandPaint.color = usaColors.maryland ?? defaultColor;
    usaCanvas.drawPath(marylandPath, marylandPaint, onTapUp: (tabdetail) {
      callback('maryland', tabdetail);
    });

    Path massachusettsPath = Path();
    massachusettsPath.moveTo(size.width * 0.9383733, size.height * 0.2937605);
    massachusettsPath.lineTo(size.width * 0.9419187, size.height * 0.2937605);
    massachusettsPath.lineTo(size.width * 0.9428571, size.height * 0.2927487);
    massachusettsPath.lineTo(size.width * 0.9429614, size.height * 0.2905565);
    massachusettsPath.lineTo(size.width * 0.9409802, size.height * 0.2875211);
    massachusettsPath.lineTo(size.width * 0.9413973, size.height * 0.2892074);
    massachusettsPath.lineTo(size.width * 0.9398332, size.height * 0.2917369);
    massachusettsPath.lineTo(size.width * 0.9374348, size.height * 0.2917369);
    massachusettsPath.lineTo(size.width * 0.9375391, size.height * 0.2930860);
    massachusettsPath.close();
    massachusettsPath.moveTo(size.width * 0.9289885, size.height * 0.2967960);
    massachusettsPath.lineTo(size.width * 0.9277372, size.height * 0.2957841);
    massachusettsPath.lineTo(size.width * 0.9287800, size.height * 0.2944351);
    massachusettsPath.lineTo(size.width * 0.9294056, size.height * 0.2908938);
    massachusettsPath.lineTo(size.width * 0.9306569, size.height * 0.2892074);
    massachusettsPath.lineTo(size.width * 0.9314911, size.height * 0.2888702);
    massachusettsPath.lineTo(size.width * 0.9321168, size.height * 0.2903879);
    massachusettsPath.lineTo(size.width * 0.9332638, size.height * 0.2907251);
    massachusettsPath.lineTo(size.width * 0.9338895, size.height * 0.2897133);
    massachusettsPath.lineTo(size.width * 0.9344108, size.height * 0.2929174);
    massachusettsPath.lineTo(size.width * 0.9330553, size.height * 0.2934233);
    massachusettsPath.lineTo(size.width * 0.9301356, size.height * 0.2946037);
    massachusettsPath.close();
    massachusettsPath.moveTo(size.width * 0.8925965, size.height * 0.2573356);
    massachusettsPath.lineTo(size.width * 0.9117831, size.height * 0.2509275);
    massachusettsPath.lineTo(size.width * 0.9128259, size.height * 0.2483980);
    massachusettsPath.lineTo(size.width * 0.9131387, size.height * 0.2455312);
    massachusettsPath.lineTo(size.width * 0.9151199, size.height * 0.2445194);
    massachusettsPath.lineTo(size.width * 0.9156413, size.height * 0.2426644);
    massachusettsPath.lineTo(size.width * 0.9174140, size.height * 0.2408094);
    massachusettsPath.lineTo(size.width * 0.9187696, size.height * 0.2413153);
    massachusettsPath.lineTo(size.width * 0.9205422, size.height * 0.2468803);
    massachusettsPath.lineTo(size.width * 0.9215850, size.height * 0.2475548);
    massachusettsPath.lineTo(size.width * 0.9227320, size.height * 0.2453626);
    massachusettsPath.lineTo(size.width * 0.9235662, size.height * 0.2475548);
    massachusettsPath.lineTo(size.width * 0.9235662, size.height * 0.2494098);
    massachusettsPath.lineTo(size.width * 0.9204380, size.height * 0.2534570);
    massachusettsPath.lineTo(size.width * 0.9206465, size.height * 0.2548061);
    massachusettsPath.lineTo(size.width * 0.9197080, size.height * 0.2564924);
    massachusettsPath.lineTo(size.width * 0.9201251, size.height * 0.2578415);
    massachusettsPath.lineTo(size.width * 0.9187696, size.height * 0.2583474);
    massachusettsPath.lineTo(size.width * 0.9197080, size.height * 0.2603710);
    massachusettsPath.lineTo(size.width * 0.9188738, size.height * 0.2615514);
    massachusettsPath.lineTo(size.width * 0.9194995, size.height * 0.2632378);
    massachusettsPath.lineTo(size.width * 0.9204380, size.height * 0.2629005);
    massachusettsPath.lineTo(size.width * 0.9207508, size.height * 0.2615514);
    massachusettsPath.lineTo(size.width * 0.9218978, size.height * 0.2625632);
    massachusettsPath.lineTo(size.width * 0.9237748, size.height * 0.2625632);
    massachusettsPath.lineTo(size.width * 0.9263816, size.height * 0.2669477);
    massachusettsPath.lineTo(size.width * 0.9265902, size.height * 0.2713322);
    massachusettsPath.lineTo(size.width * 0.9284672, size.height * 0.2715008);
    massachusettsPath.lineTo(size.width * 0.9293014, size.height * 0.2733558);
    massachusettsPath.lineTo(size.width * 0.9299270, size.height * 0.2767285);
    massachusettsPath.lineTo(size.width * 0.9309698, size.height * 0.2779089);
    massachusettsPath.lineTo(size.width * 0.9329510, size.height * 0.2779089);
    massachusettsPath.lineTo(size.width * 0.9349322, size.height * 0.2777403);
    massachusettsPath.lineTo(size.width * 0.9357664, size.height * 0.2762226);
    massachusettsPath.lineTo(size.width * 0.9374348, size.height * 0.2741990);
    massachusettsPath.lineTo(size.width * 0.9385819, size.height * 0.2736931);
    massachusettsPath.lineTo(size.width * 0.9373306, size.height * 0.2701518);
    massachusettsPath.lineTo(size.width * 0.9370177, size.height * 0.2716695);
    massachusettsPath.lineTo(size.width * 0.9354536, size.height * 0.2655987);
    massachusettsPath.lineTo(size.width * 0.9346194, size.height * 0.2655987);
    massachusettsPath.lineTo(size.width * 0.9342023, size.height * 0.2671164);
    massachusettsPath.lineTo(size.width * 0.9329510, size.height * 0.2654300);
    massachusettsPath.lineTo(size.width * 0.9343066, size.height * 0.2635750);
    massachusettsPath.lineTo(size.width * 0.9361835, size.height * 0.2642496);
    massachusettsPath.lineTo(size.width * 0.9385819, size.height * 0.2677909);
    massachusettsPath.lineTo(size.width * 0.9399374, size.height * 0.2723440);
    massachusettsPath.lineTo(size.width * 0.9411887, size.height * 0.2779089);
    massachusettsPath.lineTo(size.width * 0.9401460, size.height * 0.2826307);
    massachusettsPath.lineTo(size.width * 0.9401460, size.height * 0.2795953);
    massachusettsPath.lineTo(size.width * 0.9394161, size.height * 0.2779089);
    massachusettsPath.lineTo(size.width * 0.9357664, size.height * 0.2817875);
    massachusettsPath.lineTo(size.width * 0.9348279, size.height * 0.2812816);
    massachusettsPath.lineTo(size.width * 0.9331595, size.height * 0.2829680);
    massachusettsPath.lineTo(size.width * 0.9330553, size.height * 0.2849916);
    massachusettsPath.lineTo(size.width * 0.9307612, size.height * 0.2870152);
    massachusettsPath.lineTo(size.width * 0.9286757, size.height * 0.2905565);
    massachusettsPath.lineTo(size.width * 0.9265902, size.height * 0.2937605);
    massachusettsPath.lineTo(size.width * 0.9253389, size.height * 0.2937605);
    massachusettsPath.lineTo(size.width * 0.9287800, size.height * 0.2881956);
    massachusettsPath.lineTo(size.width * 0.9293014, size.height * 0.2849916);
    massachusettsPath.lineTo(size.width * 0.9287800, size.height * 0.2839798);
    massachusettsPath.lineTo(size.width * 0.9284672, size.height * 0.2817875);
    massachusettsPath.lineTo(size.width * 0.9275287, size.height * 0.2816189);
    massachusettsPath.lineTo(size.width * 0.9274244, size.height * 0.2838111);
    massachusettsPath.lineTo(size.width * 0.9263816, size.height * 0.2858347);
    massachusettsPath.lineTo(size.width * 0.9251303, size.height * 0.2858347);
    massachusettsPath.lineTo(size.width * 0.9248175, size.height * 0.2876897);
    massachusettsPath.lineTo(size.width * 0.9252346, size.height * 0.2897133);
    massachusettsPath.lineTo(size.width * 0.9239833, size.height * 0.2915683);
    massachusettsPath.lineTo(size.width * 0.9228363, size.height * 0.2912310);
    massachusettsPath.lineTo(size.width * 0.9224192, size.height * 0.2929174);
    massachusettsPath.lineTo(size.width * 0.9209593, size.height * 0.2878583);
    massachusettsPath.lineTo(size.width * 0.9196038, size.height * 0.2860034);
    massachusettsPath.lineTo(size.width * 0.9168926, size.height * 0.2838111);
    massachusettsPath.lineTo(size.width * 0.9162669, size.height * 0.2801012);
    massachusettsPath.lineTo(size.width * 0.9154327, size.height * 0.2801012);
    massachusettsPath.lineTo(size.width * 0.9147028, size.height * 0.2757167);
    massachusettsPath.lineTo(size.width * 0.9079249, size.height * 0.2790894);
    massachusettsPath.lineTo(size.width * 0.9078206, size.height * 0.2785835);
    massachusettsPath.lineTo(size.width * 0.8922836, size.height * 0.2843170);
    massachusettsPath.lineTo(size.width * 0.8922836, size.height * 0.2854975);
    massachusettsPath.lineTo(size.width * 0.8913452, size.height * 0.2860034);
    massachusettsPath.lineTo(size.width * 0.8908238, size.height * 0.2848229);
    massachusettsPath.lineTo(size.width * 0.8798749, size.height * 0.2888702);
    massachusettsPath.lineTo(size.width * 0.8791449, size.height * 0.2871838);
    massachusettsPath.lineTo(size.width * 0.8796663, size.height * 0.2618887);
    massachusettsPath.close();

    Paint massachusettsPaint = Paint()..style = PaintingStyle.fill;
    massachusettsPaint.color = usaColors.massachusetts ?? defaultColor;
    usaCanvas.drawPath(massachusettsPath, massachusettsPaint,
        onTapUp: (tabdetail) {
      callback('massachusetts', tabdetail);
    });

    Path michiganPath = Path();
    michiganPath.moveTo(size.width * 0.6916580, size.height * 0.3537943);
    michiganPath.lineTo(size.width * 0.6917623, size.height * 0.3561551);
    michiganPath.lineTo(size.width * 0.7140772, size.height * 0.3502530);
    michiganPath.lineTo(size.width * 0.7145985, size.height * 0.3482293);
    michiganPath.lineTo(size.width * 0.7186653, size.height * 0.3382799);
    michiganPath.lineTo(size.width * 0.7186653, size.height * 0.3310287);
    michiganPath.lineTo(size.width * 0.7194995, size.height * 0.3274874);
    michiganPath.lineTo(size.width * 0.7217935, size.height * 0.3261383);
    michiganPath.lineTo(size.width * 0.7238790, size.height * 0.3129848);
    michiganPath.lineTo(size.width * 0.7249218, size.height * 0.3121417);
    michiganPath.lineTo(size.width * 0.7259645, size.height * 0.3131535);
    michiganPath.lineTo(size.width * 0.7257560, size.height * 0.3141653);
    michiganPath.lineTo(size.width * 0.7246090, size.height * 0.3155143);
    michiganPath.lineTo(size.width * 0.7249218, size.height * 0.3170320);
    michiganPath.lineTo(size.width * 0.7257560, size.height * 0.3177066);
    michiganPath.lineTo(size.width * 0.7277372, size.height * 0.3153457);
    michiganPath.lineTo(size.width * 0.7281543, size.height * 0.2988196);
    michiganPath.lineTo(size.width * 0.7264859, size.height * 0.2949410);
    michiganPath.lineTo(size.width * 0.7252346, size.height * 0.2887015);
    michiganPath.lineTo(size.width * 0.7252346, size.height * 0.2844857);
    michiganPath.lineTo(size.width * 0.7228363, size.height * 0.2770658);
    michiganPath.lineTo(size.width * 0.7228363, size.height * 0.2740304);
    michiganPath.lineTo(size.width * 0.7215850, size.height * 0.2684654);
    michiganPath.lineTo(size.width * 0.7191867, size.height * 0.2634064);
    michiganPath.lineTo(size.width * 0.7161627, size.height * 0.2617201);
    michiganPath.lineTo(size.width * 0.7111575, size.height * 0.2667791);
    michiganPath.lineTo(size.width * 0.7085506, size.height * 0.2745363);
    michiganPath.lineTo(size.width * 0.7083420, size.height * 0.2760540);
    michiganPath.lineTo(size.width * 0.7052138, size.height * 0.2819562);
    michiganPath.lineTo(size.width * 0.7036496, size.height * 0.2816189);
    michiganPath.lineTo(size.width * 0.7006257, size.height * 0.2768971);
    michiganPath.lineTo(size.width * 0.7005214, size.height * 0.2711636);
    michiganPath.lineTo(size.width * 0.7020855, size.height * 0.2679595);
    michiganPath.lineTo(size.width * 0.7041710, size.height * 0.2676223);
    michiganPath.lineTo(size.width * 0.7054223, size.height * 0.2647555);
    michiganPath.lineTo(size.width * 0.7056309, size.height * 0.2580101);
    michiganPath.lineTo(size.width * 0.7064651, size.height * 0.2566610);
    michiganPath.lineTo(size.width * 0.7076121, size.height * 0.2564924);
    michiganPath.lineTo(size.width * 0.7085506, size.height * 0.2536256);
    michiganPath.lineTo(size.width * 0.7083420, size.height * 0.2374368);
    michiganPath.lineTo(size.width * 0.7080292, size.height * 0.2352445);
    michiganPath.lineTo(size.width * 0.7067779, size.height * 0.2332209);
    michiganPath.lineTo(size.width * 0.7050052, size.height * 0.2315346);
    michiganPath.lineTo(size.width * 0.7049009, size.height * 0.2284992);
    michiganPath.lineTo(size.width * 0.7056309, size.height * 0.2274874);
    michiganPath.lineTo(size.width * 0.7075078, size.height * 0.2288364);
    michiganPath.lineTo(size.width * 0.7071950, size.height * 0.2259696);
    michiganPath.lineTo(size.width * 0.7052138, size.height * 0.2214165);
    michiganPath.lineTo(size.width * 0.7044838, size.height * 0.2187184);
    michiganPath.lineTo(size.width * 0.7033368, size.height * 0.2168634);
    michiganPath.lineTo(size.width * 0.7010428, size.height * 0.2168634);
    michiganPath.lineTo(size.width * 0.6925965, size.height * 0.2119730);
    michiganPath.lineTo(size.width * 0.6911366, size.height * 0.2091062);
    michiganPath.lineTo(size.width * 0.6879041, size.height * 0.2086003);
    michiganPath.lineTo(size.width * 0.6866528, size.height * 0.2091062);
    michiganPath.lineTo(size.width * 0.6820647, size.height * 0.2052277);
    michiganPath.lineTo(size.width * 0.6806048, size.height * 0.2052277);
    michiganPath.lineTo(size.width * 0.6811262, size.height * 0.2069140);
    michiganPath.lineTo(size.width * 0.6783107, size.height * 0.2067454);
    michiganPath.lineTo(size.width * 0.6784150, size.height * 0.2077572);
    michiganPath.lineTo(size.width * 0.6790407, size.height * 0.2087690);
    michiganPath.lineTo(size.width * 0.6764338, size.height * 0.2123103);
    michiganPath.lineTo(size.width * 0.6765381, size.height * 0.2153457);
    michiganPath.lineTo(size.width * 0.6781022, size.height * 0.2192243);
    michiganPath.lineTo(size.width * 0.6796663, size.height * 0.2195616);
    michiganPath.lineTo(size.width * 0.6796663, size.height * 0.2205734);
    michiganPath.lineTo(size.width * 0.6781022, size.height * 0.2214165);
    michiganPath.lineTo(size.width * 0.6759124, size.height * 0.2212479);
    michiganPath.lineTo(size.width * 0.6729927, size.height * 0.2254637);
    michiganPath.lineTo(size.width * 0.6730970, size.height * 0.2296796);
    michiganPath.lineTo(size.width * 0.6735141, size.height * 0.2394604);
    michiganPath.lineTo(size.width * 0.6712200, size.height * 0.2451939);
    michiganPath.lineTo(size.width * 0.6720542, size.height * 0.2376054);
    michiganPath.lineTo(size.width * 0.6712200, size.height * 0.2365936);
    michiganPath.lineTo(size.width * 0.6702815, size.height * 0.2455312);
    michiganPath.lineTo(size.width * 0.6692388, size.height * 0.2416526);
    michiganPath.lineTo(size.width * 0.6697602, size.height * 0.2377740);
    michiganPath.lineTo(size.width * 0.6692388, size.height * 0.2360877);
    michiganPath.lineTo(size.width * 0.6698644, size.height * 0.2338954);
    michiganPath.lineTo(size.width * 0.6692388, size.height * 0.2320405);
    michiganPath.lineTo(size.width * 0.6702815, size.height * 0.2303541);
    michiganPath.lineTo(size.width * 0.6702815, size.height * 0.2283305);
    michiganPath.lineTo(size.width * 0.6689260, size.height * 0.2293423);
    michiganPath.lineTo(size.width * 0.6675704, size.height * 0.2345700);
    michiganPath.lineTo(size.width * 0.6668405, size.height * 0.2357504);
    michiganPath.lineTo(size.width * 0.6654849, size.height * 0.2397976);
    michiganPath.lineTo(size.width * 0.6637122, size.height * 0.2394604);
    michiganPath.lineTo(size.width * 0.6636079, size.height * 0.2414840);
    michiganPath.lineTo(size.width * 0.6619395, size.height * 0.2414840);
    michiganPath.lineTo(size.width * 0.6621481, size.height * 0.2440135);
    michiganPath.lineTo(size.width * 0.6623566, size.height * 0.2473862);
    michiganPath.lineTo(size.width * 0.6592284, size.height * 0.2494098);
    michiganPath.lineTo(size.width * 0.6593326, size.height * 0.2516020);
    michiganPath.lineTo(size.width * 0.6603754, size.height * 0.2544688);
    michiganPath.lineTo(size.width * 0.6602711, size.height * 0.2632378);
    michiganPath.lineTo(size.width * 0.6589155, size.height * 0.2706577);
    michiganPath.lineTo(size.width * 0.6571429, size.height * 0.2748735);
    michiganPath.lineTo(size.width * 0.6583942, size.height * 0.2772344);
    michiganPath.lineTo(size.width * 0.6592284, size.height * 0.2831366);
    michiganPath.lineTo(size.width * 0.6581856, size.height * 0.2873524);
    michiganPath.lineTo(size.width * 0.6579771, size.height * 0.2908938);
    michiganPath.lineTo(size.width * 0.6597497, size.height * 0.2966273);
    michiganPath.lineTo(size.width * 0.6623566, size.height * 0.3048904);
    michiganPath.lineTo(size.width * 0.6636079, size.height * 0.3080944);
    michiganPath.lineTo(size.width * 0.6652763, size.height * 0.3197302);
    michiganPath.lineTo(size.width * 0.6651721, size.height * 0.3345700);
    michiganPath.lineTo(size.width * 0.6642336, size.height * 0.3411467);
    michiganPath.lineTo(size.width * 0.6621481, size.height * 0.3465430);
    michiganPath.lineTo(size.width * 0.6612096, size.height * 0.3527825);
    michiganPath.lineTo(size.width * 0.6591241, size.height * 0.3578415);
    michiganPath.lineTo(size.width * 0.6578728, size.height * 0.3595278);
    michiganPath.close();
    michiganPath.moveTo(size.width * 0.5917623, size.height * 0.1905565);
    michiganPath.lineTo(size.width * 0.5948905, size.height * 0.1969646);
    michiganPath.lineTo(size.width * 0.6126173, size.height * 0.2033727);
    michiganPath.lineTo(size.width * 0.6140772, size.height * 0.2050590);
    michiganPath.lineTo(size.width * 0.6182482, size.height * 0.2064081);
    michiganPath.lineTo(size.width * 0.6189781, size.height * 0.2072513);
    michiganPath.lineTo(size.width * 0.6218978, size.height * 0.2069140);
    michiganPath.lineTo(size.width * 0.6270073, size.height * 0.2082631);
    michiganPath.lineTo(size.width * 0.6284672, size.height * 0.2107926);
    michiganPath.lineTo(size.width * 0.6274244, size.height * 0.2124789);
    michiganPath.lineTo(size.width * 0.6282586, size.height * 0.2138280);
    michiganPath.lineTo(size.width * 0.6322211, size.height * 0.2150084);
    michiganPath.lineTo(size.width * 0.6334724, size.height * 0.2170320);
    michiganPath.lineTo(size.width * 0.6335766, size.height * 0.2244519);
    michiganPath.lineTo(size.width * 0.6322211, size.height * 0.2291737);
    michiganPath.lineTo(size.width * 0.6343066, size.height * 0.2293423);
    michiganPath.lineTo(size.width * 0.6353493, size.height * 0.2279933);
    michiganPath.lineTo(size.width * 0.6362878, size.height * 0.2293423);
    michiganPath.lineTo(size.width * 0.6351408, size.height * 0.2345700);
    michiganPath.lineTo(size.width * 0.6361835, size.height * 0.2372681);
    michiganPath.lineTo(size.width * 0.6374348, size.height * 0.2377740);
    michiganPath.lineTo(size.width * 0.6382690, size.height * 0.2347386);
    michiganPath.lineTo(size.width * 0.6412930, size.height * 0.2269815);
    michiganPath.lineTo(size.width * 0.6429614, size.height * 0.2168634);
    michiganPath.lineTo(size.width * 0.6453597, size.height * 0.2134907);
    michiganPath.lineTo(size.width * 0.6448384, size.height * 0.2107926);
    michiganPath.lineTo(size.width * 0.6453597, size.height * 0.2092749);
    michiganPath.lineTo(size.width * 0.6464025, size.height * 0.2119730);
    michiganPath.lineTo(size.width * 0.6460897, size.height * 0.2156830);
    michiganPath.lineTo(size.width * 0.6491137, size.height * 0.2119730);
    michiganPath.lineTo(size.width * 0.6493222, size.height * 0.2080944);
    michiganPath.lineTo(size.width * 0.6515120, size.height * 0.2091062);
    michiganPath.lineTo(size.width * 0.6523462, size.height * 0.2064081);
    michiganPath.lineTo(size.width * 0.6530761, size.height * 0.2074199);
    michiganPath.lineTo(size.width * 0.6523462, size.height * 0.2099494);
    michiganPath.lineTo(size.width * 0.6513034, size.height * 0.2107926);
    michiganPath.lineTo(size.width * 0.6502607, size.height * 0.2141653);
    michiganPath.lineTo(size.width * 0.6517205, size.height * 0.2172007);
    michiganPath.lineTo(size.width * 0.6528676, size.height * 0.2163575);
    michiganPath.lineTo(size.width * 0.6523462, size.height * 0.2151771);
    michiganPath.lineTo(size.width * 0.6533889, size.height * 0.2126476);
    michiganPath.lineTo(size.width * 0.6553702, size.height * 0.2097808);
    michiganPath.lineTo(size.width * 0.6562044, size.height * 0.2097808);
    michiganPath.lineTo(size.width * 0.6564129, size.height * 0.2053963);
    michiganPath.lineTo(size.width * 0.6584984, size.height * 0.2023609);
    michiganPath.lineTo(size.width * 0.6667362, size.height * 0.2015177);
    michiganPath.lineTo(size.width * 0.6687174, size.height * 0.1962901);
    michiganPath.lineTo(size.width * 0.6726799, size.height * 0.1957841);
    michiganPath.lineTo(size.width * 0.6766423, size.height * 0.1978078);
    michiganPath.lineTo(size.width * 0.6810219, size.height * 0.2023609);
    michiganPath.lineTo(size.width * 0.6817518, size.height * 0.2020236);
    michiganPath.lineTo(size.width * 0.6815433, size.height * 0.1961214);
    michiganPath.lineTo(size.width * 0.6822732, size.height * 0.1957841);
    michiganPath.lineTo(size.width * 0.6869656, size.height * 0.1976391);
    michiganPath.lineTo(size.width * 0.6885297, size.height * 0.1973019);
    michiganPath.lineTo(size.width * 0.6915537, size.height * 0.1961214);
    michiganPath.lineTo(size.width * 0.6933264, size.height * 0.1967960);
    michiganPath.lineTo(size.width * 0.6952033, size.height * 0.1969646);
    michiganPath.lineTo(size.width * 0.6952033, size.height * 0.1951096);
    michiganPath.lineTo(size.width * 0.6944734, size.height * 0.1935919);
    michiganPath.lineTo(size.width * 0.6929093, size.height * 0.1932546);
    michiganPath.lineTo(size.width * 0.6917623, size.height * 0.1919056);
    michiganPath.lineTo(size.width * 0.6922836, size.height * 0.1895447);
    michiganPath.lineTo(size.width * 0.6914494, size.height * 0.1890388);
    michiganPath.lineTo(size.width * 0.6887383, size.height * 0.1892074);
    michiganPath.lineTo(size.width * 0.6886340, size.height * 0.1875211);
    michiganPath.lineTo(size.width * 0.6897810, size.height * 0.1861720);
    michiganPath.lineTo(size.width * 0.6904067, size.height * 0.1875211);
    michiganPath.lineTo(size.width * 0.6909281, size.height * 0.1844857);
    michiganPath.lineTo(size.width * 0.6901981, size.height * 0.1833052);
    michiganPath.lineTo(size.width * 0.6909281, size.height * 0.1829680);
    michiganPath.lineTo(size.width * 0.6894682, size.height * 0.1807757);
    michiganPath.lineTo(size.width * 0.6897810, size.height * 0.1785835);
    michiganPath.lineTo(size.width * 0.6898853, size.height * 0.1753794);
    michiganPath.lineTo(size.width * 0.6885297, size.height * 0.1753794);
    michiganPath.lineTo(size.width * 0.6869656, size.height * 0.1770658);
    michiganPath.lineTo(size.width * 0.6849844, size.height * 0.1772344);
    michiganPath.lineTo(size.width * 0.6844630, size.height * 0.1802698);
    michiganPath.lineTo(size.width * 0.6824818, size.height * 0.1806071);
    michiganPath.lineTo(size.width * 0.6821689, size.height * 0.1785835);
    michiganPath.lineTo(size.width * 0.6798749, size.height * 0.1787521);
    michiganPath.lineTo(size.width * 0.6788321, size.height * 0.1807757);
    michiganPath.lineTo(size.width * 0.6781022, size.height * 0.1806071);
    michiganPath.lineTo(size.width * 0.6778936, size.height * 0.1792580);
    michiganPath.lineTo(size.width * 0.6751825, size.height * 0.1799325);
    michiganPath.lineTo(size.width * 0.6750782, size.height * 0.1718381);
    michiganPath.lineTo(size.width * 0.6761210, size.height * 0.1684654);
    michiganPath.lineTo(size.width * 0.6753910, size.height * 0.1682968);
    michiganPath.lineTo(size.width * 0.6735141, size.height * 0.1701518);
    michiganPath.lineTo(size.width * 0.6712200, size.height * 0.1701518);
    michiganPath.lineTo(size.width * 0.6672576, size.height * 0.1747049);
    michiganPath.lineTo(size.width * 0.6607925, size.height * 0.1752108);
    michiganPath.lineTo(size.width * 0.6565172, size.height * 0.1765599);
    michiganPath.lineTo(size.width * 0.6545360, size.height * 0.1790894);
    michiganPath.lineTo(size.width * 0.6530761, size.height * 0.1812816);
    michiganPath.lineTo(size.width * 0.6504692, size.height * 0.1841484);
    michiganPath.lineTo(size.width * 0.6501564, size.height * 0.1854975);
    michiganPath.lineTo(size.width * 0.6495308, size.height * 0.1826307);
    michiganPath.lineTo(size.width * 0.6481752, size.height * 0.1816189);
    michiganPath.lineTo(size.width * 0.6481752, size.height * 0.1826307);
    michiganPath.lineTo(size.width * 0.6489051, size.height * 0.1838111);
    michiganPath.lineTo(size.width * 0.6489051, size.height * 0.1860034);
    michiganPath.lineTo(size.width * 0.6473410, size.height * 0.1849916);
    michiganPath.lineTo(size.width * 0.6467153, size.height * 0.1849916);
    michiganPath.lineTo(size.width * 0.6464025, size.height * 0.1870152);
    michiganPath.lineTo(size.width * 0.6443170, size.height * 0.1838111);
    michiganPath.lineTo(size.width * 0.6429614, size.height * 0.1834739);
    michiganPath.lineTo(size.width * 0.6416058, size.height * 0.1860034);
    michiganPath.lineTo(size.width * 0.6382690, size.height * 0.1858347);
    michiganPath.lineTo(size.width * 0.6377477, size.height * 0.1834739);
    michiganPath.lineTo(size.width * 0.6356621, size.height * 0.1802698);
    michiganPath.lineTo(size.width * 0.6343066, size.height * 0.1775717);
    michiganPath.lineTo(size.width * 0.6343066, size.height * 0.1763912);
    michiganPath.lineTo(size.width * 0.6331595, size.height * 0.1740304);
    michiganPath.lineTo(size.width * 0.6304484, size.height * 0.1720067);
    michiganPath.lineTo(size.width * 0.6270073, size.height * 0.1718381);
    michiganPath.lineTo(size.width * 0.6258603, size.height * 0.1703204);
    michiganPath.lineTo(size.width * 0.6244004, size.height * 0.1703204);
    michiganPath.lineTo(size.width * 0.6236705, size.height * 0.1709949);
    michiganPath.lineTo(size.width * 0.6213764, size.height * 0.1747049);
    michiganPath.lineTo(size.width * 0.6206465, size.height * 0.1765599);
    michiganPath.lineTo(size.width * 0.6196038, size.height * 0.1753794);
    michiganPath.lineTo(size.width * 0.6198123, size.height * 0.1736931);
    michiganPath.lineTo(size.width * 0.6206465, size.height * 0.1701518);
    michiganPath.lineTo(size.width * 0.6239833, size.height * 0.1617201);
    michiganPath.lineTo(size.width * 0.6248175, size.height * 0.1613828);
    michiganPath.lineTo(size.width * 0.6265902, size.height * 0.1581788);
    michiganPath.lineTo(size.width * 0.6273201, size.height * 0.1554806);
    michiganPath.lineTo(size.width * 0.6304484, size.height * 0.1544688);
    michiganPath.lineTo(size.width * 0.6312826, size.height * 0.1534570);
    michiganPath.lineTo(size.width * 0.6311783, size.height * 0.1517707);
    michiganPath.lineTo(size.width * 0.6306569, size.height * 0.1509275);
    michiganPath.lineTo(size.width * 0.6259645, size.height * 0.1512648);
    michiganPath.lineTo(size.width * 0.6238790, size.height * 0.1521079);
    michiganPath.lineTo(size.width * 0.6211679, size.height * 0.1541315);
    michiganPath.lineTo(size.width * 0.6199166, size.height * 0.1561551);
    michiganPath.lineTo(size.width * 0.6181439, size.height * 0.1598651);
    michiganPath.lineTo(size.width * 0.6162669, size.height * 0.1615514);
    michiganPath.lineTo(size.width * 0.6128259, size.height * 0.1672850);
    michiganPath.lineTo(size.width * 0.6124088, size.height * 0.1699831);
    michiganPath.lineTo(size.width * 0.6046924, size.height * 0.1777403);
    michiganPath.lineTo(size.width * 0.6005214, size.height * 0.1785835);
    michiganPath.lineTo(size.width * 0.5986444, size.height * 0.1792580);
    michiganPath.lineTo(size.width * 0.5962461, size.height * 0.1843170);
    michiganPath.lineTo(size.width * 0.5943691, size.height * 0.1854975);
    michiganPath.lineTo(size.width * 0.5897810, size.height * 0.1893761);
    michiganPath.close();
    michiganPath.moveTo(size.width * 0.6967675, size.height * 0.1969646);
    michiganPath.lineTo(size.width * 0.7007299, size.height * 0.1971332);
    michiganPath.lineTo(size.width * 0.7013556, size.height * 0.1962901);
    michiganPath.lineTo(size.width * 0.7011470, size.height * 0.1929174);
    michiganPath.lineTo(size.width * 0.6993743, size.height * 0.1898820);
    michiganPath.lineTo(size.width * 0.6973931, size.height * 0.1900506);
    michiganPath.lineTo(size.width * 0.6972888, size.height * 0.1908938);
    michiganPath.lineTo(size.width * 0.6984359, size.height * 0.1915683);
    michiganPath.lineTo(size.width * 0.6967675, size.height * 0.1929174);
    michiganPath.lineTo(size.width * 0.6964546, size.height * 0.1946037);
    michiganPath.lineTo(size.width * 0.6958290, size.height * 0.1935919);
    michiganPath.lineTo(size.width * 0.6954119, size.height * 0.1949410);
    michiganPath.close();
    michiganPath.moveTo(size.width * 0.6184567, size.height * 0.1263069);
    michiganPath.lineTo(size.width * 0.6160584, size.height * 0.1266442);
    michiganPath.lineTo(size.width * 0.6132430, size.height * 0.1298482);
    michiganPath.lineTo(size.width * 0.6058394, size.height * 0.1387858);
    michiganPath.lineTo(size.width * 0.6066736, size.height * 0.1404722);
    michiganPath.lineTo(size.width * 0.6085506, size.height * 0.1409781);
    michiganPath.lineTo(size.width * 0.6114703, size.height * 0.1376054);
    michiganPath.lineTo(size.width * 0.6103233, size.height * 0.1367622);
    michiganPath.lineTo(size.width * 0.6127216, size.height * 0.1340641);
    michiganPath.lineTo(size.width * 0.6137643, size.height * 0.1340641);
    michiganPath.lineTo(size.width * 0.6168926, size.height * 0.1308600);
    michiganPath.lineTo(size.width * 0.6167883, size.height * 0.1293423);
    michiganPath.close();
    michiganPath.moveTo(size.width * 0.6613139, size.height * 0.2322091);
    michiganPath.lineTo(size.width * 0.6613139, size.height * 0.2338954);
    michiganPath.lineTo(size.width * 0.6635036, size.height * 0.2365936);
    michiganPath.lineTo(size.width * 0.6632951, size.height * 0.2325464);
    michiganPath.close();
    michiganPath.moveTo(size.width * 0.6605839, size.height * 0.2369309);
    michiganPath.lineTo(size.width * 0.6617310, size.height * 0.2370995);
    michiganPath.lineTo(size.width * 0.6617310, size.height * 0.2386172);
    michiganPath.lineTo(size.width * 0.6606882, size.height * 0.2386172);
    michiganPath.close();
    michiganPath.moveTo(size.width * 0.6828989, size.height * 0.2010118);
    michiganPath.lineTo(size.width * 0.6828989, size.height * 0.2025295);
    michiganPath.lineTo(size.width * 0.6837331, size.height * 0.2021922);
    michiganPath.lineTo(size.width * 0.6837331, size.height * 0.2013491);
    michiganPath.close();
    michiganPath.moveTo(size.width * 0.6877998, size.height * 0.2062395);
    michiganPath.lineTo(size.width * 0.6876955, size.height * 0.2043845);
    michiganPath.lineTo(size.width * 0.6860271, size.height * 0.2040472);
    michiganPath.lineTo(size.width * 0.6854015, size.height * 0.2033727);
    michiganPath.lineTo(size.width * 0.6844630, size.height * 0.2033727);
    michiganPath.lineTo(size.width * 0.6840459, size.height * 0.2038786);
    michiganPath.lineTo(size.width * 0.6849844, size.height * 0.2045531);
    michiganPath.lineTo(size.width * 0.6861314, size.height * 0.2064081);
    michiganPath.close();
    michiganPath.moveTo(size.width * 0.6690302, size.height * 0.2082631);
    michiganPath.lineTo(size.width * 0.6689260, size.height * 0.2101180);
    michiganPath.lineTo(size.width * 0.6686131, size.height * 0.2112985);
    michiganPath.lineTo(size.width * 0.6688217, size.height * 0.2150084);
    michiganPath.lineTo(size.width * 0.6692388, size.height * 0.2155143);
    michiganPath.lineTo(size.width * 0.6699687, size.height * 0.2156830);
    michiganPath.lineTo(size.width * 0.6704901, size.height * 0.2141653);
    michiganPath.lineTo(size.width * 0.6705944, size.height * 0.2114671);
    michiganPath.lineTo(size.width * 0.6702815, size.height * 0.2104553);
    michiganPath.lineTo(size.width * 0.6701773, size.height * 0.2086003);
    michiganPath.close();

    Paint michiganPaint = Paint()..style = PaintingStyle.fill;
    michiganPaint.color = usaColors.michigan ?? defaultColor;
    usaCanvas.drawPath(michiganPath, michiganPaint, onTapUp: (tabdetail) {
      callback('michigan', tabdetail);
    });

    Path minnesotaPath = Path();
    minnesotaPath.moveTo(size.width * 0.4845673, size.height * 0.1156830);
    minnesotaPath.lineTo(size.width * 0.4834202, size.height * 0.1204047);
    minnesotaPath.lineTo(size.width * 0.4842544, size.height * 0.1227656);
    minnesotaPath.lineTo(size.width * 0.4839416, size.height * 0.1313659);
    minnesotaPath.lineTo(size.width * 0.4834202, size.height * 0.1332209);
    minnesotaPath.lineTo(size.width * 0.4862357, size.height * 0.1485666);
    minnesotaPath.lineTo(size.width * 0.4875912, size.height * 0.1527825);
    minnesotaPath.lineTo(size.width * 0.4883212, size.height * 0.1763912);
    minnesotaPath.lineTo(size.width * 0.4893639, size.height * 0.1809444);
    minnesotaPath.lineTo(size.width * 0.4889468, size.height * 0.1907251);
    minnesotaPath.lineTo(size.width * 0.4919708, size.height * 0.2032040);
    minnesotaPath.lineTo(size.width * 0.4922836, size.height * 0.2129848);
    minnesotaPath.lineTo(size.width * 0.4921794, size.height * 0.2165261);
    minnesotaPath.lineTo(size.width * 0.4920751, size.height * 0.2202361);
    minnesotaPath.lineTo(size.width * 0.4911366, size.height * 0.2236088);
    minnesotaPath.lineTo(size.width * 0.4879041, size.height * 0.2268128);
    minnesotaPath.lineTo(size.width * 0.4875912, size.height * 0.2288364);
    minnesotaPath.lineTo(size.width * 0.4893639, size.height * 0.2330523);
    minnesotaPath.lineTo(size.width * 0.4897810, size.height * 0.2360877);
    minnesotaPath.lineTo(size.width * 0.4924922, size.height * 0.2370995);
    minnesotaPath.lineTo(size.width * 0.4940563, size.height * 0.2403035);
    minnesotaPath.lineTo(size.width * 0.4938478, size.height * 0.3069140);
    minnesotaPath.lineTo(size.width * 0.5232534, size.height * 0.3069140);
    minnesotaPath.lineTo(size.width * 0.5611053, size.height * 0.3053963);
    minnesotaPath.lineTo(size.width * 0.5805005, size.height * 0.3042159);
    minnesotaPath.lineTo(size.width * 0.5793535, size.height * 0.2966273);
    minnesotaPath.lineTo(size.width * 0.5791449, size.height * 0.2915683);
    minnesotaPath.lineTo(size.width * 0.5768509, size.height * 0.2865093);
    minnesotaPath.lineTo(size.width * 0.5739312, size.height * 0.2853288);
    minnesotaPath.lineTo(size.width * 0.5685089, size.height * 0.2792580);
    minnesotaPath.lineTo(size.width * 0.5678832, size.height * 0.2736931);
    minnesotaPath.lineTo(size.width * 0.5613139, size.height * 0.2684654);
    minnesotaPath.lineTo(size.width * 0.5611053, size.height * 0.2662732);
    minnesotaPath.lineTo(size.width * 0.5576642, size.height * 0.2662732);
    minnesotaPath.lineTo(size.width * 0.5553702, size.height * 0.2618887);
    minnesotaPath.lineTo(size.width * 0.5532847, size.height * 0.2596965);
    minnesotaPath.lineTo(size.width * 0.5540146, size.height * 0.2510961);
    minnesotaPath.lineTo(size.width * 0.5530761, size.height * 0.2483980);
    minnesotaPath.lineTo(size.width * 0.5535975, size.height * 0.2392917);
    minnesotaPath.lineTo(size.width * 0.5546403, size.height * 0.2362563);
    minnesotaPath.lineTo(size.width * 0.5543274, size.height * 0.2317032);
    minnesotaPath.lineTo(size.width * 0.5530761, size.height * 0.2295110);
    minnesotaPath.lineTo(size.width * 0.5511992, size.height * 0.2290051);
    minnesotaPath.lineTo(size.width * 0.5511992, size.height * 0.2261383);
    minnesotaPath.lineTo(size.width * 0.5541189, size.height * 0.2163575);
    minnesotaPath.lineTo(size.width * 0.5602711, size.height * 0.2097808);
    minnesotaPath.lineTo(size.width * 0.5598540, size.height * 0.1878583);
    minnesotaPath.lineTo(size.width * 0.5607925, size.height * 0.1885329);
    minnesotaPath.lineTo(size.width * 0.5614181, size.height * 0.1876897);
    minnesotaPath.lineTo(size.width * 0.5615224, size.height * 0.1858347);
    minnesotaPath.lineTo(size.width * 0.5624609, size.height * 0.1848229);
    minnesotaPath.lineTo(size.width * 0.5639208, size.height * 0.1868465);
    minnesotaPath.lineTo(size.width * 0.5646507, size.height * 0.1866779);
    minnesotaPath.lineTo(size.width * 0.5646507, size.height * 0.1866779);
    minnesotaPath.lineTo(size.width * 0.5633994, size.height * 0.1829680);
    minnesotaPath.lineTo(size.width * 0.5678832, size.height * 0.1777403);
    minnesotaPath.lineTo(size.width * 0.5711157, size.height * 0.1715008);
    minnesotaPath.lineTo(size.width * 0.5727842, size.height * 0.1701518);
    minnesotaPath.lineTo(size.width * 0.5776851, size.height * 0.1602024);
    minnesotaPath.lineTo(size.width * 0.5842544, size.height * 0.1504216);
    minnesotaPath.lineTo(size.width * 0.5883212, size.height * 0.1468803);
    minnesotaPath.lineTo(size.width * 0.5948905, size.height * 0.1423272);
    minnesotaPath.lineTo(size.width * 0.6028154, size.height * 0.1347386);
    minnesotaPath.lineTo(size.width * 0.6021898, size.height * 0.1340641);
    minnesotaPath.lineTo(size.width * 0.5983316, size.height * 0.1352445);
    minnesotaPath.lineTo(size.width * 0.5954119, size.height * 0.1354132);
    minnesotaPath.lineTo(size.width * 0.5943691, size.height * 0.1327150);
    minnesotaPath.lineTo(size.width * 0.5929093, size.height * 0.1311973);
    minnesotaPath.lineTo(size.width * 0.5826903, size.height * 0.1332209);
    minnesotaPath.lineTo(size.width * 0.5816475, size.height * 0.1284992);
    minnesotaPath.lineTo(size.width * 0.5799791, size.height * 0.1283305);
    minnesotaPath.lineTo(size.width * 0.5782065, size.height * 0.1296796);
    minnesotaPath.lineTo(size.width * 0.5743483, size.height * 0.1349073);
    minnesotaPath.lineTo(size.width * 0.5700730, size.height * 0.1349073);
    minnesotaPath.lineTo(size.width * 0.5678832, size.height * 0.1332209);
    minnesotaPath.lineTo(size.width * 0.5675704, size.height * 0.1303541);
    minnesotaPath.lineTo(size.width * 0.5635036, size.height * 0.1290051);
    minnesotaPath.lineTo(size.width * 0.5628780, size.height * 0.1263069);
    minnesotaPath.lineTo(size.width * 0.5621481, size.height * 0.1241147);
    minnesotaPath.lineTo(size.width * 0.5611053, size.height * 0.1256324);
    minnesotaPath.lineTo(size.width * 0.5583942, size.height * 0.1258010);
    minnesotaPath.lineTo(size.width * 0.5480709, size.height * 0.1165261);
    minnesotaPath.lineTo(size.width * 0.5450469, size.height * 0.1165261);
    minnesotaPath.lineTo(size.width * 0.5442127, size.height * 0.1153457);
    minnesotaPath.lineTo(size.width * 0.5409802, size.height * 0.1175379);
    minnesotaPath.lineTo(size.width * 0.5401460, size.height * 0.1197302);
    minnesotaPath.lineTo(size.width * 0.5367049, size.height * 0.1210793);
    minnesotaPath.lineTo(size.width * 0.5353493, size.height * 0.1207420);
    minnesotaPath.lineTo(size.width * 0.5353493, size.height * 0.1178752);
    minnesotaPath.lineTo(size.width * 0.5346194, size.height * 0.1163575);
    minnesotaPath.lineTo(size.width * 0.5284672, size.height * 0.1163575);
    minnesotaPath.lineTo(size.width * 0.5280501, size.height * 0.1139966);
    minnesotaPath.lineTo(size.width * 0.5253389, size.height * 0.1139966);
    minnesotaPath.lineTo(size.width * 0.5241919, size.height * 0.1146712);
    minnesotaPath.lineTo(size.width * 0.5216893, size.height * 0.1118044);
    minnesotaPath.lineTo(size.width * 0.5220021, size.height * 0.1094435);
    minnesotaPath.lineTo(size.width * 0.5213764, size.height * 0.1053963);
    minnesotaPath.lineTo(size.width * 0.5206465, size.height * 0.1035413);
    minnesotaPath.lineTo(size.width * 0.5204380, size.height * 0.09848229);
    minnesotaPath.lineTo(size.width * 0.5193952, size.height * 0.09325464);
    minnesotaPath.lineTo(size.width * 0.5172054, size.height * 0.09055649);
    minnesotaPath.lineTo(size.width * 0.5141814, size.height * 0.09055649);
    minnesotaPath.lineTo(size.width * 0.5142857, size.height * 0.1040472);
    minnesotaPath.lineTo(size.width * 0.4820647, size.height * 0.1033727);
    minnesotaPath.close();

    Paint minnesotaPaint = Paint()..style = PaintingStyle.fill;
    minnesotaPaint.color = usaColors.minnesota ?? defaultColor;
    usaCanvas.drawPath(minnesotaPath, minnesotaPaint, onTapUp: (tabdetail) {
      callback('minnesota', tabdetail);
    });

    Path mississippiPath = Path();
    mississippiPath.moveTo(size.width * 0.6504692, size.height * 0.7902192);
    mississippiPath.lineTo(size.width * 0.6452555, size.height * 0.7903879);
    mississippiPath.lineTo(size.width * 0.6427529, size.height * 0.7878583);
    mississippiPath.lineTo(size.width * 0.6345151, size.height * 0.7920742);
    mississippiPath.lineTo(size.width * 0.6335766, size.height * 0.7908938);
    mississippiPath.lineTo(size.width * 0.6330553, size.height * 0.7912310);
    mississippiPath.lineTo(size.width * 0.6329510, size.height * 0.7939292);
    mississippiPath.lineTo(size.width * 0.6323253, size.height * 0.7940978);
    mississippiPath.lineTo(size.width * 0.6296142, size.height * 0.7986509);
    mississippiPath.lineTo(size.width * 0.6288843, size.height * 0.7984823);
    mississippiPath.lineTo(size.width * 0.6282586, size.height * 0.7973019);
    mississippiPath.lineTo(size.width * 0.6270073, size.height * 0.7942664);
    mississippiPath.lineTo(size.width * 0.6273201, size.height * 0.7920742);
    mississippiPath.lineTo(size.width * 0.6223149, size.height * 0.7806071);
    mississippiPath.lineTo(size.width * 0.6232534, size.height * 0.7728499);
    mississippiPath.lineTo(size.width * 0.6242961, size.height * 0.7704890);
    mississippiPath.lineTo(size.width * 0.6244004, size.height * 0.7681282);
    mississippiPath.lineTo(size.width * 0.5868613, size.height * 0.7715008);
    mississippiPath.lineTo(size.width * 0.5886340, size.height * 0.7514334);
    mississippiPath.lineTo(size.width * 0.5911366, size.height * 0.7433390);
    mississippiPath.lineTo(size.width * 0.5973931, size.height * 0.7291737);
    mississippiPath.lineTo(size.width * 0.5955162, size.height * 0.7249578);
    mississippiPath.lineTo(size.width * 0.5976017, size.height * 0.7249578);
    mississippiPath.lineTo(size.width * 0.5976017, size.height * 0.7193929);
    mississippiPath.lineTo(size.width * 0.5950991, size.height * 0.7151771);
    mississippiPath.lineTo(size.width * 0.5956204, size.height * 0.7123103);
    mississippiPath.lineTo(size.width * 0.5943691, size.height * 0.7106239);
    mississippiPath.lineTo(size.width * 0.5927007, size.height * 0.6986509);
    mississippiPath.lineTo(size.width * 0.5933264, size.height * 0.6962901);
    mississippiPath.lineTo(size.width * 0.5945777, size.height * 0.6937605);
    mississippiPath.lineTo(size.width * 0.5950991, size.height * 0.6887015);
    mississippiPath.lineTo(size.width * 0.5935349, size.height * 0.6848229);
    mississippiPath.lineTo(size.width * 0.5930136, size.height * 0.6811130);
    mississippiPath.lineTo(size.width * 0.5939520, size.height * 0.6799325);
    mississippiPath.lineTo(size.width * 0.5939520, size.height * 0.6785835);
    mississippiPath.lineTo(size.width * 0.5921794, size.height * 0.6767285);
    mississippiPath.lineTo(size.width * 0.5920751, size.height * 0.6755481);
    mississippiPath.lineTo(size.width * 0.5937435, size.height * 0.6740304);
    mississippiPath.lineTo(size.width * 0.5924922, size.height * 0.6721754);
    mississippiPath.lineTo(size.width * 0.5942649, size.height * 0.6602024);
    mississippiPath.lineTo(size.width * 0.5978102, size.height * 0.6575042);
    mississippiPath.lineTo(size.width * 0.5978102, size.height * 0.6561551);
    mississippiPath.lineTo(size.width * 0.5966632, size.height * 0.6537943);
    mississippiPath.lineTo(size.width * 0.5996872, size.height * 0.6446880);
    mississippiPath.lineTo(size.width * 0.6016684, size.height * 0.6446880);
    mississippiPath.lineTo(size.width * 0.6032325, size.height * 0.6426644);
    mississippiPath.lineTo(size.width * 0.6029197, size.height * 0.6338954);
    mississippiPath.lineTo(size.width * 0.6061522, size.height * 0.6263069);
    mississippiPath.lineTo(size.width * 0.6080292, size.height * 0.6252951);
    mississippiPath.lineTo(size.width * 0.6075078, size.height * 0.6200675);
    mississippiPath.lineTo(size.width * 0.6474453, size.height * 0.6156830);
    mississippiPath.lineTo(size.width * 0.6488008, size.height * 0.6190556);
    mississippiPath.lineTo(size.width * 0.6474453, size.height * 0.7320405);
    mississippiPath.lineTo(size.width * 0.6520334, size.height * 0.7880270);
    mississippiPath.close();

    Paint mississippiPaint = Paint()..style = PaintingStyle.fill;
    mississippiPaint.color = usaColors.mississippi ?? defaultColor;
    usaCanvas.drawPath(mississippiPath, mississippiPaint, onTapUp: (tabdetail) {
      callback('mississippi', tabdetail);
    });

    Path missouriPath = Path();
    missouriPath.moveTo(size.width * 0.5790407, size.height * 0.4197302);
    missouriPath.lineTo(size.width * 0.5778936, size.height * 0.4178752);
    missouriPath.lineTo(size.width * 0.5772680, size.height * 0.4151771);
    missouriPath.lineTo(size.width * 0.5754953, size.height * 0.4129848);
    missouriPath.lineTo(size.width * 0.5605839, size.height * 0.4143339);
    missouriPath.lineTo(size.width * 0.5322211, size.height * 0.4163575);
    missouriPath.lineTo(size.width * 0.5052138, size.height * 0.4161889);
    missouriPath.lineTo(size.width * 0.5065693, size.height * 0.4183811);
    missouriPath.lineTo(size.width * 0.5062565, size.height * 0.4207420);
    missouriPath.lineTo(size.width * 0.5084463, size.height * 0.4269815);
    missouriPath.lineTo(size.width * 0.5125130, size.height * 0.4376054);
    missouriPath.lineTo(size.width * 0.5155370, size.height * 0.4426644);
    missouriPath.lineTo(size.width * 0.5176225, size.height * 0.4436762);
    missouriPath.lineTo(size.width * 0.5185610, size.height * 0.4419899);
    missouriPath.lineTo(size.width * 0.5201251, size.height * 0.4455312);
    missouriPath.lineTo(size.width * 0.5200209, size.height * 0.4475548);
    missouriPath.lineTo(size.width * 0.5172054, size.height * 0.4519393);
    missouriPath.lineTo(size.width * 0.5166840, size.height * 0.4558179);
    missouriPath.lineTo(size.width * 0.5192909, size.height * 0.4600337);
    missouriPath.lineTo(size.width * 0.5220021, size.height * 0.4679595);
    missouriPath.lineTo(size.width * 0.5253389, size.height * 0.4691400);
    missouriPath.lineTo(size.width * 0.5258603, size.height * 0.5502530);
    missouriPath.lineTo(size.width * 0.5260688, size.height * 0.5684654);
    missouriPath.lineTo(size.width * 0.5668405, size.height * 0.5672850);
    missouriPath.lineTo(size.width * 0.6083420, size.height * 0.5639123);
    missouriPath.lineTo(size.width * 0.6100104, size.height * 0.5681282);
    missouriPath.lineTo(size.width * 0.6100104, size.height * 0.5718381);
    missouriPath.lineTo(size.width * 0.6082377, size.height * 0.5743676);
    missouriPath.lineTo(size.width * 0.6053180, size.height * 0.5829680);
    missouriPath.lineTo(size.width * 0.6169969, size.height * 0.5816189);
    missouriPath.lineTo(size.width * 0.6180396, size.height * 0.5782462);
    missouriPath.lineTo(size.width * 0.6192909, size.height * 0.5774030);
    missouriPath.lineTo(size.width * 0.6192909, size.height * 0.5762226);
    missouriPath.lineTo(size.width * 0.6180396, size.height * 0.5743676);
    missouriPath.lineTo(size.width * 0.6174140, size.height * 0.5726813);
    missouriPath.lineTo(size.width * 0.6191867, size.height * 0.5730185);
    missouriPath.lineTo(size.width * 0.6200209, size.height * 0.5718381);
    missouriPath.lineTo(size.width * 0.6185610, size.height * 0.5693086);
    missouriPath.lineTo(size.width * 0.6200209, size.height * 0.5684654);
    missouriPath.lineTo(size.width * 0.6201251, size.height * 0.5667791);
    missouriPath.lineTo(size.width * 0.6194995, size.height * 0.5650927);
    missouriPath.lineTo(size.width * 0.6194995, size.height * 0.5629005);
    missouriPath.lineTo(size.width * 0.6187696, size.height * 0.5617201);
    missouriPath.lineTo(size.width * 0.6189781, size.height * 0.5600337);
    missouriPath.lineTo(size.width * 0.6201251, size.height * 0.5600337);
    missouriPath.lineTo(size.width * 0.6208551, size.height * 0.5612142);
    missouriPath.lineTo(size.width * 0.6205422, size.height * 0.5629005);
    missouriPath.lineTo(size.width * 0.6213764, size.height * 0.5640809);
    missouriPath.lineTo(size.width * 0.6222106, size.height * 0.5623946);
    missouriPath.lineTo(size.width * 0.6232534, size.height * 0.5578415);
    missouriPath.lineTo(size.width * 0.6247132, size.height * 0.5593592);
    missouriPath.lineTo(size.width * 0.6254432, size.height * 0.5586847);
    missouriPath.lineTo(size.width * 0.6266945, size.height * 0.5517707);
    missouriPath.lineTo(size.width * 0.6256517, size.height * 0.5500843);
    missouriPath.lineTo(size.width * 0.6266945, size.height * 0.5467116);
    missouriPath.lineTo(size.width * 0.6269030, size.height * 0.5451939);
    missouriPath.lineTo(size.width * 0.6255474, size.height * 0.5438449);
    missouriPath.lineTo(size.width * 0.6226277, size.height * 0.5438449);
    missouriPath.lineTo(size.width * 0.6211679, size.height * 0.5413153);
    missouriPath.lineTo(size.width * 0.6192909, size.height * 0.5349073);
    missouriPath.lineTo(size.width * 0.6192909, size.height * 0.5317032);
    missouriPath.lineTo(size.width * 0.6201251, size.height * 0.5306914);
    missouriPath.lineTo(size.width * 0.6202294, size.height * 0.5284992);
    missouriPath.lineTo(size.width * 0.6184567, size.height * 0.5252951);
    missouriPath.lineTo(size.width * 0.6175182, size.height * 0.5210793);
    missouriPath.lineTo(size.width * 0.6147028, size.height * 0.5141653);
    missouriPath.lineTo(size.width * 0.6096976, size.height * 0.5119730);
    missouriPath.lineTo(size.width * 0.6019812, size.height * 0.5000000);
    missouriPath.lineTo(size.width * 0.6015641, size.height * 0.4959528);
    missouriPath.lineTo(size.width * 0.6044838, size.height * 0.4831366);
    missouriPath.lineTo(size.width * 0.6040667, size.height * 0.4799325);
    missouriPath.lineTo(size.width * 0.6053180, size.height * 0.4780776);
    missouriPath.lineTo(size.width * 0.6053180, size.height * 0.4758853);
    missouriPath.lineTo(size.width * 0.6023983, size.height * 0.4733558);
    missouriPath.lineTo(size.width * 0.5992701, size.height * 0.4721754);
    missouriPath.lineTo(size.width * 0.5957247, size.height * 0.4741990);
    missouriPath.lineTo(size.width * 0.5943691, size.height * 0.4703204);
    missouriPath.lineTo(size.width * 0.5949948, size.height * 0.4671164);
    missouriPath.lineTo(size.width * 0.5942649, size.height * 0.4630691);
    missouriPath.lineTo(size.width * 0.5852972, size.height * 0.4489039);
    missouriPath.lineTo(size.width * 0.5830031, size.height * 0.4463744);
    missouriPath.lineTo(size.width * 0.5803962, size.height * 0.4364250);
    missouriPath.lineTo(size.width * 0.5791449, size.height * 0.4273187);
    missouriPath.lineTo(size.width * 0.5806048, size.height * 0.4210793);
    missouriPath.close();

    Paint missouriPaint = Paint()..style = PaintingStyle.fill;
    missouriPaint.color = usaColors.missouri ?? defaultColor;
    usaCanvas.drawPath(missouriPath, missouriPaint, onTapUp: (tabdetail) {
      callback('missouri', tabdetail);
    });

    Path montanaPath = Path();
    montanaPath.moveTo(size.width * 0.2575600, size.height * 0.2200675);
    montanaPath.lineTo(size.width * 0.3173097, size.height * 0.2333895);
    montanaPath.lineTo(size.width * 0.3704901, size.height * 0.2423272);
    montanaPath.lineTo(size.width * 0.3725756, size.height * 0.2074199);
    montanaPath.lineTo(size.width * 0.3779979, size.height * 0.09494098);
    montanaPath.lineTo(size.width * 0.3222106, size.height * 0.08549747);
    montanaPath.lineTo(size.width * 0.2655892, size.height * 0.07251265);
    montanaPath.lineTo(size.width * 0.1968717, size.height * 0.05143339);
    montanaPath.lineTo(size.width * 0.1918665, size.height * 0.08853288);
    montanaPath.lineTo(size.width * 0.1957247, size.height * 0.1010118);
    montanaPath.lineTo(size.width * 0.1940563, size.height * 0.1091062);
    montanaPath.lineTo(size.width * 0.1978102, size.height * 0.1172007);
    montanaPath.lineTo(size.width * 0.1997914, size.height * 0.1183811);
    montanaPath.lineTo(size.width * 0.2038582, size.height * 0.1323777);
    montanaPath.lineTo(size.width * 0.2038582, size.height * 0.1359191);
    montanaPath.lineTo(size.width * 0.2062565, size.height * 0.1409781);
    montanaPath.lineTo(size.width * 0.2071950, size.height * 0.1409781);
    montanaPath.lineTo(size.width * 0.2086548, size.height * 0.1445194);
    montanaPath.lineTo(size.width * 0.2119917, size.height * 0.1445194);
    montanaPath.lineTo(size.width * 0.2119917, size.height * 0.1472175);
    montanaPath.lineTo(size.width * 0.2045881, size.height * 0.1758853);
    montanaPath.lineTo(size.width * 0.2040667, size.height * 0.1827993);
    montanaPath.lineTo(size.width * 0.2055266, size.height * 0.1836425);
    montanaPath.lineTo(size.width * 0.2071950, size.height * 0.1880270);
    montanaPath.lineTo(size.width * 0.2101147, size.height * 0.1856661);
    montanaPath.lineTo(size.width * 0.2138686, size.height * 0.1816189);
    montanaPath.lineTo(size.width * 0.2158498, size.height * 0.1848229);
    montanaPath.lineTo(size.width * 0.2163712, size.height * 0.1890388);
    montanaPath.lineTo(size.width * 0.2158498, size.height * 0.1944351);
    montanaPath.lineTo(size.width * 0.2184567, size.height * 0.2107926);
    montanaPath.lineTo(size.width * 0.2211679, size.height * 0.2166948);
    montanaPath.lineTo(size.width * 0.2235662, size.height * 0.2190556);
    montanaPath.lineTo(size.width * 0.2239833, size.height * 0.2241147);
    montanaPath.lineTo(size.width * 0.2239833, size.height * 0.2310287);
    montanaPath.lineTo(size.width * 0.2263816, size.height * 0.2349073);
    montanaPath.lineTo(size.width * 0.2280501, size.height * 0.2310287);
    montanaPath.lineTo(size.width * 0.2352450, size.height * 0.2337268);
    montanaPath.lineTo(size.width * 0.2374348, size.height * 0.2317032);
    montanaPath.lineTo(size.width * 0.2468196, size.height * 0.2345700);
    montanaPath.lineTo(size.width * 0.2497393, size.height * 0.2290051);
    montanaPath.lineTo(size.width * 0.2516163, size.height * 0.2279933);
    montanaPath.lineTo(size.width * 0.2528676, size.height * 0.2310287);
    montanaPath.lineTo(size.width * 0.2545360, size.height * 0.2379427);
    montanaPath.lineTo(size.width * 0.2554745, size.height * 0.2381113);
    montanaPath.close();

    Paint montanaPaint = Paint()..style = PaintingStyle.fill;
    montanaPaint.color = usaColors.montana ?? defaultColor;
    usaCanvas.drawPath(montanaPath, montanaPaint, onTapUp: (tabdetail) {
      callback('montana', tabdetail);
    });

    Path nebraskaPath = Path();
    nebraskaPath.moveTo(size.width * 0.4197080, size.height * 0.3222597);
    nebraskaPath.lineTo(size.width * 0.4593326, size.height * 0.3249578);
    nebraskaPath.lineTo(size.width * 0.4628780, size.height * 0.3303541);
    nebraskaPath.lineTo(size.width * 0.4646507, size.height * 0.3306914);
    nebraskaPath.lineTo(size.width * 0.4668405, size.height * 0.3340641);
    nebraskaPath.lineTo(size.width * 0.4687174, size.height * 0.3338954);
    nebraskaPath.lineTo(size.width * 0.4705944, size.height * 0.3305228);
    nebraskaPath.lineTo(size.width * 0.4721585, size.height * 0.3315346);
    nebraskaPath.lineTo(size.width * 0.4732013, size.height * 0.3303541);
    nebraskaPath.lineTo(size.width * 0.4739312, size.height * 0.3311973);
    nebraskaPath.lineTo(size.width * 0.4748697, size.height * 0.3305228);
    nebraskaPath.lineTo(size.width * 0.4755996, size.height * 0.3311973);
    nebraskaPath.lineTo(size.width * 0.4765381, size.height * 0.3305228);
    nebraskaPath.lineTo(size.width * 0.4775808, size.height * 0.3313659);
    nebraskaPath.lineTo(size.width * 0.4790407, size.height * 0.3303541);
    nebraskaPath.lineTo(size.width * 0.4811262, size.height * 0.3313659);
    nebraskaPath.lineTo(size.width * 0.4817518, size.height * 0.3332209);
    nebraskaPath.lineTo(size.width * 0.4881126, size.height * 0.3369309);
    nebraskaPath.lineTo(size.width * 0.4893639, size.height * 0.3391231);
    nebraskaPath.lineTo(size.width * 0.4903024, size.height * 0.3435076);
    nebraskaPath.lineTo(size.width * 0.4921794, size.height * 0.3446880);
    nebraskaPath.lineTo(size.width * 0.4937435, size.height * 0.3443508);
    nebraskaPath.lineTo(size.width * 0.4942649, size.height * 0.3458685);
    nebraskaPath.lineTo(size.width * 0.4942649, size.height * 0.3497470);
    nebraskaPath.lineTo(size.width * 0.4948905, size.height * 0.3526138);
    nebraskaPath.lineTo(size.width * 0.4948905, size.height * 0.3549747);
    nebraskaPath.lineTo(size.width * 0.4962461, size.height * 0.3612142);
    nebraskaPath.lineTo(size.width * 0.4985401, size.height * 0.3684654);
    nebraskaPath.lineTo(size.width * 0.4987487, size.height * 0.3747049);
    nebraskaPath.lineTo(size.width * 0.5016684, size.height * 0.3831366);
    nebraskaPath.lineTo(size.width * 0.5020855, size.height * 0.3934233);
    nebraskaPath.lineTo(size.width * 0.5034411, size.height * 0.3946037);
    nebraskaPath.lineTo(size.width * 0.5032325, size.height * 0.3994941);
    nebraskaPath.lineTo(size.width * 0.5040667, size.height * 0.4050590);
    nebraskaPath.lineTo(size.width * 0.5033368, size.height * 0.4087690);
    nebraskaPath.lineTo(size.width * 0.5052138, size.height * 0.4161889);
    nebraskaPath.lineTo(size.width * 0.5065693, size.height * 0.4183811);
    nebraskaPath.lineTo(size.width * 0.5062565, size.height * 0.4207420);
    nebraskaPath.lineTo(size.width * 0.5084463, size.height * 0.4269815);
    nebraskaPath.lineTo(size.width * 0.5125130, size.height * 0.4376054);
    nebraskaPath.lineTo(size.width * 0.4787278, size.height * 0.4376054);
    nebraskaPath.lineTo(size.width * 0.4331595, size.height * 0.4355818);
    nebraskaPath.lineTo(size.width * 0.3956204, size.height * 0.4322091);
    nebraskaPath.lineTo(size.width * 0.3970803, size.height * 0.3949410);
    nebraskaPath.lineTo(size.width * 0.3625652, size.height * 0.3908938);
    nebraskaPath.lineTo(size.width * 0.3664234, size.height * 0.3163575);
    nebraskaPath.close();

    Paint nebraskaPaint = Paint()..style = PaintingStyle.fill;
    nebraskaPaint.color = usaColors.nebraska ?? defaultColor;
    usaCanvas.drawPath(nebraskaPath, nebraskaPaint, onTapUp: (tabdetail) {
      callback('nebraska', tabdetail);
    });

    Path nevadaPath = Path();
    nevadaPath.moveTo(size.width * 0.1747654, size.height * 0.5005059);
    nevadaPath.lineTo(size.width * 0.1712200, size.height * 0.5300169);
    nevadaPath.lineTo(size.width * 0.1687174, size.height * 0.5349073);
    nevadaPath.lineTo(size.width * 0.1666319, size.height * 0.5349073);
    nevadaPath.lineTo(size.width * 0.1653806, size.height * 0.5303541);
    nevadaPath.lineTo(size.width * 0.1615224, size.height * 0.5279933);
    nevadaPath.lineTo(size.width * 0.1578728, size.height * 0.5290051);
    nevadaPath.lineTo(size.width * 0.1568300, size.height * 0.5519393);
    nevadaPath.lineTo(size.width * 0.1573514, size.height * 0.5602024);
    nevadaPath.lineTo(size.width * 0.1568300, size.height * 0.5650927);
    nevadaPath.lineTo(size.width * 0.1553702, size.height * 0.5701518);
    nevadaPath.lineTo(size.width * 0.08196038, size.height * 0.3930860);
    nevadaPath.lineTo(size.width * 0.08081335, size.height * 0.3871838);
    nevadaPath.lineTo(size.width * 0.09791449, size.height * 0.2807757);
    nevadaPath.lineTo(size.width * 0.1469239, size.height * 0.2996627);
    nevadaPath.lineTo(size.width * 0.1723670, size.height * 0.3087690);
    nevadaPath.lineTo(size.width * 0.1966632, size.height * 0.3166948);
    nevadaPath.close();

    Paint nevadaPaint = Paint()..style = PaintingStyle.fill;
    nevadaPaint.color = usaColors.nevada ?? defaultColor;
    usaCanvas.drawPath(nevadaPath, nevadaPaint, onTapUp: (tabdetail) {
      callback('nevada', tabdetail);
    });

    Path newHampshirePath = Path();
    newHampshirePath.moveTo(size.width * 0.8994786, size.height * 0.1578415);
    newHampshirePath.lineTo(size.width * 0.8981230, size.height * 0.1580101);
    newHampshirePath.lineTo(size.width * 0.8970803, size.height * 0.1561551);
    newHampshirePath.lineTo(size.width * 0.8950991, size.height * 0.1585160);
    newHampshirePath.lineTo(size.width * 0.8945777, size.height * 0.1688027);
    newHampshirePath.lineTo(size.width * 0.8958290, size.height * 0.1726813);
    newHampshirePath.lineTo(size.width * 0.8946820, size.height * 0.1785835);
    newHampshirePath.lineTo(size.width * 0.8968717, size.height * 0.1833052);
    newHampshirePath.lineTo(size.width * 0.8964546, size.height * 0.1861720);
    newHampshirePath.lineTo(size.width * 0.8965589, size.height * 0.1883642);
    newHampshirePath.lineTo(size.width * 0.8954119, size.height * 0.1919056);
    newHampshirePath.lineTo(size.width * 0.8939520, size.height * 0.1925801);
    newHampshirePath.lineTo(size.width * 0.8933264, size.height * 0.1947723);
    newHampshirePath.lineTo(size.width * 0.8911366, size.height * 0.1964587);
    newHampshirePath.lineTo(size.width * 0.8904067, size.height * 0.1989882);
    newHampshirePath.lineTo(size.width * 0.8918665, size.height * 0.2047218);
    newHampshirePath.lineTo(size.width * 0.8913452, size.height * 0.2089376);
    newHampshirePath.lineTo(size.width * 0.8918665, size.height * 0.2114671);
    newHampshirePath.lineTo(size.width * 0.8908238, size.height * 0.2146712);
    newHampshirePath.lineTo(size.width * 0.8912409, size.height * 0.2178752);
    newHampshirePath.lineTo(size.width * 0.8898853, size.height * 0.2210793);
    newHampshirePath.lineTo(size.width * 0.8900938, size.height * 0.2247892);
    newHampshirePath.lineTo(size.width * 0.8893639, size.height * 0.2266442);
    newHampshirePath.lineTo(size.width * 0.8900938, size.height * 0.2342327);
    newHampshirePath.lineTo(size.width * 0.8908238, size.height * 0.2367622);
    newHampshirePath.lineTo(size.width * 0.8903024, size.height * 0.2411467);
    newHampshirePath.lineTo(size.width * 0.8912409, size.height * 0.2441821);
    newHampshirePath.lineTo(size.width * 0.8910323, size.height * 0.2483980);
    newHampshirePath.lineTo(size.width * 0.8905109, size.height * 0.2505902);
    newHampshirePath.lineTo(size.width * 0.8904067, size.height * 0.2529511);
    newHampshirePath.lineTo(size.width * 0.8925965, size.height * 0.2573356);
    newHampshirePath.lineTo(size.width * 0.9117831, size.height * 0.2509275);
    newHampshirePath.lineTo(size.width * 0.9128259, size.height * 0.2483980);
    newHampshirePath.lineTo(size.width * 0.9131387, size.height * 0.2455312);
    newHampshirePath.lineTo(size.width * 0.9151199, size.height * 0.2445194);
    newHampshirePath.lineTo(size.width * 0.9156413, size.height * 0.2426644);
    newHampshirePath.lineTo(size.width * 0.9174140, size.height * 0.2408094);
    newHampshirePath.lineTo(size.width * 0.9187696, size.height * 0.2413153);
    newHampshirePath.lineTo(size.width * 0.9196038, size.height * 0.2332209);
    newHampshirePath.lineTo(size.width * 0.9172054, size.height * 0.2308600);
    newHampshirePath.lineTo(size.width * 0.9163712, size.height * 0.2271501);
    newHampshirePath.lineTo(size.width * 0.9130344, size.height * 0.2237774);
    newHampshirePath.lineTo(size.width * 0.9124088, size.height * 0.2170320);
    newHampshirePath.lineTo(size.width * 0.9000000, size.height * 0.1549747);
    newHampshirePath.close();

    Paint newHampshirePaint = Paint()..style = PaintingStyle.fill;
    newHampshirePaint.color = usaColors.newHampshire ?? defaultColor;
    usaCanvas.drawPath(newHampshirePath, newHampshirePaint,
        onTapUp: (tabdetail) {
      callback('new hampshire', tabdetail);
    });

    Path newJerseyPath = Path();
    newJerseyPath.moveTo(size.width * 0.8785193, size.height * 0.3295110);
    newJerseyPath.lineTo(size.width * 0.8632951, size.height * 0.3212479);
    newJerseyPath.lineTo(size.width * 0.8614181, size.height * 0.3254637);
    newJerseyPath.lineTo(size.width * 0.8615224, size.height * 0.3291737);
    newJerseyPath.lineTo(size.width * 0.8583942, size.height * 0.3382799);
    newJerseyPath.lineTo(size.width * 0.8599583, size.height * 0.3413153);
    newJerseyPath.lineTo(size.width * 0.8592284, size.height * 0.3446880);
    newJerseyPath.lineTo(size.width * 0.8581856, size.height * 0.3463744);
    newJerseyPath.lineTo(size.width * 0.8587070, size.height * 0.3524452);
    newJerseyPath.lineTo(size.width * 0.8615224, size.height * 0.3539629);
    newJerseyPath.lineTo(size.width * 0.8625652, size.height * 0.3586847);
    newJerseyPath.lineTo(size.width * 0.8647550, size.height * 0.3605396);
    newJerseyPath.lineTo(size.width * 0.8691345, size.height * 0.3659359);
    newJerseyPath.lineTo(size.width * 0.8656934, size.height * 0.3703204);
    newJerseyPath.lineTo(size.width * 0.8640250, size.height * 0.3741990);
    newJerseyPath.lineTo(size.width * 0.8621481, size.height * 0.3792580);
    newJerseyPath.lineTo(size.width * 0.8604797, size.height * 0.3802698);
    newJerseyPath.lineTo(size.width * 0.8590198, size.height * 0.3831366);
    newJerseyPath.lineTo(size.width * 0.8579771, size.height * 0.3868465);
    newJerseyPath.lineTo(size.width * 0.8576642, size.height * 0.3903879);
    newJerseyPath.lineTo(size.width * 0.8584984, size.height * 0.3919056);
    newJerseyPath.lineTo(size.width * 0.8589155, size.height * 0.3957841);
    newJerseyPath.lineTo(size.width * 0.8601668, size.height * 0.3967960);
    newJerseyPath.lineTo(size.width * 0.8626694, size.height * 0.3993255);
    newJerseyPath.lineTo(size.width * 0.8645464, size.height * 0.4006745);
    newJerseyPath.lineTo(size.width * 0.8662148, size.height * 0.4020236);
    newJerseyPath.lineTo(size.width * 0.8663191, size.height * 0.4038786);
    newJerseyPath.lineTo(size.width * 0.8671533, size.height * 0.4040472);
    newJerseyPath.lineTo(size.width * 0.8683003, size.height * 0.4020236);
    newJerseyPath.lineTo(size.width * 0.8691345, size.height * 0.4026981);
    newJerseyPath.lineTo(size.width * 0.8713243, size.height * 0.4030354);
    newJerseyPath.lineTo(size.width * 0.8711157, size.height * 0.4079258);
    newJerseyPath.lineTo(size.width * 0.8713243, size.height * 0.4121417);
    newJerseyPath.lineTo(size.width * 0.8732013, size.height * 0.4109612);
    newJerseyPath.lineTo(size.width * 0.8747654, size.height * 0.4043845);
    newJerseyPath.lineTo(size.width * 0.8764338, size.height * 0.3962901);
    newJerseyPath.lineTo(size.width * 0.8794578, size.height * 0.3915683);
    newJerseyPath.lineTo(size.width * 0.8800834, size.height * 0.3856661);
    newJerseyPath.lineTo(size.width * 0.8794578, size.height * 0.3836425);
    newJerseyPath.lineTo(size.width * 0.8812304, size.height * 0.3787521);
    newJerseyPath.lineTo(size.width * 0.8812304, size.height * 0.3767285);
    newJerseyPath.lineTo(size.width * 0.8805005, size.height * 0.3748735);
    newJerseyPath.lineTo(size.width * 0.8817518, size.height * 0.3703204);
    newJerseyPath.lineTo(size.width * 0.8814390, size.height * 0.3642496);
    newJerseyPath.lineTo(size.width * 0.8808133, size.height * 0.3504216);
    newJerseyPath.lineTo(size.width * 0.8795620, size.height * 0.3480607);
    newJerseyPath.lineTo(size.width * 0.8795620, size.height * 0.3504216);
    newJerseyPath.lineTo(size.width * 0.8800834, size.height * 0.3514334);
    newJerseyPath.lineTo(size.width * 0.8789364, size.height * 0.3514334);
    newJerseyPath.lineTo(size.width * 0.8783107, size.height * 0.3507589);
    newJerseyPath.lineTo(size.width * 0.8769552, size.height * 0.3504216);
    newJerseyPath.lineTo(size.width * 0.8760167, size.height * 0.3514334);
    newJerseyPath.lineTo(size.width * 0.8747654, size.height * 0.3487352);
    newJerseyPath.lineTo(size.width * 0.8754953, size.height * 0.3458685);
    newJerseyPath.lineTo(size.width * 0.8754953, size.height * 0.3441821);
    newJerseyPath.lineTo(size.width * 0.8772680, size.height * 0.3430017);
    newJerseyPath.lineTo(size.width * 0.8781022, size.height * 0.3394604);
    newJerseyPath.close();

    Paint newJerseyPaint = Paint()..style = PaintingStyle.fill;
    newJerseyPaint.color = usaColors.newJersey ?? defaultColor;
    usaCanvas.drawPath(newJerseyPath, newJerseyPaint, onTapUp: (tabdetail) {
      callback('new jersey', tabdetail);
    });

    Path newMexicoPath = Path();
    newMexicoPath.moveTo(size.width * 0.3727842, size.height * 0.5613828);
    newMexicoPath.lineTo(size.width * 0.3719499, size.height * 0.5613828);
    newMexicoPath.lineTo(size.width * 0.3637122, size.height * 0.7288364);
    newMexicoPath.lineTo(size.width * 0.3305527, size.height * 0.7244519);
    newMexicoPath.lineTo(size.width * 0.2946820, size.height * 0.7183811);
    newMexicoPath.lineTo(size.width * 0.2943691, size.height * 0.7234401);
    newMexicoPath.lineTo(size.width * 0.2964546, size.height * 0.7271501);
    newMexicoPath.lineTo(size.width * 0.2643379, size.height * 0.7202361);
    newMexicoPath.lineTo(size.width * 0.2628780, size.height * 0.7374368);
    newMexicoPath.lineTo(size.width * 0.2465068, size.height * 0.7337268);
    newMexicoPath.lineTo(size.width * 0.2646507, size.height * 0.5244519);
    newMexicoPath.lineTo(size.width * 0.3194995, size.height * 0.5354132);
    newMexicoPath.lineTo(size.width * 0.3734098, size.height * 0.5435076);
    newMexicoPath.close();

    Paint newMexicoPaint = Paint()..style = PaintingStyle.fill;
    newMexicoPaint.color = usaColors.newMexico ?? defaultColor;
    usaCanvas.drawPath(newMexicoPath, newMexicoPaint, onTapUp: (tabdetail) {
      callback('new mexico', tabdetail);
    });

    Path newYorkPath = Path();
    newYorkPath.moveTo(size.width * 0.9102190, size.height * 0.3062395);
    newYorkPath.lineTo(size.width * 0.9088634, size.height * 0.3064081);
    newYorkPath.lineTo(size.width * 0.9083420, size.height * 0.3080944);
    newYorkPath.close();
    newYorkPath.moveTo(size.width * 0.8783107, size.height * 0.3445194);
    newYorkPath.lineTo(size.width * 0.8790407, size.height * 0.3455312);
    newYorkPath.lineTo(size.width * 0.8803962, size.height * 0.3450253);
    newYorkPath.lineTo(size.width * 0.8815433, size.height * 0.3455312);
    newYorkPath.lineTo(size.width * 0.8824818, size.height * 0.3433390);
    newYorkPath.lineTo(size.width * 0.8844630, size.height * 0.3433390);
    newYorkPath.lineTo(size.width * 0.8869656, size.height * 0.3418212);
    newYorkPath.lineTo(size.width * 0.8922836, size.height * 0.3382799);
    newYorkPath.lineTo(size.width * 0.8917623, size.height * 0.3374368);
    newYorkPath.lineTo(size.width * 0.8897810, size.height * 0.3387858);
    newYorkPath.lineTo(size.width * 0.8876955, size.height * 0.3403035);
    newYorkPath.lineTo(size.width * 0.8879041, size.height * 0.3389545);
    newYorkPath.lineTo(size.width * 0.8906152, size.height * 0.3370995);
    newYorkPath.lineTo(size.width * 0.8914494, size.height * 0.3354132);
    newYorkPath.lineTo(size.width * 0.8927007, size.height * 0.3355818);
    newYorkPath.lineTo(size.width * 0.8969760, size.height * 0.3317032);
    newYorkPath.lineTo(size.width * 0.8969760, size.height * 0.3328836);
    newYorkPath.lineTo(size.width * 0.8925965, size.height * 0.3379427);
    newYorkPath.lineTo(size.width * 0.8972888, size.height * 0.3332209);
    newYorkPath.lineTo(size.width * 0.8990615, size.height * 0.3295110);
    newYorkPath.lineTo(size.width * 0.9006257, size.height * 0.3293423);
    newYorkPath.lineTo(size.width * 0.9053180, size.height * 0.3241147);
    newYorkPath.lineTo(size.width * 0.9086548, size.height * 0.3188870);
    newYorkPath.lineTo(size.width * 0.9117831, size.height * 0.3150084);
    newYorkPath.lineTo(size.width * 0.9128259, size.height * 0.3129848);
    newYorkPath.lineTo(size.width * 0.9110532, size.height * 0.3128162);
    newYorkPath.lineTo(size.width * 0.9100104, size.height * 0.3148398);
    newYorkPath.lineTo(size.width * 0.9098019, size.height * 0.3160202);
    newYorkPath.lineTo(size.width * 0.9088634, size.height * 0.3172007);
    newYorkPath.lineTo(size.width * 0.9080292, size.height * 0.3153457);
    newYorkPath.lineTo(size.width * 0.9062565, size.height * 0.3170320);
    newYorkPath.lineTo(size.width * 0.9061522, size.height * 0.3185497);
    newYorkPath.lineTo(size.width * 0.9052138, size.height * 0.3182125);
    newYorkPath.lineTo(size.width * 0.9057351, size.height * 0.3166948);
    newYorkPath.lineTo(size.width * 0.9044838, size.height * 0.3155143);
    newYorkPath.lineTo(size.width * 0.9038582, size.height * 0.3170320);
    newYorkPath.lineTo(size.width * 0.9047967, size.height * 0.3175379);
    newYorkPath.lineTo(size.width * 0.9050052, size.height * 0.3183811);
    newYorkPath.lineTo(size.width * 0.9046924, size.height * 0.3192243);
    newYorkPath.lineTo(size.width * 0.9032325, size.height * 0.3236088);
    newYorkPath.lineTo(size.width * 0.9012513, size.height * 0.3236088);
    newYorkPath.lineTo(size.width * 0.9021898, size.height * 0.3205734);
    newYorkPath.lineTo(size.width * 0.9031283, size.height * 0.3195616);
    newYorkPath.lineTo(size.width * 0.9034411, size.height * 0.3166948);
    newYorkPath.lineTo(size.width * 0.9049009, size.height * 0.3139966);
    newYorkPath.lineTo(size.width * 0.9058394, size.height * 0.3126476);
    newYorkPath.lineTo(size.width * 0.9074035, size.height * 0.3114671);
    newYorkPath.lineTo(size.width * 0.9061522, size.height * 0.3111298);
    newYorkPath.lineTo(size.width * 0.9054223, size.height * 0.3126476);
    newYorkPath.lineTo(size.width * 0.9046924, size.height * 0.3126476);
    newYorkPath.lineTo(size.width * 0.9035454, size.height * 0.3139966);
    newYorkPath.lineTo(size.width * 0.9033368, size.height * 0.3156830);
    newYorkPath.lineTo(size.width * 0.9010428, size.height * 0.3192243);
    newYorkPath.lineTo(size.width * 0.9006257, size.height * 0.3207420);
    newYorkPath.lineTo(size.width * 0.8991658, size.height * 0.3222597);
    newYorkPath.lineTo(size.width * 0.8911366, size.height * 0.3254637);
    newYorkPath.lineTo(size.width * 0.8913452, size.height * 0.3269815);
    newYorkPath.lineTo(size.width * 0.8904067, size.height * 0.3281619);
    newYorkPath.lineTo(size.width * 0.8883212, size.height * 0.3286678);
    newYorkPath.lineTo(size.width * 0.8872784, size.height * 0.3276560);
    newYorkPath.lineTo(size.width * 0.8870699, size.height * 0.3295110);
    newYorkPath.lineTo(size.width * 0.8859228, size.height * 0.3288364);
    newYorkPath.lineTo(size.width * 0.8860271, size.height * 0.3305228);
    newYorkPath.lineTo(size.width * 0.8847758, size.height * 0.3303541);
    newYorkPath.lineTo(size.width * 0.8835245, size.height * 0.3311973);
    newYorkPath.lineTo(size.width * 0.8833160, size.height * 0.3330523);
    newYorkPath.lineTo(size.width * 0.8822732, size.height * 0.3330523);
    newYorkPath.lineTo(size.width * 0.8824818, size.height * 0.3347386);
    newYorkPath.lineTo(size.width * 0.8817518, size.height * 0.3347386);
    newYorkPath.lineTo(size.width * 0.8819604, size.height * 0.3364250);
    newYorkPath.lineTo(size.width * 0.8800834, size.height * 0.3370995);
    newYorkPath.lineTo(size.width * 0.8785193, size.height * 0.3409781);
    newYorkPath.close();
    newYorkPath.moveTo(size.width * 0.8774765, size.height * 0.3438449);
    newYorkPath.lineTo(size.width * 0.8758081, size.height * 0.3445194);
    newYorkPath.lineTo(size.width * 0.8758081, size.height * 0.3462057);
    newYorkPath.lineTo(size.width * 0.8750782, size.height * 0.3489039);
    newYorkPath.lineTo(size.width * 0.8757039, size.height * 0.3500843);
    newYorkPath.lineTo(size.width * 0.8782065, size.height * 0.3462057);
    newYorkPath.lineTo(size.width * 0.8781022, size.height * 0.3446880);
    newYorkPath.close();
    newYorkPath.moveTo(size.width * 0.8669447, size.height * 0.1833052);
    newYorkPath.lineTo(size.width * 0.8663191, size.height * 0.1865093);
    newYorkPath.lineTo(size.width * 0.8677789, size.height * 0.1880270);
    newYorkPath.lineTo(size.width * 0.8673618, size.height * 0.1905565);
    newYorkPath.lineTo(size.width * 0.8678832, size.height * 0.1959528);
    newYorkPath.lineTo(size.width * 0.8701773, size.height * 0.1998314);
    newYorkPath.lineTo(size.width * 0.8697602, size.height * 0.2035413);
    newYorkPath.lineTo(size.width * 0.8703858, size.height * 0.2069140);
    newYorkPath.lineTo(size.width * 0.8699687, size.height * 0.2086003);
    newYorkPath.lineTo(size.width * 0.8696559, size.height * 0.2150084);
    newYorkPath.lineTo(size.width * 0.8728884, size.height * 0.2263069);
    newYorkPath.lineTo(size.width * 0.8720542, size.height * 0.2293423);
    newYorkPath.lineTo(size.width * 0.8729927, size.height * 0.2330523);
    newYorkPath.lineTo(size.width * 0.8739312, size.height * 0.2303541);
    newYorkPath.lineTo(size.width * 0.8759124, size.height * 0.2328836);
    newYorkPath.lineTo(size.width * 0.8790407, size.height * 0.2568297);
    newYorkPath.lineTo(size.width * 0.8785193, size.height * 0.2602024);
    newYorkPath.lineTo(size.width * 0.8796663, size.height * 0.2618887);
    newYorkPath.lineTo(size.width * 0.8791449, size.height * 0.2871838);
    newYorkPath.lineTo(size.width * 0.8798749, size.height * 0.2888702);
    newYorkPath.lineTo(size.width * 0.8827946, size.height * 0.3163575);
    newYorkPath.lineTo(size.width * 0.8846715, size.height * 0.3188870);
    newYorkPath.lineTo(size.width * 0.8810219, size.height * 0.3246206);
    newYorkPath.lineTo(size.width * 0.8827946, size.height * 0.3283305);
    newYorkPath.lineTo(size.width * 0.8814390, size.height * 0.3338954);
    newYorkPath.lineTo(size.width * 0.8798749, size.height * 0.3367622);
    newYorkPath.lineTo(size.width * 0.8783107, size.height * 0.3406408);
    newYorkPath.lineTo(size.width * 0.8781022, size.height * 0.3394604);
    newYorkPath.lineTo(size.width * 0.8785193, size.height * 0.3295110);
    newYorkPath.lineTo(size.width * 0.8632951, size.height * 0.3212479);
    newYorkPath.lineTo(size.width * 0.8616267, size.height * 0.3193929);
    newYorkPath.lineTo(size.width * 0.8596455, size.height * 0.3198988);
    newYorkPath.lineTo(size.width * 0.8565172, size.height * 0.3161889);
    newYorkPath.lineTo(size.width * 0.8533889, size.height * 0.3064081);
    newYorkPath.lineTo(size.width * 0.8513034, size.height * 0.3064081);
    newYorkPath.lineTo(size.width * 0.8508863, size.height * 0.3038786);
    newYorkPath.lineTo(size.width * 0.8491137, size.height * 0.3020236);
    newYorkPath.lineTo(size.width * 0.7755996, size.height * 0.3254637);
    newYorkPath.lineTo(size.width * 0.7747654, size.height * 0.3153457);
    newYorkPath.lineTo(size.width * 0.7792492, size.height * 0.3087690);
    newYorkPath.lineTo(size.width * 0.7798749, size.height * 0.3059022);
    newYorkPath.lineTo(size.width * 0.7839416, size.height * 0.3016863);
    newYorkPath.lineTo(size.width * 0.7845673, size.height * 0.2976391);
    newYorkPath.lineTo(size.width * 0.7869656, size.height * 0.2942664);
    newYorkPath.lineTo(size.width * 0.7877998, size.height * 0.2924115);
    newYorkPath.lineTo(size.width * 0.7860271, size.height * 0.2868465);
    newYorkPath.lineTo(size.width * 0.7842544, size.height * 0.2860034);
    newYorkPath.lineTo(size.width * 0.7823775, size.height * 0.2809444);
    newYorkPath.lineTo(size.width * 0.7821689, size.height * 0.2755481);
    newYorkPath.lineTo(size.width * 0.7900938, size.height * 0.2689713);
    newYorkPath.lineTo(size.width * 0.7986444, size.height * 0.2662732);
    newYorkPath.lineTo(size.width * 0.8032325, size.height * 0.2662732);
    newYorkPath.lineTo(size.width * 0.8065693, size.height * 0.2689713);
    newYorkPath.lineTo(size.width * 0.8075078, size.height * 0.2688027);
    newYorkPath.lineTo(size.width * 0.8093848, size.height * 0.2661046);
    newYorkPath.lineTo(size.width * 0.8129301, size.height * 0.2649241);
    newYorkPath.lineTo(size.width * 0.8160584, size.height * 0.2649241);
    newYorkPath.lineTo(size.width * 0.8187696, size.height * 0.2627319);
    newYorkPath.lineTo(size.width * 0.8213764, size.height * 0.2583474);
    newYorkPath.lineTo(size.width * 0.8238790, size.height * 0.2531197);
    newYorkPath.lineTo(size.width * 0.8258603, size.height * 0.2524452);
    newYorkPath.lineTo(size.width * 0.8270073, size.height * 0.2516020);
    newYorkPath.lineTo(size.width * 0.8274244, size.height * 0.2462057);
    newYorkPath.lineTo(size.width * 0.8259645, size.height * 0.2416526);
    newYorkPath.lineTo(size.width * 0.8247132, size.height * 0.2404722);
    newYorkPath.lineTo(size.width * 0.8267987, size.height * 0.2382799);
    newYorkPath.lineTo(size.width * 0.8266945, size.height * 0.2352445);
    newYorkPath.lineTo(size.width * 0.8251303, size.height * 0.2352445);
    newYorkPath.lineTo(size.width * 0.8227320, size.height * 0.2328836);
    newYorkPath.lineTo(size.width * 0.8226277, size.height * 0.2276560);
    newYorkPath.lineTo(size.width * 0.8290928, size.height * 0.2173693);
    newYorkPath.lineTo(size.width * 0.8298227, size.height * 0.2133221);
    newYorkPath.lineTo(size.width * 0.8336809, size.height * 0.2026981);
    newYorkPath.lineTo(size.width * 0.8398332, size.height * 0.1919056);
    newYorkPath.lineTo(size.width * 0.8420229, size.height * 0.1890388);
    newYorkPath.lineTo(size.width * 0.8446298, size.height * 0.1892074);
    newYorkPath.lineTo(size.width * 0.8661105, size.height * 0.1804384);
    newYorkPath.close();

    Paint newYorkPaint = Paint()..style = PaintingStyle.fill;
    newYorkPaint.color = usaColors.newYork ?? defaultColor;
    usaCanvas.drawPath(newYorkPath, newYorkPaint, onTapUp: (tabdetail) {
      callback('new york', tabdetail);
    });

    Path northCarolinaPath = Path();
    northCarolinaPath.moveTo(size.width * 0.8644421, size.height * 0.5060708);
    northCarolinaPath.lineTo(size.width * 0.8340980, size.height * 0.5163575);
    northCarolinaPath.lineTo(size.width * 0.7930136, size.height * 0.5286678);
    northCarolinaPath.lineTo(size.width * 0.7623566, size.height * 0.5345700);
    northCarolinaPath.lineTo(size.width * 0.7623566, size.height * 0.5433390);
    northCarolinaPath.lineTo(size.width * 0.7607925, size.height * 0.5431703);
    northCarolinaPath.lineTo(size.width * 0.7593326, size.height * 0.5451939);
    northCarolinaPath.lineTo(size.width * 0.7568300, size.height * 0.5539629);
    northCarolinaPath.lineTo(size.width * 0.7541189, size.height * 0.5521079);
    northCarolinaPath.lineTo(size.width * 0.7504692, size.height * 0.5563238);
    northCarolinaPath.lineTo(size.width * 0.7497393, size.height * 0.5598651);
    northCarolinaPath.lineTo(size.width * 0.7481752, size.height * 0.5618887);
    northCarolinaPath.lineTo(size.width * 0.7473410, size.height * 0.5605396);
    northCarolinaPath.lineTo(size.width * 0.7472367, size.height * 0.5580101);
    northCarolinaPath.lineTo(size.width * 0.7464025, size.height * 0.5576728);
    northCarolinaPath.lineTo(size.width * 0.7422315, size.height * 0.5632378);
    northCarolinaPath.lineTo(size.width * 0.7416058, size.height * 0.5689713);
    northCarolinaPath.lineTo(size.width * 0.7367049, size.height * 0.5730185);
    northCarolinaPath.lineTo(size.width * 0.7361835, size.height * 0.5750422);
    northCarolinaPath.lineTo(size.width * 0.7328467, size.height * 0.5794266);
    northCarolinaPath.lineTo(size.width * 0.7290928, size.height * 0.5802698);
    northCarolinaPath.lineTo(size.width * 0.7242961, size.height * 0.5853288);
    northCarolinaPath.lineTo(size.width * 0.7234619, size.height * 0.5922428);
    northCarolinaPath.lineTo(size.width * 0.7221064, size.height * 0.5937605);
    northCarolinaPath.lineTo(size.width * 0.7205422, size.height * 0.5935919);
    northCarolinaPath.lineTo(size.width * 0.7190824, size.height * 0.5957841);
    northCarolinaPath.lineTo(size.width * 0.7189781, size.height * 0.6040472);
    northCarolinaPath.lineTo(size.width * 0.7412930, size.height * 0.5989882);
    northCarolinaPath.lineTo(size.width * 0.7458811, size.height * 0.5957841);
    northCarolinaPath.lineTo(size.width * 0.7472367, size.height * 0.5956155);
    northCarolinaPath.lineTo(size.width * 0.7548488, size.height * 0.5883642);
    northCarolinaPath.lineTo(size.width * 0.7790407, size.height * 0.5846543);
    northCarolinaPath.lineTo(size.width * 0.7794578, size.height * 0.5854975);
    northCarolinaPath.lineTo(size.width * 0.7792492, size.height * 0.5878583);
    northCarolinaPath.lineTo(size.width * 0.7799791, size.height * 0.5883642);
    northCarolinaPath.lineTo(size.width * 0.7812304, size.height * 0.5858347);
    northCarolinaPath.lineTo(size.width * 0.7846715, size.height * 0.5908938);
    northCarolinaPath.lineTo(size.width * 0.7847758, size.height * 0.5952782);
    northCarolinaPath.lineTo(size.width * 0.8053180, size.height * 0.5905565);
    northCarolinaPath.lineTo(size.width * 0.8308655, size.height * 0.6193929);
    northCarolinaPath.lineTo(size.width * 0.8350365, size.height * 0.6156830);
    northCarolinaPath.lineTo(size.width * 0.8381648, size.height * 0.6145025);
    northCarolinaPath.lineTo(size.width * 0.8399374, size.height * 0.6145025);
    northCarolinaPath.lineTo(size.width * 0.8410845, size.height * 0.6163575);
    northCarolinaPath.lineTo(size.width * 0.8419187, size.height * 0.6129848);
    northCarolinaPath.lineTo(size.width * 0.8425443, size.height * 0.6045531);
    northCarolinaPath.lineTo(size.width * 0.8443170, size.height * 0.5979764);
    northCarolinaPath.lineTo(size.width * 0.8499479, size.height * 0.5876897);
    northCarolinaPath.lineTo(size.width * 0.8542231, size.height * 0.5817875);
    northCarolinaPath.lineTo(size.width * 0.8598540, size.height * 0.5779089);
    northCarolinaPath.lineTo(size.width * 0.8624609, size.height * 0.5772344);
    northCarolinaPath.lineTo(size.width * 0.8638165, size.height * 0.5779089);
    northCarolinaPath.lineTo(size.width * 0.8645464, size.height * 0.5797639);
    northCarolinaPath.lineTo(size.width * 0.8679875, size.height * 0.5686341);
    northCarolinaPath.lineTo(size.width * 0.8714286, size.height * 0.5596965);
    northCarolinaPath.lineTo(size.width * 0.8706986, size.height * 0.5591906);
    northCarolinaPath.lineTo(size.width * 0.8661105, size.height * 0.5706577);
    northCarolinaPath.lineTo(size.width * 0.8655892, size.height * 0.5693086);
    northCarolinaPath.lineTo(size.width * 0.8676747, size.height * 0.5655987);
    northCarolinaPath.lineTo(size.width * 0.8672576, size.height * 0.5630691);
    northCarolinaPath.lineTo(size.width * 0.8651721, size.height * 0.5622260);
    northCarolinaPath.lineTo(size.width * 0.8662148, size.height * 0.5644182);
    northCarolinaPath.lineTo(size.width * 0.8649635, size.height * 0.5645868);
    northCarolinaPath.lineTo(size.width * 0.8637122, size.height * 0.5615514);
    northCarolinaPath.lineTo(size.width * 0.8624609, size.height * 0.5649241);
    northCarolinaPath.lineTo(size.width * 0.8607925, size.height * 0.5652614);
    northCarolinaPath.lineTo(size.width * 0.8618352, size.height * 0.5607083);
    northCarolinaPath.lineTo(size.width * 0.8625652, size.height * 0.5578415);
    northCarolinaPath.lineTo(size.width * 0.8623566, size.height * 0.5529511);
    northCarolinaPath.lineTo(size.width * 0.8600626, size.height * 0.5527825);
    northCarolinaPath.lineTo(size.width * 0.8610010, size.height * 0.5512648);
    northCarolinaPath.lineTo(size.width * 0.8621481, size.height * 0.5517707);
    northCarolinaPath.lineTo(size.width * 0.8649635, size.height * 0.5519393);
    northCarolinaPath.lineTo(size.width * 0.8657977, size.height * 0.5510961);
    northCarolinaPath.lineTo(size.width * 0.8681960, size.height * 0.5510961);
    northCarolinaPath.lineTo(size.width * 0.8702815, size.height * 0.5478921);
    northCarolinaPath.lineTo(size.width * 0.8704901, size.height * 0.5424958);
    northCarolinaPath.lineTo(size.width * 0.8718457, size.height * 0.5401349);
    northCarolinaPath.lineTo(size.width * 0.8730970, size.height * 0.5397976);
    northCarolinaPath.lineTo(size.width * 0.8744526, size.height * 0.5381113);
    northCarolinaPath.lineTo(size.width * 0.8739312, size.height * 0.5318718);
    northCarolinaPath.lineTo(size.width * 0.8716371, size.height * 0.5254637);
    northCarolinaPath.lineTo(size.width * 0.8688217, size.height * 0.5251265);
    northCarolinaPath.lineTo(size.width * 0.8678832, size.height * 0.5278246);
    northCarolinaPath.lineTo(size.width * 0.8673618, size.height * 0.5261383);
    northCarolinaPath.lineTo(size.width * 0.8645464, size.height * 0.5264755);
    northCarolinaPath.lineTo(size.width * 0.8632951, size.height * 0.5271501);
    northCarolinaPath.lineTo(size.width * 0.8613139, size.height * 0.5291737);
    northCarolinaPath.lineTo(size.width * 0.8610010, size.height * 0.5284992);
    northCarolinaPath.lineTo(size.width * 0.8600626, size.height * 0.5284992);
    northCarolinaPath.lineTo(size.width * 0.8581856, size.height * 0.5305228);
    northCarolinaPath.lineTo(size.width * 0.8554745, size.height * 0.5313659);
    northCarolinaPath.lineTo(size.width * 0.8554745, size.height * 0.5291737);
    northCarolinaPath.lineTo(size.width * 0.8563087, size.height * 0.5274874);
    northCarolinaPath.lineTo(size.width * 0.8573514, size.height * 0.5286678);
    northCarolinaPath.lineTo(size.width * 0.8583942, size.height * 0.5286678);
    northCarolinaPath.lineTo(size.width * 0.8601668, size.height * 0.5251265);
    northCarolinaPath.lineTo(size.width * 0.8640250, size.height * 0.5222597);
    northCarolinaPath.lineTo(size.width * 0.8661105, size.height * 0.5185497);
    northCarolinaPath.lineTo(size.width * 0.8686131, size.height * 0.5185497);
    northCarolinaPath.lineTo(size.width * 0.8694473, size.height * 0.5207420);
    northCarolinaPath.lineTo(size.width * 0.8712200, size.height * 0.5220911);
    northCarolinaPath.lineTo(size.width * 0.8706986, size.height * 0.5195616);
    northCarolinaPath.lineTo(size.width * 0.8703858, size.height * 0.5168634);
    northCarolinaPath.lineTo(size.width * 0.8674661, size.height * 0.5116358);
    northCarolinaPath.lineTo(size.width * 0.8671533, size.height * 0.5092749);
    northCarolinaPath.lineTo(size.width * 0.8667362, size.height * 0.5109612);
    northCarolinaPath.lineTo(size.width * 0.8657977, size.height * 0.5087690);
    northCarolinaPath.close();
    northCarolinaPath.moveTo(size.width * 0.8717414, size.height * 0.5583474);
    northCarolinaPath.lineTo(size.width * 0.8745568, size.height * 0.5541315);
    northCarolinaPath.lineTo(size.width * 0.8793535, size.height * 0.5485666);
    northCarolinaPath.lineTo(size.width * 0.8793535, size.height * 0.5423272);
    northCarolinaPath.lineTo(size.width * 0.8789364, size.height * 0.5370995);
    northCarolinaPath.lineTo(size.width * 0.8771637, size.height * 0.5300169);
    northCarolinaPath.lineTo(size.width * 0.8787278, size.height * 0.5323777);
    northCarolinaPath.lineTo(size.width * 0.8797706, size.height * 0.5377740);
    northCarolinaPath.lineTo(size.width * 0.8801877, size.height * 0.5505902);
    northCarolinaPath.lineTo(size.width * 0.8784150, size.height * 0.5512648);
    northCarolinaPath.lineTo(size.width * 0.8751825, size.height * 0.5553120);
    northCarolinaPath.lineTo(size.width * 0.8718457, size.height * 0.5607083);
    northCarolinaPath.close();
    northCarolinaPath.moveTo(size.width * 0.8737226, size.height * 0.5258010);
    northCarolinaPath.lineTo(size.width * 0.8727842, size.height * 0.5254637);
    northCarolinaPath.lineTo(size.width * 0.8727842, size.height * 0.5271501);
    northCarolinaPath.lineTo(size.width * 0.8753910, size.height * 0.5308600);
    northCarolinaPath.lineTo(size.width * 0.8751825, size.height * 0.5284992);
    northCarolinaPath.close();
    northCarolinaPath.moveTo(size.width * 0.8767466, size.height * 0.5293423);
    northCarolinaPath.lineTo(size.width * 0.8752868, size.height * 0.5246206);
    northCarolinaPath.lineTo(size.width * 0.8729927, size.height * 0.5188870);
    northCarolinaPath.lineTo(size.width * 0.8704901, size.height * 0.5138280);
    northCarolinaPath.lineTo(size.width * 0.8681960, size.height * 0.5065767);
    northCarolinaPath.lineTo(size.width * 0.8673618, size.height * 0.5053963);
    northCarolinaPath.lineTo(size.width * 0.8696559, size.height * 0.5126476);
    northCarolinaPath.lineTo(size.width * 0.8699687, size.height * 0.5148398);
    northCarolinaPath.lineTo(size.width * 0.8735141, size.height * 0.5241147);
    northCarolinaPath.lineTo(size.width * 0.8753910, size.height * 0.5276560);
    northCarolinaPath.close();

    Paint northCarolinaPaint = Paint()..style = PaintingStyle.fill;
    northCarolinaPaint.color = usaColors.northCarolina ?? defaultColor;
    usaCanvas.drawPath(northCarolinaPath, northCarolinaPaint,
        onTapUp: (tabdetail) {
      callback('north carolina', tabdetail);
    });

    Path northDakotaPath = Path();
    northDakotaPath.moveTo(size.width * 0.4845673, size.height * 0.1156830);
    northDakotaPath.lineTo(size.width * 0.4834202, size.height * 0.1204047);
    northDakotaPath.lineTo(size.width * 0.4842544, size.height * 0.1227656);
    northDakotaPath.lineTo(size.width * 0.4839416, size.height * 0.1313659);
    northDakotaPath.lineTo(size.width * 0.4834202, size.height * 0.1332209);
    northDakotaPath.lineTo(size.width * 0.4862357, size.height * 0.1485666);
    northDakotaPath.lineTo(size.width * 0.4875912, size.height * 0.1527825);
    northDakotaPath.lineTo(size.width * 0.4883212, size.height * 0.1763912);
    northDakotaPath.lineTo(size.width * 0.4893639, size.height * 0.1809444);
    northDakotaPath.lineTo(size.width * 0.4889468, size.height * 0.1907251);
    northDakotaPath.lineTo(size.width * 0.4919708, size.height * 0.2032040);
    northDakotaPath.lineTo(size.width * 0.4922836, size.height * 0.2129848);
    northDakotaPath.lineTo(size.width * 0.4921794, size.height * 0.2165261);
    northDakotaPath.lineTo(size.width * 0.4614181, size.height * 0.2158516);
    northDakotaPath.lineTo(size.width * 0.4134515, size.height * 0.2123103);
    northDakotaPath.lineTo(size.width * 0.3725756, size.height * 0.2074199);
    northDakotaPath.lineTo(size.width * 0.3779979, size.height * 0.09494098);
    northDakotaPath.lineTo(size.width * 0.4244004, size.height * 0.1006745);
    northDakotaPath.lineTo(size.width * 0.4820647, size.height * 0.1033727);
    northDakotaPath.close();

    Paint northDakotaPaint = Paint()..style = PaintingStyle.fill;
    northDakotaPaint.color = usaColors.northDakota ?? defaultColor;
    usaCanvas.drawPath(northDakotaPath, northDakotaPaint, onTapUp: (tabdetail) {
      callback('north dakota', tabdetail);
    });

    Path ohioPath = Path();
    ohioPath.moveTo(size.width * 0.7150156, size.height * 0.3521079);
    ohioPath.lineTo(size.width * 0.7169969, size.height * 0.3514334);
    ohioPath.lineTo(size.width * 0.7201251, size.height * 0.3536256);
    ohioPath.lineTo(size.width * 0.7223149, size.height * 0.3546374);
    ohioPath.lineTo(size.width * 0.7230448, size.height * 0.3561551);
    ohioPath.lineTo(size.width * 0.7240876, size.height * 0.3561551);
    ohioPath.lineTo(size.width * 0.7251303, size.height * 0.3536256);
    ohioPath.lineTo(size.width * 0.7264859, size.height * 0.3549747);
    ohioPath.lineTo(size.width * 0.7280501, size.height * 0.3549747);
    ohioPath.lineTo(size.width * 0.7279458, size.height * 0.3566610);
    ohioPath.lineTo(size.width * 0.7247132, size.height * 0.3575042);
    ohioPath.lineTo(size.width * 0.7226277, size.height * 0.3593592);
    ohioPath.lineTo(size.width * 0.7246090, size.height * 0.3607083);
    ohioPath.lineTo(size.width * 0.7262774, size.height * 0.3581788);
    ohioPath.lineTo(size.width * 0.7287800, size.height * 0.3575042);
    ohioPath.lineTo(size.width * 0.7310740, size.height * 0.3600337);
    ohioPath.lineTo(size.width * 0.7326382, size.height * 0.3598651);
    ohioPath.lineTo(size.width * 0.7352450, size.height * 0.3569983);
    ohioPath.lineTo(size.width * 0.7389990, size.height * 0.3534570);
    ohioPath.lineTo(size.width * 0.7444213, size.height * 0.3529511);
    ohioPath.lineTo(size.width * 0.7495308, size.height * 0.3430017);
    ohioPath.lineTo(size.width * 0.7534932, size.height * 0.3377740);
    ohioPath.lineTo(size.width * 0.7631908, size.height * 0.3291737);
    ohioPath.lineTo(size.width * 0.7683003, size.height * 0.3795953);
    ohioPath.lineTo(size.width * 0.7660063, size.height * 0.3816189);
    ohioPath.lineTo(size.width * 0.7674661, size.height * 0.3851602);
    ohioPath.lineTo(size.width * 0.7673618, size.height * 0.3888702);
    ohioPath.lineTo(size.width * 0.7679875, size.height * 0.3922428);
    ohioPath.lineTo(size.width * 0.7668405, size.height * 0.3979764);
    ohioPath.lineTo(size.width * 0.7667362, size.height * 0.4070826);
    ohioPath.lineTo(size.width * 0.7656934, size.height * 0.4131535);
    ohioPath.lineTo(size.width * 0.7662148, size.height * 0.4150084);
    ohioPath.lineTo(size.width * 0.7657977, size.height * 0.4187184);
    ohioPath.lineTo(size.width * 0.7646507, size.height * 0.4195616);
    ohioPath.lineTo(size.width * 0.7625652, size.height * 0.4251265);
    ohioPath.lineTo(size.width * 0.7606882, size.height * 0.4284992);
    ohioPath.lineTo(size.width * 0.7600626, size.height * 0.4284992);
    ohioPath.lineTo(size.width * 0.7581856, size.height * 0.4313659);
    ohioPath.lineTo(size.width * 0.7568300, size.height * 0.4293423);
    ohioPath.lineTo(size.width * 0.7552659, size.height * 0.4323777);
    ohioPath.lineTo(size.width * 0.7549531, size.height * 0.4344013);
    ohioPath.lineTo(size.width * 0.7535975, size.height * 0.4344013);
    ohioPath.lineTo(size.width * 0.7522419, size.height * 0.4381113);
    ohioPath.lineTo(size.width * 0.7523462, size.height * 0.4416526);
    ohioPath.lineTo(size.width * 0.7513034, size.height * 0.4424958);
    ohioPath.lineTo(size.width * 0.7527633, size.height * 0.4443508);
    ohioPath.lineTo(size.width * 0.7527633, size.height * 0.4475548);
    ohioPath.lineTo(size.width * 0.7517205, size.height * 0.4478921);
    ohioPath.lineTo(size.width * 0.7509906, size.height * 0.4492411);
    ohioPath.lineTo(size.width * 0.7499479, size.height * 0.4500843);
    ohioPath.lineTo(size.width * 0.7493222, size.height * 0.4465430);
    ohioPath.lineTo(size.width * 0.7476538, size.height * 0.4456998);
    ohioPath.lineTo(size.width * 0.7466111, size.height * 0.4495784);
    ohioPath.lineTo(size.width * 0.7462982, size.height * 0.4532884);
    ohioPath.lineTo(size.width * 0.7451512, size.height * 0.4554806);
    ohioPath.lineTo(size.width * 0.7465068, size.height * 0.4615514);
    ohioPath.lineTo(size.width * 0.7449426, size.height * 0.4629005);
    ohioPath.lineTo(size.width * 0.7445255, size.height * 0.4688027);
    ohioPath.lineTo(size.width * 0.7429614, size.height * 0.4688027);
    ohioPath.lineTo(size.width * 0.7396246, size.height * 0.4711636);
    ohioPath.lineTo(size.width * 0.7383733, size.height * 0.4676223);
    ohioPath.lineTo(size.width * 0.7347237, size.height * 0.4652614);
    ohioPath.lineTo(size.width * 0.7338895, size.height * 0.4603710);
    ohioPath.lineTo(size.width * 0.7333681, size.height * 0.4590219);
    ohioPath.lineTo(size.width * 0.7298227, size.height * 0.4620573);
    ohioPath.lineTo(size.width * 0.7291971, size.height * 0.4649241);
    ohioPath.lineTo(size.width * 0.7282586, size.height * 0.4649241);
    ohioPath.lineTo(size.width * 0.7269030, size.height * 0.4661046);
    ohioPath.lineTo(size.width * 0.7256517, size.height * 0.4647555);
    ohioPath.lineTo(size.width * 0.7225235, size.height * 0.4634064);
    ohioPath.lineTo(size.width * 0.7205422, size.height * 0.4647555);
    ohioPath.lineTo(size.width * 0.7205422, size.height * 0.4664418);
    ohioPath.lineTo(size.width * 0.7182482, size.height * 0.4661046);
    ohioPath.lineTo(size.width * 0.7162669, size.height * 0.4625632);
    ohioPath.lineTo(size.width * 0.7138686, size.height * 0.4629005);
    ohioPath.lineTo(size.width * 0.7095933, size.height * 0.4617201);
    ohioPath.lineTo(size.width * 0.7095933, size.height * 0.4600337);
    ohioPath.lineTo(size.width * 0.7072993, size.height * 0.4543002);
    ohioPath.lineTo(size.width * 0.7042753, size.height * 0.4522766);
    ohioPath.lineTo(size.width * 0.7022941, size.height * 0.4536256);
    ohioPath.lineTo(size.width * 0.7000000, size.height * 0.4534570);
    ohioPath.lineTo(size.width * 0.6986444, size.height * 0.4526138);
    ohioPath.lineTo(size.width * 0.6917623, size.height * 0.3561551);
    ohioPath.lineTo(size.width * 0.7140772, size.height * 0.3502530);
    ohioPath.close();

    Paint ohioPaint = Paint()..style = PaintingStyle.fill;
    ohioPaint.color = usaColors.ohio ?? defaultColor;
    usaCanvas.drawPath(ohioPath, ohioPaint, onTapUp: (tabdetail) {
      callback('ohio', tabdetail);
    });

    Path oklahomaPath = Path();
    oklahomaPath.moveTo(size.width * 0.5229406, size.height * 0.6721754);
    oklahomaPath.lineTo(size.width * 0.5181439, size.height * 0.6657673);
    oklahomaPath.lineTo(size.width * 0.5158498, size.height * 0.6642496);
    oklahomaPath.lineTo(size.width * 0.5153285, size.height * 0.6669477);
    oklahomaPath.lineTo(size.width * 0.5100104, size.height * 0.6674536);
    oklahomaPath.lineTo(size.width * 0.5093848, size.height * 0.6649241);
    oklahomaPath.lineTo(size.width * 0.5041710, size.height * 0.6691400);
    oklahomaPath.lineTo(size.width * 0.5025026, size.height * 0.6679595);
    oklahomaPath.lineTo(size.width * 0.4986444, size.height * 0.6684654);
    oklahomaPath.lineTo(size.width * 0.4980188, size.height * 0.6713322);
    oklahomaPath.lineTo(size.width * 0.4942649, size.height * 0.6728499);
    oklahomaPath.lineTo(size.width * 0.4929093, size.height * 0.6708263);
    oklahomaPath.lineTo(size.width * 0.4916580, size.height * 0.6709949);
    oklahomaPath.lineTo(size.width * 0.4895725, size.height * 0.6679595);
    oklahomaPath.lineTo(size.width * 0.4873827, size.height * 0.6691400);
    oklahomaPath.lineTo(size.width * 0.4852972, size.height * 0.6682968);
    oklahomaPath.lineTo(size.width * 0.4834202, size.height * 0.6649241);
    oklahomaPath.lineTo(size.width * 0.4808133, size.height * 0.6720067);
    oklahomaPath.lineTo(size.width * 0.4795620, size.height * 0.6733558);
    oklahomaPath.lineTo(size.width * 0.4785193, size.height * 0.6703204);
    oklahomaPath.lineTo(size.width * 0.4788321, size.height * 0.6669477);
    oklahomaPath.lineTo(size.width * 0.4775808, size.height * 0.6657673);
    oklahomaPath.lineTo(size.width * 0.4751825, size.height * 0.6699831);
    oklahomaPath.lineTo(size.width * 0.4734098, size.height * 0.6679595);
    oklahomaPath.lineTo(size.width * 0.4733055, size.height * 0.6654300);
    oklahomaPath.lineTo(size.width * 0.4719499, size.height * 0.6662732);
    oklahomaPath.lineTo(size.width * 0.4692388, size.height * 0.6634064);
    oklahomaPath.lineTo(size.width * 0.4661105, size.height * 0.6677909);
    oklahomaPath.lineTo(size.width * 0.4637122, size.height * 0.6659359);
    oklahomaPath.lineTo(size.width * 0.4644421, size.height * 0.6623946);
    oklahomaPath.lineTo(size.width * 0.4620438, size.height * 0.6625632);
    oklahomaPath.lineTo(size.width * 0.4600626, size.height * 0.6575042);
    oklahomaPath.lineTo(size.width * 0.4564129, size.height * 0.6556492);
    oklahomaPath.lineTo(size.width * 0.4543274, size.height * 0.6595278);
    oklahomaPath.lineTo(size.width * 0.4519291, size.height * 0.6558179);
    oklahomaPath.lineTo(size.width * 0.4504692, size.height * 0.6564924);
    oklahomaPath.lineTo(size.width * 0.4483837, size.height * 0.6566610);
    oklahomaPath.lineTo(size.width * 0.4447341, size.height * 0.6534570);
    oklahomaPath.lineTo(size.width * 0.4423358, size.height * 0.6536256);
    oklahomaPath.lineTo(size.width * 0.4410845, size.height * 0.6524452);
    oklahomaPath.lineTo(size.width * 0.4405631, size.height * 0.6475548);
    oklahomaPath.lineTo(size.width * 0.4381648, size.height * 0.6446880);
    oklahomaPath.lineTo(size.width * 0.4370177, size.height * 0.6472175);
    oklahomaPath.lineTo(size.width * 0.4355579, size.height * 0.6455312);
    oklahomaPath.lineTo(size.width * 0.4343066, size.height * 0.6448567);
    oklahomaPath.lineTo(size.width * 0.4331595, size.height * 0.6465430);
    oklahomaPath.lineTo(size.width * 0.4315954, size.height * 0.6460371);
    oklahomaPath.lineTo(size.width * 0.4289885, size.height * 0.6409781);
    oklahomaPath.lineTo(size.width * 0.4261731, size.height * 0.6387858);
    oklahomaPath.lineTo(size.width * 0.4276330, size.height * 0.5667791);
    oklahomaPath.lineTo(size.width * 0.3727842, size.height * 0.5613828);
    oklahomaPath.lineTo(size.width * 0.3734098, size.height * 0.5435076);
    oklahomaPath.lineTo(size.width * 0.3906152, size.height * 0.5451939);
    oklahomaPath.lineTo(size.width * 0.4612096, size.height * 0.5500843);
    oklahomaPath.lineTo(size.width * 0.5258603, size.height * 0.5502530);
    oklahomaPath.lineTo(size.width * 0.5260688, size.height * 0.5684654);
    oklahomaPath.lineTo(size.width * 0.5303441, size.height * 0.6096121);
    oklahomaPath.lineTo(size.width * 0.5296142, size.height * 0.6753794);
    oklahomaPath.close();

    Paint oklahomaPaint = Paint()..style = PaintingStyle.fill;
    oklahomaPaint.color = usaColors.oklahoma ?? defaultColor;
    usaCanvas.drawPath(oklahomaPath, oklahomaPaint, onTapUp: (tabdetail) {
      callback('oklahoma', tabdetail);
    });

    Path oregonPath = Path();
    oregonPath.moveTo(size.width * 0.09791449, size.height * 0.2807757);
    oregonPath.lineTo(size.width * 0.1469239, size.height * 0.2996627);
    oregonPath.lineTo(size.width * 0.1557873, size.height * 0.2367622);
    oregonPath.lineTo(size.width * 0.1588113, size.height * 0.2269815);
    oregonPath.lineTo(size.width * 0.1592284, size.height * 0.2234401);
    oregonPath.lineTo(size.width * 0.1600626, size.height * 0.2219224);
    oregonPath.lineTo(size.width * 0.1591241, size.height * 0.2185497);
    oregonPath.lineTo(size.width * 0.1561001, size.height * 0.2165261);
    oregonPath.lineTo(size.width * 0.1563087, size.height * 0.2094435);
    oregonPath.lineTo(size.width * 0.1604797, size.height * 0.1996627);
    oregonPath.lineTo(size.width * 0.1630865, size.height * 0.1983137);
    oregonPath.lineTo(size.width * 0.1647550, size.height * 0.1944351);
    oregonPath.lineTo(size.width * 0.1646507, size.height * 0.1917369);
    oregonPath.lineTo(size.width * 0.1665276, size.height * 0.1890388);
    oregonPath.lineTo(size.width * 0.1698644, size.height * 0.1797639);
    oregonPath.lineTo(size.width * 0.1742440, size.height * 0.1716695);
    oregonPath.lineTo(size.width * 0.1737226, size.height * 0.1662732);
    oregonPath.lineTo(size.width * 0.1700730, size.height * 0.1610455);
    oregonPath.lineTo(size.width * 0.1684046, size.height * 0.1549747);
    oregonPath.lineTo(size.width * 0.1368092, size.height * 0.1426644);
    oregonPath.lineTo(size.width * 0.1338895, size.height * 0.1443508);
    oregonPath.lineTo(size.width * 0.1282586, size.height * 0.1428331);
    oregonPath.lineTo(size.width * 0.1263816, size.height * 0.1413153);
    oregonPath.lineTo(size.width * 0.1248175, size.height * 0.1433390);
    oregonPath.lineTo(size.width * 0.1213764, size.height * 0.1426644);
    oregonPath.lineTo(size.width * 0.1166840, size.height * 0.1435076);
    oregonPath.lineTo(size.width * 0.1157456, size.height * 0.1446880);
    oregonPath.lineTo(size.width * 0.1113660, size.height * 0.1440135);
    oregonPath.lineTo(size.width * 0.1105318, size.height * 0.1413153);
    oregonPath.lineTo(size.width * 0.1092805, size.height * 0.1409781);
    oregonPath.lineTo(size.width * 0.1046924, size.height * 0.1431703);
    oregonPath.lineTo(size.width * 0.1030240, size.height * 0.1413153);
    oregonPath.lineTo(size.width * 0.1007299, size.height * 0.1426644);
    oregonPath.lineTo(size.width * 0.1005214, size.height * 0.1396290);
    oregonPath.lineTo(size.width * 0.09812304, size.height * 0.1376054);
    oregonPath.lineTo(size.width * 0.09655892, size.height * 0.1372681);
    oregonPath.lineTo(size.width * 0.09551616, size.height * 0.1354132);
    oregonPath.lineTo(size.width * 0.09238790, size.height * 0.1359191);
    oregonPath.lineTo(size.width * 0.09113660, size.height * 0.1345700);
    oregonPath.lineTo(size.width * 0.08988530, size.height * 0.1345700);
    oregonPath.lineTo(size.width * 0.08863399, size.height * 0.1360877);
    oregonPath.lineTo(size.width * 0.08289885, size.height * 0.1372681);
    oregonPath.lineTo(size.width * 0.07601668, size.height * 0.1301855);
    oregonPath.lineTo(size.width * 0.07716371, size.height * 0.1207420);
    oregonPath.lineTo(size.width * 0.07674661, size.height * 0.1138280);
    oregonPath.lineTo(size.width * 0.07340980, size.height * 0.1075885);
    oregonPath.lineTo(size.width * 0.06955162, size.height * 0.1077572);
    oregonPath.lineTo(size.width * 0.06913452, size.height * 0.1059022);
    oregonPath.lineTo(size.width * 0.06955162, size.height * 0.1038786);
    oregonPath.lineTo(size.width * 0.06882169, size.height * 0.1025295);
    oregonPath.lineTo(size.width * 0.06777894, size.height * 0.1026981);
    oregonPath.lineTo(size.width * 0.06663191, size.height * 0.1048904);
    oregonPath.lineTo(size.width * 0.06506778, size.height * 0.1045531);
    oregonPath.lineTo(size.width * 0.06454640, size.height * 0.1026981);
    oregonPath.lineTo(size.width * 0.06350365, size.height * 0.1025295);
    oregonPath.lineTo(size.width * 0.06277372, size.height * 0.1035413);
    oregonPath.lineTo(size.width * 0.06068822, size.height * 0.1003373);
    oregonPath.lineTo(size.width * 0.06068822, size.height * 0.1075885);
    oregonPath.lineTo(size.width * 0.05933264, size.height * 0.1097808);
    oregonPath.lineTo(size.width * 0.05818561, size.height * 0.1156830);
    oregonPath.lineTo(size.width * 0.05808133, size.height * 0.1195616);
    oregonPath.lineTo(size.width * 0.05338895, size.height * 0.1403035);
    oregonPath.lineTo(size.width * 0.03962461, size.height * 0.1930860);
    oregonPath.lineTo(size.width * 0.03628780, size.height * 0.2008432);
    oregonPath.lineTo(size.width * 0.03461940, size.height * 0.2006745);
    oregonPath.lineTo(size.width * 0.03472367, size.height * 0.2042159);
    oregonPath.lineTo(size.width * 0.02930136, size.height * 0.2161889);
    oregonPath.lineTo(size.width * 0.02898853, size.height * 0.2217538);
    oregonPath.lineTo(size.width * 0.03003128, size.height * 0.2239460);
    oregonPath.lineTo(size.width * 0.03013556, size.height * 0.2279933);
    oregonPath.lineTo(size.width * 0.02888425, size.height * 0.2298482);
    oregonPath.lineTo(size.width * 0.02763295, size.height * 0.2349073);
    oregonPath.lineTo(size.width * 0.02773723, size.height * 0.2445194);
    oregonPath.lineTo(size.width * 0.02898853, size.height * 0.2494098);
    oregonPath.close();

    Paint oregonPaint = Paint()..style = PaintingStyle.fill;
    oregonPaint.color = usaColors.oregon ?? defaultColor;
    usaCanvas.drawPath(oregonPath, oregonPaint, onTapUp: (tabdetail) {
      callback('oregon', tabdetail);
    });

    Path pennsylvaniaPath = Path();
    pennsylvaniaPath.moveTo(size.width * 0.8616267, size.height * 0.3193929);
    pennsylvaniaPath.lineTo(size.width * 0.8596455, size.height * 0.3198988);
    pennsylvaniaPath.lineTo(size.width * 0.8565172, size.height * 0.3161889);
    pennsylvaniaPath.lineTo(size.width * 0.8533889, size.height * 0.3064081);
    pennsylvaniaPath.lineTo(size.width * 0.8513034, size.height * 0.3064081);
    pennsylvaniaPath.lineTo(size.width * 0.8508863, size.height * 0.3038786);
    pennsylvaniaPath.lineTo(size.width * 0.8491137, size.height * 0.3020236);
    pennsylvaniaPath.lineTo(size.width * 0.7755996, size.height * 0.3254637);
    pennsylvaniaPath.lineTo(size.width * 0.7747654, size.height * 0.3153457);
    pennsylvaniaPath.lineTo(size.width * 0.7703858, size.height * 0.3210793);
    pennsylvaniaPath.lineTo(size.width * 0.7694473, size.height * 0.3212479);
    pennsylvaniaPath.lineTo(size.width * 0.7666319, size.height * 0.3263069);
    pennsylvaniaPath.lineTo(size.width * 0.7631908, size.height * 0.3291737);
    pennsylvaniaPath.lineTo(size.width * 0.7683003, size.height * 0.3795953);
    pennsylvaniaPath.lineTo(size.width * 0.7716371, size.height * 0.4128162);
    pennsylvaniaPath.lineTo(size.width * 0.7897810, size.height * 0.4079258);
    pennsylvaniaPath.lineTo(size.width * 0.8528676, size.height * 0.3880270);
    pennsylvaniaPath.lineTo(size.width * 0.8541189, size.height * 0.3844857);
    pennsylvaniaPath.lineTo(size.width * 0.8556830, size.height * 0.3826307);
    pennsylvaniaPath.lineTo(size.width * 0.8573514, size.height * 0.3821248);
    pennsylvaniaPath.lineTo(size.width * 0.8590198, size.height * 0.3831366);
    pennsylvaniaPath.lineTo(size.width * 0.8604797, size.height * 0.3802698);
    pennsylvaniaPath.lineTo(size.width * 0.8621481, size.height * 0.3792580);
    pennsylvaniaPath.lineTo(size.width * 0.8640250, size.height * 0.3741990);
    pennsylvaniaPath.lineTo(size.width * 0.8656934, size.height * 0.3703204);
    pennsylvaniaPath.lineTo(size.width * 0.8691345, size.height * 0.3659359);
    pennsylvaniaPath.lineTo(size.width * 0.8647550, size.height * 0.3605396);
    pennsylvaniaPath.lineTo(size.width * 0.8625652, size.height * 0.3586847);
    pennsylvaniaPath.lineTo(size.width * 0.8615224, size.height * 0.3539629);
    pennsylvaniaPath.lineTo(size.width * 0.8587070, size.height * 0.3524452);
    pennsylvaniaPath.lineTo(size.width * 0.8581856, size.height * 0.3463744);
    pennsylvaniaPath.lineTo(size.width * 0.8592284, size.height * 0.3446880);
    pennsylvaniaPath.lineTo(size.width * 0.8599583, size.height * 0.3413153);
    pennsylvaniaPath.lineTo(size.width * 0.8583942, size.height * 0.3382799);
    pennsylvaniaPath.lineTo(size.width * 0.8615224, size.height * 0.3291737);
    pennsylvaniaPath.lineTo(size.width * 0.8614181, size.height * 0.3254637);
    pennsylvaniaPath.lineTo(size.width * 0.8632951, size.height * 0.3212479);
    pennsylvaniaPath.close();

    Paint pennsylvaniaPaint = Paint()..style = PaintingStyle.fill;
    pennsylvaniaPaint.color = usaColors.pennsylvania ?? defaultColor;
    usaCanvas.drawPath(pennsylvaniaPath, pennsylvaniaPaint,
        onTapUp: (tabdetail) {
      callback('pennsylvania', tabdetail);
    });

    Path rhodeIslandPath = Path();
    rhodeIslandPath.moveTo(size.width * 0.9209593, size.height * 0.2878583);
    rhodeIslandPath.lineTo(size.width * 0.9196038, size.height * 0.2860034);
    rhodeIslandPath.lineTo(size.width * 0.9168926, size.height * 0.2838111);
    rhodeIslandPath.lineTo(size.width * 0.9162669, size.height * 0.2801012);
    rhodeIslandPath.lineTo(size.width * 0.9154327, size.height * 0.2801012);
    rhodeIslandPath.lineTo(size.width * 0.9147028, size.height * 0.2757167);
    rhodeIslandPath.lineTo(size.width * 0.9079249, size.height * 0.2790894);
    rhodeIslandPath.lineTo(size.width * 0.9112617, size.height * 0.2998314);
    rhodeIslandPath.lineTo(size.width * 0.9108446, size.height * 0.3016863);
    rhodeIslandPath.lineTo(size.width * 0.9112617, size.height * 0.3047218);
    rhodeIslandPath.lineTo(size.width * 0.9171011, size.height * 0.2986509);
    rhodeIslandPath.lineTo(size.width * 0.9172054, size.height * 0.2935919);
    rhodeIslandPath.lineTo(size.width * 0.9163712, size.height * 0.2922428);
    rhodeIslandPath.lineTo(size.width * 0.9167883, size.height * 0.2912310);
    rhodeIslandPath.lineTo(size.width * 0.9166840, size.height * 0.2890388);
    rhodeIslandPath.lineTo(size.width * 0.9157456, size.height * 0.2878583);
    rhodeIslandPath.lineTo(size.width * 0.9169969, size.height * 0.2871838);
    rhodeIslandPath.lineTo(size.width * 0.9160584, size.height * 0.2844857);
    rhodeIslandPath.lineTo(size.width * 0.9179353, size.height * 0.2856661);
    rhodeIslandPath.lineTo(size.width * 0.9182482, size.height * 0.2880270);
    rhodeIslandPath.lineTo(size.width * 0.9189781, size.height * 0.2900506);
    rhodeIslandPath.lineTo(size.width * 0.9175182, size.height * 0.2887015);
    rhodeIslandPath.lineTo(size.width * 0.9186653, size.height * 0.2915683);
    rhodeIslandPath.lineTo(size.width * 0.9183525, size.height * 0.2935919);
    rhodeIslandPath.lineTo(size.width * 0.9177268, size.height * 0.2917369);
    rhodeIslandPath.lineTo(size.width * 0.9177268, size.height * 0.2959528);
    rhodeIslandPath.lineTo(size.width * 0.9183525, size.height * 0.2944351);
    rhodeIslandPath.lineTo(size.width * 0.9187696, size.height * 0.2959528);
    rhodeIslandPath.lineTo(size.width * 0.9201251, size.height * 0.2934233);
    rhodeIslandPath.lineTo(size.width * 0.9199166, size.height * 0.2892074);
    rhodeIslandPath.lineTo(size.width * 0.9213764, size.height * 0.2944351);
    rhodeIslandPath.lineTo(size.width * 0.9224192, size.height * 0.2929174);
    rhodeIslandPath.close();
    rhodeIslandPath.moveTo(size.width * 0.9160584, size.height * 0.3084317);
    rhodeIslandPath.lineTo(size.width * 0.9169969, size.height * 0.3084317);
    rhodeIslandPath.lineTo(size.width * 0.9175182, size.height * 0.3074199);
    rhodeIslandPath.lineTo(size.width * 0.9166840, size.height * 0.3052277);
    rhodeIslandPath.lineTo(size.width * 0.9159541, size.height * 0.3064081);
    rhodeIslandPath.close();

    Paint rhodeIslandPaint = Paint()..style = PaintingStyle.fill;
    rhodeIslandPaint.color = usaColors.rhodeIsland ?? defaultColor;
    usaCanvas.drawPath(rhodeIslandPath, rhodeIslandPaint, onTapUp: (tabdetail) {
      callback('rhode island', tabdetail);
    });

    Path southCarolinaPath = Path();
    southCarolinaPath.moveTo(size.width * 0.8053180, size.height * 0.5905565);
    southCarolinaPath.lineTo(size.width * 0.7847758, size.height * 0.5952782);
    southCarolinaPath.lineTo(size.width * 0.7846715, size.height * 0.5908938);
    southCarolinaPath.lineTo(size.width * 0.7812304, size.height * 0.5858347);
    southCarolinaPath.lineTo(size.width * 0.7799791, size.height * 0.5883642);
    southCarolinaPath.lineTo(size.width * 0.7792492, size.height * 0.5878583);
    southCarolinaPath.lineTo(size.width * 0.7794578, size.height * 0.5854975);
    southCarolinaPath.lineTo(size.width * 0.7790407, size.height * 0.5846543);
    southCarolinaPath.lineTo(size.width * 0.7548488, size.height * 0.5883642);
    southCarolinaPath.lineTo(size.width * 0.7472367, size.height * 0.5956155);
    southCarolinaPath.lineTo(size.width * 0.7458811, size.height * 0.5957841);
    southCarolinaPath.lineTo(size.width * 0.7412930, size.height * 0.5989882);
    southCarolinaPath.lineTo(size.width * 0.7411887, size.height * 0.6021922);
    southCarolinaPath.lineTo(size.width * 0.7392075, size.height * 0.6038786);
    southCarolinaPath.lineTo(size.width * 0.7377477, size.height * 0.6092749);
    southCarolinaPath.lineTo(size.width * 0.7379562, size.height * 0.6114671);
    southCarolinaPath.lineTo(size.width * 0.7443170, size.height * 0.6178752);
    southCarolinaPath.lineTo(size.width * 0.7470282, size.height * 0.6173693);
    southCarolinaPath.lineTo(size.width * 0.7502607, size.height * 0.6241147);
    southCarolinaPath.lineTo(size.width * 0.7506778, size.height * 0.6269815);
    southCarolinaPath.lineTo(size.width * 0.7550574, size.height * 0.6355818);
    southCarolinaPath.lineTo(size.width * 0.7577685, size.height * 0.6384486);
    southCarolinaPath.lineTo(size.width * 0.7592284, size.height * 0.6387858);
    southCarolinaPath.lineTo(size.width * 0.7615224, size.height * 0.6414840);
    southCarolinaPath.lineTo(size.width * 0.7626694, size.height * 0.6451939);
    southCarolinaPath.lineTo(size.width * 0.7647550, size.height * 0.6478921);
    southCarolinaPath.lineTo(size.width * 0.7666319, size.height * 0.6487352);
    southCarolinaPath.lineTo(size.width * 0.7694473, size.height * 0.6532884);
    southCarolinaPath.lineTo(size.width * 0.7695516, size.height * 0.6556492);
    southCarolinaPath.lineTo(size.width * 0.7722628, size.height * 0.6603710);
    southCarolinaPath.lineTo(size.width * 0.7774765, size.height * 0.6642496);
    southCarolinaPath.lineTo(size.width * 0.7812304, size.height * 0.6755481);
    southCarolinaPath.lineTo(size.width * 0.7815433, size.height * 0.6801012);
    southCarolinaPath.lineTo(size.width * 0.7856100, size.height * 0.6836425);
    southCarolinaPath.lineTo(size.width * 0.7882169, size.height * 0.6917369);
    southCarolinaPath.lineTo(size.width * 0.7890511, size.height * 0.6969646);
    southCarolinaPath.lineTo(size.width * 0.7934307, size.height * 0.6976391);
    southCarolinaPath.lineTo(size.width * 0.7942649, size.height * 0.6951096);
    southCarolinaPath.lineTo(size.width * 0.7948905, size.height * 0.6951096);
    southCarolinaPath.lineTo(size.width * 0.7967675, size.height * 0.6925801);
    southCarolinaPath.lineTo(size.width * 0.7972888, size.height * 0.6892074);
    southCarolinaPath.lineTo(size.width * 0.8006257, size.height * 0.6856661);
    southCarolinaPath.lineTo(size.width * 0.8009385, size.height * 0.6816189);
    southCarolinaPath.lineTo(size.width * 0.7996872, size.height * 0.6801012);
    southCarolinaPath.lineTo(size.width * 0.8005214, size.height * 0.6789207);
    southCarolinaPath.lineTo(size.width * 0.8013556, size.height * 0.6795953);
    southCarolinaPath.lineTo(size.width * 0.8027112, size.height * 0.6789207);
    southCarolinaPath.lineTo(size.width * 0.8045881, size.height * 0.6753794);
    southCarolinaPath.lineTo(size.width * 0.8085506, size.height * 0.6723440);
    southCarolinaPath.lineTo(size.width * 0.8102190, size.height * 0.6682968);
    southCarolinaPath.lineTo(size.width * 0.8103233, size.height * 0.6671164);
    southCarolinaPath.lineTo(size.width * 0.8153285, size.height * 0.6596965);
    southCarolinaPath.lineTo(size.width * 0.8152242, size.height * 0.6588533);
    southCarolinaPath.lineTo(size.width * 0.8142857, size.height * 0.6575042);
    southCarolinaPath.lineTo(size.width * 0.8154327, size.height * 0.6549747);
    southCarolinaPath.lineTo(size.width * 0.8162669, size.height * 0.6549747);
    southCarolinaPath.lineTo(size.width * 0.8166840, size.height * 0.6558179);
    southCarolinaPath.lineTo(size.width * 0.8174140, size.height * 0.6544688);
    southCarolinaPath.lineTo(size.width * 0.8187696, size.height * 0.6544688);
    southCarolinaPath.lineTo(size.width * 0.8193952, size.height * 0.6519393);
    southCarolinaPath.lineTo(size.width * 0.8217935, size.height * 0.6483980);
    southCarolinaPath.lineTo(size.width * 0.8214807, size.height * 0.6392917);
    southCarolinaPath.lineTo(size.width * 0.8223149, size.height * 0.6354132);
    southCarolinaPath.lineTo(size.width * 0.8260688, size.height * 0.6249578);
    southCarolinaPath.lineTo(size.width * 0.8285714, size.height * 0.6212479);
    southCarolinaPath.lineTo(size.width * 0.8308655, size.height * 0.6193929);
    southCarolinaPath.close();

    Paint southCarolinaPaint = Paint()..style = PaintingStyle.fill;
    southCarolinaPaint.color = usaColors.southCarolina ?? defaultColor;
    usaCanvas.drawPath(southCarolinaPath, southCarolinaPaint,
        onTapUp: (tabdetail) {
      callback('south carolina', tabdetail);
    });

    Path southDakotaPath = Path();
    southDakotaPath.moveTo(size.width * 0.4134515, size.height * 0.2123103);
    southDakotaPath.lineTo(size.width * 0.4614181, size.height * 0.2158516);
    southDakotaPath.lineTo(size.width * 0.4921794, size.height * 0.2165261);
    southDakotaPath.lineTo(size.width * 0.4920751, size.height * 0.2202361);
    southDakotaPath.lineTo(size.width * 0.4911366, size.height * 0.2236088);
    southDakotaPath.lineTo(size.width * 0.4879041, size.height * 0.2268128);
    southDakotaPath.lineTo(size.width * 0.4875912, size.height * 0.2288364);
    southDakotaPath.lineTo(size.width * 0.4893639, size.height * 0.2330523);
    southDakotaPath.lineTo(size.width * 0.4897810, size.height * 0.2360877);
    southDakotaPath.lineTo(size.width * 0.4924922, size.height * 0.2370995);
    southDakotaPath.lineTo(size.width * 0.4940563, size.height * 0.2403035);
    southDakotaPath.lineTo(size.width * 0.4938478, size.height * 0.3069140);
    southDakotaPath.lineTo(size.width * 0.4915537, size.height * 0.3067454);
    southDakotaPath.lineTo(size.width * 0.4914494, size.height * 0.3094435);
    southDakotaPath.lineTo(size.width * 0.4928050, size.height * 0.3119730);
    southDakotaPath.lineTo(size.width * 0.4927007, size.height * 0.3138280);
    southDakotaPath.lineTo(size.width * 0.4916580, size.height * 0.3146712);
    southDakotaPath.lineTo(size.width * 0.4920751, size.height * 0.3173693);
    southDakotaPath.lineTo(size.width * 0.4934307, size.height * 0.3180438);
    southDakotaPath.lineTo(size.width * 0.4941606, size.height * 0.3214165);
    southDakotaPath.lineTo(size.width * 0.4923879, size.height * 0.3300169);
    southDakotaPath.lineTo(size.width * 0.4913452, size.height * 0.3372681);
    southDakotaPath.lineTo(size.width * 0.4927007, size.height * 0.3392917);
    southDakotaPath.lineTo(size.width * 0.4930136, size.height * 0.3414840);
    southDakotaPath.lineTo(size.width * 0.4937435, size.height * 0.3443508);
    southDakotaPath.lineTo(size.width * 0.4921794, size.height * 0.3446880);
    southDakotaPath.lineTo(size.width * 0.4903024, size.height * 0.3435076);
    southDakotaPath.lineTo(size.width * 0.4893639, size.height * 0.3391231);
    southDakotaPath.lineTo(size.width * 0.4881126, size.height * 0.3369309);
    southDakotaPath.lineTo(size.width * 0.4817518, size.height * 0.3332209);
    southDakotaPath.lineTo(size.width * 0.4811262, size.height * 0.3313659);
    southDakotaPath.lineTo(size.width * 0.4790407, size.height * 0.3303541);
    southDakotaPath.lineTo(size.width * 0.4775808, size.height * 0.3313659);
    southDakotaPath.lineTo(size.width * 0.4765381, size.height * 0.3305228);
    southDakotaPath.lineTo(size.width * 0.4755996, size.height * 0.3311973);
    southDakotaPath.lineTo(size.width * 0.4748697, size.height * 0.3305228);
    southDakotaPath.lineTo(size.width * 0.4739312, size.height * 0.3311973);
    southDakotaPath.lineTo(size.width * 0.4732013, size.height * 0.3303541);
    southDakotaPath.lineTo(size.width * 0.4721585, size.height * 0.3315346);
    southDakotaPath.lineTo(size.width * 0.4705944, size.height * 0.3305228);
    southDakotaPath.lineTo(size.width * 0.4687174, size.height * 0.3338954);
    southDakotaPath.lineTo(size.width * 0.4668405, size.height * 0.3340641);
    southDakotaPath.lineTo(size.width * 0.4646507, size.height * 0.3306914);
    southDakotaPath.lineTo(size.width * 0.4628780, size.height * 0.3303541);
    southDakotaPath.lineTo(size.width * 0.4593326, size.height * 0.3249578);
    southDakotaPath.lineTo(size.width * 0.4197080, size.height * 0.3222597);
    southDakotaPath.lineTo(size.width * 0.3664234, size.height * 0.3163575);
    southDakotaPath.lineTo(size.width * 0.3704901, size.height * 0.2423272);
    southDakotaPath.lineTo(size.width * 0.3725756, size.height * 0.2074199);
    southDakotaPath.close();

    Paint southDakotaPaint = Paint()..style = PaintingStyle.fill;
    southDakotaPaint.color = usaColors.southDakota ?? defaultColor;
    usaCanvas.drawPath(southDakotaPath, southDakotaPaint, onTapUp: (tabdetail) {
      callback('south dakota', tabdetail);
    });

    Path tennesseePath = Path();
    tennesseePath.moveTo(size.width * 0.6474453, size.height * 0.6156830);
    tennesseePath.lineTo(size.width * 0.6950991, size.height * 0.6089376);
    tennesseePath.lineTo(size.width * 0.7189781, size.height * 0.6040472);
    tennesseePath.lineTo(size.width * 0.7190824, size.height * 0.5957841);
    tennesseePath.lineTo(size.width * 0.7205422, size.height * 0.5935919);
    tennesseePath.lineTo(size.width * 0.7221064, size.height * 0.5937605);
    tennesseePath.lineTo(size.width * 0.7234619, size.height * 0.5922428);
    tennesseePath.lineTo(size.width * 0.7242961, size.height * 0.5853288);
    tennesseePath.lineTo(size.width * 0.7290928, size.height * 0.5802698);
    tennesseePath.lineTo(size.width * 0.7328467, size.height * 0.5794266);
    tennesseePath.lineTo(size.width * 0.7361835, size.height * 0.5750422);
    tennesseePath.lineTo(size.width * 0.7367049, size.height * 0.5730185);
    tennesseePath.lineTo(size.width * 0.7416058, size.height * 0.5689713);
    tennesseePath.lineTo(size.width * 0.7422315, size.height * 0.5632378);
    tennesseePath.lineTo(size.width * 0.7464025, size.height * 0.5576728);
    tennesseePath.lineTo(size.width * 0.7472367, size.height * 0.5580101);
    tennesseePath.lineTo(size.width * 0.7473410, size.height * 0.5605396);
    tennesseePath.lineTo(size.width * 0.7481752, size.height * 0.5618887);
    tennesseePath.lineTo(size.width * 0.7497393, size.height * 0.5598651);
    tennesseePath.lineTo(size.width * 0.7504692, size.height * 0.5563238);
    tennesseePath.lineTo(size.width * 0.7541189, size.height * 0.5521079);
    tennesseePath.lineTo(size.width * 0.7568300, size.height * 0.5539629);
    tennesseePath.lineTo(size.width * 0.7593326, size.height * 0.5451939);
    tennesseePath.lineTo(size.width * 0.7607925, size.height * 0.5431703);
    tennesseePath.lineTo(size.width * 0.7623566, size.height * 0.5433390);
    tennesseePath.lineTo(size.width * 0.7623566, size.height * 0.5345700);
    tennesseePath.lineTo(size.width * 0.7626694, size.height * 0.5333895);
    tennesseePath.lineTo(size.width * 0.7578728, size.height * 0.5342327);
    tennesseePath.lineTo(size.width * 0.7576642, size.height * 0.5359191);
    tennesseePath.lineTo(size.width * 0.7275287, size.height * 0.5414840);
    tennesseePath.lineTo(size.width * 0.7216893, size.height * 0.5438449);
    tennesseePath.lineTo(size.width * 0.7003128, size.height * 0.5462057);
    tennesseePath.lineTo(size.width * 0.6948905, size.height * 0.5475548);
    tennesseePath.lineTo(size.width * 0.6767466, size.height * 0.5492411);
    tennesseePath.lineTo(size.width * 0.6740355, size.height * 0.5505902);
    tennesseePath.lineTo(size.width * 0.6504692, size.height * 0.5539629);
    tennesseePath.lineTo(size.width * 0.6497393, size.height * 0.5529511);
    tennesseePath.lineTo(size.width * 0.6458811, size.height * 0.5529511);
    tennesseePath.lineTo(size.width * 0.6471324, size.height * 0.5583474);
    tennesseePath.lineTo(size.width * 0.6465068, size.height * 0.5598651);
    tennesseePath.lineTo(size.width * 0.6222106, size.height * 0.5623946);
    tennesseePath.lineTo(size.width * 0.6213764, size.height * 0.5640809);
    tennesseePath.lineTo(size.width * 0.6205422, size.height * 0.5629005);
    tennesseePath.lineTo(size.width * 0.6194995, size.height * 0.5629005);
    tennesseePath.lineTo(size.width * 0.6194995, size.height * 0.5650927);
    tennesseePath.lineTo(size.width * 0.6201251, size.height * 0.5667791);
    tennesseePath.lineTo(size.width * 0.6200209, size.height * 0.5684654);
    tennesseePath.lineTo(size.width * 0.6185610, size.height * 0.5693086);
    tennesseePath.lineTo(size.width * 0.6200209, size.height * 0.5718381);
    tennesseePath.lineTo(size.width * 0.6191867, size.height * 0.5730185);
    tennesseePath.lineTo(size.width * 0.6174140, size.height * 0.5726813);
    tennesseePath.lineTo(size.width * 0.6180396, size.height * 0.5743676);
    tennesseePath.lineTo(size.width * 0.6192909, size.height * 0.5762226);
    tennesseePath.lineTo(size.width * 0.6192909, size.height * 0.5774030);
    tennesseePath.lineTo(size.width * 0.6180396, size.height * 0.5782462);
    tennesseePath.lineTo(size.width * 0.6169969, size.height * 0.5816189);
    tennesseePath.lineTo(size.width * 0.6171011, size.height * 0.5826307);
    tennesseePath.lineTo(size.width * 0.6185610, size.height * 0.5843170);
    tennesseePath.lineTo(size.width * 0.6181439, size.height * 0.5854975);
    tennesseePath.lineTo(size.width * 0.6165798, size.height * 0.5854975);
    tennesseePath.lineTo(size.width * 0.6165798, size.height * 0.5863406);
    tennesseePath.lineTo(size.width * 0.6175182, size.height * 0.5878583);
    tennesseePath.lineTo(size.width * 0.6176225, size.height * 0.5892074);
    tennesseePath.lineTo(size.width * 0.6161627, size.height * 0.5895447);
    tennesseePath.lineTo(size.width * 0.6156413, size.height * 0.5908938);
    tennesseePath.lineTo(size.width * 0.6139729, size.height * 0.5912310);
    tennesseePath.lineTo(size.width * 0.6130344, size.height * 0.5927487);
    tennesseePath.lineTo(size.width * 0.6136601, size.height * 0.5942664);
    tennesseePath.lineTo(size.width * 0.6148071, size.height * 0.5940978);
    tennesseePath.lineTo(size.width * 0.6153285, size.height * 0.5956155);
    tennesseePath.lineTo(size.width * 0.6136601, size.height * 0.5978078);
    tennesseePath.lineTo(size.width * 0.6140772, size.height * 0.6003373);
    tennesseePath.lineTo(size.width * 0.6119917, size.height * 0.5993255);
    tennesseePath.lineTo(size.width * 0.6118874, size.height * 0.6005059);
    tennesseePath.lineTo(size.width * 0.6123045, size.height * 0.6023609);
    tennesseePath.lineTo(size.width * 0.6119917, size.height * 0.6047218);
    tennesseePath.lineTo(size.width * 0.6106361, size.height * 0.6033727);
    tennesseePath.lineTo(size.width * 0.6098019, size.height * 0.6047218);
    tennesseePath.lineTo(size.width * 0.6109489, size.height * 0.6048904);
    tennesseePath.lineTo(size.width * 0.6110532, size.height * 0.6074199);
    tennesseePath.lineTo(size.width * 0.6104275, size.height * 0.6091062);
    tennesseePath.lineTo(size.width * 0.6115746, size.height * 0.6106239);
    tennesseePath.lineTo(size.width * 0.6112617, size.height * 0.6131535);
    tennesseePath.lineTo(size.width * 0.6120959, size.height * 0.6143339);
    tennesseePath.lineTo(size.width * 0.6113660, size.height * 0.6160202);
    tennesseePath.lineTo(size.width * 0.6101147, size.height * 0.6151771);
    tennesseePath.lineTo(size.width * 0.6091762, size.height * 0.6188870);
    tennesseePath.lineTo(size.width * 0.6075078, size.height * 0.6200675);
    tennesseePath.close();

    Paint tennesseePaint = Paint()..style = PaintingStyle.fill;
    tennesseePaint.color = usaColors.tennessee ?? defaultColor;
    usaCanvas.drawPath(tennesseePath, tennesseePaint, onTapUp: (tabdetail) {
      callback('tennessee', tabdetail);
    });

    Path texasPath = Path();
    texasPath.moveTo(size.width * 0.2943691, size.height * 0.7234401);
    texasPath.lineTo(size.width * 0.2946820, size.height * 0.7183811);
    texasPath.lineTo(size.width * 0.3305527, size.height * 0.7244519);
    texasPath.lineTo(size.width * 0.3637122, size.height * 0.7288364);
    texasPath.lineTo(size.width * 0.3719499, size.height * 0.5613828);
    texasPath.lineTo(size.width * 0.3727842, size.height * 0.5613828);
    texasPath.lineTo(size.width * 0.4276330, size.height * 0.5667791);
    texasPath.lineTo(size.width * 0.4261731, size.height * 0.6387858);
    texasPath.lineTo(size.width * 0.4289885, size.height * 0.6409781);
    texasPath.lineTo(size.width * 0.4315954, size.height * 0.6460371);
    texasPath.lineTo(size.width * 0.4331595, size.height * 0.6465430);
    texasPath.lineTo(size.width * 0.4343066, size.height * 0.6448567);
    texasPath.lineTo(size.width * 0.4355579, size.height * 0.6455312);
    texasPath.lineTo(size.width * 0.4370177, size.height * 0.6472175);
    texasPath.lineTo(size.width * 0.4381648, size.height * 0.6446880);
    texasPath.lineTo(size.width * 0.4405631, size.height * 0.6475548);
    texasPath.lineTo(size.width * 0.4410845, size.height * 0.6524452);
    texasPath.lineTo(size.width * 0.4423358, size.height * 0.6536256);
    texasPath.lineTo(size.width * 0.4447341, size.height * 0.6534570);
    texasPath.lineTo(size.width * 0.4483837, size.height * 0.6566610);
    texasPath.lineTo(size.width * 0.4504692, size.height * 0.6564924);
    texasPath.lineTo(size.width * 0.4519291, size.height * 0.6558179);
    texasPath.lineTo(size.width * 0.4543274, size.height * 0.6595278);
    texasPath.lineTo(size.width * 0.4564129, size.height * 0.6556492);
    texasPath.lineTo(size.width * 0.4600626, size.height * 0.6575042);
    texasPath.lineTo(size.width * 0.4620438, size.height * 0.6625632);
    texasPath.lineTo(size.width * 0.4644421, size.height * 0.6623946);
    texasPath.lineTo(size.width * 0.4637122, size.height * 0.6659359);
    texasPath.lineTo(size.width * 0.4661105, size.height * 0.6677909);
    texasPath.lineTo(size.width * 0.4692388, size.height * 0.6634064);
    texasPath.lineTo(size.width * 0.4719499, size.height * 0.6662732);
    texasPath.lineTo(size.width * 0.4733055, size.height * 0.6654300);
    texasPath.lineTo(size.width * 0.4734098, size.height * 0.6679595);
    texasPath.lineTo(size.width * 0.4751825, size.height * 0.6699831);
    texasPath.lineTo(size.width * 0.4775808, size.height * 0.6657673);
    texasPath.lineTo(size.width * 0.4788321, size.height * 0.6669477);
    texasPath.lineTo(size.width * 0.4785193, size.height * 0.6703204);
    texasPath.lineTo(size.width * 0.4795620, size.height * 0.6733558);
    texasPath.lineTo(size.width * 0.4808133, size.height * 0.6720067);
    texasPath.lineTo(size.width * 0.4834202, size.height * 0.6649241);
    texasPath.lineTo(size.width * 0.4852972, size.height * 0.6682968);
    texasPath.lineTo(size.width * 0.4873827, size.height * 0.6691400);
    texasPath.lineTo(size.width * 0.4895725, size.height * 0.6679595);
    texasPath.lineTo(size.width * 0.4916580, size.height * 0.6709949);
    texasPath.lineTo(size.width * 0.4929093, size.height * 0.6708263);
    texasPath.lineTo(size.width * 0.4942649, size.height * 0.6728499);
    texasPath.lineTo(size.width * 0.4980188, size.height * 0.6713322);
    texasPath.lineTo(size.width * 0.4986444, size.height * 0.6684654);
    texasPath.lineTo(size.width * 0.5025026, size.height * 0.6679595);
    texasPath.lineTo(size.width * 0.5041710, size.height * 0.6691400);
    texasPath.lineTo(size.width * 0.5093848, size.height * 0.6649241);
    texasPath.lineTo(size.width * 0.5100104, size.height * 0.6674536);
    texasPath.lineTo(size.width * 0.5153285, size.height * 0.6669477);
    texasPath.lineTo(size.width * 0.5158498, size.height * 0.6642496);
    texasPath.lineTo(size.width * 0.5181439, size.height * 0.6657673);
    texasPath.lineTo(size.width * 0.5229406, size.height * 0.6721754);
    texasPath.lineTo(size.width * 0.5296142, size.height * 0.6753794);
    texasPath.lineTo(size.width * 0.5323253, size.height * 0.6792580);
    texasPath.lineTo(size.width * 0.5352450, size.height * 0.6770658);
    texasPath.lineTo(size.width * 0.5385819, size.height * 0.6784148);
    texasPath.lineTo(size.width * 0.5387904, size.height * 0.6984823);
    texasPath.lineTo(size.width * 0.5393118, size.height * 0.7320405);
    texasPath.lineTo(size.width * 0.5400417, size.height * 0.7377740);
    texasPath.lineTo(size.width * 0.5427529, size.height * 0.7424958);
    texasPath.lineTo(size.width * 0.5434828, size.height * 0.7516020);
    texasPath.lineTo(size.width * 0.5474453, size.height * 0.7593592);
    texasPath.lineTo(size.width * 0.5482795, size.height * 0.7666105);
    texasPath.lineTo(size.width * 0.5493222, size.height * 0.7666105);
    texasPath.lineTo(size.width * 0.5492179, size.height * 0.7789207);
    texasPath.lineTo(size.width * 0.5457769, size.height * 0.7897133);
    texasPath.lineTo(size.width * 0.5471324, size.height * 0.7935919);
    texasPath.lineTo(size.width * 0.5457769, size.height * 0.7961214);
    texasPath.lineTo(size.width * 0.5465068, size.height * 0.8011804);
    texasPath.lineTo(size.width * 0.5464025, size.height * 0.8084317);
    texasPath.lineTo(size.width * 0.5441084, size.height * 0.8143339);
    texasPath.lineTo(size.width * 0.5440042, size.height * 0.8156830);
    texasPath.lineTo(size.width * 0.5422315, size.height * 0.8177066);
    texasPath.lineTo(size.width * 0.5432742, size.height * 0.8207420);
    texasPath.lineTo(size.width * 0.5445255, size.height * 0.8225970);
    texasPath.lineTo(size.width * 0.5408759, size.height * 0.8231029);
    texasPath.lineTo(size.width * 0.5321168, size.height * 0.8296796);
    texasPath.lineTo(size.width * 0.5284672, size.height * 0.8320405);
    texasPath.lineTo(size.width * 0.5265902, size.height * 0.8350759);
    texasPath.lineTo(size.width * 0.5258603, size.height * 0.8342327);
    texasPath.lineTo(size.width * 0.5280501, size.height * 0.8303541);
    texasPath.lineTo(size.width * 0.5299270, size.height * 0.8291737);
    texasPath.lineTo(size.width * 0.5304484, size.height * 0.8276560);
    texasPath.lineTo(size.width * 0.5274244, size.height * 0.8274874);
    texasPath.lineTo(size.width * 0.5266945, size.height * 0.8261383);
    texasPath.lineTo(size.width * 0.5275287, size.height * 0.8227656);
    texasPath.lineTo(size.width * 0.5265902, size.height * 0.8197302);
    texasPath.lineTo(size.width * 0.5259645, size.height * 0.8197302);
    texasPath.lineTo(size.width * 0.5234619, size.height * 0.8219224);
    texasPath.lineTo(size.width * 0.5214807, size.height * 0.8263069);
    texasPath.lineTo(size.width * 0.5217935, size.height * 0.8291737);
    texasPath.lineTo(size.width * 0.5252346, size.height * 0.8349073);
    texasPath.lineTo(size.width * 0.5265902, size.height * 0.8354132);
    texasPath.lineTo(size.width * 0.5265902, size.height * 0.8367622);
    texasPath.lineTo(size.width * 0.5241919, size.height * 0.8394604);
    texasPath.lineTo(size.width * 0.5190824, size.height * 0.8462057);
    texasPath.lineTo(size.width * 0.5149114, size.height * 0.8527825);
    texasPath.lineTo(size.width * 0.5115746, size.height * 0.8551433);
    texasPath.lineTo(size.width * 0.5063608, size.height * 0.8602024);
    texasPath.lineTo(size.width * 0.5025026, size.height * 0.8635750);
    texasPath.lineTo(size.width * 0.4978102, size.height * 0.8667791);
    texasPath.lineTo(size.width * 0.4935349, size.height * 0.8709949);
    texasPath.lineTo(size.width * 0.4968717, size.height * 0.8659359);
    texasPath.lineTo(size.width * 0.4968717, size.height * 0.8640809);
    texasPath.lineTo(size.width * 0.4974974, size.height * 0.8627319);
    texasPath.lineTo(size.width * 0.4972888, size.height * 0.8596965);
    texasPath.lineTo(size.width * 0.4957247, size.height * 0.8595278);
    texasPath.lineTo(size.width * 0.4945777, size.height * 0.8620573);
    texasPath.lineTo(size.width * 0.4918665, size.height * 0.8642496);
    texasPath.lineTo(size.width * 0.4899896, size.height * 0.8622260);
    texasPath.lineTo(size.width * 0.4896767, size.height * 0.8593592);
    texasPath.lineTo(size.width * 0.4881126, size.height * 0.8593592);
    texasPath.lineTo(size.width * 0.4889468, size.height * 0.8630691);
    texasPath.lineTo(size.width * 0.4904067, size.height * 0.8642496);
    texasPath.lineTo(size.width * 0.4916580, size.height * 0.8657673);
    texasPath.lineTo(size.width * 0.4935349, size.height * 0.8684654);
    texasPath.lineTo(size.width * 0.4928050, size.height * 0.8698145);
    texasPath.lineTo(size.width * 0.4887383, size.height * 0.8726813);
    texasPath.lineTo(size.width * 0.4869656, size.height * 0.8728499);
    texasPath.lineTo(size.width * 0.4857143, size.height * 0.8708263);
    texasPath.lineTo(size.width * 0.4851929, size.height * 0.8743676);
    texasPath.lineTo(size.width * 0.4857143, size.height * 0.8762226);
    texasPath.lineTo(size.width * 0.4828989, size.height * 0.8795953);
    texasPath.lineTo(size.width * 0.4813347, size.height * 0.8799325);
    texasPath.lineTo(size.width * 0.4805005, size.height * 0.8811130);
    texasPath.lineTo(size.width * 0.4800834, size.height * 0.8839798);
    texasPath.lineTo(size.width * 0.4782065, size.height * 0.8895447);
    texasPath.lineTo(size.width * 0.4765381, size.height * 0.8907251);
    texasPath.lineTo(size.width * 0.4748697, size.height * 0.8897133);
    texasPath.lineTo(size.width * 0.4729927, size.height * 0.8915683);
    texasPath.lineTo(size.width * 0.4733055, size.height * 0.8939292);
    texasPath.lineTo(size.width * 0.4746611, size.height * 0.8952782);
    texasPath.lineTo(size.width * 0.4757039, size.height * 0.8966273);
    texasPath.lineTo(size.width * 0.4738269, size.height * 0.9025295);
    texasPath.lineTo(size.width * 0.4735141, size.height * 0.9072513);
    texasPath.lineTo(size.width * 0.4724713, size.height * 0.9101180);
    texasPath.lineTo(size.width * 0.4710115, size.height * 0.9118044);
    texasPath.lineTo(size.width * 0.4679875, size.height * 0.9124789);
    texasPath.lineTo(size.width * 0.4698644, size.height * 0.9134907);
    texasPath.lineTo(size.width * 0.4718457, size.height * 0.9124789);
    texasPath.lineTo(size.width * 0.4714286, size.height * 0.9178752);
    texasPath.lineTo(size.width * 0.4702815, size.height * 0.9177066);
    texasPath.lineTo(size.width * 0.4704901, size.height * 0.9197302);
    texasPath.lineTo(size.width * 0.4708029, size.height * 0.9220911);
    texasPath.lineTo(size.width * 0.4694473, size.height * 0.9236088);
    texasPath.lineTo(size.width * 0.4694473, size.height * 0.9288364);
    texasPath.lineTo(size.width * 0.4711157, size.height * 0.9311973);
    texasPath.lineTo(size.width * 0.4717414, size.height * 0.9364250);
    texasPath.lineTo(size.width * 0.4713243, size.height * 0.9401349);
    texasPath.lineTo(size.width * 0.4702815, size.height * 0.9408094);
    texasPath.lineTo(size.width * 0.4706986, size.height * 0.9433390);
    texasPath.lineTo(size.width * 0.4718457, size.height * 0.9440135);
    texasPath.lineTo(size.width * 0.4726799, size.height * 0.9468803);
    texasPath.lineTo(size.width * 0.4726799, size.height * 0.9512648);
    texasPath.lineTo(size.width * 0.4738269, size.height * 0.9548061);
    texasPath.lineTo(size.width * 0.4761210, size.height * 0.9591906);
    texasPath.lineTo(size.width * 0.4760167, size.height * 0.9603710);
    texasPath.lineTo(size.width * 0.4737226, size.height * 0.9600337);
    texasPath.lineTo(size.width * 0.4720542, size.height * 0.9623946);
    texasPath.lineTo(size.width * 0.4722628, size.height * 0.9647555);
    texasPath.lineTo(size.width * 0.4713243, size.height * 0.9642496);
    texasPath.lineTo(size.width * 0.4698644, size.height * 0.9639123);
    texasPath.lineTo(size.width * 0.4663191, size.height * 0.9576728);
    texasPath.lineTo(size.width * 0.4639208, size.height * 0.9566610);
    texasPath.lineTo(size.width * 0.4565172, size.height * 0.9566610);
    texasPath.lineTo(size.width * 0.4535975, size.height * 0.9553120);
    texasPath.lineTo(size.width * 0.4498436, size.height * 0.9502530);
    texasPath.lineTo(size.width * 0.4480709, size.height * 0.9485666);
    texasPath.lineTo(size.width * 0.4458811, size.height * 0.9487352);
    texasPath.lineTo(size.width * 0.4425443, size.height * 0.9443508);
    texasPath.lineTo(size.width * 0.4369135, size.height * 0.9416526);
    texasPath.lineTo(size.width * 0.4369135, size.height * 0.9394604);
    texasPath.lineTo(size.width * 0.4354536, size.height * 0.9364250);
    texasPath.lineTo(size.width * 0.4345151, size.height * 0.9284992);
    texasPath.lineTo(size.width * 0.4333681, size.height * 0.9256324);
    texasPath.lineTo(size.width * 0.4315954, size.height * 0.9232715);
    texasPath.lineTo(size.width * 0.4315954, size.height * 0.9205734);
    texasPath.lineTo(size.width * 0.4301356, size.height * 0.9195616);
    texasPath.lineTo(size.width * 0.4307612, size.height * 0.9151771);
    texasPath.lineTo(size.width * 0.4304484, size.height * 0.9114671);
    texasPath.lineTo(size.width * 0.4290928, size.height * 0.9091062);
    texasPath.lineTo(size.width * 0.4298227, size.height * 0.9040472);
    texasPath.lineTo(size.width * 0.4289885, size.height * 0.8986509);
    texasPath.lineTo(size.width * 0.4272158, size.height * 0.8962901);
    texasPath.lineTo(size.width * 0.4260688, size.height * 0.8962901);
    texasPath.lineTo(size.width * 0.4218978, size.height * 0.8903879);
    texasPath.lineTo(size.width * 0.4220021, size.height * 0.8871838);
    texasPath.lineTo(size.width * 0.4211679, size.height * 0.8843170);
    texasPath.lineTo(size.width * 0.4203337, size.height * 0.8839798);
    texasPath.lineTo(size.width * 0.4193952, size.height * 0.8799325);
    texasPath.lineTo(size.width * 0.4173097, size.height * 0.8772344);
    texasPath.lineTo(size.width * 0.4142857, size.height * 0.8730185);
    texasPath.lineTo(size.width * 0.4140772, size.height * 0.8694772);
    texasPath.lineTo(size.width * 0.4130344, size.height * 0.8682968);
    texasPath.lineTo(size.width * 0.4132430, size.height * 0.8655987);
    texasPath.lineTo(size.width * 0.4137643, size.height * 0.8644182);
    texasPath.lineTo(size.width * 0.4123045, size.height * 0.8618887);
    texasPath.lineTo(size.width * 0.4124088, size.height * 0.8607083);
    texasPath.lineTo(size.width * 0.4103233, size.height * 0.8569983);
    texasPath.lineTo(size.width * 0.4104275, size.height * 0.8534570);
    texasPath.lineTo(size.width * 0.4076121, size.height * 0.8451939);
    texasPath.lineTo(size.width * 0.4075078, size.height * 0.8423272);
    texasPath.lineTo(size.width * 0.4056309, size.height * 0.8370995);
    texasPath.lineTo(size.width * 0.4003128, size.height * 0.8290051);
    texasPath.lineTo(size.width * 0.4003128, size.height * 0.8271501);
    texasPath.lineTo(size.width * 0.3968717, size.height * 0.8242833);
    texasPath.lineTo(size.width * 0.3967675, size.height * 0.8212479);
    texasPath.lineTo(size.width * 0.3955162, size.height * 0.8205734);
    texasPath.lineTo(size.width * 0.3955162, size.height * 0.8193929);
    texasPath.lineTo(size.width * 0.3946820, size.height * 0.8190556);
    texasPath.lineTo(size.width * 0.3924922, size.height * 0.8143339);
    texasPath.lineTo(size.width * 0.3916580, size.height * 0.8143339);
    texasPath.lineTo(size.width * 0.3909281, size.height * 0.8133221);
    texasPath.lineTo(size.width * 0.3895725, size.height * 0.8151771);
    texasPath.lineTo(size.width * 0.3872784, size.height * 0.8151771);
    texasPath.lineTo(size.width * 0.3845673, size.height * 0.8133221);
    texasPath.lineTo(size.width * 0.3797706, size.height * 0.8133221);
    texasPath.lineTo(size.width * 0.3753910, size.height * 0.8097808);
    texasPath.lineTo(size.width * 0.3740355, size.height * 0.8129848);
    texasPath.lineTo(size.width * 0.3717414, size.height * 0.8119730);
    texasPath.lineTo(size.width * 0.3683003, size.height * 0.8139966);
    texasPath.lineTo(size.width * 0.3665276, size.height * 0.8187184);
    texasPath.lineTo(size.width * 0.3644421, size.height * 0.8241147);
    texasPath.lineTo(size.width * 0.3632951, size.height * 0.8315346);
    texasPath.lineTo(size.width * 0.3618352, size.height * 0.8335582);
    texasPath.lineTo(size.width * 0.3606882, size.height * 0.8337268);
    texasPath.lineTo(size.width * 0.3597497, size.height * 0.8364250);
    texasPath.lineTo(size.width * 0.3583942, size.height * 0.8374368);
    texasPath.lineTo(size.width * 0.3582899, size.height * 0.8404722);
    texasPath.lineTo(size.width * 0.3552659, size.height * 0.8406408);
    texasPath.lineTo(size.width * 0.3533889, size.height * 0.8381113);
    texasPath.lineTo(size.width * 0.3523462, size.height * 0.8381113);
    texasPath.lineTo(size.width * 0.3502607, size.height * 0.8332209);
    texasPath.lineTo(size.width * 0.3465068, size.height * 0.8323777);
    texasPath.lineTo(size.width * 0.3447341, size.height * 0.8284992);
    texasPath.lineTo(size.width * 0.3433785, size.height * 0.8281619);
    texasPath.lineTo(size.width * 0.3411887, size.height * 0.8268128);
    texasPath.lineTo(size.width * 0.3376434, size.height * 0.8210793);
    texasPath.lineTo(size.width * 0.3378519, size.height * 0.8197302);
    texasPath.lineTo(size.width * 0.3361835, size.height * 0.8177066);
    texasPath.lineTo(size.width * 0.3351408, size.height * 0.8175379);
    texasPath.lineTo(size.width * 0.3315954, size.height * 0.8123103);
    texasPath.lineTo(size.width * 0.3314911, size.height * 0.8089376);
    texasPath.lineTo(size.width * 0.3290928, size.height * 0.8021922);
    texasPath.lineTo(size.width * 0.3293014, size.height * 0.7994941);
    texasPath.lineTo(size.width * 0.3285714, size.height * 0.7973019);
    texasPath.lineTo(size.width * 0.3294056, size.height * 0.7947723);
    texasPath.lineTo(size.width * 0.3293014, size.height * 0.7907251);
    texasPath.lineTo(size.width * 0.3265902, size.height * 0.7838111);
    texasPath.lineTo(size.width * 0.3259645, size.height * 0.7767285);
    texasPath.lineTo(size.width * 0.3242961, size.height * 0.7740304);
    texasPath.lineTo(size.width * 0.3242961, size.height * 0.7723440);
    texasPath.lineTo(size.width * 0.3230448, size.height * 0.7720067);
    texasPath.lineTo(size.width * 0.3223149, size.height * 0.7701518);
    texasPath.lineTo(size.width * 0.3198123, size.height * 0.7672850);
    texasPath.lineTo(size.width * 0.3188738, size.height * 0.7671164);
    texasPath.lineTo(size.width * 0.3168926, size.height * 0.7644182);
    texasPath.lineTo(size.width * 0.3168926, size.height * 0.7625632);
    texasPath.lineTo(size.width * 0.3138686, size.height * 0.7595278);
    texasPath.lineTo(size.width * 0.3132430, size.height * 0.7559865);
    texasPath.lineTo(size.width * 0.3105318, size.height * 0.7521079);
    texasPath.lineTo(size.width * 0.3071950, size.height * 0.7446880);
    texasPath.lineTo(size.width * 0.3040667, size.height * 0.7424958);
    texasPath.lineTo(size.width * 0.3018770, size.height * 0.7394604);
    texasPath.lineTo(size.width * 0.3020855, size.height * 0.7374368);
    texasPath.lineTo(size.width * 0.3007299, size.height * 0.7350759);
    texasPath.lineTo(size.width * 0.2989572, size.height * 0.7288364);
    texasPath.lineTo(size.width * 0.2964546, size.height * 0.7271501);
    texasPath.close();
    texasPath.moveTo(size.width * 0.4767466, size.height * 0.9566610);
    texasPath.lineTo(size.width * 0.4775808, size.height * 0.9568297);
    texasPath.lineTo(size.width * 0.4769552, size.height * 0.9487352);
    texasPath.lineTo(size.width * 0.4733055, size.height * 0.9279933);
    texasPath.lineTo(size.width * 0.4730970, size.height * 0.9143339);
    texasPath.lineTo(size.width * 0.4782065, size.height * 0.8966273);
    texasPath.lineTo(size.width * 0.4845673, size.height * 0.8827993);
    texasPath.lineTo(size.width * 0.4920751, size.height * 0.8741990);
    texasPath.lineTo(size.width * 0.4920751, size.height * 0.8730185);
    texasPath.lineTo(size.width * 0.4912409, size.height * 0.8730185);
    texasPath.lineTo(size.width * 0.4885297, size.height * 0.8747049);
    texasPath.lineTo(size.width * 0.4847758, size.height * 0.8785835);
    texasPath.lineTo(size.width * 0.4840459, size.height * 0.8811130);
    texasPath.lineTo(size.width * 0.4754953, size.height * 0.9006745);
    texasPath.lineTo(size.width * 0.4725756, size.height * 0.9139966);
    texasPath.lineTo(size.width * 0.4725756, size.height * 0.9288364);
    texasPath.lineTo(size.width * 0.4763295, size.height * 0.9490725);
    texasPath.close();

    Paint texasPaint = Paint()..style = PaintingStyle.fill;
    texasPaint.color = usaColors.texas ?? defaultColor;
    usaCanvas.drawPath(texasPath, texasPaint, onTapUp: (tabdetail) {
      callback('texas', tabdetail);
    });

    Path utahPath = Path();
    utahPath.moveTo(size.width * 0.2431700, size.height * 0.3674536);
    utahPath.lineTo(size.width * 0.2466111, size.height * 0.3305228);
    utahPath.lineTo(size.width * 0.1966632, size.height * 0.3166948);
    utahPath.lineTo(size.width * 0.1747654, size.height * 0.5005059);
    utahPath.lineTo(size.width * 0.2229406, size.height * 0.5143339);
    utahPath.lineTo(size.width * 0.2646507, size.height * 0.5244519);
    utahPath.lineTo(size.width * 0.2766423, size.height * 0.3755481);
    utahPath.close();

    Paint utahPaint = Paint()..style = PaintingStyle.fill;
    utahPaint.color = usaColors.utah ?? defaultColor;
    usaCanvas.drawPath(utahPath, utahPaint, onTapUp: (tabdetail) {
      callback('utah', tabdetail);
    });

    Path vermontPath = Path();
    vermontPath.moveTo(size.width * 0.8958290, size.height * 0.1726813);
    vermontPath.lineTo(size.width * 0.8946820, size.height * 0.1785835);
    vermontPath.lineTo(size.width * 0.8968717, size.height * 0.1833052);
    vermontPath.lineTo(size.width * 0.8964546, size.height * 0.1861720);
    vermontPath.lineTo(size.width * 0.8965589, size.height * 0.1883642);
    vermontPath.lineTo(size.width * 0.8954119, size.height * 0.1919056);
    vermontPath.lineTo(size.width * 0.8939520, size.height * 0.1925801);
    vermontPath.lineTo(size.width * 0.8933264, size.height * 0.1947723);
    vermontPath.lineTo(size.width * 0.8911366, size.height * 0.1964587);
    vermontPath.lineTo(size.width * 0.8904067, size.height * 0.1989882);
    vermontPath.lineTo(size.width * 0.8918665, size.height * 0.2047218);
    vermontPath.lineTo(size.width * 0.8913452, size.height * 0.2089376);
    vermontPath.lineTo(size.width * 0.8918665, size.height * 0.2114671);
    vermontPath.lineTo(size.width * 0.8908238, size.height * 0.2146712);
    vermontPath.lineTo(size.width * 0.8912409, size.height * 0.2178752);
    vermontPath.lineTo(size.width * 0.8898853, size.height * 0.2210793);
    vermontPath.lineTo(size.width * 0.8900938, size.height * 0.2247892);
    vermontPath.lineTo(size.width * 0.8893639, size.height * 0.2266442);
    vermontPath.lineTo(size.width * 0.8900938, size.height * 0.2342327);
    vermontPath.lineTo(size.width * 0.8908238, size.height * 0.2367622);
    vermontPath.lineTo(size.width * 0.8903024, size.height * 0.2411467);
    vermontPath.lineTo(size.width * 0.8912409, size.height * 0.2441821);
    vermontPath.lineTo(size.width * 0.8910323, size.height * 0.2483980);
    vermontPath.lineTo(size.width * 0.8905109, size.height * 0.2505902);
    vermontPath.lineTo(size.width * 0.8904067, size.height * 0.2529511);
    vermontPath.lineTo(size.width * 0.8925965, size.height * 0.2573356);
    vermontPath.lineTo(size.width * 0.8796663, size.height * 0.2618887);
    vermontPath.lineTo(size.width * 0.8785193, size.height * 0.2602024);
    vermontPath.lineTo(size.width * 0.8790407, size.height * 0.2568297);
    vermontPath.lineTo(size.width * 0.8759124, size.height * 0.2328836);
    vermontPath.lineTo(size.width * 0.8739312, size.height * 0.2303541);
    vermontPath.lineTo(size.width * 0.8729927, size.height * 0.2330523);
    vermontPath.lineTo(size.width * 0.8720542, size.height * 0.2293423);
    vermontPath.lineTo(size.width * 0.8728884, size.height * 0.2263069);
    vermontPath.lineTo(size.width * 0.8696559, size.height * 0.2150084);
    vermontPath.lineTo(size.width * 0.8699687, size.height * 0.2086003);
    vermontPath.lineTo(size.width * 0.8703858, size.height * 0.2069140);
    vermontPath.lineTo(size.width * 0.8697602, size.height * 0.2035413);
    vermontPath.lineTo(size.width * 0.8701773, size.height * 0.1998314);
    vermontPath.lineTo(size.width * 0.8678832, size.height * 0.1959528);
    vermontPath.lineTo(size.width * 0.8673618, size.height * 0.1905565);
    vermontPath.lineTo(size.width * 0.8677789, size.height * 0.1880270);
    vermontPath.lineTo(size.width * 0.8663191, size.height * 0.1865093);
    vermontPath.lineTo(size.width * 0.8669447, size.height * 0.1833052);
    vermontPath.lineTo(size.width * 0.8661105, size.height * 0.1804384);
    vermontPath.lineTo(size.width * 0.8945777, size.height * 0.1688027);
    vermontPath.close();

    Paint vermontPaint = Paint()..style = PaintingStyle.fill;
    vermontPaint.color = usaColors.vermont ?? defaultColor;
    usaCanvas.drawPath(vermontPath, vermontPaint, onTapUp: (tabdetail) {
      callback('vermont', tabdetail);
    });

    Path virginiaPath = Path();
    virginiaPath.moveTo(size.width * 0.8703858, size.height * 0.4475548);
    virginiaPath.lineTo(size.width * 0.8692388, size.height * 0.4522766);
    virginiaPath.lineTo(size.width * 0.8697602, size.height * 0.4541315);
    virginiaPath.lineTo(size.width * 0.8701773, size.height * 0.4522766);
    virginiaPath.lineTo(size.width * 0.8710115, size.height * 0.4470489);
    virginiaPath.close();
    virginiaPath.moveTo(size.width * 0.8343066, size.height * 0.4357504);
    virginiaPath.lineTo(size.width * 0.8335766, size.height * 0.4340641);
    virginiaPath.lineTo(size.width * 0.8346194, size.height * 0.4338954);
    virginiaPath.lineTo(size.width * 0.8356621, size.height * 0.4323777);
    virginiaPath.lineTo(size.width * 0.8360792, size.height * 0.4293423);
    virginiaPath.lineTo(size.width * 0.8358707, size.height * 0.4284992);
    virginiaPath.lineTo(size.width * 0.8359750, size.height * 0.4276560);
    virginiaPath.lineTo(size.width * 0.8356621, size.height * 0.4264755);
    virginiaPath.lineTo(size.width * 0.8350365, size.height * 0.4256324);
    virginiaPath.lineTo(size.width * 0.8346194, size.height * 0.4254637);
    virginiaPath.lineTo(size.width * 0.8340980, size.height * 0.4247892);
    virginiaPath.lineTo(size.width * 0.8334724, size.height * 0.4237774);
    virginiaPath.lineTo(size.width * 0.8324296, size.height * 0.4237774);
    virginiaPath.lineTo(size.width * 0.8318040, size.height * 0.4236088);
    virginiaPath.lineTo(size.width * 0.8313869, size.height * 0.4229342);
    virginiaPath.lineTo(size.width * 0.8314911, size.height * 0.4220911);
    virginiaPath.lineTo(size.width * 0.8297185, size.height * 0.4210793);
    virginiaPath.lineTo(size.width * 0.8288843, size.height * 0.4215852);
    virginiaPath.lineTo(size.width * 0.8276330, size.height * 0.4214165);
    virginiaPath.lineTo(size.width * 0.8269030, size.height * 0.4202361);
    virginiaPath.lineTo(size.width * 0.8263816, size.height * 0.4198988);
    virginiaPath.lineTo(size.width * 0.8261731, size.height * 0.4187184);
    virginiaPath.lineTo(size.width * 0.8267987, size.height * 0.4173693);
    virginiaPath.lineTo(size.width * 0.8267987, size.height * 0.4158516);
    virginiaPath.lineTo(size.width * 0.8255474, size.height * 0.4155143);
    virginiaPath.lineTo(size.width * 0.8245047, size.height * 0.4139966);
    virginiaPath.lineTo(size.width * 0.8235662, size.height * 0.4141653);
    virginiaPath.lineTo(size.width * 0.8218978, size.height * 0.4136594);
    virginiaPath.lineTo(size.width * 0.8214807, size.height * 0.4148398);
    virginiaPath.lineTo(size.width * 0.8210636, size.height * 0.4175379);
    virginiaPath.lineTo(size.width * 0.8205422, size.height * 0.4214165);
    virginiaPath.lineTo(size.width * 0.8101147, size.height * 0.4126476);
    virginiaPath.lineTo(size.width * 0.8099062, size.height * 0.4141653);
    virginiaPath.lineTo(size.width * 0.8108446, size.height * 0.4168634);
    virginiaPath.lineTo(size.width * 0.8100104, size.height * 0.4207420);
    virginiaPath.lineTo(size.width * 0.8101147, size.height * 0.4256324);
    virginiaPath.lineTo(size.width * 0.8088634, size.height * 0.4269815);
    virginiaPath.lineTo(size.width * 0.8083420, size.height * 0.4305228);
    virginiaPath.lineTo(size.width * 0.8074035, size.height * 0.4318718);
    virginiaPath.lineTo(size.width * 0.8059437, size.height * 0.4349073);
    virginiaPath.lineTo(size.width * 0.8050052, size.height * 0.4362563);
    virginiaPath.lineTo(size.width * 0.8039625, size.height * 0.4404722);
    virginiaPath.lineTo(size.width * 0.8014599, size.height * 0.4386172);
    virginiaPath.lineTo(size.width * 0.7990615, size.height * 0.4529511);
    virginiaPath.lineTo(size.width * 0.7977059, size.height * 0.4556492);
    virginiaPath.lineTo(size.width * 0.7947862, size.height * 0.4548061);
    virginiaPath.lineTo(size.width * 0.7934307, size.height * 0.4516020);
    virginiaPath.lineTo(size.width * 0.7910323, size.height * 0.4504216);
    virginiaPath.lineTo(size.width * 0.7909281, size.height * 0.4583474);
    virginiaPath.lineTo(size.width * 0.7894682, size.height * 0.4612142);
    virginiaPath.lineTo(size.width * 0.7898853, size.height * 0.4637437);
    virginiaPath.lineTo(size.width * 0.7876955, size.height * 0.4674536);
    virginiaPath.lineTo(size.width * 0.7881126, size.height * 0.4706577);
    virginiaPath.lineTo(size.width * 0.7842544, size.height * 0.4812816);
    virginiaPath.lineTo(size.width * 0.7832117, size.height * 0.4868465);
    virginiaPath.lineTo(size.width * 0.7847758, size.height * 0.4888702);
    virginiaPath.lineTo(size.width * 0.7832117, size.height * 0.4920742);
    virginiaPath.lineTo(size.width * 0.7833160, size.height * 0.4944351);
    virginiaPath.lineTo(size.width * 0.7809176, size.height * 0.4978078);
    virginiaPath.lineTo(size.width * 0.7801877, size.height * 0.4959528);
    virginiaPath.lineTo(size.width * 0.7757039, size.height * 0.5011804);
    virginiaPath.lineTo(size.width * 0.7741397, size.height * 0.4994941);
    virginiaPath.lineTo(size.width * 0.7735141, size.height * 0.5018550);
    virginiaPath.lineTo(size.width * 0.7743483, size.height * 0.5026981);
    virginiaPath.lineTo(size.width * 0.7738269, size.height * 0.5042159);
    virginiaPath.lineTo(size.width * 0.7680918, size.height * 0.5082631);
    virginiaPath.lineTo(size.width * 0.7649635, size.height * 0.5052277);
    virginiaPath.lineTo(size.width * 0.7641293, size.height * 0.5080944);
    virginiaPath.lineTo(size.width * 0.7621481, size.height * 0.5111298);
    virginiaPath.lineTo(size.width * 0.7597497, size.height * 0.5112985);
    virginiaPath.lineTo(size.width * 0.7551616, size.height * 0.5074199);
    virginiaPath.lineTo(size.width * 0.7550574, size.height * 0.5048904);
    virginiaPath.lineTo(size.width * 0.7534932, size.height * 0.5037099);
    virginiaPath.lineTo(size.width * 0.7543274, size.height * 0.5016863);
    virginiaPath.lineTo(size.width * 0.7535975, size.height * 0.5006745);
    virginiaPath.lineTo(size.width * 0.7484880, size.height * 0.5118044);
    virginiaPath.lineTo(size.width * 0.7454640, size.height * 0.5134907);
    virginiaPath.lineTo(size.width * 0.7423358, size.height * 0.5185497);
    virginiaPath.lineTo(size.width * 0.7419187, size.height * 0.5222597);
    virginiaPath.lineTo(size.width * 0.7397289, size.height * 0.5244519);
    virginiaPath.lineTo(size.width * 0.7396246, size.height * 0.5273187);
    virginiaPath.lineTo(size.width * 0.7381648, size.height * 0.5296796);
    virginiaPath.lineTo(size.width * 0.7362878, size.height * 0.5305228);
    virginiaPath.lineTo(size.width * 0.7357664, size.height * 0.5337268);
    virginiaPath.lineTo(size.width * 0.7347237, size.height * 0.5344013);
    virginiaPath.lineTo(size.width * 0.7275287, size.height * 0.5414840);
    virginiaPath.lineTo(size.width * 0.7576642, size.height * 0.5359191);
    virginiaPath.lineTo(size.width * 0.7578728, size.height * 0.5342327);
    virginiaPath.lineTo(size.width * 0.7626694, size.height * 0.5333895);
    virginiaPath.lineTo(size.width * 0.7623566, size.height * 0.5345700);
    virginiaPath.lineTo(size.width * 0.7930136, size.height * 0.5286678);
    virginiaPath.lineTo(size.width * 0.8340980, size.height * 0.5163575);
    virginiaPath.lineTo(size.width * 0.8644421, size.height * 0.5060708);
    virginiaPath.lineTo(size.width * 0.8638165, size.height * 0.5040472);
    virginiaPath.lineTo(size.width * 0.8642336, size.height * 0.5038786);
    virginiaPath.lineTo(size.width * 0.8651721, size.height * 0.5053963);
    virginiaPath.lineTo(size.width * 0.8650678, size.height * 0.5030354);
    virginiaPath.lineTo(size.width * 0.8647550, size.height * 0.4998314);
    virginiaPath.lineTo(size.width * 0.8664234, size.height * 0.5018550);
    virginiaPath.lineTo(size.width * 0.8673618, size.height * 0.5053963);
    virginiaPath.lineTo(size.width * 0.8673618, size.height * 0.5032040);
    virginiaPath.lineTo(size.width * 0.8638165, size.height * 0.4939292);
    virginiaPath.lineTo(size.width * 0.8638165, size.height * 0.4919056);
    virginiaPath.lineTo(size.width * 0.8630865, size.height * 0.4905565);
    virginiaPath.lineTo(size.width * 0.8617310, size.height * 0.4917369);
    virginiaPath.lineTo(size.width * 0.8622523, size.height * 0.4940978);
    virginiaPath.lineTo(size.width * 0.8614181, size.height * 0.4940978);
    virginiaPath.lineTo(size.width * 0.8610010, size.height * 0.4924115);
    virginiaPath.lineTo(size.width * 0.8603754, size.height * 0.4939292);
    virginiaPath.lineTo(size.width * 0.8594369, size.height * 0.4920742);
    virginiaPath.lineTo(size.width * 0.8572471, size.height * 0.4919056);
    virginiaPath.lineTo(size.width * 0.8570386, size.height * 0.4930860);
    virginiaPath.lineTo(size.width * 0.8586027, size.height * 0.4966273);
    virginiaPath.lineTo(size.width * 0.8571429, size.height * 0.4954469);
    virginiaPath.lineTo(size.width * 0.8566215, size.height * 0.4937605);
    virginiaPath.lineTo(size.width * 0.8562044, size.height * 0.4951096);
    virginiaPath.lineTo(size.width * 0.8553702, size.height * 0.4952782);
    virginiaPath.lineTo(size.width * 0.8538060, size.height * 0.4981450);
    virginiaPath.lineTo(size.width * 0.8541189, size.height * 0.4954469);
    virginiaPath.lineTo(size.width * 0.8541189, size.height * 0.4930860);
    virginiaPath.lineTo(size.width * 0.8525547, size.height * 0.4919056);
    virginiaPath.lineTo(size.width * 0.8506778, size.height * 0.4910624);
    virginiaPath.lineTo(size.width * 0.8504692, size.height * 0.4881956);
    virginiaPath.lineTo(size.width * 0.8498436, size.height * 0.4860034);
    virginiaPath.lineTo(size.width * 0.8492179, size.height * 0.4878583);
    virginiaPath.lineTo(size.width * 0.8474453, size.height * 0.4861720);
    virginiaPath.lineTo(size.width * 0.8453597, size.height * 0.4866779);
    virginiaPath.lineTo(size.width * 0.8455683, size.height * 0.4851602);
    virginiaPath.lineTo(size.width * 0.8471324, size.height * 0.4848229);
    virginiaPath.lineTo(size.width * 0.8480709, size.height * 0.4856661);
    virginiaPath.lineTo(size.width * 0.8498436, size.height * 0.4843170);
    virginiaPath.lineTo(size.width * 0.8507821, size.height * 0.4849916);
    virginiaPath.lineTo(size.width * 0.8513034, size.height * 0.4866779);
    virginiaPath.lineTo(size.width * 0.8513034, size.height * 0.4878583);
    virginiaPath.lineTo(size.width * 0.8532847, size.height * 0.4885329);
    virginiaPath.lineTo(size.width * 0.8535975, size.height * 0.4900506);
    virginiaPath.lineTo(size.width * 0.8545360, size.height * 0.4907251);
    virginiaPath.lineTo(size.width * 0.8554745, size.height * 0.4927487);
    virginiaPath.lineTo(size.width * 0.8569343, size.height * 0.4900506);
    virginiaPath.lineTo(size.width * 0.8575600, size.height * 0.4900506);
    virginiaPath.lineTo(size.width * 0.8574557, size.height * 0.4865093);
    virginiaPath.lineTo(size.width * 0.8561001, size.height * 0.4881956);
    virginiaPath.lineTo(size.width * 0.8554745, size.height * 0.4866779);
    virginiaPath.lineTo(size.width * 0.8570386, size.height * 0.4863406);
    virginiaPath.lineTo(size.width * 0.8557873, size.height * 0.4848229);
    virginiaPath.lineTo(size.width * 0.8545360, size.height * 0.4858347);
    virginiaPath.lineTo(size.width * 0.8544317, size.height * 0.4829680);
    virginiaPath.lineTo(size.width * 0.8526590, size.height * 0.4833052);
    virginiaPath.lineTo(size.width * 0.8503650, size.height * 0.4814503);
    virginiaPath.lineTo(size.width * 0.8484880, size.height * 0.4777403);
    virginiaPath.lineTo(size.width * 0.8522419, size.height * 0.4814503);
    virginiaPath.lineTo(size.width * 0.8531804, size.height * 0.4819562);
    virginiaPath.lineTo(size.width * 0.8549531, size.height * 0.4806071);
    virginiaPath.lineTo(size.width * 0.8531804, size.height * 0.4790894);
    virginiaPath.lineTo(size.width * 0.8538060, size.height * 0.4780776);
    virginiaPath.lineTo(size.width * 0.8527633, size.height * 0.4772344);
    virginiaPath.lineTo(size.width * 0.8535975, size.height * 0.4768971);
    virginiaPath.lineTo(size.width * 0.8532847, size.height * 0.4753794);
    virginiaPath.lineTo(size.width * 0.8544317, size.height * 0.4768971);
    virginiaPath.lineTo(size.width * 0.8548488, size.height * 0.4755481);
    virginiaPath.lineTo(size.width * 0.8552659, size.height * 0.4777403);
    virginiaPath.lineTo(size.width * 0.8565172, size.height * 0.4790894);
    virginiaPath.lineTo(size.width * 0.8571429, size.height * 0.4782462);
    virginiaPath.lineTo(size.width * 0.8566215, size.height * 0.4772344);
    virginiaPath.lineTo(size.width * 0.8565172, size.height * 0.4730185);
    virginiaPath.lineTo(size.width * 0.8553702, size.height * 0.4728499);
    virginiaPath.lineTo(size.width * 0.8537018, size.height * 0.4715008);
    virginiaPath.lineTo(size.width * 0.8546403, size.height * 0.4696459);
    virginiaPath.lineTo(size.width * 0.8525547, size.height * 0.4694772);
    virginiaPath.lineTo(size.width * 0.8521376, size.height * 0.4686341);
    virginiaPath.lineTo(size.width * 0.8506778, size.height * 0.4696459);
    virginiaPath.lineTo(size.width * 0.8492179, size.height * 0.4682968);
    virginiaPath.lineTo(size.width * 0.8486966, size.height * 0.4662732);
    virginiaPath.lineTo(size.width * 0.8465068, size.height * 0.4642496);
    virginiaPath.lineTo(size.width * 0.8443170, size.height * 0.4612142);
    virginiaPath.lineTo(size.width * 0.8420229, size.height * 0.4580101);
    virginiaPath.lineTo(size.width * 0.8451512, size.height * 0.4602024);
    virginiaPath.lineTo(size.width * 0.8460897, size.height * 0.4622260);
    virginiaPath.lineTo(size.width * 0.8482795, size.height * 0.4634064);
    virginiaPath.lineTo(size.width * 0.8506778, size.height * 0.4676223);
    virginiaPath.lineTo(size.width * 0.8508863, size.height * 0.4647555);
    virginiaPath.lineTo(size.width * 0.8515120, size.height * 0.4669477);
    virginiaPath.lineTo(size.width * 0.8539103, size.height * 0.4677909);
    virginiaPath.lineTo(size.width * 0.8539103, size.height * 0.4610455);
    virginiaPath.lineTo(size.width * 0.8530761, size.height * 0.4591906);
    virginiaPath.lineTo(size.width * 0.8542231, size.height * 0.4598651);
    virginiaPath.lineTo(size.width * 0.8543274, size.height * 0.4571669);
    virginiaPath.lineTo(size.width * 0.8510949, size.height * 0.4548061);
    virginiaPath.lineTo(size.width * 0.8494265, size.height * 0.4544688);
    virginiaPath.lineTo(size.width * 0.8480709, size.height * 0.4541315);
    virginiaPath.lineTo(size.width * 0.8483837, size.height * 0.4521079);
    virginiaPath.lineTo(size.width * 0.8468196, size.height * 0.4516020);
    virginiaPath.lineTo(size.width * 0.8467153, size.height * 0.4505902);
    virginiaPath.lineTo(size.width * 0.8448384, size.height * 0.4505902);
    virginiaPath.lineTo(size.width * 0.8446298, size.height * 0.4519393);
    virginiaPath.lineTo(size.width * 0.8438999, size.height * 0.4502530);
    virginiaPath.lineTo(size.width * 0.8410845, size.height * 0.4502530);
    virginiaPath.lineTo(size.width * 0.8400417, size.height * 0.4495784);
    virginiaPath.lineTo(size.width * 0.8398332, size.height * 0.4478921);
    virginiaPath.lineTo(size.width * 0.8385819, size.height * 0.4468803);
    virginiaPath.lineTo(size.width * 0.8381648, size.height * 0.4443508);
    virginiaPath.lineTo(size.width * 0.8375391, size.height * 0.4436762);
    virginiaPath.lineTo(size.width * 0.8368092, size.height * 0.4455312);
    virginiaPath.lineTo(size.width * 0.8358707, size.height * 0.4458685);
    virginiaPath.lineTo(size.width * 0.8349322, size.height * 0.4470489);
    virginiaPath.lineTo(size.width * 0.8333681, size.height * 0.4470489);
    virginiaPath.lineTo(size.width * 0.8324296, size.height * 0.4448567);
    virginiaPath.lineTo(size.width * 0.8328467, size.height * 0.4396290);
    virginiaPath.lineTo(size.width * 0.8333681, size.height * 0.4355818);
    virginiaPath.lineTo(size.width * 0.8339937, size.height * 0.4364250);
    virginiaPath.close();
    virginiaPath.moveTo(size.width * 0.8571429, size.height * 0.4553120);
    virginiaPath.lineTo(size.width * 0.8580813, size.height * 0.4551433);
    virginiaPath.lineTo(size.width * 0.8580813, size.height * 0.4541315);
    virginiaPath.lineTo(size.width * 0.8572471, size.height * 0.4543002);
    virginiaPath.close();
    virginiaPath.moveTo(size.width * 0.8649635, size.height * 0.4792580);
    virginiaPath.lineTo(size.width * 0.8639208, size.height * 0.4838111);
    virginiaPath.lineTo(size.width * 0.8651721, size.height * 0.4816189);
    virginiaPath.close();
    virginiaPath.moveTo(size.width * 0.8630865, size.height * 0.4534570);
    virginiaPath.lineTo(size.width * 0.8638165, size.height * 0.4539629);
    virginiaPath.lineTo(size.width * 0.8636079, size.height * 0.4571669);
    virginiaPath.lineTo(size.width * 0.8630865, size.height * 0.4563238);
    virginiaPath.lineTo(size.width * 0.8617310, size.height * 0.4580101);
    virginiaPath.lineTo(size.width * 0.8627737, size.height * 0.4586847);
    virginiaPath.lineTo(size.width * 0.8608968, size.height * 0.4661046);
    virginiaPath.lineTo(size.width * 0.8610010, size.height * 0.4797639);
    virginiaPath.lineTo(size.width * 0.8629823, size.height * 0.4849916);
    virginiaPath.lineTo(size.width * 0.8635036, size.height * 0.4824621);
    virginiaPath.lineTo(size.width * 0.8639208, size.height * 0.4779089);
    virginiaPath.lineTo(size.width * 0.8636079, size.height * 0.4740304);
    virginiaPath.lineTo(size.width * 0.8643379, size.height * 0.4725126);
    virginiaPath.lineTo(size.width * 0.8641293, size.height * 0.4701518);
    virginiaPath.lineTo(size.width * 0.8653806, size.height * 0.4691400);
    virginiaPath.lineTo(size.width * 0.8647550, size.height * 0.4682968);
    virginiaPath.lineTo(size.width * 0.8652763, size.height * 0.4671164);
    virginiaPath.lineTo(size.width * 0.8661105, size.height * 0.4689713);
    virginiaPath.lineTo(size.width * 0.8659020, size.height * 0.4708263);
    virginiaPath.lineTo(size.width * 0.8654849, size.height * 0.4774030);
    virginiaPath.lineTo(size.width * 0.8666319, size.height * 0.4736931);
    virginiaPath.lineTo(size.width * 0.8670490, size.height * 0.4684654);
    virginiaPath.lineTo(size.width * 0.8671533, size.height * 0.4634064);
    virginiaPath.lineTo(size.width * 0.8668405, size.height * 0.4600337);
    virginiaPath.lineTo(size.width * 0.8674661, size.height * 0.4561551);
    virginiaPath.lineTo(size.width * 0.8686131, size.height * 0.4531197);
    virginiaPath.lineTo(size.width * 0.8687174, size.height * 0.4494098);
    virginiaPath.lineTo(size.width * 0.8690302, size.height * 0.4478921);
    virginiaPath.lineTo(size.width * 0.8642336, size.height * 0.4505902);
    virginiaPath.lineTo(size.width * 0.8635036, size.height * 0.4519393);
    virginiaPath.close();

    Paint virginiaPaint = Paint()..style = PaintingStyle.fill;
    virginiaPaint.color = usaColors.virginia ?? defaultColor;
    usaCanvas.drawPath(virginiaPath, virginiaPaint, onTapUp: (tabdetail) {
      callback('virginia', tabdetail);
    });

    Path washingtonPath = Path();
    washingtonPath.moveTo(size.width * 0.1688217, size.height * 0.1409781);
    washingtonPath.lineTo(size.width * 0.1695516, size.height * 0.1477234);
    washingtonPath.lineTo(size.width * 0.1684046, size.height * 0.1549747);
    washingtonPath.lineTo(size.width * 0.1368092, size.height * 0.1426644);
    washingtonPath.lineTo(size.width * 0.1338895, size.height * 0.1443508);
    washingtonPath.lineTo(size.width * 0.1282586, size.height * 0.1428331);
    washingtonPath.lineTo(size.width * 0.1263816, size.height * 0.1413153);
    washingtonPath.lineTo(size.width * 0.1248175, size.height * 0.1433390);
    washingtonPath.lineTo(size.width * 0.1213764, size.height * 0.1426644);
    washingtonPath.lineTo(size.width * 0.1166840, size.height * 0.1435076);
    washingtonPath.lineTo(size.width * 0.1157456, size.height * 0.1446880);
    washingtonPath.lineTo(size.width * 0.1113660, size.height * 0.1440135);
    washingtonPath.lineTo(size.width * 0.1105318, size.height * 0.1413153);
    washingtonPath.lineTo(size.width * 0.1092805, size.height * 0.1409781);
    washingtonPath.lineTo(size.width * 0.1046924, size.height * 0.1431703);
    washingtonPath.lineTo(size.width * 0.1030240, size.height * 0.1413153);
    washingtonPath.lineTo(size.width * 0.1007299, size.height * 0.1426644);
    washingtonPath.lineTo(size.width * 0.1005214, size.height * 0.1396290);
    washingtonPath.lineTo(size.width * 0.09812304, size.height * 0.1376054);
    washingtonPath.lineTo(size.width * 0.09655892, size.height * 0.1372681);
    washingtonPath.lineTo(size.width * 0.09551616, size.height * 0.1354132);
    washingtonPath.lineTo(size.width * 0.09238790, size.height * 0.1359191);
    washingtonPath.lineTo(size.width * 0.09113660, size.height * 0.1345700);
    washingtonPath.lineTo(size.width * 0.08988530, size.height * 0.1345700);
    washingtonPath.lineTo(size.width * 0.08863399, size.height * 0.1360877);
    washingtonPath.lineTo(size.width * 0.08289885, size.height * 0.1372681);
    washingtonPath.lineTo(size.width * 0.07601668, size.height * 0.1301855);
    washingtonPath.lineTo(size.width * 0.07716371, size.height * 0.1207420);
    washingtonPath.lineTo(size.width * 0.07674661, size.height * 0.1138280);
    washingtonPath.lineTo(size.width * 0.07340980, size.height * 0.1075885);
    washingtonPath.lineTo(size.width * 0.06955162, size.height * 0.1077572);
    washingtonPath.lineTo(size.width * 0.06913452, size.height * 0.1059022);
    washingtonPath.lineTo(size.width * 0.06955162, size.height * 0.1038786);
    washingtonPath.lineTo(size.width * 0.06882169, size.height * 0.1025295);
    washingtonPath.lineTo(size.width * 0.06777894, size.height * 0.1026981);
    washingtonPath.lineTo(size.width * 0.06558916, size.height * 0.1001686);
    washingtonPath.lineTo(size.width * 0.06433785, size.height * 0.1008432);
    washingtonPath.lineTo(size.width * 0.06225235, size.height * 0.1006745);
    washingtonPath.lineTo(size.width * 0.06152242, size.height * 0.09814503);
    washingtonPath.lineTo(size.width * 0.05985401, size.height * 0.09763912);
    washingtonPath.lineTo(size.width * 0.06246090, size.height * 0.08499157);
    washingtonPath.lineTo(size.width * 0.06173097, size.height * 0.09510961);
    washingtonPath.lineTo(size.width * 0.06225235, size.height * 0.09595278);
    washingtonPath.lineTo(size.width * 0.06225235, size.height * 0.09258010);
    washingtonPath.lineTo(size.width * 0.06308655, size.height * 0.09224283);
    washingtonPath.lineTo(size.width * 0.06423358, size.height * 0.09612142);
    washingtonPath.lineTo(size.width * 0.06371220, size.height * 0.09241147);
    washingtonPath.lineTo(size.width * 0.06496350, size.height * 0.08532884);
    washingtonPath.lineTo(size.width * 0.06684046, size.height * 0.08600337);
    washingtonPath.lineTo(size.width * 0.06569343, size.height * 0.08263069);
    washingtonPath.lineTo(size.width * 0.06465068, size.height * 0.08313659);
    washingtonPath.lineTo(size.width * 0.06308655, size.height * 0.08246206);
    washingtonPath.lineTo(size.width * 0.06329510, size.height * 0.07537943);
    washingtonPath.lineTo(size.width * 0.06350365, size.height * 0.07790894);
    washingtonPath.lineTo(size.width * 0.06444213, size.height * 0.07875211);
    washingtonPath.lineTo(size.width * 0.06506778, size.height * 0.07605396);
    washingtonPath.lineTo(size.width * 0.06840459, size.height * 0.07605396);
    washingtonPath.lineTo(size.width * 0.06611053, size.height * 0.07403035);
    washingtonPath.lineTo(size.width * 0.06433785, size.height * 0.07082631);
    washingtonPath.lineTo(size.width * 0.06287800, size.height * 0.07352445);
    washingtonPath.lineTo(size.width * 0.06412930, size.height * 0.06829680);
    washingtonPath.lineTo(size.width * 0.06381648, size.height * 0.06053963);
    washingtonPath.lineTo(size.width * 0.06360792, size.height * 0.05446880);
    washingtonPath.lineTo(size.width * 0.06454640, size.height * 0.04418212);
    washingtonPath.lineTo(size.width * 0.06402503, size.height * 0.04080944);
    washingtonPath.lineTo(size.width * 0.06256517, size.height * 0.03726813);
    washingtonPath.lineTo(size.width * 0.06266945, size.height * 0.03052277);
    washingtonPath.lineTo(size.width * 0.06308655, size.height * 0.02596965);
    washingtonPath.lineTo(size.width * 0.06517205, size.height * 0.02209106);
    washingtonPath.lineTo(size.width * 0.06444213, size.height * 0.01973019);
    washingtonPath.lineTo(size.width * 0.06465068, size.height * 0.01871838);
    washingtonPath.lineTo(size.width * 0.06558916, size.height * 0.01888702);
    washingtonPath.lineTo(size.width * 0.07372263, size.height * 0.03170320);
    washingtonPath.lineTo(size.width * 0.07862357, size.height * 0.03490725);
    washingtonPath.lineTo(size.width * 0.08394161, size.height * 0.03912310);
    washingtonPath.lineTo(size.width * 0.08727842, size.height * 0.03895447);
    washingtonPath.lineTo(size.width * 0.08748697, size.height * 0.04401349);
    washingtonPath.lineTo(size.width * 0.08852972, size.height * 0.04131535);
    washingtonPath.lineTo(size.width * 0.08925965, size.height * 0.04131535);
    washingtonPath.lineTo(size.width * 0.08988530, size.height * 0.04586847);
    washingtonPath.lineTo(size.width * 0.09040667, size.height * 0.04148398);
    washingtonPath.lineTo(size.width * 0.09186653, size.height * 0.04114671);
    washingtonPath.lineTo(size.width * 0.09238790, size.height * 0.04232715);
    washingtonPath.lineTo(size.width * 0.09124088, size.height * 0.04333895);
    washingtonPath.lineTo(size.width * 0.09134515, size.height * 0.04603710);
    washingtonPath.lineTo(size.width * 0.09207508, size.height * 0.04350759);
    washingtonPath.lineTo(size.width * 0.09322211, size.height * 0.04350759);
    washingtonPath.lineTo(size.width * 0.09280501, size.height * 0.04789207);
    washingtonPath.lineTo(size.width * 0.09165798, size.height * 0.04654300);
    washingtonPath.lineTo(size.width * 0.09207508, size.height * 0.04890388);
    washingtonPath.lineTo(size.width * 0.09197080, size.height * 0.05143339);
    washingtonPath.lineTo(size.width * 0.09113660, size.height * 0.05261383);
    washingtonPath.lineTo(size.width * 0.08852972, size.height * 0.05750422);
    washingtonPath.lineTo(size.width * 0.08978102, size.height * 0.05177066);
    washingtonPath.lineTo(size.width * 0.08811262, size.height * 0.05244519);
    washingtonPath.lineTo(size.width * 0.08769552, size.height * 0.05598651);
    washingtonPath.lineTo(size.width * 0.08373306, size.height * 0.06070826);
    washingtonPath.lineTo(size.width * 0.08331595, size.height * 0.06239460);
    washingtonPath.lineTo(size.width * 0.08112617, size.height * 0.06610455);
    washingtonPath.lineTo(size.width * 0.08102190, size.height * 0.06779089);
    washingtonPath.lineTo(size.width * 0.08331595, size.height * 0.06779089);
    washingtonPath.lineTo(size.width * 0.08581856, size.height * 0.06745363);
    washingtonPath.lineTo(size.width * 0.08633994, size.height * 0.06593592);
    washingtonPath.lineTo(size.width * 0.08227320, size.height * 0.06677909);
    washingtonPath.lineTo(size.width * 0.08227320, size.height * 0.06576728);
    washingtonPath.lineTo(size.width * 0.08498436, size.height * 0.06104553);
    washingtonPath.lineTo(size.width * 0.08686131, size.height * 0.05969646);
    washingtonPath.lineTo(size.width * 0.08884254, size.height * 0.05935919);
    washingtonPath.lineTo(size.width * 0.08988530, size.height * 0.05666105);
    washingtonPath.lineTo(size.width * 0.09301356, size.height * 0.05278246);
    washingtonPath.lineTo(size.width * 0.09301356, size.height * 0.05042159);
    washingtonPath.lineTo(size.width * 0.09416058, size.height * 0.05042159);
    washingtonPath.lineTo(size.width * 0.09426486, size.height * 0.05716695);
    washingtonPath.lineTo(size.width * 0.09270073, size.height * 0.05716695);
    washingtonPath.lineTo(size.width * 0.09207508, size.height * 0.05851602);
    washingtonPath.lineTo(size.width * 0.09092805, size.height * 0.05699831);
    washingtonPath.lineTo(size.width * 0.09124088, size.height * 0.05885329);
    washingtonPath.lineTo(size.width * 0.09124088, size.height * 0.06172007);
    washingtonPath.lineTo(size.width * 0.09051095, size.height * 0.06290051);
    washingtonPath.lineTo(size.width * 0.09019812, size.height * 0.06020236);
    washingtonPath.lineTo(size.width * 0.08936392, size.height * 0.06155143);
    washingtonPath.lineTo(size.width * 0.09009385, size.height * 0.06256324);
    washingtonPath.lineTo(size.width * 0.08915537, size.height * 0.06441821);
    washingtonPath.lineTo(size.width * 0.09051095, size.height * 0.06441821);
    washingtonPath.lineTo(size.width * 0.09124088, size.height * 0.06357504);
    washingtonPath.lineTo(size.width * 0.09134515, size.height * 0.06694772);
    washingtonPath.lineTo(size.width * 0.09030240, size.height * 0.07015177);
    washingtonPath.lineTo(size.width * 0.08936392, size.height * 0.07183811);
    washingtonPath.lineTo(size.width * 0.08925965, size.height * 0.07487352);
    washingtonPath.lineTo(size.width * 0.08821689, size.height * 0.07453626);
    washingtonPath.lineTo(size.width * 0.08800834, size.height * 0.07217538);
    washingtonPath.lineTo(size.width * 0.08894682, size.height * 0.07032040);
    washingtonPath.lineTo(size.width * 0.08811262, size.height * 0.06947723);
    washingtonPath.lineTo(size.width * 0.08727842, size.height * 0.07065767);
    washingtonPath.lineTo(size.width * 0.08654849, size.height * 0.07436762);
    washingtonPath.lineTo(size.width * 0.08571429, size.height * 0.07588533);
    washingtonPath.lineTo(size.width * 0.08561001, size.height * 0.07251265);
    washingtonPath.lineTo(size.width * 0.08644421, size.height * 0.07065767);
    washingtonPath.lineTo(size.width * 0.08623566, size.height * 0.06880270);
    washingtonPath.lineTo(size.width * 0.08498436, size.height * 0.07082631);
    washingtonPath.lineTo(size.width * 0.08508863, size.height * 0.07453626);
    washingtonPath.lineTo(size.width * 0.08446298, size.height * 0.07521079);
    washingtonPath.lineTo(size.width * 0.08227320, size.height * 0.07453626);
    washingtonPath.lineTo(size.width * 0.08091762, size.height * 0.07655987);
    washingtonPath.lineTo(size.width * 0.08321168, size.height * 0.07554806);
    washingtonPath.lineTo(size.width * 0.08300313, size.height * 0.07925801);
    washingtonPath.lineTo(size.width * 0.08404588, size.height * 0.07622260);
    washingtonPath.lineTo(size.width * 0.08446298, size.height * 0.07858347);
    washingtonPath.lineTo(size.width * 0.08498436, size.height * 0.07689713);
    washingtonPath.lineTo(size.width * 0.08571429, size.height * 0.07993255);
    washingtonPath.lineTo(size.width * 0.08644421, size.height * 0.07993255);
    washingtonPath.lineTo(size.width * 0.08717414, size.height * 0.07858347);
    washingtonPath.lineTo(size.width * 0.08779979, size.height * 0.07841484);
    washingtonPath.lineTo(size.width * 0.08988530, size.height * 0.07521079);
    washingtonPath.lineTo(size.width * 0.09009385, size.height * 0.07318718);
    washingtonPath.lineTo(size.width * 0.09092805, size.height * 0.07419899);
    washingtonPath.lineTo(size.width * 0.09124088, size.height * 0.07571669);
    washingtonPath.lineTo(size.width * 0.09197080, size.height * 0.07521079);
    washingtonPath.lineTo(size.width * 0.09207508, size.height * 0.07318718);
    washingtonPath.lineTo(size.width * 0.09343066, size.height * 0.07318718);
    washingtonPath.lineTo(size.width * 0.09363921, size.height * 0.06829680);
    washingtonPath.lineTo(size.width * 0.09353493, size.height * 0.06374368);
    washingtonPath.lineTo(size.width * 0.09447341, size.height * 0.06424958);
    washingtonPath.lineTo(size.width * 0.09374348, size.height * 0.06070826);
    washingtonPath.lineTo(size.width * 0.09520334, size.height * 0.05935919);
    washingtonPath.lineTo(size.width * 0.09541189, size.height * 0.05531197);
    washingtonPath.lineTo(size.width * 0.09781022, size.height * 0.05160202);
    washingtonPath.lineTo(size.width * 0.09885297, size.height * 0.05177066);
    washingtonPath.lineTo(size.width * 0.09916580, size.height * 0.04940978);
    washingtonPath.lineTo(size.width * 0.09791449, size.height * 0.04704890);
    washingtonPath.lineTo(size.width * 0.09781022, size.height * 0.04114671);
    washingtonPath.lineTo(size.width * 0.09697602, size.height * 0.04266442);
    washingtonPath.lineTo(size.width * 0.09770594, size.height * 0.04755481);
    washingtonPath.lineTo(size.width * 0.09708029, size.height * 0.04772344);
    washingtonPath.lineTo(size.width * 0.09645464, size.height * 0.04451939);
    washingtonPath.lineTo(size.width * 0.09582899, size.height * 0.04367622);
    washingtonPath.lineTo(size.width * 0.09614181, size.height * 0.03979764);
    washingtonPath.lineTo(size.width * 0.09801877, size.height * 0.03962901);
    washingtonPath.lineTo(size.width * 0.09833160, size.height * 0.04080944);
    washingtonPath.lineTo(size.width * 0.09864442, size.height * 0.03811130);
    washingtonPath.lineTo(size.width * 0.09697602, size.height * 0.03524452);
    washingtonPath.lineTo(size.width * 0.09635036, size.height * 0.03254637);
    washingtonPath.lineTo(size.width * 0.09614181, size.height * 0.03591906);
    washingtonPath.lineTo(size.width * 0.09708029, size.height * 0.03777403);
    washingtonPath.lineTo(size.width * 0.09635036, size.height * 0.03844857);
    washingtonPath.lineTo(size.width * 0.09530761, size.height * 0.03709949);
    washingtonPath.lineTo(size.width * 0.09343066, size.height * 0.03929174);
    washingtonPath.lineTo(size.width * 0.09499479, size.height * 0.04013491);
    washingtonPath.lineTo(size.width * 0.09520334, size.height * 0.04418212);
    washingtonPath.lineTo(size.width * 0.09489051, size.height * 0.04721754);
    washingtonPath.lineTo(size.width * 0.09582899, size.height * 0.04502530);
    washingtonPath.lineTo(size.width * 0.09728884, size.height * 0.04890388);
    washingtonPath.lineTo(size.width * 0.09687174, size.height * 0.05210793);
    washingtonPath.lineTo(size.width * 0.09530761, size.height * 0.05210793);
    washingtonPath.lineTo(size.width * 0.09530761, size.height * 0.05008432);
    washingtonPath.lineTo(size.width * 0.09374348, size.height * 0.04806071);
    washingtonPath.lineTo(size.width * 0.09426486, size.height * 0.04300169);
    washingtonPath.lineTo(size.width * 0.09228363, size.height * 0.03861720);
    washingtonPath.lineTo(size.width * 0.09509906, size.height * 0.03355818);
    washingtonPath.lineTo(size.width * 0.09572471, size.height * 0.02664418);
    washingtonPath.lineTo(size.width * 0.09666319, size.height * 0.02664418);
    washingtonPath.lineTo(size.width * 0.09812304, size.height * 0.03204047);
    washingtonPath.lineTo(size.width * 0.09812304, size.height * 0.02765599);
    washingtonPath.lineTo(size.width * 0.09937435, size.height * 0.02816189);
    washingtonPath.lineTo(size.width * 0.09937435, size.height * 0.02259696);
    washingtonPath.lineTo(size.width * 0.09843587, size.height * 0.02124789);
    washingtonPath.lineTo(size.width * 0.09718457, size.height * 0.02546374);
    washingtonPath.lineTo(size.width * 0.09614181, size.height * 0.02040472);
    washingtonPath.lineTo(size.width * 0.09749739, size.height * 0.02023609);
    washingtonPath.lineTo(size.width * 0.09593326, size.height * 0.01197302);
    washingtonPath.lineTo(size.width * 0.09791449, size.height * 0.01096121);
    washingtonPath.lineTo(size.width * 0.1244004, size.height * 0.02360877);
    washingtonPath.lineTo(size.width * 0.1574557, size.height * 0.03709949);
    washingtonPath.lineTo(size.width * 0.1820647, size.height * 0.04637437);
    washingtonPath.close();
    washingtonPath.moveTo(size.width * 0.08675704, size.height * 0.07453626);
    washingtonPath.lineTo(size.width * 0.08727842, size.height * 0.07453626);
    washingtonPath.lineTo(size.width * 0.08738269, size.height * 0.07588533);
    washingtonPath.lineTo(size.width * 0.08686131, size.height * 0.07639123);
    washingtonPath.lineTo(size.width * 0.08696559, size.height * 0.07740304);
    washingtonPath.lineTo(size.width * 0.08623566, size.height * 0.07807757);
    washingtonPath.lineTo(size.width * 0.08602711, size.height * 0.07655987);
    washingtonPath.lineTo(size.width * 0.08654849, size.height * 0.07588533);
    washingtonPath.close();
    washingtonPath.moveTo(size.width * 0.09197080, size.height * 0.06728499);
    washingtonPath.lineTo(size.width * 0.09071950, size.height * 0.07048904);
    washingtonPath.lineTo(size.width * 0.09061522, size.height * 0.07183811);
    washingtonPath.lineTo(size.width * 0.09103233, size.height * 0.07217538);
    washingtonPath.lineTo(size.width * 0.09155370, size.height * 0.07116358);
    washingtonPath.lineTo(size.width * 0.09270073, size.height * 0.07133221);
    washingtonPath.close();
    washingtonPath.moveTo(size.width * 0.09155370, size.height * 0.03086003);
    washingtonPath.lineTo(size.width * 0.09207508, size.height * 0.03187184);
    washingtonPath.lineTo(size.width * 0.09343066, size.height * 0.03136594);
    washingtonPath.lineTo(size.width * 0.09363921, size.height * 0.02967960);
    washingtonPath.lineTo(size.width * 0.09489051, size.height * 0.02664418);
    washingtonPath.lineTo(size.width * 0.09384776, size.height * 0.02596965);
    washingtonPath.lineTo(size.width * 0.09311783, size.height * 0.02866779);
    washingtonPath.lineTo(size.width * 0.09301356, size.height * 0.02596965);
    washingtonPath.lineTo(size.width * 0.09186653, size.height * 0.02630691);
    washingtonPath.lineTo(size.width * 0.09113660, size.height * 0.02866779);
    washingtonPath.close();
    washingtonPath.moveTo(size.width * 0.09489051, size.height * 0.02158516);
    washingtonPath.lineTo(size.width * 0.09562044, size.height * 0.02411467);
    washingtonPath.lineTo(size.width * 0.09468196, size.height * 0.02445194);
    washingtonPath.lineTo(size.width * 0.09384776, size.height * 0.02512648);
    washingtonPath.lineTo(size.width * 0.09363921, size.height * 0.02107926);
    washingtonPath.close();
    washingtonPath.moveTo(size.width * 0.09207508, size.height * 0.01888702);
    washingtonPath.lineTo(size.width * 0.09092805, size.height * 0.01854975);
    washingtonPath.lineTo(size.width * 0.09144943, size.height * 0.02091062);
    washingtonPath.close();
    washingtonPath.moveTo(size.width * 0.09103233, size.height * 0.02310287);
    washingtonPath.lineTo(size.width * 0.09186653, size.height * 0.02377740);
    washingtonPath.lineTo(size.width * 0.09144943, size.height * 0.02563238);
    washingtonPath.lineTo(size.width * 0.09322211, size.height * 0.02478921);
    washingtonPath.lineTo(size.width * 0.09301356, size.height * 0.02107926);
    washingtonPath.lineTo(size.width * 0.09207508, size.height * 0.02074199);
    washingtonPath.close();
    washingtonPath.moveTo(size.width * 0.08821689, size.height * 0.02242833);
    washingtonPath.lineTo(size.width * 0.08852972, size.height * 0.02698145);
    washingtonPath.lineTo(size.width * 0.09019812, size.height * 0.02917369);
    washingtonPath.lineTo(size.width * 0.09082377, size.height * 0.02596965);
    washingtonPath.lineTo(size.width * 0.08967675, size.height * 0.02225970);
    washingtonPath.close();
    washingtonPath.moveTo(size.width * 0.09019812, size.height * 0.02057336);
    washingtonPath.lineTo(size.width * 0.08905109, size.height * 0.01888702);
    washingtonPath.lineTo(size.width * 0.08811262, size.height * 0.01905565);
    washingtonPath.lineTo(size.width * 0.08998957, size.height * 0.02158516);
    washingtonPath.close();
    washingtonPath.moveTo(size.width * 0.09353493, size.height * 0.008768971);
    washingtonPath.lineTo(size.width * 0.09228363, size.height * 0.008768971);
    washingtonPath.lineTo(size.width * 0.09228363, size.height * 0.01011804);
    washingtonPath.lineTo(size.width * 0.09353493, size.height * 0.01112985);
    washingtonPath.close();
    washingtonPath.moveTo(size.width * 0.09259645, size.height * 0.06357504);
    washingtonPath.lineTo(size.width * 0.09301356, size.height * 0.05902192);
    washingtonPath.lineTo(size.width * 0.09186653, size.height * 0.05902192);
    washingtonPath.lineTo(size.width * 0.09165798, size.height * 0.06222597);
    washingtonPath.close();

    Paint wasthingtonPaint = Paint()..style = PaintingStyle.fill;
    wasthingtonPaint.color = usaColors.washington ?? defaultColor;
    usaCanvas.drawPath(washingtonPath, wasthingtonPaint, onTapUp: (tabdetail) {
      callback('washington', tabdetail);
    });

    Path westVirginiaPath = Path();
    westVirginiaPath.moveTo(size.width * 0.7543274, size.height * 0.5016863);
    westVirginiaPath.lineTo(size.width * 0.7534932, size.height * 0.5037099);
    westVirginiaPath.lineTo(size.width * 0.7550574, size.height * 0.5048904);
    westVirginiaPath.lineTo(size.width * 0.7551616, size.height * 0.5074199);
    westVirginiaPath.lineTo(size.width * 0.7597497, size.height * 0.5112985);
    westVirginiaPath.lineTo(size.width * 0.7621481, size.height * 0.5111298);
    westVirginiaPath.lineTo(size.width * 0.7641293, size.height * 0.5080944);
    westVirginiaPath.lineTo(size.width * 0.7649635, size.height * 0.5052277);
    westVirginiaPath.lineTo(size.width * 0.7680918, size.height * 0.5082631);
    westVirginiaPath.lineTo(size.width * 0.7738269, size.height * 0.5042159);
    westVirginiaPath.lineTo(size.width * 0.7743483, size.height * 0.5026981);
    westVirginiaPath.lineTo(size.width * 0.7735141, size.height * 0.5018550);
    westVirginiaPath.lineTo(size.width * 0.7741397, size.height * 0.4994941);
    westVirginiaPath.lineTo(size.width * 0.7757039, size.height * 0.5011804);
    westVirginiaPath.lineTo(size.width * 0.7801877, size.height * 0.4959528);
    westVirginiaPath.lineTo(size.width * 0.7809176, size.height * 0.4978078);
    westVirginiaPath.lineTo(size.width * 0.7833160, size.height * 0.4944351);
    westVirginiaPath.lineTo(size.width * 0.7832117, size.height * 0.4920742);
    westVirginiaPath.lineTo(size.width * 0.7847758, size.height * 0.4888702);
    westVirginiaPath.lineTo(size.width * 0.7832117, size.height * 0.4868465);
    westVirginiaPath.lineTo(size.width * 0.7842544, size.height * 0.4812816);
    westVirginiaPath.lineTo(size.width * 0.7881126, size.height * 0.4706577);
    westVirginiaPath.lineTo(size.width * 0.7876955, size.height * 0.4674536);
    westVirginiaPath.lineTo(size.width * 0.7898853, size.height * 0.4637437);
    westVirginiaPath.lineTo(size.width * 0.7894682, size.height * 0.4612142);
    westVirginiaPath.lineTo(size.width * 0.7909281, size.height * 0.4583474);
    westVirginiaPath.lineTo(size.width * 0.7910323, size.height * 0.4504216);
    westVirginiaPath.lineTo(size.width * 0.7934307, size.height * 0.4516020);
    westVirginiaPath.lineTo(size.width * 0.7947862, size.height * 0.4548061);
    westVirginiaPath.lineTo(size.width * 0.7977059, size.height * 0.4556492);
    westVirginiaPath.lineTo(size.width * 0.7990615, size.height * 0.4529511);
    westVirginiaPath.lineTo(size.width * 0.8014599, size.height * 0.4386172);
    westVirginiaPath.lineTo(size.width * 0.8039625, size.height * 0.4404722);
    westVirginiaPath.lineTo(size.width * 0.8050052, size.height * 0.4362563);
    westVirginiaPath.lineTo(size.width * 0.8059437, size.height * 0.4349073);
    westVirginiaPath.lineTo(size.width * 0.8074035, size.height * 0.4318718);
    westVirginiaPath.lineTo(size.width * 0.8083420, size.height * 0.4305228);
    westVirginiaPath.lineTo(size.width * 0.8088634, size.height * 0.4269815);
    westVirginiaPath.lineTo(size.width * 0.8101147, size.height * 0.4256324);
    westVirginiaPath.lineTo(size.width * 0.8100104, size.height * 0.4207420);
    westVirginiaPath.lineTo(size.width * 0.8108446, size.height * 0.4168634);
    westVirginiaPath.lineTo(size.width * 0.8099062, size.height * 0.4141653);
    westVirginiaPath.lineTo(size.width * 0.8101147, size.height * 0.4126476);
    westVirginiaPath.lineTo(size.width * 0.8205422, size.height * 0.4214165);
    westVirginiaPath.lineTo(size.width * 0.8210636, size.height * 0.4175379);
    westVirginiaPath.lineTo(size.width * 0.8214807, size.height * 0.4148398);
    westVirginiaPath.lineTo(size.width * 0.8218978, size.height * 0.4136594);
    westVirginiaPath.lineTo(size.width * 0.8209593, size.height * 0.4129848);
    westVirginiaPath.lineTo(size.width * 0.8211679, size.height * 0.4102867);
    westVirginiaPath.lineTo(size.width * 0.8201251, size.height * 0.4094435);
    westVirginiaPath.lineTo(size.width * 0.8199166, size.height * 0.4082631);
    westVirginiaPath.lineTo(size.width * 0.8191867, size.height * 0.4082631);
    westVirginiaPath.lineTo(size.width * 0.8183525, size.height * 0.4062395);
    westVirginiaPath.lineTo(size.width * 0.8185610, size.height * 0.4045531);
    westVirginiaPath.lineTo(size.width * 0.8158498, size.height * 0.4052277);
    westVirginiaPath.lineTo(size.width * 0.8135558, size.height * 0.4025295);
    westVirginiaPath.lineTo(size.width * 0.8120959, size.height * 0.4030354);
    westVirginiaPath.lineTo(size.width * 0.8111575, size.height * 0.4053963);
    westVirginiaPath.lineTo(size.width * 0.8098019, size.height * 0.4053963);
    westVirginiaPath.lineTo(size.width * 0.8080292, size.height * 0.4102867);
    westVirginiaPath.lineTo(size.width * 0.8045881, size.height * 0.4109612);
    westVirginiaPath.lineTo(size.width * 0.8026069, size.height * 0.4092749);
    westVirginiaPath.lineTo(size.width * 0.7998957, size.height * 0.4156830);
    westVirginiaPath.lineTo(size.width * 0.7976017, size.height * 0.4151771);
    westVirginiaPath.lineTo(size.width * 0.7943691, size.height * 0.4217538);
    westVirginiaPath.lineTo(size.width * 0.7934307, size.height * 0.4244519);
    westVirginiaPath.lineTo(size.width * 0.7915537, size.height * 0.4271501);
    westVirginiaPath.lineTo(size.width * 0.7897810, size.height * 0.4079258);
    westVirginiaPath.lineTo(size.width * 0.7716371, size.height * 0.4128162);
    westVirginiaPath.lineTo(size.width * 0.7683003, size.height * 0.3795953);
    westVirginiaPath.lineTo(size.width * 0.7660063, size.height * 0.3816189);
    westVirginiaPath.lineTo(size.width * 0.7674661, size.height * 0.3851602);
    westVirginiaPath.lineTo(size.width * 0.7673618, size.height * 0.3888702);
    westVirginiaPath.lineTo(size.width * 0.7679875, size.height * 0.3922428);
    westVirginiaPath.lineTo(size.width * 0.7668405, size.height * 0.3979764);
    westVirginiaPath.lineTo(size.width * 0.7667362, size.height * 0.4070826);
    westVirginiaPath.lineTo(size.width * 0.7656934, size.height * 0.4131535);
    westVirginiaPath.lineTo(size.width * 0.7662148, size.height * 0.4150084);
    westVirginiaPath.lineTo(size.width * 0.7657977, size.height * 0.4187184);
    westVirginiaPath.lineTo(size.width * 0.7646507, size.height * 0.4195616);
    westVirginiaPath.lineTo(size.width * 0.7625652, size.height * 0.4251265);
    westVirginiaPath.lineTo(size.width * 0.7606882, size.height * 0.4284992);
    westVirginiaPath.lineTo(size.width * 0.7600626, size.height * 0.4284992);
    westVirginiaPath.lineTo(size.width * 0.7581856, size.height * 0.4313659);
    westVirginiaPath.lineTo(size.width * 0.7568300, size.height * 0.4293423);
    westVirginiaPath.lineTo(size.width * 0.7552659, size.height * 0.4323777);
    westVirginiaPath.lineTo(size.width * 0.7549531, size.height * 0.4344013);
    westVirginiaPath.lineTo(size.width * 0.7535975, size.height * 0.4344013);
    westVirginiaPath.lineTo(size.width * 0.7522419, size.height * 0.4381113);
    westVirginiaPath.lineTo(size.width * 0.7523462, size.height * 0.4416526);
    westVirginiaPath.lineTo(size.width * 0.7513034, size.height * 0.4424958);
    westVirginiaPath.lineTo(size.width * 0.7527633, size.height * 0.4443508);
    westVirginiaPath.lineTo(size.width * 0.7527633, size.height * 0.4475548);
    westVirginiaPath.lineTo(size.width * 0.7517205, size.height * 0.4478921);
    westVirginiaPath.lineTo(size.width * 0.7509906, size.height * 0.4492411);
    westVirginiaPath.lineTo(size.width * 0.7499479, size.height * 0.4500843);
    westVirginiaPath.lineTo(size.width * 0.7493222, size.height * 0.4465430);
    westVirginiaPath.lineTo(size.width * 0.7476538, size.height * 0.4456998);
    westVirginiaPath.lineTo(size.width * 0.7466111, size.height * 0.4495784);
    westVirginiaPath.lineTo(size.width * 0.7462982, size.height * 0.4532884);
    westVirginiaPath.lineTo(size.width * 0.7451512, size.height * 0.4554806);
    westVirginiaPath.lineTo(size.width * 0.7465068, size.height * 0.4615514);
    westVirginiaPath.lineTo(size.width * 0.7449426, size.height * 0.4629005);
    westVirginiaPath.lineTo(size.width * 0.7445255, size.height * 0.4688027);
    westVirginiaPath.lineTo(size.width * 0.7429614, size.height * 0.4688027);
    westVirginiaPath.lineTo(size.width * 0.7396246, size.height * 0.4711636);
    westVirginiaPath.lineTo(size.width * 0.7395203, size.height * 0.4730185);
    westVirginiaPath.lineTo(size.width * 0.7401460, size.height * 0.4747049);
    westVirginiaPath.lineTo(size.width * 0.7395203, size.height * 0.4807757);
    westVirginiaPath.lineTo(size.width * 0.7415016, size.height * 0.4834739);
    westVirginiaPath.lineTo(size.width * 0.7423358, size.height * 0.4853288);
    westVirginiaPath.lineTo(size.width * 0.7433785, size.height * 0.4863406);
    westVirginiaPath.lineTo(size.width * 0.7432742, size.height * 0.4878583);
    westVirginiaPath.lineTo(size.width * 0.7478624, size.height * 0.4973019);
    westVirginiaPath.lineTo(size.width * 0.7493222, size.height * 0.4973019);
    westVirginiaPath.lineTo(size.width * 0.7508863, size.height * 0.5003373);
    westVirginiaPath.lineTo(size.width * 0.7521376, size.height * 0.5008432);
    westVirginiaPath.lineTo(size.width * 0.7535975, size.height * 0.5006745);
    westVirginiaPath.close();

    Paint westVirginiaPaint = Paint()..style = PaintingStyle.fill;
    westVirginiaPaint.color = usaColors.westVirginia ?? defaultColor;
    usaCanvas.drawPath(westVirginiaPath, westVirginiaPaint,
        onTapUp: (tabdetail) {
      callback('west virginia', tabdetail);
    });

    Path wisconsinPath = Path();
    wisconsinPath.moveTo(size.width * 0.6371220, size.height * 0.2428331);
    wisconsinPath.lineTo(size.width * 0.6340980, size.height * 0.2441821);
    wisconsinPath.lineTo(size.width * 0.6343066, size.height * 0.2480607);
    wisconsinPath.lineTo(size.width * 0.6318040, size.height * 0.2537943);
    wisconsinPath.lineTo(size.width * 0.6315954, size.height * 0.2590219);
    wisconsinPath.lineTo(size.width * 0.6322211, size.height * 0.2602024);
    wisconsinPath.lineTo(size.width * 0.6330553, size.height * 0.2590219);
    wisconsinPath.lineTo(size.width * 0.6335766, size.height * 0.2563238);
    wisconsinPath.lineTo(size.width * 0.6356621, size.height * 0.2544688);
    wisconsinPath.lineTo(size.width * 0.6373306, size.height * 0.2473862);
    wisconsinPath.lineTo(size.width * 0.6409802, size.height * 0.2455312);
    wisconsinPath.lineTo(size.width * 0.6418144, size.height * 0.2399663);
    wisconsinPath.lineTo(size.width * 0.6425443, size.height * 0.2384486);
    wisconsinPath.lineTo(size.width * 0.6429614, size.height * 0.2349073);
    wisconsinPath.lineTo(size.width * 0.6448384, size.height * 0.2330523);
    wisconsinPath.lineTo(size.width * 0.6448384, size.height * 0.2305228);
    wisconsinPath.lineTo(size.width * 0.6458811, size.height * 0.2290051);
    wisconsinPath.lineTo(size.width * 0.6473410, size.height * 0.2291737);
    wisconsinPath.lineTo(size.width * 0.6473410, size.height * 0.2325464);
    wisconsinPath.lineTo(size.width * 0.6462982, size.height * 0.2327150);
    wisconsinPath.lineTo(size.width * 0.6468196, size.height * 0.2347386);
    wisconsinPath.lineTo(size.width * 0.6460897, size.height * 0.2384486);
    wisconsinPath.lineTo(size.width * 0.6454640, size.height * 0.2386172);
    wisconsinPath.lineTo(size.width * 0.6442127, size.height * 0.2462057);
    wisconsinPath.lineTo(size.width * 0.6434828, size.height * 0.2470489);
    wisconsinPath.lineTo(size.width * 0.6405631, size.height * 0.2591906);
    wisconsinPath.lineTo(size.width * 0.6402503, size.height * 0.2662732);
    wisconsinPath.lineTo(size.width * 0.6408759, size.height * 0.2696459);
    wisconsinPath.lineTo(size.width * 0.6409802, size.height * 0.2718381);
    wisconsinPath.lineTo(size.width * 0.6384776, size.height * 0.2750422);
    wisconsinPath.lineTo(size.width * 0.6387904, size.height * 0.2782462);
    wisconsinPath.lineTo(size.width * 0.6378519, size.height * 0.2834739);
    wisconsinPath.lineTo(size.width * 0.6381648, size.height * 0.2861720);
    wisconsinPath.lineTo(size.width * 0.6385819, size.height * 0.2924115);
    wisconsinPath.lineTo(size.width * 0.6374348, size.height * 0.2993255);
    wisconsinPath.lineTo(size.width * 0.6358707, size.height * 0.3077572);
    wisconsinPath.lineTo(size.width * 0.6369135, size.height * 0.3102867);
    wisconsinPath.lineTo(size.width * 0.6366006, size.height * 0.3107926);
    wisconsinPath.lineTo(size.width * 0.6374348, size.height * 0.3136594);
    wisconsinPath.lineTo(size.width * 0.6369135, size.height * 0.3155143);
    wisconsinPath.lineTo(size.width * 0.6380605, size.height * 0.3170320);
    wisconsinPath.lineTo(size.width * 0.6380605, size.height * 0.3215852);
    wisconsinPath.lineTo(size.width * 0.6394161, size.height * 0.3241147);
    wisconsinPath.lineTo(size.width * 0.6389990, size.height * 0.3291737);
    wisconsinPath.lineTo(size.width * 0.6393118, size.height * 0.3359191);
    wisconsinPath.lineTo(size.width * 0.5914494, size.height * 0.3406408);
    wisconsinPath.lineTo(size.width * 0.5900938, size.height * 0.3359191);
    wisconsinPath.lineTo(size.width * 0.5866528, size.height * 0.3347386);
    wisconsinPath.lineTo(size.width * 0.5838373, size.height * 0.3322091);
    wisconsinPath.lineTo(size.width * 0.5817518, size.height * 0.3229342);
    wisconsinPath.lineTo(size.width * 0.5818561, size.height * 0.3187184);
    wisconsinPath.lineTo(size.width * 0.5835245, size.height * 0.3131535);
    wisconsinPath.lineTo(size.width * 0.5828989, size.height * 0.3112985);
    wisconsinPath.lineTo(size.width * 0.5807091, size.height * 0.3086003);
    wisconsinPath.lineTo(size.width * 0.5805005, size.height * 0.3042159);
    wisconsinPath.lineTo(size.width * 0.5793535, size.height * 0.2966273);
    wisconsinPath.lineTo(size.width * 0.5791449, size.height * 0.2915683);
    wisconsinPath.lineTo(size.width * 0.5768509, size.height * 0.2865093);
    wisconsinPath.lineTo(size.width * 0.5739312, size.height * 0.2853288);
    wisconsinPath.lineTo(size.width * 0.5685089, size.height * 0.2792580);
    wisconsinPath.lineTo(size.width * 0.5678832, size.height * 0.2736931);
    wisconsinPath.lineTo(size.width * 0.5613139, size.height * 0.2684654);
    wisconsinPath.lineTo(size.width * 0.5611053, size.height * 0.2662732);
    wisconsinPath.lineTo(size.width * 0.5576642, size.height * 0.2662732);
    wisconsinPath.lineTo(size.width * 0.5553702, size.height * 0.2618887);
    wisconsinPath.lineTo(size.width * 0.5532847, size.height * 0.2596965);
    wisconsinPath.lineTo(size.width * 0.5540146, size.height * 0.2510961);
    wisconsinPath.lineTo(size.width * 0.5530761, size.height * 0.2483980);
    wisconsinPath.lineTo(size.width * 0.5535975, size.height * 0.2392917);
    wisconsinPath.lineTo(size.width * 0.5546403, size.height * 0.2362563);
    wisconsinPath.lineTo(size.width * 0.5543274, size.height * 0.2317032);
    wisconsinPath.lineTo(size.width * 0.5530761, size.height * 0.2295110);
    wisconsinPath.lineTo(size.width * 0.5511992, size.height * 0.2290051);
    wisconsinPath.lineTo(size.width * 0.5511992, size.height * 0.2261383);
    wisconsinPath.lineTo(size.width * 0.5541189, size.height * 0.2163575);
    wisconsinPath.lineTo(size.width * 0.5602711, size.height * 0.2097808);
    wisconsinPath.lineTo(size.width * 0.5598540, size.height * 0.1878583);
    wisconsinPath.lineTo(size.width * 0.5607925, size.height * 0.1885329);
    wisconsinPath.lineTo(size.width * 0.5614181, size.height * 0.1876897);
    wisconsinPath.lineTo(size.width * 0.5615224, size.height * 0.1858347);
    wisconsinPath.lineTo(size.width * 0.5624609, size.height * 0.1848229);
    wisconsinPath.lineTo(size.width * 0.5639208, size.height * 0.1868465);
    wisconsinPath.lineTo(size.width * 0.5646507, size.height * 0.1866779);
    wisconsinPath.lineTo(size.width * 0.5673618, size.height * 0.1866779);
    wisconsinPath.lineTo(size.width * 0.5744526, size.height * 0.1822934);
    wisconsinPath.lineTo(size.width * 0.5747654, size.height * 0.1806071);
    wisconsinPath.lineTo(size.width * 0.5760167, size.height * 0.1806071);
    wisconsinPath.lineTo(size.width * 0.5767466, size.height * 0.1785835);
    wisconsinPath.lineTo(size.width * 0.5771637, size.height * 0.1799325);
    wisconsinPath.lineTo(size.width * 0.5790407, size.height * 0.1784148);
    wisconsinPath.lineTo(size.width * 0.5809176, size.height * 0.1755481);
    wisconsinPath.lineTo(size.width * 0.5812304, size.height * 0.1763912);
    wisconsinPath.lineTo(size.width * 0.5822732, size.height * 0.1747049);
    wisconsinPath.lineTo(size.width * 0.5845673, size.height * 0.1774030);
    wisconsinPath.lineTo(size.width * 0.5837331, size.height * 0.1801012);
    wisconsinPath.lineTo(size.width * 0.5824818, size.height * 0.1824621);
    wisconsinPath.lineTo(size.width * 0.5830031, size.height * 0.1849916);
    wisconsinPath.lineTo(size.width * 0.5815433, size.height * 0.1876897);
    wisconsinPath.lineTo(size.width * 0.5819604, size.height * 0.1892074);
    wisconsinPath.lineTo(size.width * 0.5843587, size.height * 0.1873524);
    wisconsinPath.lineTo(size.width * 0.5843587, size.height * 0.1849916);
    wisconsinPath.lineTo(size.width * 0.5877998, size.height * 0.1881956);
    wisconsinPath.lineTo(size.width * 0.5897810, size.height * 0.1893761);
    wisconsinPath.lineTo(size.width * 0.5917623, size.height * 0.1905565);
    wisconsinPath.lineTo(size.width * 0.5948905, size.height * 0.1969646);
    wisconsinPath.lineTo(size.width * 0.6126173, size.height * 0.2033727);
    wisconsinPath.lineTo(size.width * 0.6140772, size.height * 0.2050590);
    wisconsinPath.lineTo(size.width * 0.6182482, size.height * 0.2064081);
    wisconsinPath.lineTo(size.width * 0.6189781, size.height * 0.2072513);
    wisconsinPath.lineTo(size.width * 0.6218978, size.height * 0.2069140);
    wisconsinPath.lineTo(size.width * 0.6270073, size.height * 0.2082631);
    wisconsinPath.lineTo(size.width * 0.6284672, size.height * 0.2107926);
    wisconsinPath.lineTo(size.width * 0.6274244, size.height * 0.2124789);
    wisconsinPath.lineTo(size.width * 0.6282586, size.height * 0.2138280);
    wisconsinPath.lineTo(size.width * 0.6322211, size.height * 0.2150084);
    wisconsinPath.lineTo(size.width * 0.6334724, size.height * 0.2170320);
    wisconsinPath.lineTo(size.width * 0.6335766, size.height * 0.2244519);
    wisconsinPath.lineTo(size.width * 0.6322211, size.height * 0.2291737);
    wisconsinPath.lineTo(size.width * 0.6343066, size.height * 0.2293423);
    wisconsinPath.lineTo(size.width * 0.6353493, size.height * 0.2279933);
    wisconsinPath.lineTo(size.width * 0.6362878, size.height * 0.2293423);
    wisconsinPath.lineTo(size.width * 0.6351408, size.height * 0.2345700);
    wisconsinPath.lineTo(size.width * 0.6361835, size.height * 0.2372681);
    wisconsinPath.lineTo(size.width * 0.6374348, size.height * 0.2377740);
    wisconsinPath.close();
    wisconsinPath.moveTo(size.width * 0.5855057, size.height * 0.1799325);
    wisconsinPath.lineTo(size.width * 0.5849844, size.height * 0.1801012);
    wisconsinPath.lineTo(size.width * 0.5834202, size.height * 0.1827993);
    wisconsinPath.lineTo(size.width * 0.5836288, size.height * 0.1836425);
    wisconsinPath.lineTo(size.width * 0.5851929, size.height * 0.1826307);
    wisconsinPath.lineTo(size.width * 0.5851929, size.height * 0.1816189);
    wisconsinPath.lineTo(size.width * 0.5861314, size.height * 0.1811130);
    wisconsinPath.close();
    wisconsinPath.moveTo(size.width * 0.5871741, size.height * 0.1780776);
    wisconsinPath.lineTo(size.width * 0.5861314, size.height * 0.1785835);
    wisconsinPath.lineTo(size.width * 0.5859228, size.height * 0.1797639);
    wisconsinPath.lineTo(size.width * 0.5868613, size.height * 0.1795953);
    wisconsinPath.close();
    wisconsinPath.moveTo(size.width * 0.5858186, size.height * 0.1753794);
    wisconsinPath.lineTo(size.width * 0.5856100, size.height * 0.1768971);
    wisconsinPath.lineTo(size.width * 0.5873827, size.height * 0.1768971);
    wisconsinPath.lineTo(size.width * 0.5880083, size.height * 0.1762226);
    wisconsinPath.lineTo(size.width * 0.5881126, size.height * 0.1745363);
    wisconsinPath.close();
    wisconsinPath.moveTo(size.width * 0.5887383, size.height * 0.1703204);
    wisconsinPath.lineTo(size.width * 0.5884254, size.height * 0.1735245);
    wisconsinPath.lineTo(size.width * 0.5896767, size.height * 0.1726813);
    wisconsinPath.lineTo(size.width * 0.5897810, size.height * 0.1703204);
    wisconsinPath.close();
    wisconsinPath.moveTo(size.width * 0.6495308, size.height * 0.2241147);
    wisconsinPath.lineTo(size.width * 0.6474453, size.height * 0.2246206);
    wisconsinPath.lineTo(size.width * 0.6470282, size.height * 0.2268128);
    wisconsinPath.lineTo(size.width * 0.6483837, size.height * 0.2296796);
    wisconsinPath.close();

    Paint wisconsinPaint = Paint()..style = PaintingStyle.fill;
    wisconsinPaint.color = usaColors.wisconsin ?? defaultColor;
    usaCanvas.drawPath(wisconsinPath, wisconsinPaint, onTapUp: (tabdetail) {
      callback('wisconsin', tabdetail);
    });

    Path wyomingPath = Path();
    wyomingPath.moveTo(size.width * 0.3704901, size.height * 0.2423272);
    wyomingPath.lineTo(size.width * 0.3173097, size.height * 0.2333895);
    wyomingPath.lineTo(size.width * 0.2575600, size.height * 0.2200675);
    wyomingPath.lineTo(size.width * 0.2554745, size.height * 0.2381113);
    wyomingPath.lineTo(size.width * 0.2466111, size.height * 0.3305228);
    wyomingPath.lineTo(size.width * 0.2431700, size.height * 0.3674536);
    wyomingPath.lineTo(size.width * 0.2766423, size.height * 0.3755481);
    wyomingPath.lineTo(size.width * 0.3234619, size.height * 0.3851602);
    wyomingPath.lineTo(size.width * 0.3625652, size.height * 0.3908938);
    wyomingPath.lineTo(size.width * 0.3664234, size.height * 0.3163575);
    wyomingPath.close();

    Paint wyomingPaint = Paint()..style = PaintingStyle.fill;
    wyomingPaint.color = usaColors.wyoming ?? defaultColor;
    usaCanvas.drawPath(wyomingPath, wyomingPaint, onTapUp: (tabdetail) {
      callback('wyoming', tabdetail);
    });
  }

  @override
  bool shouldRepaint(covariant CustomPainter oldDelegate) {
    return true;
  }
}
